//! Contains test vectors for Orchard note encryptions.
use lazy_static::lazy_static;

#[allow(missing_docs)]
pub struct TestVector {
    pub incoming_viewing_key: [u8; 64],
    pub ovk: [u8; 32],
    pub default_d: [u8; 11],
    pub default_pk_d: [u8; 32],
    pub v: u64,
    pub rseed: [u8; 32],
    pub memo: [u8; 512],
    pub cv_net: [u8; 32],
    pub rho: [u8; 32],
    pub cmx: [u8; 32],
    pub esk: [u8; 32],
    pub ephemeral_key: [u8; 32],
    pub shared_secret: [u8; 32],
    pub k_enc: [u8; 32],
    pub p_enc: [u8; 564],
    pub c_enc: [u8; 580],
    pub ock: [u8; 32],
    pub op: [u8; 64],
    pub c_out: [u8; 80],
}

lazy_static! {
    /// Array of Orchard note encryptions using an all-zero OVKs.
    // From https://github.com/zcash-hackworks/zcash-test-vectors/blob/master/orchard_note_encryption.py
    // (edited with `sender_ovk = b'\0' * 32`)
    pub static ref ORCHARD_NOTE_ENCRYPTION_ZERO_VECTOR: Vec<TestVector> = vec![
        TestVector {
            incoming_viewing_key: [
                0x31, 0xd6, 0xa6, 0x85, 0xbe, 0x57, 0x0f, 0x9f, 0xaf, 0x3c, 0xa8, 0xb0, 0x52, 0xe8,
                0x87, 0x84, 0x0b, 0x2c, 0x9f, 0x8d, 0x67, 0x22, 0x4c, 0xa8, 0x2a, 0xef, 0xb9, 0xe2,
                0xee, 0x5b, 0xed, 0xaf, 0x85, 0xc8, 0xb5, 0xcd, 0x1a, 0xc3, 0xec, 0x3a, 0xd7, 0x09,
                0x21, 0x32, 0xf9, 0x7f, 0x01, 0x78, 0xb0, 0x75, 0xc8, 0x1a, 0x13, 0x9f, 0xd4, 0x60,
                0xbb, 0xe0, 0xdf, 0xcd, 0x75, 0x51, 0x47, 0x24,
            ],
            ovk: [
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
                0x00, 0x00, 0x00, 0x00,
            ],
            default_d: [
                0x8f, 0xf3, 0x38, 0x69, 0x71, 0xcb, 0x64, 0xb8, 0xe7, 0x78, 0x99,
            ],
            default_pk_d: [
                0x08, 0xdd, 0x8e, 0xbd, 0x7d, 0xe9, 0x2a, 0x68, 0xe5, 0x86, 0xa3, 0x4d, 0xb8, 0xfe,
                0xa9, 0x99, 0xef, 0xd2, 0x01, 0x6f, 0xae, 0x76, 0x75, 0x0a, 0xfa, 0xe7, 0xee, 0x94,
                0x16, 0x46, 0xbc, 0xb9,
            ],
            v: 14705728171106467089,
            rseed: [
                0x1c, 0xdd, 0x86, 0xb3, 0xcc, 0x43, 0x18, 0xd9, 0x61, 0x4f, 0xc8, 0x20, 0x90, 0x5d,
                0x04, 0x2b, 0xb1, 0xef, 0x9c, 0xa3, 0xf2, 0x49, 0x88, 0xc7, 0xb3, 0x53, 0x42, 0x01,
                0xcf, 0xb1, 0xcd, 0x8d,
            ],
            memo: [
                0xff, 0xbf, 0x69, 0xb8, 0x25, 0x0c, 0x18, 0xef, 0x41, 0x29, 0x4c, 0xa9, 0x79, 0x93,
                0xdb, 0x54, 0x6c, 0x1f, 0xe0, 0x1f, 0x7e, 0x9c, 0x8e, 0x36, 0xd6, 0xa5, 0xe2, 0x9d,
                0x4e, 0x30, 0xa7, 0x35, 0x94, 0xbf, 0x50, 0x98, 0x42, 0x1c, 0x69, 0x37, 0x8a, 0xf1,
                0xe4, 0x0f, 0x64, 0xe1, 0x25, 0x94, 0x6f, 0x62, 0xc2, 0xfa, 0x7b, 0x2f, 0xec, 0xbc,
                0xb6, 0x4b, 0x69, 0x68, 0x91, 0x2a, 0x63, 0x81, 0xce, 0x3d, 0xc1, 0x66, 0xd5, 0x6a,
                0x1d, 0x62, 0xf5, 0xa8, 0xd7, 0x55, 0x1d, 0xb5, 0xfd, 0x93, 0x13, 0xe8, 0xc7, 0x20,
                0x3d, 0x99, 0x6a, 0xf7, 0xd4, 0x77, 0x08, 0x37, 0x56, 0xd5, 0x9a, 0xf8, 0x0d, 0x06,
                0xa7, 0x45, 0xf4, 0x4a, 0xb0, 0x23, 0x75, 0x2c, 0xb5, 0xb4, 0x06, 0xed, 0x89, 0x85,
                0xe1, 0x81, 0x30, 0xab, 0x33, 0x36, 0x26, 0x97, 0xb0, 0xe4, 0xe4, 0xc7, 0x63, 0xcc,
                0xb8, 0xf6, 0x76, 0x49, 0x5c, 0x22, 0x2f, 0x7f, 0xba, 0x1e, 0x31, 0xde, 0xfa, 0x3d,
                0x5a, 0x57, 0xef, 0xc2, 0xe1, 0xe9, 0xb0, 0x1a, 0x03, 0x55, 0x87, 0xd5, 0xfb, 0x1a,
                0x38, 0xe0, 0x1d, 0x94, 0x90, 0x3d, 0x3c, 0x3e, 0x0a, 0xd3, 0x36, 0x0c, 0x1d, 0x37,
                0x10, 0xac, 0xd2, 0x0b, 0x18, 0x3e, 0x31, 0xd4, 0x9f, 0x25, 0xc9, 0xa1, 0x38, 0xf4,
                0x9b, 0x1a, 0x53, 0x7e, 0xdc, 0xf0, 0x4b, 0xe3, 0x4a, 0x98, 0x51, 0xa7, 0xaf, 0x9d,
                0xb6, 0x99, 0x0e, 0xd8, 0x3d, 0xd6, 0x4a, 0xf3, 0x59, 0x7c, 0x04, 0x32, 0x3e, 0xa5,
                0x1b, 0x00, 0x52, 0xad, 0x80, 0x84, 0xa8, 0xb9, 0xda, 0x94, 0x8d, 0x32, 0x0d, 0xad,
                0xd6, 0x4f, 0x54, 0x31, 0xe6, 0x1d, 0xdf, 0x65, 0x8d, 0x24, 0xae, 0x67, 0xc2, 0x2c,
                0x8d, 0x13, 0x09, 0x13, 0x1f, 0xc0, 0x0f, 0xe7, 0xf2, 0x35, 0x73, 0x42, 0x76, 0xd3,
                0x8d, 0x47, 0xf1, 0xe1, 0x91, 0xe0, 0x0c, 0x7a, 0x1d, 0x48, 0xaf, 0x04, 0x68, 0x27,
                0x59, 0x1e, 0x97, 0x33, 0xa9, 0x7f, 0xa6, 0xb6, 0x79, 0xf3, 0xdc, 0x60, 0x1d, 0x00,
                0x82, 0x85, 0xed, 0xcb, 0xda, 0xe6, 0x9c, 0xe8, 0xfc, 0x1b, 0xe4, 0xaa, 0xc0, 0x0f,
                0xf2, 0x71, 0x1e, 0xbd, 0x93, 0x1d, 0xe5, 0x18, 0x85, 0x68, 0x78, 0xf7, 0x34, 0x76,
                0xf2, 0x1a, 0x48, 0x2e, 0xc9, 0x37, 0x83, 0x65, 0xc8, 0xf7, 0x39, 0x3c, 0x94, 0xe2,
                0x88, 0x53, 0x15, 0xeb, 0x46, 0x71, 0x09, 0x8b, 0x79, 0x53, 0x5e, 0x79, 0x0f, 0xe5,
                0x3e, 0x29, 0xfe, 0xf2, 0xb3, 0x76, 0x66, 0x97, 0xac, 0x32, 0xb4, 0xf4, 0x73, 0xf4,
                0x68, 0xa0, 0x08, 0xe7, 0x23, 0x89, 0xfc, 0x03, 0x88, 0x0d, 0x78, 0x0c, 0xb0, 0x7f,
                0xcf, 0xaa, 0xbe, 0x3f, 0x1a, 0x84, 0xb2, 0x7d, 0xb5, 0x9a, 0x4a, 0x15, 0x3d, 0x88,
                0x2d, 0x2b, 0x21, 0x03, 0x59, 0x65, 0x55, 0xed, 0x94, 0x94, 0xc6, 0xac, 0x89, 0x3c,
                0x49, 0x72, 0x38, 0x33, 0xec, 0x89, 0x26, 0xc1, 0x03, 0x95, 0x86, 0xa7, 0xaf, 0xcf,
                0x4a, 0x0d, 0x9c, 0x73, 0x1e, 0x98, 0x5d, 0x99, 0x58, 0x9c, 0x8b, 0xb8, 0x38, 0xe8,
                0xaa, 0xf7, 0x45, 0x53, 0x3e, 0xd9, 0xe8, 0xae, 0x3a, 0x1c, 0xd0, 0x74, 0xa5, 0x1a,
                0x20, 0xda, 0x8a, 0xba, 0x18, 0xd1, 0xdb, 0xeb, 0xbc, 0x86, 0x2d, 0xed, 0x42, 0x43,
                0x5e, 0x92, 0x47, 0x69, 0x30, 0xd0, 0x69, 0x89, 0x6c, 0xff, 0x30, 0xeb, 0x41, 0x4f,
                0x72, 0x7b, 0x89, 0xe0, 0x01, 0xaf, 0xa2, 0xfb, 0x8d, 0xc3, 0x43, 0x6d, 0x75, 0xa4,
                0xa6, 0xf2, 0x65, 0x72, 0x50, 0x4b, 0x19, 0x22, 0x32, 0xec, 0xb9, 0xf0, 0xc0, 0x24,
                0x11, 0xe5, 0x25, 0x96, 0xbc, 0x5e, 0x90, 0x45, 0x7e, 0x74, 0x59, 0x39, 0xff, 0xed,
                0xbd, 0x12, 0x86, 0x3c, 0xe7, 0x1a, 0x02, 0xaf,
            ],
            cv_net: [
                0x73, 0xe5, 0x63, 0x7c, 0x63, 0x5a, 0x9e, 0xb3, 0x06, 0x7c, 0x31, 0xca, 0x20, 0x60,
                0xa0, 0x2d, 0x3d, 0x30, 0xea, 0x94, 0xdf, 0xf3, 0xcb, 0xf6, 0xcd, 0xcb, 0x68, 0xa6,
                0xd5, 0x94, 0x0d, 0xb3,
            ],
            rho: [
                0xca, 0x1f, 0xeb, 0x30, 0xca, 0x11, 0x17, 0x76, 0xc0, 0x41, 0x74, 0x66, 0xbd, 0x69,
                0xb3, 0xd2, 0x13, 0x88, 0x2e, 0xef, 0x55, 0xe6, 0x0b, 0x6d, 0x9e, 0x2a, 0x98, 0xe7,
                0x05, 0xee, 0xf3, 0x27,
            ],
            cmx: [
                0xf9, 0xa6, 0x95, 0xcf, 0x08, 0x27, 0xc5, 0x9b, 0xa0, 0xb2, 0x90, 0x83, 0xd4, 0xd1,
                0xaf, 0x88, 0xdb, 0x03, 0x73, 0x95, 0xca, 0x36, 0x2b, 0xbd, 0xe6, 0x5f, 0x99, 0x5b,
                0x64, 0x52, 0xb7, 0x12,
            ],
            esk: [
                0x4e, 0x8e, 0x30, 0xf4, 0xe9, 0x8f, 0xce, 0xfa, 0xc2, 0x54, 0x6c, 0x30, 0x41, 0xd5,
                0xed, 0xef, 0x29, 0xfc, 0x0d, 0xc4, 0xc1, 0x02, 0x6d, 0xf7, 0x4d, 0x6c, 0x42, 0x5f,
                0x4b, 0xcc, 0x16, 0x32,
            ],
            ephemeral_key: [
                0xff, 0xa2, 0x4f, 0xdb, 0xd3, 0x74, 0xe3, 0xf5, 0xb5, 0x93, 0x06, 0x14, 0x42, 0x6c,
                0x9b, 0x6b, 0x26, 0x76, 0xe9, 0xe8, 0xc5, 0x7c, 0x63, 0xad, 0x27, 0xcf, 0x32, 0xa9,
                0xaf, 0x9c, 0xac, 0x86,
            ],
            shared_secret: [
                0xb4, 0x7b, 0x48, 0xfa, 0x78, 0x67, 0x0e, 0x55, 0xd2, 0xce, 0x09, 0xb6, 0x4c, 0xef,
                0x7e, 0x2f, 0xdd, 0x0e, 0x7b, 0x31, 0xa8, 0x84, 0x09, 0x35, 0x4c, 0x0c, 0x7c, 0x48,
                0x13, 0xfe, 0xff, 0xa0,
            ],
            k_enc: [
                0x12, 0x0b, 0x29, 0xef, 0xb8, 0x7f, 0x57, 0x05, 0xf7, 0xf9, 0x3a, 0xe7, 0x8c, 0xb1,
                0xfa, 0xe6, 0x46, 0xab, 0xd0, 0x1b, 0x90, 0x31, 0xb9, 0x0a, 0xd8, 0xc3, 0xcd, 0x3c,
                0xca, 0x5a, 0x90, 0x45,
            ],
            p_enc: [
                0x02, 0x8f, 0xf3, 0x38, 0x69, 0x71, 0xcb, 0x64, 0xb8, 0xe7, 0x78, 0x99, 0x11, 0x7d,
                0x41, 0x7a, 0xdb, 0x3d, 0x15, 0xcc, 0x1c, 0xdd, 0x86, 0xb3, 0xcc, 0x43, 0x18, 0xd9,
                0x61, 0x4f, 0xc8, 0x20, 0x90, 0x5d, 0x04, 0x2b, 0xb1, 0xef, 0x9c, 0xa3, 0xf2, 0x49,
                0x88, 0xc7, 0xb3, 0x53, 0x42, 0x01, 0xcf, 0xb1, 0xcd, 0x8d, 0xff, 0xbf, 0x69, 0xb8,
                0x25, 0x0c, 0x18, 0xef, 0x41, 0x29, 0x4c, 0xa9, 0x79, 0x93, 0xdb, 0x54, 0x6c, 0x1f,
                0xe0, 0x1f, 0x7e, 0x9c, 0x8e, 0x36, 0xd6, 0xa5, 0xe2, 0x9d, 0x4e, 0x30, 0xa7, 0x35,
                0x94, 0xbf, 0x50, 0x98, 0x42, 0x1c, 0x69, 0x37, 0x8a, 0xf1, 0xe4, 0x0f, 0x64, 0xe1,
                0x25, 0x94, 0x6f, 0x62, 0xc2, 0xfa, 0x7b, 0x2f, 0xec, 0xbc, 0xb6, 0x4b, 0x69, 0x68,
                0x91, 0x2a, 0x63, 0x81, 0xce, 0x3d, 0xc1, 0x66, 0xd5, 0x6a, 0x1d, 0x62, 0xf5, 0xa8,
                0xd7, 0x55, 0x1d, 0xb5, 0xfd, 0x93, 0x13, 0xe8, 0xc7, 0x20, 0x3d, 0x99, 0x6a, 0xf7,
                0xd4, 0x77, 0x08, 0x37, 0x56, 0xd5, 0x9a, 0xf8, 0x0d, 0x06, 0xa7, 0x45, 0xf4, 0x4a,
                0xb0, 0x23, 0x75, 0x2c, 0xb5, 0xb4, 0x06, 0xed, 0x89, 0x85, 0xe1, 0x81, 0x30, 0xab,
                0x33, 0x36, 0x26, 0x97, 0xb0, 0xe4, 0xe4, 0xc7, 0x63, 0xcc, 0xb8, 0xf6, 0x76, 0x49,
                0x5c, 0x22, 0x2f, 0x7f, 0xba, 0x1e, 0x31, 0xde, 0xfa, 0x3d, 0x5a, 0x57, 0xef, 0xc2,
                0xe1, 0xe9, 0xb0, 0x1a, 0x03, 0x55, 0x87, 0xd5, 0xfb, 0x1a, 0x38, 0xe0, 0x1d, 0x94,
                0x90, 0x3d, 0x3c, 0x3e, 0x0a, 0xd3, 0x36, 0x0c, 0x1d, 0x37, 0x10, 0xac, 0xd2, 0x0b,
                0x18, 0x3e, 0x31, 0xd4, 0x9f, 0x25, 0xc9, 0xa1, 0x38, 0xf4, 0x9b, 0x1a, 0x53, 0x7e,
                0xdc, 0xf0, 0x4b, 0xe3, 0x4a, 0x98, 0x51, 0xa7, 0xaf, 0x9d, 0xb6, 0x99, 0x0e, 0xd8,
                0x3d, 0xd6, 0x4a, 0xf3, 0x59, 0x7c, 0x04, 0x32, 0x3e, 0xa5, 0x1b, 0x00, 0x52, 0xad,
                0x80, 0x84, 0xa8, 0xb9, 0xda, 0x94, 0x8d, 0x32, 0x0d, 0xad, 0xd6, 0x4f, 0x54, 0x31,
                0xe6, 0x1d, 0xdf, 0x65, 0x8d, 0x24, 0xae, 0x67, 0xc2, 0x2c, 0x8d, 0x13, 0x09, 0x13,
                0x1f, 0xc0, 0x0f, 0xe7, 0xf2, 0x35, 0x73, 0x42, 0x76, 0xd3, 0x8d, 0x47, 0xf1, 0xe1,
                0x91, 0xe0, 0x0c, 0x7a, 0x1d, 0x48, 0xaf, 0x04, 0x68, 0x27, 0x59, 0x1e, 0x97, 0x33,
                0xa9, 0x7f, 0xa6, 0xb6, 0x79, 0xf3, 0xdc, 0x60, 0x1d, 0x00, 0x82, 0x85, 0xed, 0xcb,
                0xda, 0xe6, 0x9c, 0xe8, 0xfc, 0x1b, 0xe4, 0xaa, 0xc0, 0x0f, 0xf2, 0x71, 0x1e, 0xbd,
                0x93, 0x1d, 0xe5, 0x18, 0x85, 0x68, 0x78, 0xf7, 0x34, 0x76, 0xf2, 0x1a, 0x48, 0x2e,
                0xc9, 0x37, 0x83, 0x65, 0xc8, 0xf7, 0x39, 0x3c, 0x94, 0xe2, 0x88, 0x53, 0x15, 0xeb,
                0x46, 0x71, 0x09, 0x8b, 0x79, 0x53, 0x5e, 0x79, 0x0f, 0xe5, 0x3e, 0x29, 0xfe, 0xf2,
                0xb3, 0x76, 0x66, 0x97, 0xac, 0x32, 0xb4, 0xf4, 0x73, 0xf4, 0x68, 0xa0, 0x08, 0xe7,
                0x23, 0x89, 0xfc, 0x03, 0x88, 0x0d, 0x78, 0x0c, 0xb0, 0x7f, 0xcf, 0xaa, 0xbe, 0x3f,
                0x1a, 0x84, 0xb2, 0x7d, 0xb5, 0x9a, 0x4a, 0x15, 0x3d, 0x88, 0x2d, 0x2b, 0x21, 0x03,
                0x59, 0x65, 0x55, 0xed, 0x94, 0x94, 0xc6, 0xac, 0x89, 0x3c, 0x49, 0x72, 0x38, 0x33,
                0xec, 0x89, 0x26, 0xc1, 0x03, 0x95, 0x86, 0xa7, 0xaf, 0xcf, 0x4a, 0x0d, 0x9c, 0x73,
                0x1e, 0x98, 0x5d, 0x99, 0x58, 0x9c, 0x8b, 0xb8, 0x38, 0xe8, 0xaa, 0xf7, 0x45, 0x53,
                0x3e, 0xd9, 0xe8, 0xae, 0x3a, 0x1c, 0xd0, 0x74, 0xa5, 0x1a, 0x20, 0xda, 0x8a, 0xba,
                0x18, 0xd1, 0xdb, 0xeb, 0xbc, 0x86, 0x2d, 0xed, 0x42, 0x43, 0x5e, 0x92, 0x47, 0x69,
                0x30, 0xd0, 0x69, 0x89, 0x6c, 0xff, 0x30, 0xeb, 0x41, 0x4f, 0x72, 0x7b, 0x89, 0xe0,
                0x01, 0xaf, 0xa2, 0xfb, 0x8d, 0xc3, 0x43, 0x6d, 0x75, 0xa4, 0xa6, 0xf2, 0x65, 0x72,
                0x50, 0x4b, 0x19, 0x22, 0x32, 0xec, 0xb9, 0xf0, 0xc0, 0x24, 0x11, 0xe5, 0x25, 0x96,
                0xbc, 0x5e, 0x90, 0x45, 0x7e, 0x74, 0x59, 0x39, 0xff, 0xed, 0xbd, 0x12, 0x86, 0x3c,
                0xe7, 0x1a, 0x02, 0xaf,
            ],
            c_enc: [
                0x26, 0xed, 0xa0, 0xa6, 0x19, 0xa2, 0x69, 0x5e, 0xfe, 0xd7, 0x96, 0x7a, 0x6a, 0xe0,
                0x74, 0x88, 0x60, 0xfa, 0x3e, 0xe4, 0xc6, 0xda, 0x29, 0x3d, 0x59, 0xec, 0x76, 0xfe,
                0xe0, 0xbf, 0xd0, 0x02, 0x53, 0x86, 0x3b, 0xe3, 0x8f, 0x78, 0xa8, 0xdd, 0x93, 0xa1,
                0x04, 0x4d, 0xff, 0xe8, 0x68, 0xe7, 0xa5, 0x1b, 0xae, 0x49, 0xb2, 0xe8, 0xca, 0xcc,
                0x42, 0x7e, 0x4c, 0xf5, 0xd9, 0xda, 0x22, 0x90, 0x62, 0xed, 0x74, 0xbb, 0xad, 0x3d,
                0x1b, 0x7b, 0xe6, 0x8c, 0x76, 0x05, 0x9c, 0xed, 0x11, 0xce, 0x4d, 0x19, 0x63, 0x1d,
                0xd4, 0x00, 0xe2, 0x05, 0x54, 0xe3, 0x39, 0xd2, 0xb2, 0x91, 0xb2, 0x64, 0xb5, 0x88,
                0x49, 0x0b, 0x32, 0xce, 0xbc, 0xa1, 0x49, 0x90, 0x10, 0x1e, 0x06, 0x4c, 0x86, 0x8a,
                0x50, 0xaa, 0xec, 0x5c, 0xb5, 0xaf, 0x59, 0x38, 0x06, 0x54, 0x8f, 0xc7, 0xe9, 0x7a,
                0x6b, 0xf7, 0xc3, 0x66, 0x64, 0x19, 0x8b, 0x28, 0xea, 0x7a, 0x43, 0x3b, 0xf8, 0xa6,
                0x33, 0xd0, 0x70, 0x73, 0xd8, 0x3e, 0xca, 0xb1, 0x6c, 0xcb, 0x8d, 0x42, 0xc6, 0xe2,
                0x8b, 0x2d, 0xd4, 0xe0, 0xa6, 0x16, 0x4e, 0x7a, 0xfc, 0x70, 0x53, 0xcd, 0xe9, 0x50,
                0x8c, 0xc5, 0x33, 0xe3, 0x53, 0x51, 0x11, 0xcb, 0x8c, 0xe4, 0xef, 0xb8, 0x43, 0x96,
                0x11, 0x0b, 0x7e, 0x89, 0xbd, 0x49, 0xeb, 0x62, 0xe7, 0x8a, 0xc3, 0xba, 0xd9, 0x29,
                0x6a, 0xcd, 0xd8, 0x89, 0x33, 0xd2, 0xe9, 0x74, 0xe3, 0x8c, 0x49, 0x5e, 0x61, 0xd4,
                0xcb, 0x18, 0xe3, 0x27, 0x39, 0x49, 0x28, 0xca, 0x8d, 0x3c, 0xd8, 0x00, 0x90, 0xf9,
                0xbb, 0x39, 0x59, 0xe5, 0xa0, 0x4b, 0xc5, 0xef, 0xd2, 0xa8, 0xe0, 0x98, 0xf5, 0x83,
                0xe1, 0x54, 0x3a, 0xdb, 0x3d, 0x58, 0x35, 0x91, 0x3c, 0xca, 0xd5, 0x6c, 0x3e, 0xcb,
                0x57, 0x1a, 0x86, 0xf8, 0x31, 0xd8, 0x76, 0x3b, 0xe6, 0x62, 0x89, 0x64, 0xc2, 0x61,
                0xbe, 0xcb, 0x30, 0x8d, 0x95, 0xdd, 0x1d, 0x35, 0x05, 0xea, 0x79, 0xf8, 0x51, 0xb3,
                0x9c, 0x64, 0xe0, 0xdb, 0x4b, 0xbd, 0xeb, 0xff, 0xad, 0x10, 0x96, 0x71, 0xc4, 0xa1,
                0xd9, 0x82, 0xd1, 0x38, 0xd5, 0xc9, 0xc1, 0x99, 0x50, 0x18, 0x4e, 0x85, 0xad, 0xa8,
                0xf4, 0x50, 0x20, 0x1d, 0x07, 0xac, 0x43, 0xfd, 0x24, 0x74, 0x00, 0x54, 0xaa, 0x5a,
                0x6a, 0xa7, 0x89, 0x1c, 0x83, 0x56, 0x30, 0x65, 0x4d, 0x4a, 0x15, 0xcc, 0x99, 0x75,
                0xae, 0x96, 0x11, 0x6a, 0xed, 0xc2, 0x81, 0xa5, 0x02, 0x51, 0x4d, 0xdd, 0x6b, 0x3b,
                0xb6, 0x5f, 0x2e, 0x93, 0x6a, 0xc7, 0xe9, 0x73, 0x2f, 0xca, 0xff, 0x9d, 0x8b, 0xd0,
                0xe4, 0x3b, 0x37, 0x85, 0x11, 0x49, 0x8b, 0xe6, 0x27, 0xbd, 0xaa, 0xf4, 0x8c, 0xc8,
                0x1a, 0x2e, 0xb5, 0xd9, 0x75, 0xc4, 0xc3, 0x06, 0xe3, 0x1a, 0xf9, 0x3b, 0x26, 0x3c,
                0xbd, 0x4b, 0xe2, 0x26, 0xca, 0x0d, 0x2e, 0x92, 0xc0, 0x45, 0x42, 0xc5, 0x9c, 0x9a,
                0x3f, 0x0d, 0x2a, 0x0c, 0x29, 0xa7, 0xc7, 0xf5, 0x84, 0xbe, 0xd0, 0xc0, 0x9b, 0x8b,
                0x5c, 0x4a, 0xba, 0x11, 0xb3, 0xf6, 0x8f, 0xdf, 0x75, 0xb5, 0x36, 0xcf, 0xb4, 0xde,
                0x79, 0x7b, 0x1f, 0x1b, 0x13, 0x51, 0xba, 0xe8, 0xf4, 0x14, 0x1d, 0xb3, 0x3d, 0xdc,
                0xd6, 0x0d, 0xcf, 0xd4, 0x8e, 0x2e, 0xd5, 0xc2, 0x5d, 0x46, 0xda, 0x89, 0x16, 0xe1,
                0x8f, 0x71, 0xbd, 0x15, 0x0a, 0xaf, 0xef, 0xf4, 0x97, 0xc3, 0xba, 0x21, 0x30, 0xb2,
                0x6a, 0x49, 0x52, 0xc4, 0xc8, 0xc1, 0x85, 0x0f, 0x53, 0x5e, 0x0e, 0xb2, 0xbf, 0x82,
                0x1a, 0x76, 0x40, 0x3b, 0xd0, 0x6f, 0xef, 0xfb, 0x4a, 0x97, 0xf8, 0x8d, 0xf2, 0xdb,
                0x23, 0x70, 0xf2, 0x49, 0x91, 0x13, 0xd6, 0x1a, 0xa6, 0x59, 0x40, 0x7c, 0xc2, 0x68,
                0xc3, 0x06, 0x60, 0x88, 0xcd, 0xf0, 0x74, 0x8c, 0x57, 0xcb, 0xaa, 0x94, 0x3e, 0x5c,
                0x4c, 0xb6, 0xf9, 0xd5, 0xff, 0x05, 0xd2, 0x6a, 0xf4, 0x9c, 0xa2, 0x86, 0xab, 0xbf,
                0x92, 0x4f, 0x57, 0x96, 0xe4, 0x19, 0x43, 0x28, 0xd3, 0xbc, 0x4d, 0x87, 0x6f, 0xf8,
                0x08, 0x1c, 0x60, 0x5b, 0x2b, 0x54, 0xa8, 0x60, 0x38, 0x8e, 0xd1, 0xfa, 0xb2, 0x65,
                0xd8, 0xef, 0x8e, 0x37, 0x3b, 0x15,
            ],
            ock: [
                0x67, 0x71, 0x7b, 0xfd, 0xea, 0xc3, 0xd0, 0x61, 0x69, 0x00, 0x13, 0x45, 0x7c, 0x9a,
                0xbe, 0x1c, 0xd5, 0x5c, 0x98, 0x63, 0xcb, 0xef, 0x44, 0x2f, 0x69, 0xe3, 0x34, 0xcc,
                0xec, 0x75, 0x3a, 0x6a,
            ],
            op: [
                0x08, 0xdd, 0x8e, 0xbd, 0x7d, 0xe9, 0x2a, 0x68, 0xe5, 0x86, 0xa3, 0x4d, 0xb8, 0xfe,
                0xa9, 0x99, 0xef, 0xd2, 0x01, 0x6f, 0xae, 0x76, 0x75, 0x0a, 0xfa, 0xe7, 0xee, 0x94,
                0x16, 0x46, 0xbc, 0xb9, 0x4e, 0x8e, 0x30, 0xf4, 0xe9, 0x8f, 0xce, 0xfa, 0xc2, 0x54,
                0x6c, 0x30, 0x41, 0xd5, 0xed, 0xef, 0x29, 0xfc, 0x0d, 0xc4, 0xc1, 0x02, 0x6d, 0xf7,
                0x4d, 0x6c, 0x42, 0x5f, 0x4b, 0xcc, 0x16, 0x32,
            ],
            c_out: [
                0xf1, 0x20, 0xd2, 0xec, 0xc8, 0xe1, 0xff, 0x67, 0x2c, 0x8d, 0x0a, 0x9c, 0x12, 0x0a,
                0xf4, 0x79, 0xfe, 0xa9, 0xdc, 0x14, 0x62, 0xcf, 0x0c, 0xc9, 0x30, 0x11, 0xf6, 0x1c,
                0x2e, 0x92, 0x9d, 0x2d, 0x09, 0xb0, 0x9f, 0xdf, 0x89, 0x35, 0x78, 0x15, 0x7a, 0x20,
                0x60, 0xf7, 0xad, 0x73, 0xdf, 0x9b, 0x7a, 0x90, 0xd8, 0xb9, 0xcb, 0x7c, 0x82, 0xd4,
                0x6f, 0x12, 0xab, 0xe8, 0x55, 0x1c, 0x55, 0x82, 0x07, 0x2c, 0x9e, 0xde, 0xa6, 0x0f,
                0x49, 0x9b, 0x65, 0x2f, 0xfa, 0xe2, 0x8c, 0x0e, 0x82, 0xa1,
            ],
        },
        TestVector {
            incoming_viewing_key: [
                0x5b, 0x8a, 0x4d, 0x30, 0x77, 0x0d, 0x75, 0xd5, 0x75, 0x19, 0xbe, 0xb8, 0xcf, 0x90,
                0xc0, 0x63, 0x5c, 0xe9, 0xe3, 0x8c, 0x36, 0xab, 0xd9, 0x3d, 0x87, 0xb4, 0x20, 0x30,
                0x3c, 0x67, 0x48, 0xf5, 0xb2, 0x98, 0xcf, 0xa8, 0xb4, 0xcb, 0x39, 0x5b, 0x15, 0x1f,
                0x5f, 0xf3, 0x72, 0xe6, 0xfe, 0xd9, 0x29, 0x2e, 0xe6, 0x82, 0x97, 0x1e, 0xe2, 0xf0,
                0xd4, 0xc1, 0x5b, 0xfb, 0x22, 0x78, 0x14, 0x28,
            ],
            ovk: [
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
                0x00, 0x00, 0x00, 0x00,
            ],
            default_d: [
                0x03, 0x60, 0xba, 0xe4, 0x72, 0xbe, 0x46, 0x7c, 0xbc, 0xf0, 0xec,
            ],
            default_pk_d: [
                0xcf, 0xaf, 0xc9, 0x38, 0xab, 0x44, 0x30, 0xaa, 0xc4, 0xdc, 0xcb, 0x35, 0x13, 0x1c,
                0x39, 0x1e, 0x60, 0x32, 0x84, 0x13, 0xb4, 0x32, 0x98, 0x7a, 0x01, 0x8b, 0x5b, 0x7c,
                0xf9, 0xbb, 0x31, 0xa0,
            ],
            v: 16644083129188108223,
            rseed: [
                0x73, 0xd3, 0x16, 0xeb, 0x16, 0x0d, 0xc0, 0xb7, 0x16, 0xc4, 0x8f, 0xbd, 0x46, 0x7f,
                0x75, 0xb7, 0x80, 0x14, 0x9a, 0xe8, 0x80, 0x8f, 0x4e, 0x68, 0xf5, 0x0c, 0x05, 0x36,
                0xac, 0xdd, 0xf6, 0xf1,
            ],
            memo: [
                0xff, 0xae, 0xab, 0x01, 0x6b, 0x6b, 0xc1, 0xec, 0x14, 0x4b, 0x4e, 0x55, 0x3a, 0xcf,
                0xd6, 0x70, 0xf7, 0x7e, 0x75, 0x5f, 0xc8, 0x8e, 0x06, 0x77, 0xe3, 0x1b, 0xa4, 0x59,
                0xb4, 0x4e, 0x30, 0x77, 0x68, 0x95, 0x8f, 0xe3, 0x78, 0x9d, 0x41, 0xc2, 0xb1, 0xff,
                0x43, 0x4c, 0xb3, 0x0e, 0x15, 0x91, 0x4f, 0x01, 0xbc, 0x6b, 0xc2, 0x30, 0x7b, 0x48,
                0x8d, 0x25, 0x56, 0xd7, 0xb7, 0x38, 0x0e, 0xa4, 0xff, 0xd7, 0x12, 0xf6, 0xb0, 0x2f,
                0xe8, 0x06, 0xb9, 0x45, 0x69, 0xcd, 0x40, 0x59, 0xf3, 0x96, 0xbf, 0x29, 0xb9, 0x9d,
                0x0a, 0x40, 0xe5, 0xe1, 0x71, 0x1c, 0xa9, 0x44, 0xf7, 0x2d, 0x43, 0x6a, 0x10, 0x2f,
                0xca, 0x4b, 0x97, 0x69, 0x3d, 0xa0, 0xb0, 0x86, 0xfe, 0x9d, 0x2e, 0x71, 0x62, 0x47,
                0x0d, 0x02, 0xe0, 0xf0, 0x5d, 0x4b, 0xec, 0x95, 0x12, 0xbf, 0xb3, 0xf3, 0x83, 0x27,
                0x29, 0x6e, 0xfa, 0xa7, 0x43, 0x28, 0xb1, 0x18, 0xc2, 0x74, 0x02, 0xc7, 0x0c, 0x3a,
                0x90, 0xb4, 0x9a, 0xd4, 0xbb, 0xc6, 0x8e, 0x37, 0xc0, 0xaa, 0x7d, 0x9b, 0x3f, 0xe1,
                0x77, 0x99, 0xd7, 0x3b, 0x84, 0x1e, 0x75, 0x17, 0x13, 0xa0, 0x29, 0x43, 0x90, 0x5a,
                0xae, 0x08, 0x03, 0xfd, 0x69, 0x44, 0x2e, 0xb7, 0x68, 0x1e, 0xc2, 0xa0, 0x56, 0x00,
                0x05, 0x4e, 0x92, 0xee, 0xd5, 0x55, 0x02, 0x8f, 0x21, 0xb6, 0xa1, 0x55, 0x26, 0x8a,
                0x2d, 0xd6, 0x64, 0x0a, 0x69, 0x30, 0x1a, 0x52, 0xa3, 0x8d, 0x4d, 0x9f, 0x9f, 0x95,
                0x7a, 0xe3, 0x5a, 0xf7, 0x16, 0x71, 0x18, 0x14, 0x1c, 0xe4, 0xc9, 0xbe, 0x0a, 0x6a,
                0x49, 0x2f, 0xe7, 0x9f, 0x15, 0x81, 0xa1, 0x55, 0xfa, 0x3a, 0x2b, 0x9d, 0xaf, 0xd8,
                0x2e, 0x65, 0x0b, 0x38, 0x6a, 0xd3, 0xa0, 0x8c, 0xb6, 0xb8, 0x31, 0x31, 0xac, 0x30,
                0x0b, 0x08, 0x46, 0x35, 0x4a, 0x7e, 0xef, 0x9c, 0x41, 0x0e, 0x4b, 0x62, 0xc4, 0x7c,
                0x54, 0x26, 0x90, 0x7d, 0xfc, 0x66, 0x85, 0xc5, 0xc9, 0x9b, 0x71, 0x41, 0xac, 0x62,
                0x6a, 0xb4, 0x76, 0x1f, 0xd3, 0xf4, 0x1e, 0x72, 0x8e, 0x1a, 0x28, 0xf8, 0x9d, 0xb8,
                0x9f, 0xfd, 0xec, 0xa3, 0x64, 0xdd, 0x2f, 0x0f, 0x07, 0x39, 0xf0, 0x53, 0x45, 0x56,
                0x48, 0x31, 0x99, 0xc7, 0x1f, 0x18, 0x93, 0x41, 0xac, 0x9b, 0x78, 0xa2, 0x69, 0x16,
                0x42, 0x06, 0xa0, 0xea, 0x1c, 0xe7, 0x3b, 0xfb, 0x2a, 0x94, 0x2e, 0x73, 0x70, 0xb2,
                0x47, 0xc0, 0x46, 0xf8, 0xe7, 0x5e, 0xf8, 0xe3, 0xf8, 0xbd, 0x82, 0x1c, 0xf5, 0x77,
                0x49, 0x18, 0x64, 0xe2, 0x0e, 0x6d, 0x08, 0xfd, 0x2e, 0x32, 0xb5, 0x55, 0xc9, 0x2c,
                0x66, 0x1f, 0x19, 0x58, 0x8b, 0x72, 0xa8, 0x95, 0x99, 0x71, 0x0a, 0x88, 0x06, 0x12,
                0x53, 0xca, 0x28, 0x5b, 0x63, 0x04, 0xb3, 0x7d, 0xa2, 0xb5, 0x29, 0x4f, 0x5c, 0xb3,
                0x54, 0xa8, 0x94, 0x32, 0x28, 0x48, 0xcc, 0xbd, 0xc7, 0xc2, 0x54, 0x5b, 0x7d, 0xa5,
                0x68, 0xaf, 0xac, 0x87, 0xff, 0xa0, 0x05, 0xc3, 0x12, 0x24, 0x1c, 0x2d, 0x57, 0xf4,
                0xb4, 0x5d, 0x64, 0x19, 0xf0, 0xd2, 0xe2, 0xc5, 0xaf, 0x33, 0xae, 0x24, 0x37, 0x85,
                0xb3, 0x25, 0xcd, 0xab, 0x95, 0x40, 0x4f, 0xc7, 0xae, 0xd7, 0x05, 0x25, 0xcd, 0xdb,
                0x41, 0x87, 0x2c, 0xfc, 0xc2, 0x14, 0xb1, 0x32, 0x32, 0xed, 0xc7, 0x86, 0x09, 0x75,
                0x3d, 0xbf, 0xf9, 0x30, 0xeb, 0x0d, 0xc1, 0x56, 0x61, 0x2b, 0x9c, 0xb4, 0x34, 0xbc,
                0x4b, 0x69, 0x33, 0x92, 0xde, 0xb8, 0x7c, 0x53, 0x04, 0x35, 0x31, 0x2e, 0xdc, 0xed,
                0xc6, 0xa9, 0x61, 0x13, 0x33, 0x38, 0xd7, 0x86, 0xc4, 0xa3, 0xe1, 0x03, 0xf6, 0x01,
                0x10, 0xa1, 0x6b, 0x13, 0x37, 0x12, 0x97, 0x04,
            ],
            cv_net: [
                0x14, 0x4d, 0xf7, 0x44, 0x61, 0xa3, 0xbc, 0x0b, 0xb4, 0x44, 0x11, 0xa9, 0x8a, 0xb1,
                0x5c, 0x89, 0xde, 0x93, 0x4f, 0x8a, 0x31, 0xe4, 0x3b, 0xad, 0xdd, 0x28, 0x69, 0x39,
                0xbd, 0x77, 0xa7, 0x8e,
            ],
            rho: [
                0xc1, 0xe1, 0x59, 0x5b, 0x8d, 0xe7, 0x55, 0x97, 0x66, 0xe5, 0xa6, 0x72, 0x5f, 0x5b,
                0xe5, 0x74, 0x2f, 0x43, 0xbf, 0x40, 0x62, 0x3b, 0x71, 0x49, 0xca, 0xe2, 0x67, 0x5c,
                0x4d, 0xb2, 0xc7, 0x31,
            ],
            cmx: [
                0x02, 0xe0, 0x30, 0xb4, 0xe6, 0x0e, 0xe7, 0xa7, 0x8e, 0x7e, 0x1a, 0x65, 0xc6, 0xac,
                0x46, 0xa9, 0x02, 0x14, 0x35, 0x9a, 0xdd, 0x2f, 0x1e, 0xe5, 0x78, 0x28, 0xfa, 0x00,
                0x24, 0xe1, 0xc7, 0x0a,
            ],
            esk: [
                0xbd, 0x8f, 0x56, 0xa3, 0xf4, 0xf0, 0x9c, 0xbc, 0x87, 0xbb, 0xcf, 0xe7, 0x7e, 0x60,
                0x40, 0x60, 0x73, 0x46, 0xb4, 0x67, 0xaa, 0x5d, 0x00, 0x4e, 0xe4, 0xe4, 0xb0, 0xff,
                0xcc, 0xcf, 0x86, 0x2c,
            ],
            ephemeral_key: [
                0x69, 0x75, 0xab, 0xb1, 0xc7, 0x7a, 0xae, 0x78, 0x98, 0x3a, 0x68, 0xc7, 0x4c, 0x73,
                0x63, 0x18, 0xf9, 0x3f, 0x62, 0x7a, 0x00, 0x4c, 0x0e, 0x91, 0xd0, 0x11, 0x70, 0x9d,
                0x47, 0xc1, 0x42, 0x1f,
            ],
            shared_secret: [
                0xaf, 0x1a, 0x16, 0x5b, 0x29, 0x83, 0x15, 0x13, 0x32, 0x57, 0x8c, 0x24, 0x40, 0xe3,
                0xa8, 0x7e, 0x39, 0x87, 0x03, 0xb6, 0x47, 0x60, 0x02, 0x6e, 0x67, 0xe0, 0x32, 0x2e,
                0x63, 0x1b, 0xa6, 0x30,
            ],
            k_enc: [
                0xb8, 0x48, 0x77, 0x8f, 0xaa, 0x88, 0x99, 0x93, 0x2f, 0x60, 0x80, 0x3a, 0xc8, 0x79,
                0xf9, 0x36, 0x17, 0xcd, 0x3b, 0xfa, 0x33, 0x7c, 0xd2, 0x05, 0x23, 0x5d, 0x44, 0x0e,
                0x74, 0x5b, 0x86, 0x82,
            ],
            p_enc: [
                0x02, 0x03, 0x60, 0xba, 0xe4, 0x72, 0xbe, 0x46, 0x7c, 0xbc, 0xf0, 0xec, 0xbf, 0x47,
                0x54, 0xff, 0x6b, 0xa9, 0xfb, 0xe6, 0x73, 0xd3, 0x16, 0xeb, 0x16, 0x0d, 0xc0, 0xb7,
                0x16, 0xc4, 0x8f, 0xbd, 0x46, 0x7f, 0x75, 0xb7, 0x80, 0x14, 0x9a, 0xe8, 0x80, 0x8f,
                0x4e, 0x68, 0xf5, 0x0c, 0x05, 0x36, 0xac, 0xdd, 0xf6, 0xf1, 0xff, 0xae, 0xab, 0x01,
                0x6b, 0x6b, 0xc1, 0xec, 0x14, 0x4b, 0x4e, 0x55, 0x3a, 0xcf, 0xd6, 0x70, 0xf7, 0x7e,
                0x75, 0x5f, 0xc8, 0x8e, 0x06, 0x77, 0xe3, 0x1b, 0xa4, 0x59, 0xb4, 0x4e, 0x30, 0x77,
                0x68, 0x95, 0x8f, 0xe3, 0x78, 0x9d, 0x41, 0xc2, 0xb1, 0xff, 0x43, 0x4c, 0xb3, 0x0e,
                0x15, 0x91, 0x4f, 0x01, 0xbc, 0x6b, 0xc2, 0x30, 0x7b, 0x48, 0x8d, 0x25, 0x56, 0xd7,
                0xb7, 0x38, 0x0e, 0xa4, 0xff, 0xd7, 0x12, 0xf6, 0xb0, 0x2f, 0xe8, 0x06, 0xb9, 0x45,
                0x69, 0xcd, 0x40, 0x59, 0xf3, 0x96, 0xbf, 0x29, 0xb9, 0x9d, 0x0a, 0x40, 0xe5, 0xe1,
                0x71, 0x1c, 0xa9, 0x44, 0xf7, 0x2d, 0x43, 0x6a, 0x10, 0x2f, 0xca, 0x4b, 0x97, 0x69,
                0x3d, 0xa0, 0xb0, 0x86, 0xfe, 0x9d, 0x2e, 0x71, 0x62, 0x47, 0x0d, 0x02, 0xe0, 0xf0,
                0x5d, 0x4b, 0xec, 0x95, 0x12, 0xbf, 0xb3, 0xf3, 0x83, 0x27, 0x29, 0x6e, 0xfa, 0xa7,
                0x43, 0x28, 0xb1, 0x18, 0xc2, 0x74, 0x02, 0xc7, 0x0c, 0x3a, 0x90, 0xb4, 0x9a, 0xd4,
                0xbb, 0xc6, 0x8e, 0x37, 0xc0, 0xaa, 0x7d, 0x9b, 0x3f, 0xe1, 0x77, 0x99, 0xd7, 0x3b,
                0x84, 0x1e, 0x75, 0x17, 0x13, 0xa0, 0x29, 0x43, 0x90, 0x5a, 0xae, 0x08, 0x03, 0xfd,
                0x69, 0x44, 0x2e, 0xb7, 0x68, 0x1e, 0xc2, 0xa0, 0x56, 0x00, 0x05, 0x4e, 0x92, 0xee,
                0xd5, 0x55, 0x02, 0x8f, 0x21, 0xb6, 0xa1, 0x55, 0x26, 0x8a, 0x2d, 0xd6, 0x64, 0x0a,
                0x69, 0x30, 0x1a, 0x52, 0xa3, 0x8d, 0x4d, 0x9f, 0x9f, 0x95, 0x7a, 0xe3, 0x5a, 0xf7,
                0x16, 0x71, 0x18, 0x14, 0x1c, 0xe4, 0xc9, 0xbe, 0x0a, 0x6a, 0x49, 0x2f, 0xe7, 0x9f,
                0x15, 0x81, 0xa1, 0x55, 0xfa, 0x3a, 0x2b, 0x9d, 0xaf, 0xd8, 0x2e, 0x65, 0x0b, 0x38,
                0x6a, 0xd3, 0xa0, 0x8c, 0xb6, 0xb8, 0x31, 0x31, 0xac, 0x30, 0x0b, 0x08, 0x46, 0x35,
                0x4a, 0x7e, 0xef, 0x9c, 0x41, 0x0e, 0x4b, 0x62, 0xc4, 0x7c, 0x54, 0x26, 0x90, 0x7d,
                0xfc, 0x66, 0x85, 0xc5, 0xc9, 0x9b, 0x71, 0x41, 0xac, 0x62, 0x6a, 0xb4, 0x76, 0x1f,
                0xd3, 0xf4, 0x1e, 0x72, 0x8e, 0x1a, 0x28, 0xf8, 0x9d, 0xb8, 0x9f, 0xfd, 0xec, 0xa3,
                0x64, 0xdd, 0x2f, 0x0f, 0x07, 0x39, 0xf0, 0x53, 0x45, 0x56, 0x48, 0x31, 0x99, 0xc7,
                0x1f, 0x18, 0x93, 0x41, 0xac, 0x9b, 0x78, 0xa2, 0x69, 0x16, 0x42, 0x06, 0xa0, 0xea,
                0x1c, 0xe7, 0x3b, 0xfb, 0x2a, 0x94, 0x2e, 0x73, 0x70, 0xb2, 0x47, 0xc0, 0x46, 0xf8,
                0xe7, 0x5e, 0xf8, 0xe3, 0xf8, 0xbd, 0x82, 0x1c, 0xf5, 0x77, 0x49, 0x18, 0x64, 0xe2,
                0x0e, 0x6d, 0x08, 0xfd, 0x2e, 0x32, 0xb5, 0x55, 0xc9, 0x2c, 0x66, 0x1f, 0x19, 0x58,
                0x8b, 0x72, 0xa8, 0x95, 0x99, 0x71, 0x0a, 0x88, 0x06, 0x12, 0x53, 0xca, 0x28, 0x5b,
                0x63, 0x04, 0xb3, 0x7d, 0xa2, 0xb5, 0x29, 0x4f, 0x5c, 0xb3, 0x54, 0xa8, 0x94, 0x32,
                0x28, 0x48, 0xcc, 0xbd, 0xc7, 0xc2, 0x54, 0x5b, 0x7d, 0xa5, 0x68, 0xaf, 0xac, 0x87,
                0xff, 0xa0, 0x05, 0xc3, 0x12, 0x24, 0x1c, 0x2d, 0x57, 0xf4, 0xb4, 0x5d, 0x64, 0x19,
                0xf0, 0xd2, 0xe2, 0xc5, 0xaf, 0x33, 0xae, 0x24, 0x37, 0x85, 0xb3, 0x25, 0xcd, 0xab,
                0x95, 0x40, 0x4f, 0xc7, 0xae, 0xd7, 0x05, 0x25, 0xcd, 0xdb, 0x41, 0x87, 0x2c, 0xfc,
                0xc2, 0x14, 0xb1, 0x32, 0x32, 0xed, 0xc7, 0x86, 0x09, 0x75, 0x3d, 0xbf, 0xf9, 0x30,
                0xeb, 0x0d, 0xc1, 0x56, 0x61, 0x2b, 0x9c, 0xb4, 0x34, 0xbc, 0x4b, 0x69, 0x33, 0x92,
                0xde, 0xb8, 0x7c, 0x53, 0x04, 0x35, 0x31, 0x2e, 0xdc, 0xed, 0xc6, 0xa9, 0x61, 0x13,
                0x33, 0x38, 0xd7, 0x86, 0xc4, 0xa3, 0xe1, 0x03, 0xf6, 0x01, 0x10, 0xa1, 0x6b, 0x13,
                0x37, 0x12, 0x97, 0x04,
            ],
            c_enc: [
                0xd3, 0xaf, 0xf1, 0xec, 0x23, 0x0a, 0x4c, 0xb6, 0xb4, 0x65, 0x9c, 0x84, 0x18, 0xce,
                0xa3, 0x67, 0xa3, 0x8d, 0x38, 0xfd, 0x1b, 0xbd, 0x88, 0x8a, 0x4c, 0x87, 0x9e, 0x04,
                0x4b, 0x50, 0x79, 0xb5, 0x3a, 0xb2, 0x97, 0x05, 0xe7, 0x39, 0x06, 0x38, 0x93, 0x6b,
                0x62, 0x8a, 0xed, 0xe1, 0x50, 0xe5, 0x9c, 0xbb, 0xe1, 0x8d, 0x94, 0xef, 0xd7, 0x91,
                0xbb, 0x95, 0x6c, 0x30, 0x0e, 0x2a, 0x86, 0x1c, 0x3a, 0x5a, 0x9f, 0xc6, 0x5c, 0x69,
                0x0b, 0x36, 0x81, 0xa0, 0xc2, 0x8e, 0x54, 0x5b, 0xb0, 0x99, 0xf1, 0x9a, 0x85, 0xee,
                0x7f, 0x6c, 0x7c, 0xf5, 0x2d, 0xab, 0x85, 0x16, 0x25, 0xcd, 0x58, 0x22, 0x6c, 0x19,
                0xa4, 0x09, 0xaa, 0x64, 0xd2, 0x23, 0x60, 0x2a, 0x9b, 0x0c, 0x64, 0xd0, 0xb4, 0x11,
                0x52, 0x07, 0x15, 0xbf, 0xb4, 0x3a, 0x00, 0xe7, 0xeb, 0x35, 0xd7, 0x10, 0xe4, 0x73,
                0x12, 0x84, 0x01, 0xc4, 0x68, 0x84, 0xfe, 0x5d, 0x7e, 0x18, 0xfd, 0x35, 0x0a, 0xce,
                0x69, 0xb4, 0xf9, 0xcd, 0xf4, 0xbe, 0x29, 0xc5, 0x36, 0xb4, 0x6f, 0x16, 0xb6, 0xa6,
                0x05, 0x6e, 0x2a, 0x89, 0xb5, 0x83, 0xb9, 0x5c, 0x2f, 0x7e, 0xf8, 0xbc, 0xdf, 0x3f,
                0xc0, 0xc5, 0x45, 0x5a, 0xb5, 0x85, 0xd0, 0x8e, 0xcd, 0x93, 0x9b, 0xef, 0xdd, 0x50,
                0x15, 0xce, 0x6a, 0x4a, 0xa1, 0x53, 0x69, 0x3c, 0xf1, 0x4f, 0xa6, 0x3d, 0xb8, 0x5e,
                0x07, 0x85, 0x09, 0x3f, 0x9c, 0x1d, 0xb3, 0x9a, 0xed, 0x89, 0x69, 0xf4, 0x91, 0xba,
                0x3b, 0x2f, 0x19, 0x8f, 0xf5, 0x41, 0x28, 0x67, 0xf4, 0xa7, 0x42, 0x7f, 0x92, 0x77,
                0xba, 0x15, 0x05, 0xf5, 0xef, 0xcc, 0x58, 0xeb, 0x0a, 0xc9, 0xfe, 0xc1, 0xea, 0x40,
                0x35, 0x6a, 0x6b, 0x4f, 0x5b, 0x17, 0x48, 0x2c, 0xff, 0x9d, 0x56, 0x86, 0xb3, 0xdd,
                0xb3, 0x22, 0x75, 0xe0, 0x32, 0xd7, 0xde, 0x9d, 0xf5, 0xbe, 0xe9, 0xe6, 0x16, 0x71,
                0x76, 0x37, 0xe2, 0x30, 0xbc, 0xc5, 0xb3, 0xbc, 0xeb, 0x38, 0x88, 0xbe, 0x64, 0xae,
                0x28, 0xb4, 0xa0, 0x91, 0xf9, 0xba, 0x2b, 0xae, 0xb5, 0xf4, 0x37, 0xb2, 0x73, 0x3b,
                0xe5, 0x6a, 0xf4, 0xf2, 0x14, 0x59, 0x9f, 0x13, 0x9c, 0xd4, 0x74, 0x86, 0xe3, 0x52,
                0x05, 0x03, 0x2a, 0xeb, 0x6a, 0x95, 0x1f, 0xb0, 0xc0, 0x7e, 0x58, 0xfe, 0xe1, 0xc3,
                0xba, 0xaf, 0xde, 0xc6, 0xcb, 0x49, 0xfb, 0x98, 0x03, 0x1c, 0xc6, 0x69, 0x86, 0xe4,
                0x29, 0xea, 0x00, 0x88, 0x4e, 0xa7, 0xf3, 0x3a, 0x5d, 0x3f, 0x46, 0x3d, 0xd7, 0x3c,
                0xcb, 0x73, 0x9f, 0xf3, 0xf7, 0x30, 0x45, 0xbf, 0xc1, 0x53, 0xd0, 0x62, 0x70, 0x14,
                0xc8, 0xa1, 0x33, 0x41, 0x5e, 0xb3, 0x25, 0x08, 0xe4, 0xa9, 0x26, 0x92, 0xee, 0xfd,
                0xd3, 0xd9, 0x8f, 0x44, 0x7f, 0x9b, 0x32, 0xb8, 0xa4, 0xd4, 0x83, 0xd0, 0xe2, 0xf6,
                0x24, 0xdb, 0x5f, 0x9a, 0xd5, 0x92, 0xfd, 0x91, 0x7f, 0xe3, 0x60, 0x0e, 0x5b, 0xe5,
                0xb8, 0xa8, 0xe0, 0x30, 0xf1, 0x89, 0x96, 0xc2, 0xf3, 0x8b, 0x22, 0x30, 0x15, 0x31,
                0x8b, 0xdb, 0x82, 0x53, 0xb1, 0x50, 0x63, 0xad, 0x63, 0xf1, 0xbb, 0x56, 0xe3, 0x1b,
                0xe3, 0x9d, 0xab, 0x42, 0x0b, 0x8b, 0x4d, 0x3c, 0x97, 0x67, 0xe8, 0x50, 0x5b, 0x3e,
                0xad, 0x8e, 0x0d, 0x7b, 0x12, 0xe7, 0x63, 0x3e, 0x98, 0x4e, 0x3e, 0xa9, 0x54, 0x16,
                0x7b, 0xf1, 0xbd, 0x55, 0xc5, 0x35, 0x9f, 0xe7, 0x53, 0x70, 0x12, 0xfa, 0x10, 0x20,
                0x6b, 0x53, 0x63, 0x66, 0x66, 0x9b, 0xdd, 0x54, 0xab, 0x71, 0x4f, 0x20, 0xe3, 0xdc,
                0x0f, 0x15, 0x06, 0x43, 0xe3, 0x26, 0x5e, 0x80, 0x06, 0x16, 0x1c, 0x6f, 0x84, 0xa5,
                0xbe, 0xef, 0x00, 0x23, 0xa5, 0xca, 0xeb, 0x9a, 0xde, 0xc3, 0xe2, 0xea, 0x65, 0x8c,
                0x38, 0x26, 0x6e, 0x5a, 0x24, 0x97, 0xf8, 0x21, 0x94, 0xa5, 0xc3, 0x3a, 0xfd, 0x52,
                0x3f, 0x21, 0x6d, 0x22, 0x02, 0x41, 0x20, 0xce, 0xc1, 0x07, 0xc3, 0xaa, 0x6e, 0xfc,
                0x6c, 0x09, 0x5a, 0x10, 0x64, 0x73, 0xf4, 0xee, 0xae, 0x0c, 0x3f, 0x02, 0xc7, 0x04,
                0x19, 0xb4, 0x54, 0x2e, 0xe6, 0xd5, 0xa2, 0xf5, 0x2b, 0x3f, 0x5e, 0x78, 0xc1, 0x6a,
                0xb2, 0x82, 0x36, 0x08, 0x64, 0x13,
            ],
            ock: [
                0xaf, 0x84, 0x6d, 0x19, 0x0a, 0x3b, 0xbd, 0xfd, 0x01, 0xff, 0x1d, 0xca, 0x3f, 0xd2,
                0xac, 0x94, 0xb1, 0x0f, 0x23, 0x11, 0x20, 0x49, 0x8f, 0x25, 0x8f, 0x0d, 0x4e, 0x01,
                0xd7, 0x48, 0x55, 0xa1,
            ],
            op: [
                0xcf, 0xaf, 0xc9, 0x38, 0xab, 0x44, 0x30, 0xaa, 0xc4, 0xdc, 0xcb, 0x35, 0x13, 0x1c,
                0x39, 0x1e, 0x60, 0x32, 0x84, 0x13, 0xb4, 0x32, 0x98, 0x7a, 0x01, 0x8b, 0x5b, 0x7c,
                0xf9, 0xbb, 0x31, 0xa0, 0xbd, 0x8f, 0x56, 0xa3, 0xf4, 0xf0, 0x9c, 0xbc, 0x87, 0xbb,
                0xcf, 0xe7, 0x7e, 0x60, 0x40, 0x60, 0x73, 0x46, 0xb4, 0x67, 0xaa, 0x5d, 0x00, 0x4e,
                0xe4, 0xe4, 0xb0, 0xff, 0xcc, 0xcf, 0x86, 0x2c,
            ],
            c_out: [
                0xc5, 0xad, 0x61, 0x31, 0x7b, 0x7b, 0xd1, 0x6d, 0x24, 0xd0, 0xc8, 0x9d, 0x6b, 0x7e,
                0x14, 0xb2, 0x68, 0x72, 0x0f, 0xd4, 0xe8, 0xb4, 0x41, 0x19, 0x1b, 0x47, 0x4d, 0xed,
                0xb1, 0xbf, 0x9d, 0xbe, 0x59, 0x7a, 0xf3, 0x99, 0xfa, 0xc4, 0x55, 0xd9, 0x00, 0xb3,
                0x39, 0x2b, 0x8c, 0xf6, 0x93, 0x3d, 0x74, 0xb6, 0xe4, 0x47, 0x34, 0x85, 0x95, 0x8f,
                0x41, 0xdd, 0x4b, 0x86, 0xd2, 0x37, 0xfa, 0xef, 0x3f, 0x5e, 0x58, 0xab, 0xda, 0x3f,
                0x5e, 0xc0, 0x7b, 0xe0, 0x81, 0x60, 0x9d, 0xc7, 0x5f, 0x48,
            ],
        },
        TestVector {
            incoming_viewing_key: [
                0xab, 0x9a, 0xdc, 0x10, 0x52, 0xec, 0x33, 0x16, 0xba, 0x8a, 0xd1, 0x07, 0x82, 0x17,
                0xe2, 0x90, 0x94, 0x58, 0x6e, 0xe7, 0x64, 0x61, 0xf6, 0x92, 0x6e, 0x98, 0xa2, 0xfa,
                0x31, 0xed, 0x02, 0xf9, 0x1a, 0xec, 0x98, 0x42, 0x69, 0xe5, 0xa6, 0xe9, 0xe9, 0x98,
                0xb7, 0xe9, 0x19, 0x8d, 0x29, 0xe2, 0xa2, 0x59, 0x25, 0x9f, 0xd2, 0x91, 0x94, 0x67,
                0xb5, 0x0e, 0xe4, 0xaf, 0x47, 0xc7, 0x80, 0x22,
            ],
            ovk: [
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
                0x00, 0x00, 0x00, 0x00,
            ],
            default_d: [
                0x44, 0xad, 0x8c, 0x86, 0xeb, 0x07, 0xd2, 0x56, 0xef, 0x76, 0xfa,
            ],
            default_pk_d: [
                0x9a, 0x2e, 0xd9, 0xe2, 0x4e, 0xa1, 0x03, 0xab, 0x9a, 0x22, 0xe1, 0x29, 0xbd, 0x96,
                0xb6, 0x51, 0x62, 0xb6, 0x71, 0x17, 0x2b, 0x94, 0x93, 0x83, 0x81, 0xda, 0xf8, 0x8a,
                0xfe, 0x0b, 0x9f, 0x83,
            ],
            v: 1173411008555061269,
            rseed: [
                0x6e, 0x68, 0xf3, 0x7b, 0xf6, 0xf3, 0xac, 0x2d, 0x26, 0xb8, 0x46, 0x86, 0xe5, 0x69,
                0xd5, 0x8d, 0x99, 0xc1, 0x38, 0x35, 0x97, 0xfa, 0xd8, 0x11, 0x93, 0xc4, 0xc1, 0xb1,
                0x6e, 0x6a, 0x90, 0xe2,
            ],
            memo: [
                0xff, 0xd5, 0x07, 0xcd, 0xfe, 0x6f, 0xbd, 0xaa, 0x86, 0x16, 0x3e, 0x9c, 0xf5, 0xde,
                0x31, 0x00, 0xfb, 0xca, 0x7e, 0x8d, 0xa0, 0x47, 0xb0, 0x90, 0xdb, 0x9f, 0x37, 0x95,
                0x2f, 0xbf, 0xee, 0x76, 0xaf, 0x61, 0x66, 0x81, 0x90, 0xbd, 0x52, 0xed, 0x49, 0x0e,
                0x67, 0x7b, 0x51, 0x5d, 0x01, 0x43, 0x84, 0xaf, 0x07, 0x21, 0x9c, 0x7c, 0x0e, 0xe7,
                0xfc, 0x7b, 0xfc, 0x79, 0xf3, 0x25, 0x64, 0x4e, 0x4d, 0xf4, 0xc0, 0xd7, 0xdb, 0x08,
                0xe9, 0xf0, 0xbd, 0x02, 0x49, 0x43, 0xc7, 0x05, 0xab, 0xff, 0x89, 0x94, 0xbf, 0xa6,
                0x05, 0xcf, 0xbc, 0x7e, 0xd7, 0x46, 0xa7, 0xd3, 0xf7, 0xc3, 0x7d, 0x9e, 0x8b, 0xdc,
                0x43, 0x3b, 0x7d, 0x79, 0xe0, 0x8a, 0x12, 0xf7, 0x38, 0xa8, 0xf0, 0xdb, 0xdd, 0xfe,
                0xf2, 0xf2, 0x65, 0x7e, 0xf3, 0xe4, 0x7d, 0x1b, 0x0f, 0xd1, 0x1e, 0x6a, 0x13, 0x31,
                0x1f, 0xb7, 0x99, 0xc7, 0x9c, 0x64, 0x1d, 0x9d, 0xa4, 0x3b, 0x33, 0xe7, 0xad, 0x01,
                0x2e, 0x28, 0x25, 0x53, 0x98, 0x78, 0x92, 0x62, 0x27, 0x5f, 0x11, 0x75, 0xbe, 0x84,
                0x62, 0xc0, 0x14, 0x91, 0xc4, 0xd8, 0x42, 0x40, 0x6d, 0x0e, 0xc4, 0x28, 0x2c, 0x95,
                0x26, 0x17, 0x4a, 0x09, 0x87, 0x8f, 0xe8, 0xfd, 0xde, 0x33, 0xa2, 0x96, 0x04, 0xe5,
                0xe5, 0xe7, 0xb2, 0xa0, 0x25, 0xd6, 0x65, 0x0b, 0x97, 0xdb, 0xb5, 0x2b, 0xef, 0xb5,
                0x9b, 0x1d, 0x30, 0xa5, 0x74, 0x33, 0xb0, 0xa3, 0x51, 0x47, 0x44, 0x44, 0x09, 0x9d,
                0xaa, 0x37, 0x10, 0x46, 0x61, 0x32, 0x60, 0xcf, 0x33, 0x54, 0xcf, 0xcd, 0xad, 0xa6,
                0x63, 0xec, 0xe8, 0x24, 0xff, 0xd7, 0xe4, 0x43, 0x93, 0x88, 0x6a, 0x86, 0x16, 0x5d,
                0xdd, 0xdf, 0x2b, 0x4c, 0x41, 0x77, 0x35, 0x54, 0xc8, 0x69, 0x95, 0x26, 0x94, 0x08,
                0xb1, 0x1e, 0x67, 0x37, 0xa4, 0xc4, 0x47, 0x58, 0x6f, 0x69, 0x17, 0x34, 0x46, 0xd8,
                0xe4, 0x8b, 0xf8, 0x4c, 0xbc, 0x00, 0x0a, 0x80, 0x78, 0x99, 0x97, 0x3e, 0xb9, 0x3c,
                0x5e, 0x81, 0x9a, 0xad, 0x66, 0x94, 0x13, 0xf8, 0x38, 0x79, 0x33, 0xad, 0x15, 0x84,
                0xaa, 0x35, 0xe4, 0x3f, 0x4e, 0xcd, 0x1e, 0x2d, 0x04, 0x07, 0xc0, 0xb1, 0xb8, 0x99,
                0x20, 0xff, 0xdf, 0xdb, 0x9b, 0xea, 0x51, 0xac, 0x95, 0xb5, 0x57, 0xaf, 0x71, 0xb8,
                0x9f, 0x90, 0x3f, 0x5d, 0x98, 0x48, 0xf1, 0x4f, 0xcb, 0xeb, 0x18, 0x37, 0x57, 0x0f,
                0x54, 0x4d, 0x63, 0x59, 0xeb, 0x23, 0xfa, 0xf3, 0x8a, 0x08, 0x22, 0xda, 0x36, 0xce,
                0x42, 0x6c, 0x4a, 0x2f, 0xbe, 0xff, 0xeb, 0x0a, 0x8a, 0x2e, 0x29, 0x7a, 0x9d, 0x19,
                0xba, 0x15, 0x02, 0x45, 0x90, 0xe3, 0x32, 0x9d, 0x9f, 0xa9, 0x26, 0x1f, 0x99, 0x38,
                0xa4, 0x03, 0x2d, 0xd3, 0x46, 0x06, 0xc9, 0xcf, 0x9f, 0x3d, 0xd3, 0x3e, 0x57, 0x6f,
                0x05, 0xcd, 0x1d, 0xd6, 0x81, 0x1c, 0x62, 0x98, 0x75, 0x7d, 0x77, 0xd9, 0xe8, 0x10,
                0xab, 0xdb, 0x22, 0x6a, 0xfc, 0xaa, 0x43, 0x46, 0xa6, 0x56, 0x0f, 0x89, 0x32, 0xb3,
                0x18, 0x1f, 0xd3, 0x55, 0xd5, 0xd3, 0x91, 0x97, 0x61, 0x83, 0xf8, 0xd9, 0x93, 0x88,
                0x83, 0x96, 0x32, 0xd6, 0x35, 0x4f, 0x66, 0x6d, 0x09, 0xd3, 0xe5, 0x62, 0x9e, 0xa1,
                0x97, 0x37, 0x38, 0x86, 0x13, 0xd3, 0x8a, 0x34, 0xfd, 0x0f, 0x6e, 0x50, 0xee, 0x5a,
                0x0c, 0xc9, 0x67, 0x71, 0x77, 0xf5, 0x00, 0x28, 0xc1, 0x41, 0x37, 0x81, 0x87, 0xbd,
                0x28, 0x19, 0x40, 0x3f, 0xc5, 0x34, 0xf8, 0x00, 0x76, 0xe9, 0x38, 0x0c, 0xb4, 0x96,
                0x4d, 0x3b, 0x6b, 0x45, 0x81, 0x9d, 0x3b, 0x8e, 0x9c, 0xaf, 0x54, 0xf0, 0x51, 0x85,
                0x2d, 0x67, 0x1b, 0xf8, 0xc1, 0xff, 0xde, 0x2d,
            ],
            cv_net: [
                0xba, 0x2f, 0x83, 0x52, 0x5e, 0xce, 0x08, 0x4c, 0xb5, 0x39, 0x93, 0xa8, 0xe6, 0xd1,
                0x6a, 0xd9, 0xcd, 0x73, 0xef, 0x32, 0x70, 0x5f, 0xee, 0xef, 0x11, 0x00, 0x0a, 0x31,
                0x00, 0x41, 0x97, 0x8e,
            ],
            rho: [
                0xc8, 0x8d, 0x00, 0x84, 0x84, 0xc5, 0xd7, 0x98, 0x20, 0xab, 0x68, 0xc6, 0x7d, 0x08,
                0x36, 0x72, 0xb0, 0x7f, 0x72, 0x7d, 0x44, 0xd0, 0xcd, 0x14, 0x73, 0x88, 0x00, 0xf8,
                0x25, 0xb9, 0xff, 0x16,
            ],
            cmx: [
                0x1a, 0x08, 0x83, 0x57, 0x98, 0x16, 0xf7, 0x99, 0x4b, 0xda, 0x6f, 0xb9, 0xe8, 0xb7,
                0x46, 0x3e, 0x67, 0xa3, 0x1f, 0xa3, 0x9b, 0x20, 0xb1, 0xf4, 0xdf, 0x11, 0x3b, 0xd7,
                0x25, 0x4f, 0x5b, 0x16,
            ],
            esk: [
                0x09, 0xea, 0x0c, 0xf8, 0x8d, 0xed, 0xc0, 0x82, 0xe9, 0xcd, 0xc8, 0x91, 0x99, 0xc7,
                0x31, 0x9a, 0xc7, 0x4b, 0xe1, 0xdb, 0xbe, 0x70, 0x31, 0xd8, 0xe0, 0x09, 0xa0, 0x47,
                0x0a, 0xec, 0x0a, 0x26,
            ],
            ephemeral_key: [
                0x10, 0x61, 0xe7, 0x54, 0x29, 0x6e, 0xa3, 0xc7, 0xbb, 0x4d, 0x91, 0x6c, 0x84, 0xf4,
                0x0b, 0xaa, 0xaa, 0xf3, 0x40, 0x9c, 0x30, 0x55, 0x3d, 0x2b, 0xaa, 0x9a, 0xa5, 0x8d,
                0x6a, 0x70, 0xf2, 0x0e,
            ],
            shared_secret: [
                0xd4, 0x4c, 0xcf, 0x4c, 0xd7, 0x43, 0x8b, 0x5b, 0x7c, 0x68, 0x39, 0xeb, 0x4c, 0xcc,
                0x17, 0x38, 0xae, 0x53, 0x45, 0x4a, 0x27, 0xb9, 0x63, 0x45, 0x95, 0xa7, 0xc5, 0x3f,
                0x60, 0xa3, 0xca, 0x92,
            ],
            k_enc: [
                0xd4, 0x4d, 0x3a, 0xcf, 0x29, 0x3d, 0xbe, 0x61, 0x1c, 0xe6, 0xf6, 0xdf, 0x1f, 0xcb,
                0xcb, 0xee, 0x4b, 0x17, 0x27, 0x40, 0x39, 0x2d, 0xcf, 0x50, 0x4c, 0xad, 0xc3, 0xf9,
                0x29, 0xa3, 0x9d, 0x70,
            ],
            p_enc: [
                0x02, 0x44, 0xad, 0x8c, 0x86, 0xeb, 0x07, 0xd2, 0x56, 0xef, 0x76, 0xfa, 0x15, 0x10,
                0x75, 0x64, 0x18, 0xcb, 0x48, 0x10, 0x6e, 0x68, 0xf3, 0x7b, 0xf6, 0xf3, 0xac, 0x2d,
                0x26, 0xb8, 0x46, 0x86, 0xe5, 0x69, 0xd5, 0x8d, 0x99, 0xc1, 0x38, 0x35, 0x97, 0xfa,
                0xd8, 0x11, 0x93, 0xc4, 0xc1, 0xb1, 0x6e, 0x6a, 0x90, 0xe2, 0xff, 0xd5, 0x07, 0xcd,
                0xfe, 0x6f, 0xbd, 0xaa, 0x86, 0x16, 0x3e, 0x9c, 0xf5, 0xde, 0x31, 0x00, 0xfb, 0xca,
                0x7e, 0x8d, 0xa0, 0x47, 0xb0, 0x90, 0xdb, 0x9f, 0x37, 0x95, 0x2f, 0xbf, 0xee, 0x76,
                0xaf, 0x61, 0x66, 0x81, 0x90, 0xbd, 0x52, 0xed, 0x49, 0x0e, 0x67, 0x7b, 0x51, 0x5d,
                0x01, 0x43, 0x84, 0xaf, 0x07, 0x21, 0x9c, 0x7c, 0x0e, 0xe7, 0xfc, 0x7b, 0xfc, 0x79,
                0xf3, 0x25, 0x64, 0x4e, 0x4d, 0xf4, 0xc0, 0xd7, 0xdb, 0x08, 0xe9, 0xf0, 0xbd, 0x02,
                0x49, 0x43, 0xc7, 0x05, 0xab, 0xff, 0x89, 0x94, 0xbf, 0xa6, 0x05, 0xcf, 0xbc, 0x7e,
                0xd7, 0x46, 0xa7, 0xd3, 0xf7, 0xc3, 0x7d, 0x9e, 0x8b, 0xdc, 0x43, 0x3b, 0x7d, 0x79,
                0xe0, 0x8a, 0x12, 0xf7, 0x38, 0xa8, 0xf0, 0xdb, 0xdd, 0xfe, 0xf2, 0xf2, 0x65, 0x7e,
                0xf3, 0xe4, 0x7d, 0x1b, 0x0f, 0xd1, 0x1e, 0x6a, 0x13, 0x31, 0x1f, 0xb7, 0x99, 0xc7,
                0x9c, 0x64, 0x1d, 0x9d, 0xa4, 0x3b, 0x33, 0xe7, 0xad, 0x01, 0x2e, 0x28, 0x25, 0x53,
                0x98, 0x78, 0x92, 0x62, 0x27, 0x5f, 0x11, 0x75, 0xbe, 0x84, 0x62, 0xc0, 0x14, 0x91,
                0xc4, 0xd8, 0x42, 0x40, 0x6d, 0x0e, 0xc4, 0x28, 0x2c, 0x95, 0x26, 0x17, 0x4a, 0x09,
                0x87, 0x8f, 0xe8, 0xfd, 0xde, 0x33, 0xa2, 0x96, 0x04, 0xe5, 0xe5, 0xe7, 0xb2, 0xa0,
                0x25, 0xd6, 0x65, 0x0b, 0x97, 0xdb, 0xb5, 0x2b, 0xef, 0xb5, 0x9b, 0x1d, 0x30, 0xa5,
                0x74, 0x33, 0xb0, 0xa3, 0x51, 0x47, 0x44, 0x44, 0x09, 0x9d, 0xaa, 0x37, 0x10, 0x46,
                0x61, 0x32, 0x60, 0xcf, 0x33, 0x54, 0xcf, 0xcd, 0xad, 0xa6, 0x63, 0xec, 0xe8, 0x24,
                0xff, 0xd7, 0xe4, 0x43, 0x93, 0x88, 0x6a, 0x86, 0x16, 0x5d, 0xdd, 0xdf, 0x2b, 0x4c,
                0x41, 0x77, 0x35, 0x54, 0xc8, 0x69, 0x95, 0x26, 0x94, 0x08, 0xb1, 0x1e, 0x67, 0x37,
                0xa4, 0xc4, 0x47, 0x58, 0x6f, 0x69, 0x17, 0x34, 0x46, 0xd8, 0xe4, 0x8b, 0xf8, 0x4c,
                0xbc, 0x00, 0x0a, 0x80, 0x78, 0x99, 0x97, 0x3e, 0xb9, 0x3c, 0x5e, 0x81, 0x9a, 0xad,
                0x66, 0x94, 0x13, 0xf8, 0x38, 0x79, 0x33, 0xad, 0x15, 0x84, 0xaa, 0x35, 0xe4, 0x3f,
                0x4e, 0xcd, 0x1e, 0x2d, 0x04, 0x07, 0xc0, 0xb1, 0xb8, 0x99, 0x20, 0xff, 0xdf, 0xdb,
                0x9b, 0xea, 0x51, 0xac, 0x95, 0xb5, 0x57, 0xaf, 0x71, 0xb8, 0x9f, 0x90, 0x3f, 0x5d,
                0x98, 0x48, 0xf1, 0x4f, 0xcb, 0xeb, 0x18, 0x37, 0x57, 0x0f, 0x54, 0x4d, 0x63, 0x59,
                0xeb, 0x23, 0xfa, 0xf3, 0x8a, 0x08, 0x22, 0xda, 0x36, 0xce, 0x42, 0x6c, 0x4a, 0x2f,
                0xbe, 0xff, 0xeb, 0x0a, 0x8a, 0x2e, 0x29, 0x7a, 0x9d, 0x19, 0xba, 0x15, 0x02, 0x45,
                0x90, 0xe3, 0x32, 0x9d, 0x9f, 0xa9, 0x26, 0x1f, 0x99, 0x38, 0xa4, 0x03, 0x2d, 0xd3,
                0x46, 0x06, 0xc9, 0xcf, 0x9f, 0x3d, 0xd3, 0x3e, 0x57, 0x6f, 0x05, 0xcd, 0x1d, 0xd6,
                0x81, 0x1c, 0x62, 0x98, 0x75, 0x7d, 0x77, 0xd9, 0xe8, 0x10, 0xab, 0xdb, 0x22, 0x6a,
                0xfc, 0xaa, 0x43, 0x46, 0xa6, 0x56, 0x0f, 0x89, 0x32, 0xb3, 0x18, 0x1f, 0xd3, 0x55,
                0xd5, 0xd3, 0x91, 0x97, 0x61, 0x83, 0xf8, 0xd9, 0x93, 0x88, 0x83, 0x96, 0x32, 0xd6,
                0x35, 0x4f, 0x66, 0x6d, 0x09, 0xd3, 0xe5, 0x62, 0x9e, 0xa1, 0x97, 0x37, 0x38, 0x86,
                0x13, 0xd3, 0x8a, 0x34, 0xfd, 0x0f, 0x6e, 0x50, 0xee, 0x5a, 0x0c, 0xc9, 0x67, 0x71,
                0x77, 0xf5, 0x00, 0x28, 0xc1, 0x41, 0x37, 0x81, 0x87, 0xbd, 0x28, 0x19, 0x40, 0x3f,
                0xc5, 0x34, 0xf8, 0x00, 0x76, 0xe9, 0x38, 0x0c, 0xb4, 0x96, 0x4d, 0x3b, 0x6b, 0x45,
                0x81, 0x9d, 0x3b, 0x8e, 0x9c, 0xaf, 0x54, 0xf0, 0x51, 0x85, 0x2d, 0x67, 0x1b, 0xf8,
                0xc1, 0xff, 0xde, 0x2d,
            ],
            c_enc: [
                0xef, 0x9e, 0x87, 0x36, 0x54, 0xd7, 0xca, 0x53, 0xfd, 0xf0, 0xf8, 0x35, 0x46, 0x56,
                0x28, 0x2f, 0xc6, 0xa0, 0x6a, 0xf6, 0x4b, 0x95, 0x67, 0x4e, 0x8c, 0xf4, 0x2b, 0x4c,
                0x32, 0x6a, 0x90, 0x6b, 0xfe, 0xa8, 0xdc, 0x09, 0xbf, 0xd4, 0x3f, 0x96, 0xef, 0x82,
                0x93, 0xf1, 0x50, 0x60, 0x28, 0x38, 0xc7, 0x2b, 0x8e, 0x34, 0xc7, 0x6b, 0x11, 0xfd,
                0xb1, 0xeb, 0x9d, 0x62, 0x5f, 0xe4, 0xc5, 0x43, 0x8d, 0xf3, 0x96, 0x2a, 0x30, 0xf8,
                0x91, 0x0d, 0xe7, 0x68, 0xc6, 0x24, 0x01, 0x31, 0x0b, 0xf8, 0xcc, 0xd5, 0x1e, 0xd7,
                0xdd, 0x62, 0x38, 0xa3, 0x77, 0x12, 0x51, 0x4d, 0x46, 0xd0, 0x95, 0xa6, 0xce, 0x65,
                0x4f, 0x05, 0x11, 0x29, 0x66, 0xf2, 0xb5, 0xdf, 0xfa, 0x70, 0x5c, 0x29, 0x24, 0x4c,
                0xab, 0xbd, 0x15, 0xd3, 0xb9, 0x2a, 0xb3, 0x0b, 0x37, 0x8a, 0x7b, 0xe1, 0x35, 0xb1,
                0x72, 0xd8, 0xb6, 0x35, 0x6c, 0x77, 0xc7, 0x42, 0x2d, 0x67, 0xa0, 0xe0, 0x1e, 0x68,
                0x78, 0x78, 0x78, 0x7e, 0x06, 0x8c, 0x66, 0x7d, 0xdf, 0x1a, 0xe7, 0x60, 0x3d, 0xa2,
                0xbb, 0x4f, 0x1b, 0xc8, 0xe0, 0x30, 0x4a, 0x50, 0x3b, 0xa3, 0xae, 0xe3, 0xf1, 0xae,
                0xa4, 0x0f, 0xd8, 0x23, 0x53, 0x18, 0x61, 0xcc, 0xab, 0xf0, 0x7d, 0x87, 0x9a, 0x5e,
                0x69, 0x0e, 0x4a, 0xe3, 0x9f, 0x0b, 0x67, 0x7a, 0x2e, 0x1a, 0x22, 0xc8, 0x5a, 0xbb,
                0xd6, 0xd3, 0x71, 0xb5, 0xbb, 0xbc, 0x3c, 0xa3, 0x89, 0x67, 0xac, 0x75, 0xe2, 0x6b,
                0x8b, 0x85, 0x34, 0xbf, 0x50, 0x77, 0x84, 0x7e, 0x43, 0x1d, 0x51, 0x06, 0x2d, 0x9f,
                0x33, 0xc8, 0x41, 0xbf, 0x96, 0x01, 0xd2, 0x65, 0x05, 0xca, 0x56, 0x89, 0x9e, 0x19,
                0x20, 0x97, 0xe4, 0x67, 0xcf, 0x7c, 0x07, 0x4e, 0xdf, 0xab, 0x25, 0xb2, 0xb2, 0x50,
                0x02, 0x75, 0x54, 0xb6, 0x56, 0x71, 0x07, 0xf8, 0xda, 0x17, 0x75, 0xcf, 0x4e, 0x55,
                0x8c, 0x2c, 0xc6, 0x6c, 0xed, 0x41, 0xe0, 0x45, 0xff, 0x0e, 0xdb, 0xfd, 0xed, 0x4b,
                0x78, 0x02, 0x8c, 0xca, 0x3a, 0xa0, 0x3e, 0xb6, 0xfd, 0x82, 0x48, 0xd3, 0xbf, 0x52,
                0xc4, 0x5b, 0x75, 0x95, 0x37, 0x2d, 0xf2, 0x1a, 0xa5, 0xfb, 0x0b, 0x22, 0x1d, 0xfc,
                0x9d, 0xca, 0x86, 0x39, 0x6a, 0xfd, 0x60, 0xe0, 0x7c, 0x7d, 0x97, 0xee, 0xa4, 0x39,
                0x55, 0x5f, 0x25, 0x72, 0x9b, 0xd7, 0x25, 0x41, 0x7f, 0x39, 0x8f, 0x2a, 0xc8, 0xba,
                0x0b, 0x4b, 0xa8, 0xab, 0xbe, 0x56, 0x89, 0xbc, 0x38, 0xae, 0xa1, 0x91, 0x35, 0x49,
                0x3d, 0x56, 0x47, 0xda, 0xce, 0x63, 0x8f, 0x3b, 0xf2, 0xe4, 0xec, 0x3e, 0xfc, 0x32,
                0xce, 0xdd, 0xe3, 0xae, 0x01, 0x34, 0x60, 0x6b, 0xd5, 0xe5, 0xb6, 0xaf, 0xac, 0xbe,
                0x3c, 0x83, 0x10, 0x6b, 0xf3, 0x17, 0x75, 0xbb, 0x18, 0x54, 0xb4, 0xf1, 0x7f, 0x9b,
                0xfa, 0x2a, 0xd2, 0xb6, 0x2c, 0x73, 0xb5, 0x89, 0x0c, 0xa3, 0xc0, 0x98, 0x5f, 0x0e,
                0x10, 0xf6, 0xc4, 0xb9, 0x5b, 0x04, 0x5c, 0x56, 0x21, 0xb4, 0xf2, 0xd2, 0xa3, 0x20,
                0x4d, 0xb7, 0x24, 0x41, 0xda, 0x7d, 0x92, 0xd1, 0x8b, 0x2b, 0x21, 0x5f, 0x6e, 0x83,
                0x75, 0x88, 0x1e, 0x8c, 0xbf, 0xbd, 0x39, 0xc0, 0xc7, 0x5a, 0x8b, 0x69, 0xc9, 0x9f,
                0xb7, 0xee, 0x3e, 0x5b, 0x16, 0xc8, 0x74, 0x77, 0x36, 0xc7, 0xcc, 0xaf, 0x99, 0x80,
                0xbc, 0x6c, 0x90, 0x69, 0xf0, 0x82, 0x6f, 0x83, 0x8b, 0xd7, 0x0b, 0xfb, 0x20, 0xb9,
                0xa8, 0xbb, 0x6e, 0x1a, 0xa5, 0x42, 0x87, 0x75, 0xe0, 0xc6, 0x6a, 0xb2, 0xe8, 0x5b,
                0xd3, 0xef, 0x2c, 0xc9, 0x4d, 0x9c, 0x9b, 0xa6, 0x91, 0x6f, 0x29, 0xd6, 0x57, 0xd2,
                0x26, 0x8b, 0x8d, 0xc6, 0xd7, 0xde, 0xd1, 0x90, 0xad, 0xc0, 0x02, 0x3c, 0xf3, 0xf7,
                0x5c, 0x5a, 0x13, 0x9b, 0x42, 0xd9, 0x8a, 0xd0, 0x76, 0x52, 0x2e, 0xe5, 0x0a, 0x6c,
                0x84, 0xcc, 0xa0, 0xe8, 0xaa, 0xfe, 0x4f, 0xda, 0x1d, 0x69, 0x47, 0xd5, 0x41, 0x25,
                0x21, 0xc8, 0x54, 0x04, 0x9b, 0xbe, 0x97, 0xfb, 0xcb, 0x58, 0xcd, 0xfe, 0xe0, 0x17,
                0xf5, 0xb5, 0x5a, 0x9b, 0x26, 0x23, 0x38, 0xae, 0xbc, 0xd9, 0xaf, 0xbf, 0x2e, 0xc3,
                0xcf, 0xd7, 0x94, 0x51, 0xbc, 0x7d,
            ],
            ock: [
                0xc4, 0xd2, 0x3b, 0xc1, 0x41, 0x8b, 0x0a, 0x29, 0x73, 0x13, 0xf3, 0x03, 0x51, 0x57,
                0xd9, 0x3d, 0x5e, 0x72, 0x0d, 0xfb, 0x3a, 0xa0, 0x5a, 0x06, 0xca, 0xcf, 0xac, 0x07,
                0xc0, 0x8d, 0xe6, 0x0e,
            ],
            op: [
                0x9a, 0x2e, 0xd9, 0xe2, 0x4e, 0xa1, 0x03, 0xab, 0x9a, 0x22, 0xe1, 0x29, 0xbd, 0x96,
                0xb6, 0x51, 0x62, 0xb6, 0x71, 0x17, 0x2b, 0x94, 0x93, 0x83, 0x81, 0xda, 0xf8, 0x8a,
                0xfe, 0x0b, 0x9f, 0x83, 0x09, 0xea, 0x0c, 0xf8, 0x8d, 0xed, 0xc0, 0x82, 0xe9, 0xcd,
                0xc8, 0x91, 0x99, 0xc7, 0x31, 0x9a, 0xc7, 0x4b, 0xe1, 0xdb, 0xbe, 0x70, 0x31, 0xd8,
                0xe0, 0x09, 0xa0, 0x47, 0x0a, 0xec, 0x0a, 0x26,
            ],
            c_out: [
                0x00, 0x64, 0x77, 0x26, 0xd0, 0x9d, 0x64, 0xc1, 0xd1, 0x23, 0x42, 0xfa, 0xca, 0x1d,
                0x39, 0x24, 0x95, 0xbe, 0x31, 0xc4, 0x42, 0x1b, 0x18, 0x38, 0x99, 0xc7, 0x1c, 0xf6,
                0x8b, 0x22, 0x27, 0x79, 0x2f, 0xc8, 0x29, 0xf2, 0x14, 0xf7, 0x46, 0xc7, 0x66, 0x6c,
                0x3f, 0x12, 0xc8, 0xed, 0x63, 0xb0, 0x51, 0x6f, 0xce, 0xac, 0x98, 0x81, 0x16, 0x60,
                0x37, 0xe5, 0x7a, 0x93, 0xe4, 0x86, 0x2d, 0x99, 0xae, 0xc6, 0x9d, 0x4e, 0xda, 0xbd,
                0xd0, 0x66, 0x42, 0x04, 0x88, 0xce, 0x35, 0x89, 0xcc, 0x6e,
            ],
        },
        TestVector {
            incoming_viewing_key: [
                0xe6, 0xd4, 0xfe, 0x5b, 0x6b, 0x2a, 0xe9, 0xe4, 0x8b, 0x73, 0xa1, 0x5f, 0xef, 0x1d,
                0xc8, 0x03, 0xac, 0xf4, 0x62, 0x53, 0x13, 0xb7, 0xec, 0x40, 0x04, 0x17, 0x6e, 0xed,
                0xf0, 0xbc, 0x0b, 0xae, 0xdc, 0x25, 0xbb, 0x88, 0x8e, 0x3f, 0x55, 0xa4, 0xd4, 0x28,
                0xa4, 0xae, 0x71, 0xcb, 0x03, 0xcb, 0x2a, 0x58, 0xa1, 0xc4, 0x69, 0x22, 0xc1, 0x3b,
                0xe9, 0x11, 0x35, 0x38, 0x3a, 0x67, 0xaf, 0x3c,
            ],
            ovk: [
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
                0x00, 0x00, 0x00, 0x00,
            ],
            default_d: [
                0xf6, 0x87, 0x91, 0x7d, 0x5d, 0x3c, 0xd1, 0x8f, 0x38, 0x48, 0x99,
            ],
            default_pk_d: [
                0x93, 0x96, 0x68, 0xe5, 0x01, 0xc2, 0x83, 0x87, 0xc0, 0xbd, 0x33, 0x5e, 0x95, 0x46,
                0x92, 0xc9, 0x05, 0xcd, 0x42, 0xb0, 0xf0, 0xd5, 0x48, 0x39, 0x23, 0x41, 0xd4, 0x96,
                0x14, 0x7a, 0x3e, 0x31,
            ],
            v: 9133066973574047943,
            rseed: [
                0x1a, 0xbd, 0xcb, 0xd4, 0x9f, 0xe4, 0xf8, 0x5b, 0x62, 0x3c, 0x78, 0x28, 0xc7, 0x13,
                0x82, 0xe1, 0x03, 0x4e, 0xa6, 0x7b, 0xc8, 0xae, 0x97, 0x40, 0x4b, 0x0c, 0x50, 0xb2,
                0xa0, 0x4f, 0x55, 0x9e,
            ],
            memo: [
                0xff, 0x49, 0x95, 0x0a, 0xfc, 0xb0, 0xef, 0x46, 0x2a, 0x2a, 0xe0, 0x24, 0xb0, 0xf0,
                0x22, 0x4d, 0xfd, 0x73, 0x68, 0x4b, 0x88, 0xc7, 0xfb, 0xe9, 0x2d, 0x02, 0xb6, 0x8f,
                0x75, 0x9c, 0x47, 0x52, 0x66, 0x3c, 0xd7, 0xb9, 0x7a, 0x14, 0x94, 0x36, 0x49, 0x30,
                0x55, 0x21, 0x32, 0x6b, 0xde, 0x08, 0x56, 0x30, 0x86, 0x46, 0x29, 0x29, 0x1b, 0xae,
                0x25, 0xff, 0x88, 0x22, 0xa1, 0x4c, 0x4b, 0x66, 0x6a, 0x92, 0x59, 0xad, 0x0d, 0xc4,
                0x2a, 0x82, 0x90, 0xac, 0x7b, 0xc7, 0xf5, 0x3a, 0x16, 0xf3, 0x79, 0xf7, 0x58, 0xe5,
                0xde, 0x75, 0x0f, 0x04, 0xfd, 0x7c, 0xad, 0x47, 0x70, 0x1c, 0x85, 0x97, 0xf9, 0x78,
                0x88, 0xbe, 0xa6, 0xfa, 0x0b, 0xf2, 0x99, 0x99, 0x56, 0xfb, 0xfd, 0x0e, 0xe6, 0x8e,
                0xc3, 0x6e, 0x46, 0x88, 0x80, 0x9a, 0xe2, 0x31, 0xeb, 0x8b, 0xc4, 0x36, 0x9f, 0x5f,
                0xe1, 0x57, 0x3f, 0x57, 0xe0, 0x99, 0xd9, 0xc0, 0x99, 0x01, 0xbf, 0x39, 0xca, 0xac,
                0x48, 0xdc, 0x11, 0x95, 0x6a, 0x8a, 0xe9, 0x05, 0xea, 0xd8, 0x69, 0x54, 0x54, 0x7c,
                0x44, 0x8a, 0xe4, 0x3d, 0x31, 0x5e, 0x66, 0x9c, 0x42, 0x42, 0xda, 0x56, 0x59, 0x38,
                0xf4, 0x17, 0xbf, 0x43, 0xce, 0x7b, 0x2b, 0x30, 0xb1, 0xcd, 0x40, 0x18, 0x38, 0x8e,
                0x1a, 0x91, 0x0f, 0x0f, 0xc4, 0x1f, 0xb0, 0x87, 0x7a, 0x59, 0x25, 0xe4, 0x66, 0x81,
                0x9d, 0x37, 0x5b, 0x0a, 0x91, 0x2d, 0x4f, 0xe8, 0x43, 0xb7, 0x6e, 0xf6, 0xf2, 0x23,
                0xf0, 0xf7, 0xc8, 0x94, 0xf3, 0x8f, 0x7a, 0xb7, 0x80, 0xdf, 0xd7, 0x5f, 0x66, 0x9c,
                0x8c, 0x06, 0xcf, 0xfa, 0x43, 0xeb, 0x47, 0x56, 0x5a, 0x50, 0xe3, 0xb1, 0xfa, 0x45,
                0xad, 0x61, 0xce, 0x9a, 0x1c, 0x47, 0x27, 0xb7, 0xaa, 0xa5, 0x35, 0x62, 0xf5, 0x23,
                0xe7, 0x39, 0x52, 0xbb, 0xf3, 0x3d, 0x8a, 0x41, 0x04, 0x07, 0x8a, 0xde, 0x3e, 0xaa,
                0xa4, 0x96, 0x99, 0xa6, 0x9f, 0xdf, 0x1c, 0x5a, 0xc7, 0x73, 0x21, 0x46, 0xee, 0x5e,
                0x1d, 0x6b, 0x6c, 0xa9, 0xb9, 0x18, 0x0f, 0x96, 0x4c, 0xc9, 0xd0, 0x87, 0x8a, 0xe1,
                0x37, 0x35, 0x24, 0xd7, 0xd5, 0x10, 0xe5, 0x82, 0x27, 0xdf, 0x6d, 0xe9, 0xd3, 0x0d,
                0x27, 0x18, 0x67, 0x64, 0x01, 0x77, 0xb0, 0xf1, 0x85, 0x6e, 0x28, 0xd5, 0xc8, 0xaf,
                0xb0, 0x95, 0xef, 0x61, 0x84, 0xfe, 0xd6, 0x51, 0x58, 0x90, 0x22, 0xee, 0xae, 0xa4,
                0xc0, 0xce, 0x1f, 0xa6, 0xf0, 0x85, 0x09, 0x2b, 0x04, 0x97, 0x94, 0x89, 0x17, 0x2b,
                0x3e, 0xf8, 0x19, 0x4a, 0x79, 0x8d, 0xf5, 0x72, 0x4d, 0x6b, 0x05, 0xf1, 0xae, 0x00,
                0x00, 0x13, 0xa0, 0x8d, 0x61, 0x2b, 0xca, 0x8a, 0x8c, 0x31, 0x44, 0x3c, 0x10, 0x34,
                0x6d, 0xbf, 0x61, 0xde, 0x84, 0x75, 0xc0, 0xbb, 0xec, 0x51, 0x04, 0xb4, 0x75, 0x56,
                0xaf, 0x3d, 0x51, 0x44, 0x58, 0xe2, 0x32, 0x1d, 0x14, 0x60, 0x71, 0x78, 0x9d, 0x23,
                0x35, 0x93, 0x4a, 0x68, 0x06, 0x14, 0xe8, 0x35, 0x62, 0xf8, 0x2d, 0xfd, 0x40, 0x5b,
                0x54, 0xa4, 0x5e, 0xb3, 0x2c, 0x16, 0x54, 0x48, 0xd4, 0xd5, 0xd6, 0x1c, 0xa2, 0x85,
                0x95, 0x85, 0x36, 0x9f, 0x53, 0xf1, 0xa1, 0x37, 0xe9, 0xe8, 0x2b, 0x67, 0xb8, 0xfd,
                0xaf, 0x01, 0xbd, 0xa5, 0x4a, 0x31, 0x73, 0x11, 0x89, 0x6a, 0xe1, 0x02, 0x80, 0xa0,
                0x32, 0x44, 0x0c, 0x42, 0x0a, 0x42, 0x1e, 0x94, 0x4d, 0x1e, 0x95, 0x2b, 0x70, 0xd5,
                0x82, 0x6c, 0xd3, 0xb0, 0x8b, 0x7d, 0xb9, 0x63, 0x0f, 0xe4, 0xfd, 0x5f, 0x22, 0x12,
                0x5d, 0xe8, 0x40, 0xfc, 0xc4, 0x0b, 0x98, 0x03, 0x8a, 0xf1, 0x1d, 0x55, 0xbe, 0x25,
                0x43, 0x25, 0x97, 0xb4, 0xb6, 0x5b, 0x9e, 0xc1,
            ],
            cv_net: [
                0x9c, 0xa4, 0x28, 0xa4, 0xcc, 0x6e, 0xf8, 0xc8, 0xb2, 0x7b, 0x54, 0xa3, 0x6b, 0x39,
                0xff, 0x80, 0x43, 0x0a, 0xcb, 0xb9, 0xde, 0x55, 0xe4, 0x26, 0xd3, 0x6b, 0x40, 0x08,
                0x7e, 0xe7, 0x88, 0x3a,
            ],
            rho: [
                0xa9, 0x0a, 0x9b, 0x8a, 0xb1, 0x35, 0x9d, 0xc9, 0x6b, 0xda, 0xe9, 0x0e, 0x52, 0x74,
                0x78, 0x8c, 0xb0, 0xc4, 0x26, 0xef, 0xf2, 0x60, 0x43, 0x61, 0x85, 0x39, 0x8b, 0xff,
                0xf5, 0x0e, 0x92, 0x37,
            ],
            cmx: [
                0x9b, 0x8f, 0x7f, 0x23, 0xf9, 0x57, 0xea, 0x01, 0x6b, 0x2f, 0xb7, 0x29, 0x4a, 0xbd,
                0xcf, 0x9e, 0x00, 0x43, 0xa9, 0x72, 0xee, 0x69, 0xa4, 0xe8, 0xfe, 0xcc, 0x5d, 0xf7,
                0x66, 0xd0, 0xee, 0x15,
            ],
            esk: [
                0x2a, 0xbb, 0xc2, 0xe9, 0xf5, 0xa9, 0x78, 0x5f, 0x5a, 0x4f, 0x08, 0x87, 0x5e, 0x81,
                0x61, 0x71, 0x33, 0xe1, 0xf6, 0x26, 0x2b, 0x03, 0xa9, 0xfc, 0x15, 0x2e, 0x6b, 0xa4,
                0xbe, 0x8f, 0x52, 0x12,
            ],
            ephemeral_key: [
                0xb9, 0x62, 0x4b, 0xef, 0x3a, 0xd1, 0xb7, 0x36, 0x56, 0x8f, 0xc6, 0xba, 0xa9, 0xde,
                0x1f, 0xf2, 0x79, 0x97, 0xfb, 0x97, 0x4f, 0xcc, 0xbe, 0x0b, 0xc6, 0x86, 0xbd, 0xe4,
                0xd6, 0xcc, 0x67, 0x88,
            ],
            shared_secret: [
                0x27, 0xa9, 0x86, 0xa0, 0x46, 0x06, 0x4f, 0x90, 0x69, 0x93, 0xcf, 0x6a, 0x79, 0xbd,
                0x39, 0x1c, 0x60, 0xf7, 0x6e, 0x2a, 0xb3, 0x90, 0x62, 0x42, 0xd2, 0x95, 0x2f, 0xfd,
                0x8c, 0x83, 0x57, 0xbf,
            ],
            k_enc: [
                0x38, 0x24, 0x6a, 0xf2, 0xa7, 0x00, 0xbd, 0x67, 0xd3, 0xf2, 0x59, 0x5a, 0x5d, 0x84,
                0x53, 0x23, 0x28, 0x27, 0xcc, 0xf7, 0x1c, 0x36, 0x69, 0x7b, 0xa7, 0x12, 0x09, 0x68,
                0x1f, 0x47, 0x13, 0x10,
            ],
            p_enc: [
                0x02, 0xf6, 0x87, 0x91, 0x7d, 0x5d, 0x3c, 0xd1, 0x8f, 0x38, 0x48, 0x99, 0xc7, 0xa8,
                0xbb, 0xfd, 0x05, 0x2c, 0xbf, 0x7e, 0x1a, 0xbd, 0xcb, 0xd4, 0x9f, 0xe4, 0xf8, 0x5b,
                0x62, 0x3c, 0x78, 0x28, 0xc7, 0x13, 0x82, 0xe1, 0x03, 0x4e, 0xa6, 0x7b, 0xc8, 0xae,
                0x97, 0x40, 0x4b, 0x0c, 0x50, 0xb2, 0xa0, 0x4f, 0x55, 0x9e, 0xff, 0x49, 0x95, 0x0a,
                0xfc, 0xb0, 0xef, 0x46, 0x2a, 0x2a, 0xe0, 0x24, 0xb0, 0xf0, 0x22, 0x4d, 0xfd, 0x73,
                0x68, 0x4b, 0x88, 0xc7, 0xfb, 0xe9, 0x2d, 0x02, 0xb6, 0x8f, 0x75, 0x9c, 0x47, 0x52,
                0x66, 0x3c, 0xd7, 0xb9, 0x7a, 0x14, 0x94, 0x36, 0x49, 0x30, 0x55, 0x21, 0x32, 0x6b,
                0xde, 0x08, 0x56, 0x30, 0x86, 0x46, 0x29, 0x29, 0x1b, 0xae, 0x25, 0xff, 0x88, 0x22,
                0xa1, 0x4c, 0x4b, 0x66, 0x6a, 0x92, 0x59, 0xad, 0x0d, 0xc4, 0x2a, 0x82, 0x90, 0xac,
                0x7b, 0xc7, 0xf5, 0x3a, 0x16, 0xf3, 0x79, 0xf7, 0x58, 0xe5, 0xde, 0x75, 0x0f, 0x04,
                0xfd, 0x7c, 0xad, 0x47, 0x70, 0x1c, 0x85, 0x97, 0xf9, 0x78, 0x88, 0xbe, 0xa6, 0xfa,
                0x0b, 0xf2, 0x99, 0x99, 0x56, 0xfb, 0xfd, 0x0e, 0xe6, 0x8e, 0xc3, 0x6e, 0x46, 0x88,
                0x80, 0x9a, 0xe2, 0x31, 0xeb, 0x8b, 0xc4, 0x36, 0x9f, 0x5f, 0xe1, 0x57, 0x3f, 0x57,
                0xe0, 0x99, 0xd9, 0xc0, 0x99, 0x01, 0xbf, 0x39, 0xca, 0xac, 0x48, 0xdc, 0x11, 0x95,
                0x6a, 0x8a, 0xe9, 0x05, 0xea, 0xd8, 0x69, 0x54, 0x54, 0x7c, 0x44, 0x8a, 0xe4, 0x3d,
                0x31, 0x5e, 0x66, 0x9c, 0x42, 0x42, 0xda, 0x56, 0x59, 0x38, 0xf4, 0x17, 0xbf, 0x43,
                0xce, 0x7b, 0x2b, 0x30, 0xb1, 0xcd, 0x40, 0x18, 0x38, 0x8e, 0x1a, 0x91, 0x0f, 0x0f,
                0xc4, 0x1f, 0xb0, 0x87, 0x7a, 0x59, 0x25, 0xe4, 0x66, 0x81, 0x9d, 0x37, 0x5b, 0x0a,
                0x91, 0x2d, 0x4f, 0xe8, 0x43, 0xb7, 0x6e, 0xf6, 0xf2, 0x23, 0xf0, 0xf7, 0xc8, 0x94,
                0xf3, 0x8f, 0x7a, 0xb7, 0x80, 0xdf, 0xd7, 0x5f, 0x66, 0x9c, 0x8c, 0x06, 0xcf, 0xfa,
                0x43, 0xeb, 0x47, 0x56, 0x5a, 0x50, 0xe3, 0xb1, 0xfa, 0x45, 0xad, 0x61, 0xce, 0x9a,
                0x1c, 0x47, 0x27, 0xb7, 0xaa, 0xa5, 0x35, 0x62, 0xf5, 0x23, 0xe7, 0x39, 0x52, 0xbb,
                0xf3, 0x3d, 0x8a, 0x41, 0x04, 0x07, 0x8a, 0xde, 0x3e, 0xaa, 0xa4, 0x96, 0x99, 0xa6,
                0x9f, 0xdf, 0x1c, 0x5a, 0xc7, 0x73, 0x21, 0x46, 0xee, 0x5e, 0x1d, 0x6b, 0x6c, 0xa9,
                0xb9, 0x18, 0x0f, 0x96, 0x4c, 0xc9, 0xd0, 0x87, 0x8a, 0xe1, 0x37, 0x35, 0x24, 0xd7,
                0xd5, 0x10, 0xe5, 0x82, 0x27, 0xdf, 0x6d, 0xe9, 0xd3, 0x0d, 0x27, 0x18, 0x67, 0x64,
                0x01, 0x77, 0xb0, 0xf1, 0x85, 0x6e, 0x28, 0xd5, 0xc8, 0xaf, 0xb0, 0x95, 0xef, 0x61,
                0x84, 0xfe, 0xd6, 0x51, 0x58, 0x90, 0x22, 0xee, 0xae, 0xa4, 0xc0, 0xce, 0x1f, 0xa6,
                0xf0, 0x85, 0x09, 0x2b, 0x04, 0x97, 0x94, 0x89, 0x17, 0x2b, 0x3e, 0xf8, 0x19, 0x4a,
                0x79, 0x8d, 0xf5, 0x72, 0x4d, 0x6b, 0x05, 0xf1, 0xae, 0x00, 0x00, 0x13, 0xa0, 0x8d,
                0x61, 0x2b, 0xca, 0x8a, 0x8c, 0x31, 0x44, 0x3c, 0x10, 0x34, 0x6d, 0xbf, 0x61, 0xde,
                0x84, 0x75, 0xc0, 0xbb, 0xec, 0x51, 0x04, 0xb4, 0x75, 0x56, 0xaf, 0x3d, 0x51, 0x44,
                0x58, 0xe2, 0x32, 0x1d, 0x14, 0x60, 0x71, 0x78, 0x9d, 0x23, 0x35, 0x93, 0x4a, 0x68,
                0x06, 0x14, 0xe8, 0x35, 0x62, 0xf8, 0x2d, 0xfd, 0x40, 0x5b, 0x54, 0xa4, 0x5e, 0xb3,
                0x2c, 0x16, 0x54, 0x48, 0xd4, 0xd5, 0xd6, 0x1c, 0xa2, 0x85, 0x95, 0x85, 0x36, 0x9f,
                0x53, 0xf1, 0xa1, 0x37, 0xe9, 0xe8, 0x2b, 0x67, 0xb8, 0xfd, 0xaf, 0x01, 0xbd, 0xa5,
                0x4a, 0x31, 0x73, 0x11, 0x89, 0x6a, 0xe1, 0x02, 0x80, 0xa0, 0x32, 0x44, 0x0c, 0x42,
                0x0a, 0x42, 0x1e, 0x94, 0x4d, 0x1e, 0x95, 0x2b, 0x70, 0xd5, 0x82, 0x6c, 0xd3, 0xb0,
                0x8b, 0x7d, 0xb9, 0x63, 0x0f, 0xe4, 0xfd, 0x5f, 0x22, 0x12, 0x5d, 0xe8, 0x40, 0xfc,
                0xc4, 0x0b, 0x98, 0x03, 0x8a, 0xf1, 0x1d, 0x55, 0xbe, 0x25, 0x43, 0x25, 0x97, 0xb4,
                0xb6, 0x5b, 0x9e, 0xc1,
            ],
            c_enc: [
                0x16, 0x8b, 0x70, 0xd5, 0x24, 0x6e, 0xb3, 0x5b, 0x21, 0x0b, 0x76, 0xe5, 0x60, 0xeb,
                0xfc, 0x3a, 0x14, 0xb4, 0xa5, 0x28, 0xd6, 0xac, 0x9d, 0x7a, 0x09, 0xc8, 0xd2, 0x2a,
                0x41, 0xcd, 0xcb, 0x9c, 0x8e, 0x42, 0x44, 0xb8, 0x96, 0x10, 0xcc, 0xcd, 0x10, 0x1e,
                0x10, 0xee, 0x7a, 0xc8, 0x96, 0xc3, 0x20, 0xb8, 0x6a, 0x05, 0x5e, 0x3e, 0x7b, 0x29,
                0x05, 0xe9, 0xa9, 0xe4, 0x8e, 0x25, 0x34, 0xf3, 0x61, 0x8d, 0xd1, 0x39, 0xb2, 0x17,
                0xde, 0xe1, 0x2f, 0x09, 0x82, 0xf8, 0xdc, 0xb0, 0x78, 0xfe, 0x8d, 0x4e, 0x73, 0x5e,
                0xc4, 0x6b, 0xd0, 0x95, 0xb5, 0x4b, 0xc9, 0x8a, 0x97, 0xbe, 0x4b, 0xb0, 0x06, 0xb6,
                0x1a, 0x7b, 0x03, 0xc7, 0xe7, 0x26, 0x82, 0x0e, 0x89, 0x4d, 0xf4, 0x4a, 0x9f, 0x1c,
                0xd8, 0x10, 0xf5, 0x9b, 0xe0, 0xc9, 0xc8, 0x39, 0x49, 0xd9, 0xc4, 0x07, 0xff, 0x12,
                0xdd, 0x08, 0xd2, 0xff, 0x9f, 0x29, 0x1d, 0x66, 0x00, 0x03, 0x31, 0x84, 0xca, 0xb7,
                0xdd, 0xf7, 0x26, 0x07, 0x43, 0x6d, 0x78, 0xdb, 0x9d, 0xaf, 0xa2, 0xf9, 0x1c, 0x0d,
                0xa0, 0x29, 0x9d, 0x16, 0x34, 0xe5, 0xb9, 0x6c, 0x2c, 0xd0, 0x43, 0xf0, 0x77, 0x80,
                0x8a, 0x1f, 0x16, 0xaf, 0x8e, 0x9c, 0x65, 0x33, 0x7d, 0xd0, 0x51, 0x90, 0xdc, 0xc6,
                0x47, 0x44, 0x78, 0x60, 0x41, 0xf9, 0x1e, 0x16, 0x5f, 0x7f, 0xd3, 0xd0, 0x5c, 0x77,
                0xf0, 0x80, 0xb4, 0x80, 0x27, 0x64, 0xef, 0x07, 0x15, 0xa9, 0x57, 0xd6, 0xb6, 0x86,
                0x85, 0x55, 0x0d, 0x33, 0x86, 0x65, 0xcf, 0xb8, 0x37, 0xda, 0x20, 0xe4, 0x69, 0xef,
                0xf9, 0xc9, 0x12, 0xcf, 0x6a, 0xdb, 0x31, 0xc7, 0xa1, 0x83, 0xab, 0x3e, 0x5d, 0xc4,
                0x1e, 0x4a, 0x68, 0x0e, 0x0a, 0x99, 0x7e, 0x2b, 0x5a, 0x1c, 0xbe, 0x10, 0xa4, 0x13,
                0x1a, 0x8e, 0x4a, 0x09, 0x2a, 0xca, 0x55, 0x79, 0xa4, 0x73, 0xf0, 0x21, 0x3f, 0xa3,
                0x2b, 0x1f, 0x66, 0x2a, 0x32, 0x98, 0x3a, 0x75, 0x51, 0x43, 0xb3, 0x61, 0xef, 0x86,
                0x11, 0x6c, 0x95, 0xfd, 0x76, 0xce, 0x13, 0x08, 0x79, 0x76, 0x6e, 0xa5, 0x07, 0xc2,
                0xd7, 0xb4, 0x1c, 0xe9, 0xca, 0x23, 0x35, 0x58, 0x9f, 0x7c, 0x77, 0x24, 0x03, 0x4d,
                0x84, 0x94, 0xfd, 0x84, 0x11, 0x04, 0xa6, 0x80, 0x27, 0x10, 0xcc, 0x92, 0x36, 0x17,
                0xb9, 0x14, 0x9b, 0x36, 0x0e, 0xaf, 0x14, 0xa0, 0x99, 0xf3, 0x4d, 0x95, 0xb6, 0x2a,
                0x84, 0x02, 0xbc, 0x76, 0xc5, 0xb0, 0x1b, 0x6b, 0xe2, 0x1e, 0xaf, 0x94, 0x73, 0xd5,
                0xe5, 0xd8, 0x23, 0xf4, 0xab, 0xc0, 0x7c, 0x7b, 0xa2, 0xf4, 0x57, 0x10, 0x5a, 0x29,
                0xa3, 0x7a, 0xcb, 0x25, 0xf3, 0x30, 0x38, 0xf3, 0x0d, 0x5c, 0x08, 0x87, 0x4d, 0x01,
                0x12, 0xf7, 0xcc, 0x3d, 0x3d, 0xd3, 0xa7, 0xb3, 0x3b, 0xf9, 0xf0, 0xd5, 0xd2, 0xe5,
                0xc8, 0xa4, 0x33, 0x7c, 0xb6, 0x5c, 0x3b, 0xd8, 0xaf, 0x5f, 0xeb, 0x86, 0x39, 0x6c,
                0x54, 0x0f, 0x08, 0x01, 0x22, 0x8e, 0x26, 0x6d, 0x16, 0x7d, 0x8b, 0xfc, 0xd3, 0xe4,
                0xf5, 0xe2, 0xf2, 0xc5, 0x45, 0x46, 0x5e, 0x4c, 0xf6, 0x40, 0x60, 0x04, 0x76, 0x9e,
                0xab, 0x28, 0x78, 0x6b, 0x3f, 0xe7, 0x6e, 0x67, 0x55, 0xf1, 0x8f, 0x6a, 0x3e, 0x7c,
                0x4b, 0xe7, 0x18, 0x6d, 0x2e, 0x16, 0x53, 0xb4, 0xb9, 0x51, 0xd2, 0xfc, 0x7e, 0x42,
                0x29, 0xa9, 0x21, 0xd3, 0x1c, 0xd7, 0xf9, 0x7d, 0x5e, 0xef, 0x81, 0xd1, 0xbf, 0x0a,
                0x49, 0x90, 0xc3, 0xd1, 0xca, 0x51, 0x4e, 0xec, 0xeb, 0xe2, 0xa8, 0xfb, 0x23, 0x3a,
                0x70, 0xd1, 0x77, 0x83, 0x8f, 0xc3, 0x27, 0xce, 0xeb, 0x2b, 0x44, 0x35, 0x2c, 0xdd,
                0xc2, 0x4f, 0x01, 0xa3, 0xf0, 0xdc, 0x1d, 0x49, 0xcc, 0xdb, 0xa1, 0x59, 0x92, 0xf0,
                0x76, 0x5e, 0x6f, 0xb6, 0x6f, 0xbb, 0xac, 0x49, 0xd1, 0xfc, 0x40, 0x99, 0xf5, 0xbc,
                0x02, 0x36, 0xa3, 0x81, 0xd1, 0x65, 0xc4, 0x6a, 0xc6, 0x23, 0x77, 0xce, 0xf5, 0x2e,
                0x66, 0x1e, 0x66, 0xc9, 0xab, 0xd1, 0xd7, 0x6c, 0x83, 0x0d, 0x63, 0x69, 0x31, 0x5f,
                0x94, 0x16, 0x6a, 0x58, 0x92, 0x37, 0x24, 0x08, 0xba, 0xc9, 0xfe, 0x5a, 0xba, 0x02,
                0x2e, 0xa3, 0x5f, 0xc0, 0xc4, 0x91,
            ],
            ock: [
                0x09, 0x95, 0xb6, 0x7f, 0xeb, 0x01, 0x5d, 0x2c, 0x29, 0xe9, 0x28, 0xd9, 0xc7, 0xc1,
                0x8c, 0x23, 0x79, 0x0b, 0x4c, 0xe7, 0x51, 0xa0, 0x9a, 0x50, 0x5d, 0x00, 0xad, 0xcb,
                0x17, 0x9c, 0xce, 0x3d,
            ],
            op: [
                0x93, 0x96, 0x68, 0xe5, 0x01, 0xc2, 0x83, 0x87, 0xc0, 0xbd, 0x33, 0x5e, 0x95, 0x46,
                0x92, 0xc9, 0x05, 0xcd, 0x42, 0xb0, 0xf0, 0xd5, 0x48, 0x39, 0x23, 0x41, 0xd4, 0x96,
                0x14, 0x7a, 0x3e, 0x31, 0x2a, 0xbb, 0xc2, 0xe9, 0xf5, 0xa9, 0x78, 0x5f, 0x5a, 0x4f,
                0x08, 0x87, 0x5e, 0x81, 0x61, 0x71, 0x33, 0xe1, 0xf6, 0x26, 0x2b, 0x03, 0xa9, 0xfc,
                0x15, 0x2e, 0x6b, 0xa4, 0xbe, 0x8f, 0x52, 0x12,
            ],
            c_out: [
                0xca, 0xd4, 0x16, 0xec, 0x2c, 0xd0, 0x98, 0x1e, 0xba, 0x86, 0x66, 0x9a, 0xde, 0xdf,
                0x25, 0x83, 0xb8, 0x2c, 0xdc, 0x47, 0x82, 0x0f, 0xed, 0x90, 0x10, 0x53, 0xc3, 0x79,
                0x41, 0x29, 0x5e, 0x17, 0x7c, 0x50, 0x05, 0x44, 0xd7, 0x7d, 0xdc, 0x6c, 0xdd, 0x7c,
                0x21, 0x5d, 0x97, 0xac, 0x0a, 0xef, 0x58, 0x13, 0xce, 0x9e, 0x55, 0x4e, 0xde, 0x86,
                0xe7, 0xdf, 0xb1, 0x3c, 0xe3, 0xe2, 0xaf, 0xf1, 0x5e, 0x45, 0xa4, 0x83, 0xb4, 0x8b,
                0x65, 0xaf, 0x3b, 0x47, 0xe6, 0xfc, 0x11, 0x19, 0xa3, 0xbf,
            ],
        },
        TestVector {
            incoming_viewing_key: [
                0x54, 0x5b, 0x1a, 0x74, 0x6e, 0xaf, 0xd0, 0xc9, 0x7d, 0x51, 0x42, 0x53, 0x87, 0x84,
                0x4c, 0xc8, 0x7f, 0xc8, 0x7a, 0x79, 0x4b, 0x69, 0x47, 0xfe, 0x58, 0x32, 0xf7, 0x72,
                0x1c, 0xe2, 0x9c, 0xb4, 0x76, 0x40, 0x0f, 0xb4, 0xb7, 0x3c, 0xe0, 0xff, 0xf0, 0xf1,
                0xe7, 0xbe, 0xba, 0x0c, 0x67, 0x77, 0x18, 0x20, 0x8e, 0x2e, 0xa2, 0xc4, 0xc3, 0x00,
                0xd1, 0x74, 0x81, 0x44, 0x4c, 0x88, 0x4c, 0x1d,
            ],
            ovk: [
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
                0x00, 0x00, 0x00, 0x00,
            ],
            default_d: [
                0x93, 0xbb, 0x38, 0xc5, 0x96, 0x6a, 0x05, 0x1c, 0xa4, 0x70, 0x47,
            ],
            default_pk_d: [
                0x93, 0x4a, 0xa4, 0x78, 0x08, 0xa4, 0x91, 0x7c, 0xa5, 0xe9, 0xfc, 0x0c, 0xae, 0x04,
                0x75, 0xa5, 0x4f, 0x41, 0xaf, 0x8d, 0x70, 0x2c, 0x4a, 0x25, 0x73, 0x07, 0xe1, 0xf9,
                0x46, 0xe6, 0x73, 0x96,
            ],
            v: 15675879937408561761,
            rseed: [
                0x0d, 0xbb, 0xba, 0xf8, 0x45, 0x98, 0xd9, 0x72, 0xb0, 0x53, 0x4f, 0x48, 0xa5, 0xe5,
                0x26, 0x70, 0x43, 0x6a, 0xaa, 0x77, 0x6e, 0xd2, 0x48, 0x2a, 0xd7, 0x03, 0x43, 0x02,
                0x01, 0xe5, 0x34, 0x43,
            ],
            memo: [
                0xff, 0xc3, 0x6d, 0xcf, 0xd3, 0x4a, 0x0c, 0xb6, 0x63, 0x78, 0x76, 0x10, 0x5e, 0x79,
                0xbf, 0x3b, 0xd5, 0x8e, 0xc1, 0x48, 0xcb, 0x64, 0x97, 0x0e, 0x32, 0x23, 0xa9, 0x1f,
                0x71, 0xdf, 0xcf, 0xd5, 0xa0, 0x4b, 0x66, 0x7f, 0xba, 0xf3, 0xd4, 0xb3, 0xb9, 0x08,
                0xb9, 0x82, 0x88, 0x20, 0xdf, 0xec, 0xdd, 0x75, 0x37, 0x50, 0xb5, 0xf9, 0xd2, 0x21,
                0x6e, 0x56, 0xc6, 0x15, 0x27, 0x2f, 0x85, 0x44, 0x64, 0xc0, 0xca, 0x4b, 0x1e, 0x85,
                0xae, 0xdd, 0x03, 0x82, 0x92, 0xc4, 0xe1, 0xa5, 0x77, 0x44, 0xeb, 0xba, 0x01, 0x0b,
                0x9e, 0xbf, 0xbb, 0x01, 0x1b, 0xd6, 0xf0, 0xb7, 0x88, 0x05, 0x02, 0x5d, 0x27, 0xf3,
                0xc1, 0x77, 0x46, 0xba, 0xe1, 0x16, 0xc1, 0x5d, 0x9f, 0x47, 0x1f, 0x0f, 0x62, 0x88,
                0xa1, 0x50, 0x64, 0x7b, 0x2a, 0xfe, 0x9d, 0xf7, 0xcc, 0xcf, 0x01, 0xf5, 0xcd, 0xe5,
                0xf0, 0x46, 0x80, 0xbb, 0xfe, 0xd8, 0x7f, 0x6c, 0xf4, 0x29, 0xfb, 0x27, 0xad, 0x6b,
                0xab, 0xe7, 0x91, 0x76, 0x66, 0x11, 0xcf, 0x5b, 0xc2, 0x0e, 0x48, 0xbe, 0xf1, 0x19,
                0x25, 0x9b, 0x9b, 0x8a, 0x0e, 0x39, 0xc3, 0xdf, 0x28, 0xcb, 0x95, 0x82, 0xea, 0x33,
                0x86, 0x01, 0xcd, 0xc4, 0x81, 0xb3, 0x2f, 0xb8, 0x2a, 0xde, 0xeb, 0xb3, 0xda, 0xde,
                0x25, 0xd1, 0xa3, 0xdf, 0x20, 0xc3, 0x7e, 0x71, 0x25, 0x06, 0xb5, 0xd9, 0x96, 0xc4,
                0x9a, 0x9f, 0x0f, 0x30, 0xdd, 0xcb, 0x91, 0xfe, 0x90, 0x04, 0xe1, 0xe8, 0x32, 0x94,
                0xa6, 0xc9, 0x20, 0x3d, 0x94, 0xe8, 0xdc, 0x2c, 0xbb, 0x44, 0x9d, 0xe4, 0x15, 0x50,
                0x32, 0x60, 0x4e, 0x47, 0x99, 0x70, 0x16, 0xb3, 0x04, 0xfd, 0x43, 0x7d, 0x82, 0x35,
                0x04, 0x5e, 0x25, 0x5a, 0x19, 0xb7, 0x43, 0xa0, 0xa9, 0xf2, 0xe3, 0x36, 0xb4, 0x4c,
                0xae, 0x30, 0x7b, 0xb3, 0x98, 0x7b, 0xd3, 0xe4, 0xe7, 0x77, 0xfb, 0xb3, 0x4c, 0x0a,
                0xb8, 0xcc, 0x3d, 0x67, 0x46, 0x6c, 0x0a, 0x88, 0xdd, 0x4c, 0xca, 0xd1, 0x8a, 0x07,
                0xa8, 0xd1, 0x06, 0x8d, 0xf5, 0xb6, 0x29, 0xe5, 0x71, 0x8d, 0x0f, 0x6d, 0xf5, 0xc9,
                0x57, 0xcf, 0x71, 0xbb, 0x00, 0xa5, 0x17, 0x8f, 0x17, 0x5c, 0xac, 0xa9, 0x44, 0xe6,
                0x35, 0xc5, 0x15, 0x9f, 0x73, 0x8e, 0x24, 0x02, 0xa2, 0xd2, 0x1a, 0xa0, 0x81, 0xe1,
                0x0e, 0x45, 0x6a, 0xfb, 0x00, 0xb9, 0xf6, 0x24, 0x16, 0xc8, 0xb9, 0xc0, 0xf7, 0x22,
                0x8f, 0x51, 0x07, 0x29, 0xe0, 0xbe, 0x3f, 0x30, 0x53, 0x13, 0xd7, 0x7f, 0x73, 0x79,
                0xdc, 0x2a, 0xf2, 0x48, 0x69, 0xc6, 0xc7, 0x4e, 0xe4, 0x47, 0x14, 0x98, 0x86, 0x1d,
                0x19, 0x2f, 0x0f, 0xf0, 0xf5, 0x08, 0x28, 0x5d, 0xab, 0x6b, 0x6a, 0x36, 0xcc, 0xf7,
                0xd1, 0x22, 0x56, 0xcc, 0x76, 0xb9, 0x55, 0x03, 0x72, 0x0a, 0xc6, 0x72, 0xd0, 0x82,
                0x68, 0xd2, 0xcf, 0x77, 0x73, 0xb6, 0xba, 0x2a, 0x5f, 0x66, 0x48, 0x47, 0xbf, 0x70,
                0x7f, 0x2f, 0xc1, 0x0c, 0x98, 0xf2, 0xf0, 0x06, 0xec, 0x22, 0xcc, 0xb5, 0xa8, 0xc8,
                0xb7, 0xc4, 0x0c, 0x7c, 0x2d, 0x49, 0xa6, 0x63, 0x9b, 0x9f, 0x2c, 0xe3, 0x3c, 0x25,
                0xc0, 0x4b, 0xc4, 0x61, 0xe7, 0x44, 0xdf, 0xa5, 0x36, 0xb0, 0x0d, 0x94, 0xba, 0xdd,
                0xf4, 0xf4, 0xd1, 0x40, 0x44, 0xc6, 0x95, 0xa3, 0x38, 0x81, 0x47, 0x7d, 0xf1, 0x24,
                0xf0, 0xfc, 0xf2, 0x06, 0xa9, 0xfb, 0x2e, 0x65, 0xe3, 0x04, 0xcd, 0xbf, 0x0c, 0x4d,
                0x23, 0x90, 0x17, 0x0c, 0x13, 0x0a, 0xb8, 0x49, 0xc2, 0xf2, 0x2b, 0x5c, 0xdd, 0x39,
                0x21, 0x64, 0x0c, 0x8c, 0xf1, 0x97, 0x6a, 0xe1, 0x01, 0x0b, 0x0d, 0xfd, 0x9c, 0xb2,
                0x54, 0x3e, 0x45, 0xf9, 0x97, 0x49, 0xcc, 0x4d,
            ],
            cv_net: [
                0x7e, 0xa0, 0x59, 0xfe, 0x8c, 0x35, 0x41, 0xd0, 0xf1, 0xf1, 0x18, 0xc1, 0xf2, 0xe9,
                0x7e, 0x0c, 0x1d, 0xa3, 0xba, 0x77, 0xe6, 0x4a, 0x60, 0x0f, 0x0f, 0x8a, 0x82, 0x8c,
                0xd1, 0x84, 0xd5, 0x34,
            ],
            rho: [
                0x8d, 0x67, 0xe3, 0xba, 0x4d, 0xbc, 0x9d, 0xa5, 0xe8, 0x38, 0x23, 0xa1, 0x23, 0x11,
                0x63, 0x96, 0x51, 0xa4, 0xff, 0xa9, 0x5f, 0x27, 0xc1, 0x83, 0x0d, 0x91, 0xd8, 0xb7,
                0x3c, 0xfb, 0xf1, 0x31,
            ],
            cmx: [
                0x80, 0x25, 0x67, 0xd8, 0xfe, 0x48, 0xf2, 0x4c, 0x60, 0x4f, 0x66, 0x65, 0xd4, 0xd0,
                0x10, 0x94, 0x96, 0x2d, 0x9c, 0x70, 0x7d, 0xb0, 0x70, 0x52, 0x18, 0x68, 0xef, 0xcc,
                0x7b, 0x41, 0xcf, 0x31,
            ],
            esk: [
                0x79, 0xfb, 0xb7, 0x29, 0xa8, 0xf4, 0x9a, 0x29, 0xa7, 0x17, 0x5b, 0x6f, 0x2e, 0xdf,
                0xc5, 0x17, 0xa3, 0x04, 0x02, 0xd4, 0xca, 0x8e, 0x4a, 0xf7, 0xa9, 0xb1, 0xbe, 0x1c,
                0xa8, 0x4f, 0x7f, 0x38,
            ],
            ephemeral_key: [
                0xef, 0x79, 0x23, 0xe6, 0x6c, 0x2e, 0xc8, 0x1c, 0x48, 0x72, 0xfc, 0x3a, 0xaf, 0x6c,
                0x71, 0xc9, 0x00, 0xf8, 0x22, 0x02, 0x0a, 0xfb, 0x55, 0x29, 0x90, 0x15, 0x73, 0xc2,
                0x5f, 0xae, 0x2e, 0xa7,
            ],
            shared_secret: [
                0xf5, 0x69, 0x56, 0x7d, 0x83, 0x2f, 0xf9, 0x62, 0x5a, 0xb3, 0xb8, 0xfc, 0xee, 0xa5,
                0x53, 0xb5, 0x7e, 0xdb, 0x40, 0x89, 0xd4, 0x87, 0xf3, 0xcd, 0x93, 0x39, 0x90, 0x12,
                0xdd, 0x63, 0xef, 0x21,
            ],
            k_enc: [
                0xc6, 0x67, 0xc4, 0xab, 0x13, 0xdc, 0xc9, 0x97, 0x5a, 0x15, 0xbb, 0x74, 0x48, 0x0a,
                0xbf, 0xc6, 0xb7, 0x8a, 0x8b, 0x01, 0x11, 0xae, 0x9e, 0x64, 0x70, 0xc7, 0x30, 0x28,
                0x0f, 0xfb, 0x09, 0x62,
            ],
            p_enc: [
                0x02, 0x93, 0xbb, 0x38, 0xc5, 0x96, 0x6a, 0x05, 0x1c, 0xa4, 0x70, 0x47, 0x61, 0xf2,
                0xe8, 0xaa, 0xbf, 0xe9, 0x8b, 0xd9, 0x0d, 0xbb, 0xba, 0xf8, 0x45, 0x98, 0xd9, 0x72,
                0xb0, 0x53, 0x4f, 0x48, 0xa5, 0xe5, 0x26, 0x70, 0x43, 0x6a, 0xaa, 0x77, 0x6e, 0xd2,
                0x48, 0x2a, 0xd7, 0x03, 0x43, 0x02, 0x01, 0xe5, 0x34, 0x43, 0xff, 0xc3, 0x6d, 0xcf,
                0xd3, 0x4a, 0x0c, 0xb6, 0x63, 0x78, 0x76, 0x10, 0x5e, 0x79, 0xbf, 0x3b, 0xd5, 0x8e,
                0xc1, 0x48, 0xcb, 0x64, 0x97, 0x0e, 0x32, 0x23, 0xa9, 0x1f, 0x71, 0xdf, 0xcf, 0xd5,
                0xa0, 0x4b, 0x66, 0x7f, 0xba, 0xf3, 0xd4, 0xb3, 0xb9, 0x08, 0xb9, 0x82, 0x88, 0x20,
                0xdf, 0xec, 0xdd, 0x75, 0x37, 0x50, 0xb5, 0xf9, 0xd2, 0x21, 0x6e, 0x56, 0xc6, 0x15,
                0x27, 0x2f, 0x85, 0x44, 0x64, 0xc0, 0xca, 0x4b, 0x1e, 0x85, 0xae, 0xdd, 0x03, 0x82,
                0x92, 0xc4, 0xe1, 0xa5, 0x77, 0x44, 0xeb, 0xba, 0x01, 0x0b, 0x9e, 0xbf, 0xbb, 0x01,
                0x1b, 0xd6, 0xf0, 0xb7, 0x88, 0x05, 0x02, 0x5d, 0x27, 0xf3, 0xc1, 0x77, 0x46, 0xba,
                0xe1, 0x16, 0xc1, 0x5d, 0x9f, 0x47, 0x1f, 0x0f, 0x62, 0x88, 0xa1, 0x50, 0x64, 0x7b,
                0x2a, 0xfe, 0x9d, 0xf7, 0xcc, 0xcf, 0x01, 0xf5, 0xcd, 0xe5, 0xf0, 0x46, 0x80, 0xbb,
                0xfe, 0xd8, 0x7f, 0x6c, 0xf4, 0x29, 0xfb, 0x27, 0xad, 0x6b, 0xab, 0xe7, 0x91, 0x76,
                0x66, 0x11, 0xcf, 0x5b, 0xc2, 0x0e, 0x48, 0xbe, 0xf1, 0x19, 0x25, 0x9b, 0x9b, 0x8a,
                0x0e, 0x39, 0xc3, 0xdf, 0x28, 0xcb, 0x95, 0x82, 0xea, 0x33, 0x86, 0x01, 0xcd, 0xc4,
                0x81, 0xb3, 0x2f, 0xb8, 0x2a, 0xde, 0xeb, 0xb3, 0xda, 0xde, 0x25, 0xd1, 0xa3, 0xdf,
                0x20, 0xc3, 0x7e, 0x71, 0x25, 0x06, 0xb5, 0xd9, 0x96, 0xc4, 0x9a, 0x9f, 0x0f, 0x30,
                0xdd, 0xcb, 0x91, 0xfe, 0x90, 0x04, 0xe1, 0xe8, 0x32, 0x94, 0xa6, 0xc9, 0x20, 0x3d,
                0x94, 0xe8, 0xdc, 0x2c, 0xbb, 0x44, 0x9d, 0xe4, 0x15, 0x50, 0x32, 0x60, 0x4e, 0x47,
                0x99, 0x70, 0x16, 0xb3, 0x04, 0xfd, 0x43, 0x7d, 0x82, 0x35, 0x04, 0x5e, 0x25, 0x5a,
                0x19, 0xb7, 0x43, 0xa0, 0xa9, 0xf2, 0xe3, 0x36, 0xb4, 0x4c, 0xae, 0x30, 0x7b, 0xb3,
                0x98, 0x7b, 0xd3, 0xe4, 0xe7, 0x77, 0xfb, 0xb3, 0x4c, 0x0a, 0xb8, 0xcc, 0x3d, 0x67,
                0x46, 0x6c, 0x0a, 0x88, 0xdd, 0x4c, 0xca, 0xd1, 0x8a, 0x07, 0xa8, 0xd1, 0x06, 0x8d,
                0xf5, 0xb6, 0x29, 0xe5, 0x71, 0x8d, 0x0f, 0x6d, 0xf5, 0xc9, 0x57, 0xcf, 0x71, 0xbb,
                0x00, 0xa5, 0x17, 0x8f, 0x17, 0x5c, 0xac, 0xa9, 0x44, 0xe6, 0x35, 0xc5, 0x15, 0x9f,
                0x73, 0x8e, 0x24, 0x02, 0xa2, 0xd2, 0x1a, 0xa0, 0x81, 0xe1, 0x0e, 0x45, 0x6a, 0xfb,
                0x00, 0xb9, 0xf6, 0x24, 0x16, 0xc8, 0xb9, 0xc0, 0xf7, 0x22, 0x8f, 0x51, 0x07, 0x29,
                0xe0, 0xbe, 0x3f, 0x30, 0x53, 0x13, 0xd7, 0x7f, 0x73, 0x79, 0xdc, 0x2a, 0xf2, 0x48,
                0x69, 0xc6, 0xc7, 0x4e, 0xe4, 0x47, 0x14, 0x98, 0x86, 0x1d, 0x19, 0x2f, 0x0f, 0xf0,
                0xf5, 0x08, 0x28, 0x5d, 0xab, 0x6b, 0x6a, 0x36, 0xcc, 0xf7, 0xd1, 0x22, 0x56, 0xcc,
                0x76, 0xb9, 0x55, 0x03, 0x72, 0x0a, 0xc6, 0x72, 0xd0, 0x82, 0x68, 0xd2, 0xcf, 0x77,
                0x73, 0xb6, 0xba, 0x2a, 0x5f, 0x66, 0x48, 0x47, 0xbf, 0x70, 0x7f, 0x2f, 0xc1, 0x0c,
                0x98, 0xf2, 0xf0, 0x06, 0xec, 0x22, 0xcc, 0xb5, 0xa8, 0xc8, 0xb7, 0xc4, 0x0c, 0x7c,
                0x2d, 0x49, 0xa6, 0x63, 0x9b, 0x9f, 0x2c, 0xe3, 0x3c, 0x25, 0xc0, 0x4b, 0xc4, 0x61,
                0xe7, 0x44, 0xdf, 0xa5, 0x36, 0xb0, 0x0d, 0x94, 0xba, 0xdd, 0xf4, 0xf4, 0xd1, 0x40,
                0x44, 0xc6, 0x95, 0xa3, 0x38, 0x81, 0x47, 0x7d, 0xf1, 0x24, 0xf0, 0xfc, 0xf2, 0x06,
                0xa9, 0xfb, 0x2e, 0x65, 0xe3, 0x04, 0xcd, 0xbf, 0x0c, 0x4d, 0x23, 0x90, 0x17, 0x0c,
                0x13, 0x0a, 0xb8, 0x49, 0xc2, 0xf2, 0x2b, 0x5c, 0xdd, 0x39, 0x21, 0x64, 0x0c, 0x8c,
                0xf1, 0x97, 0x6a, 0xe1, 0x01, 0x0b, 0x0d, 0xfd, 0x9c, 0xb2, 0x54, 0x3e, 0x45, 0xf9,
                0x97, 0x49, 0xcc, 0x4d,
            ],
            c_enc: [
                0x02, 0xc1, 0x9c, 0x32, 0x84, 0x8c, 0xdd, 0x16, 0x71, 0xeb, 0x1e, 0xb0, 0x4a, 0x7f,
                0xa3, 0x20, 0x28, 0x3b, 0x92, 0x81, 0x10, 0x89, 0x37, 0x88, 0x2f, 0x1c, 0xcd, 0x19,
                0xc8, 0xba, 0x77, 0x82, 0x1a, 0x1a, 0x6b, 0xfd, 0xb5, 0x96, 0x20, 0x8a, 0xa2, 0xfd,
                0xfc, 0xf6, 0xd0, 0x4c, 0x0e, 0x7f, 0xdd, 0x9a, 0x94, 0x77, 0xc5, 0x37, 0x29, 0x7c,
                0xa1, 0x05, 0x1b, 0xca, 0x40, 0xa9, 0xd1, 0xf4, 0x56, 0xc3, 0x87, 0xb9, 0xaa, 0x20,
                0xdd, 0x64, 0x14, 0xde, 0x4a, 0x76, 0x51, 0x42, 0xfc, 0xec, 0xfe, 0x80, 0xa5, 0x90,
                0x0b, 0x1a, 0xeb, 0x97, 0x1c, 0x6e, 0x54, 0x89, 0x7a, 0xec, 0xe0, 0x88, 0x37, 0x58,
                0xa1, 0x9b, 0xcd, 0xcd, 0xb8, 0x7a, 0x80, 0x10, 0xc5, 0x38, 0xdd, 0xd0, 0x60, 0x4a,
                0xfa, 0xf3, 0x5e, 0x8f, 0x17, 0xf3, 0x0b, 0x3c, 0xce, 0x10, 0x52, 0x13, 0x47, 0x38,
                0xf4, 0x29, 0x08, 0x0d, 0xb0, 0x64, 0x7a, 0x7a, 0xdf, 0x49, 0xe3, 0xe3, 0x8a, 0x72,
                0xb4, 0xef, 0x61, 0xe5, 0x53, 0xf6, 0x3d, 0x79, 0x3f, 0x7c, 0x57, 0xdf, 0x77, 0xbd,
                0x58, 0xba, 0xb3, 0x7d, 0x6f, 0x4a, 0xb2, 0x34, 0x59, 0x35, 0x5e, 0x09, 0x12, 0x13,
                0xe5, 0xd8, 0xe7, 0x00, 0x71, 0x7f, 0xbe, 0xe6, 0xec, 0x0f, 0x41, 0x1b, 0x84, 0x4c,
                0x7c, 0xbe, 0xf7, 0xa1, 0x37, 0x91, 0x59, 0x73, 0x05, 0x85, 0x67, 0xb8, 0x9e, 0xef,
                0xeb, 0x87, 0xd5, 0xe7, 0xa1, 0xdf, 0xd3, 0x3c, 0x70, 0x74, 0x07, 0x11, 0xb6, 0xd2,
                0x19, 0x2e, 0x21, 0x10, 0xac, 0xf8, 0x81, 0xb5, 0x74, 0xbe, 0xc1, 0x63, 0x33, 0x70,
                0x46, 0x71, 0x1c, 0x97, 0xe9, 0xef, 0x28, 0xed, 0x38, 0xaf, 0xc8, 0xe7, 0x72, 0xb9,
                0xaa, 0x21, 0xb4, 0x24, 0x7e, 0x29, 0x86, 0x1f, 0x36, 0x24, 0x0c, 0x75, 0x0f, 0xa5,
                0xfb, 0x5f, 0x68, 0xdc, 0x4d, 0xf4, 0x8f, 0xeb, 0x09, 0x28, 0xee, 0xc8, 0xe4, 0x14,
                0x48, 0xc4, 0x38, 0x0d, 0xa2, 0xfc, 0x01, 0x63, 0x9d, 0xae, 0x3a, 0x2c, 0x51, 0xf3,
                0x4e, 0xf8, 0x95, 0x0a, 0x0c, 0xca, 0x07, 0x3a, 0x2d, 0xb7, 0xd8, 0xd6, 0x6a, 0x7d,
                0x22, 0xd2, 0xf4, 0xf0, 0x9a, 0x10, 0xff, 0x56, 0x0c, 0x66, 0x53, 0xd0, 0x20, 0x7c,
                0x76, 0xe1, 0x38, 0x86, 0xec, 0x63, 0x4e, 0x1e, 0x67, 0x1e, 0xba, 0xda, 0xaa, 0x07,
                0xe9, 0xf1, 0x3e, 0x55, 0x0f, 0x60, 0x1d, 0x72, 0x4b, 0x00, 0x71, 0xec, 0x9e, 0x45,
                0x5e, 0xea, 0xff, 0x5e, 0x92, 0xde, 0x1c, 0xe3, 0xb7, 0x8b, 0xb2, 0xe5, 0xb8, 0x88,
                0xa1, 0x0c, 0x51, 0x85, 0x76, 0x97, 0xec, 0x11, 0x19, 0x54, 0xef, 0x44, 0x3f, 0x1f,
                0x57, 0xab, 0x02, 0x42, 0x37, 0x23, 0x8b, 0xc1, 0xd3, 0xd9, 0x9e, 0xd6, 0x8a, 0x75,
                0x22, 0xba, 0x8e, 0xe7, 0xfc, 0x76, 0xea, 0x56, 0x16, 0xb8, 0x1e, 0xd6, 0xeb, 0x84,
                0x70, 0x96, 0x47, 0x06, 0x05, 0x10, 0x8b, 0x04, 0x6a, 0x04, 0xd5, 0xfa, 0x97, 0xee,
                0xb8, 0x17, 0x59, 0x5c, 0x17, 0x47, 0x47, 0x94, 0xe2, 0x13, 0x7a, 0x5e, 0xb2, 0xf5,
                0xf2, 0x40, 0x26, 0xcb, 0xd7, 0xd8, 0xe0, 0x71, 0x44, 0xaa, 0x30, 0x15, 0x0a, 0x4e,
                0xd8, 0x36, 0x4d, 0x36, 0x92, 0xd8, 0x26, 0xa1, 0x07, 0x75, 0x04, 0x8c, 0x51, 0x6a,
                0x98, 0xdf, 0x7e, 0xe4, 0x41, 0x15, 0xbd, 0x9b, 0x1a, 0xcc, 0xd8, 0xea, 0xfd, 0x37,
                0xc7, 0x99, 0xe9, 0x9c, 0xa2, 0x2a, 0x43, 0xc9, 0x6e, 0xc2, 0x4b, 0x53, 0x87, 0x06,
                0x67, 0xc8, 0xc0, 0x31, 0xe6, 0x4f, 0x20, 0x44, 0xd8, 0x62, 0x6e, 0x15, 0xaa, 0xfe,
                0x69, 0x25, 0x5f, 0xb0, 0xeb, 0x66, 0xf2, 0x3f, 0x8d, 0x50, 0x53, 0xd9, 0x1e, 0xc4,
                0x7a, 0xcd, 0xd1, 0xca, 0xd5, 0xf4, 0x01, 0x18, 0x14, 0xd5, 0xd3, 0xaa, 0xef, 0xcc,
                0x99, 0xb4, 0xcd, 0x89, 0x88, 0x7e, 0x04, 0x20, 0xad, 0x68, 0x60, 0x05, 0x39, 0xc1,
                0xae, 0xf9, 0x2c, 0x32, 0x84, 0xf4, 0xb4, 0x28, 0x06, 0x2c, 0x6f, 0xac, 0x87, 0x5e,
                0x18, 0x62, 0x88, 0xbf, 0x6f, 0xd4, 0x5b, 0x2d, 0x98, 0x85, 0x21, 0x74, 0x2e, 0x9b,
                0x25, 0xcb, 0x56, 0x95, 0xdc, 0xf9, 0x7d, 0x1c, 0x9d, 0x4f, 0xc5, 0x9c, 0x76, 0x44,
                0x20, 0xc7, 0xfb, 0x97, 0x23, 0xf7,
            ],
            ock: [
                0x15, 0xcb, 0x18, 0xf0, 0x8b, 0x75, 0x72, 0x44, 0xec, 0x15, 0x23, 0xbc, 0xdb, 0xfa,
                0x22, 0xde, 0xd1, 0x56, 0x97, 0x61, 0x40, 0x4e, 0x47, 0x51, 0x33, 0x13, 0xfe, 0x8a,
                0xb8, 0x55, 0x9d, 0xa1,
            ],
            op: [
                0x93, 0x4a, 0xa4, 0x78, 0x08, 0xa4, 0x91, 0x7c, 0xa5, 0xe9, 0xfc, 0x0c, 0xae, 0x04,
                0x75, 0xa5, 0x4f, 0x41, 0xaf, 0x8d, 0x70, 0x2c, 0x4a, 0x25, 0x73, 0x07, 0xe1, 0xf9,
                0x46, 0xe6, 0x73, 0x96, 0x79, 0xfb, 0xb7, 0x29, 0xa8, 0xf4, 0x9a, 0x29, 0xa7, 0x17,
                0x5b, 0x6f, 0x2e, 0xdf, 0xc5, 0x17, 0xa3, 0x04, 0x02, 0xd4, 0xca, 0x8e, 0x4a, 0xf7,
                0xa9, 0xb1, 0xbe, 0x1c, 0xa8, 0x4f, 0x7f, 0x38,
            ],
            c_out: [
                0xa1, 0x42, 0x25, 0x41, 0x5b, 0x26, 0xb8, 0x82, 0xeb, 0x1c, 0x05, 0xf2, 0x0c, 0x38,
                0x86, 0x40, 0xa0, 0x83, 0xba, 0x40, 0xd6, 0x49, 0x59, 0xad, 0x94, 0x44, 0x0e, 0xe9,
                0x97, 0x2f, 0x6f, 0x54, 0x47, 0xb5, 0xeb, 0xe3, 0x48, 0x31, 0x39, 0x82, 0xc1, 0xb0,
                0x3a, 0x0f, 0x05, 0x58, 0x92, 0x42, 0x06, 0xd6, 0xe5, 0x62, 0x17, 0x35, 0x4b, 0x60,
                0x8a, 0xfa, 0x4c, 0x71, 0xbd, 0x31, 0x63, 0xe6, 0x89, 0xf8, 0xb2, 0xd3, 0xf3, 0x08,
                0x0f, 0xc5, 0x4a, 0x72, 0x2f, 0x04, 0xcb, 0x33, 0xdb, 0x93,
            ],
        },
        TestVector {
            incoming_viewing_key: [
                0x09, 0x43, 0x92, 0x00, 0x8f, 0x7c, 0xa6, 0x16, 0xa7, 0xd2, 0x62, 0x91, 0xee, 0x61,
                0xa2, 0x8c, 0x5f, 0x95, 0x9e, 0x98, 0x47, 0xb5, 0x87, 0x98, 0x66, 0xd9, 0xd1, 0x4f,
                0x2a, 0x3d, 0xba, 0x25, 0x50, 0xcd, 0xae, 0xc8, 0x71, 0x14, 0x0f, 0x1a, 0x5c, 0x1f,
                0x71, 0x4d, 0x87, 0x3e, 0x7b, 0xd3, 0x78, 0x20, 0xe7, 0xa3, 0x39, 0xce, 0x7a, 0x9d,
                0x1f, 0x5a, 0xe7, 0x77, 0x1c, 0x9b, 0xf2, 0x10,
            ],
            ovk: [
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
                0x00, 0x00, 0x00, 0x00,
            ],
            default_d: [
                0x5a, 0x57, 0x97, 0xd9, 0x8c, 0x97, 0xff, 0xb9, 0xf0, 0x51, 0x78,
            ],
            default_pk_d: [
                0xfb, 0xb7, 0x25, 0x06, 0xba, 0x12, 0xd4, 0xca, 0x99, 0x8f, 0x9a, 0x62, 0x43, 0x06,
                0x83, 0x64, 0xe0, 0x5b, 0x84, 0x04, 0x8e, 0x4c, 0x99, 0xd1, 0xbf, 0x63, 0xc0, 0x93,
                0x04, 0x6a, 0xd7, 0xad,
            ],
            v: 2367411484911514344,
            rseed: [
                0x7b, 0xea, 0x1a, 0x24, 0xae, 0x7b, 0xed, 0x65, 0xb4, 0xaf, 0xdc, 0x8f, 0x12, 0x78,
                0xc3, 0x0e, 0x2d, 0xb9, 0x8f, 0xd1, 0x72, 0x73, 0x0a, 0xc6, 0xbb, 0xed, 0x4f, 0x11,
                0x27, 0xcd, 0x32, 0xb0,
            ],
            memo: [
                0xff, 0x4a, 0x95, 0xb2, 0x05, 0x52, 0x6c, 0xfc, 0xb4, 0xc4, 0xe1, 0xcc, 0x95, 0x51,
                0x75, 0xb3, 0xe8, 0xde, 0x1f, 0x5d, 0x81, 0xb1, 0x86, 0x69, 0x69, 0x23, 0x50, 0xaa,
                0xa1, 0xa1, 0xd7, 0x97, 0x61, 0x75, 0x82, 0xe5, 0x4d, 0x7a, 0x5b, 0x57, 0xa6, 0x83,
                0xb3, 0x2f, 0xb1, 0x09, 0x80, 0x62, 0xda, 0xd7, 0xb0, 0xc2, 0xeb, 0x51, 0x8f, 0x68,
                0x62, 0xe8, 0x3d, 0xb2, 0x5e, 0x3d, 0xba, 0xf7, 0xae, 0xd5, 0x04, 0xde, 0x93, 0x2a,
                0xcb, 0x99, 0xd7, 0x35, 0x99, 0x2c, 0xe6, 0x2b, 0xae, 0x9e, 0xf8, 0x93, 0xff, 0x6a,
                0xcc, 0x0f, 0xfc, 0xf8, 0xe3, 0x48, 0x3e, 0x14, 0x6b, 0x9d, 0x49, 0xdd, 0x8c, 0x78,
                0x35, 0xf4, 0x3a, 0x37, 0xdc, 0xa0, 0x78, 0x7e, 0x3e, 0xc9, 0xf6, 0x60, 0x52, 0x23,
                0xd5, 0xba, 0x7a, 0xe0, 0xab, 0x90, 0x25, 0xb7, 0x3b, 0xc0, 0x3f, 0x7f, 0xac, 0x36,
                0xc0, 0x09, 0xa5, 0x6d, 0x4d, 0x95, 0xd1, 0xe8, 0x1d, 0x3b, 0x3e, 0xbc, 0xa7, 0xe5,
                0x4c, 0xc1, 0xa1, 0x2d, 0x12, 0x7b, 0x57, 0xc8, 0x13, 0x89, 0x76, 0xe7, 0x91, 0x01,
                0x3b, 0x01, 0x5f, 0x06, 0xa6, 0x24, 0xf5, 0x21, 0xb6, 0xee, 0x04, 0xec, 0x98, 0x08,
                0x93, 0xc7, 0xe5, 0xe0, 0x1a, 0x33, 0x62, 0x03, 0x59, 0x40, 0x94, 0xf8, 0x28, 0x33,
                0xd7, 0x44, 0x5f, 0xe2, 0xd0, 0x91, 0x30, 0xf6, 0x35, 0x11, 0xda, 0x54, 0x83, 0x2d,
                0xe9, 0x13, 0x6b, 0x39, 0xf4, 0x59, 0x9f, 0x5a, 0xa5, 0xdf, 0xbb, 0x45, 0xda, 0x60,
                0xcd, 0xce, 0xab, 0x7e, 0xef, 0xde, 0x89, 0xbe, 0x63, 0xf3, 0xf7, 0xc0, 0xd2, 0x32,
                0x48, 0x47, 0xcc, 0xe1, 0x40, 0x5d, 0xef, 0x7c, 0x46, 0x9b, 0x0e, 0x27, 0x24, 0x94,
                0xe5, 0xdf, 0x54, 0xf5, 0x68, 0x65, 0x6c, 0xb9, 0xc8, 0x81, 0x8d, 0x92, 0xb7, 0x2b,
                0x8b, 0xc3, 0x4d, 0xb7, 0xbb, 0x31, 0x12, 0x48, 0x7e, 0x74, 0x6e, 0xef, 0xe4, 0xe8,
                0x08, 0xbb, 0xb2, 0x87, 0xd9, 0x9b, 0xf0, 0x7d, 0x00, 0xda, 0xbe, 0xde, 0xdc, 0x5e,
                0x5f, 0x07, 0x4f, 0xfe, 0xae, 0x0c, 0xba, 0x7d, 0xa3, 0xa5, 0x16, 0xc1, 0x73, 0xbe,
                0x1c, 0x51, 0x33, 0x23, 0xe1, 0x19, 0xf6, 0x35, 0xe8, 0x20, 0x9a, 0x07, 0x4b, 0x21,
                0x6b, 0x70, 0x23, 0xfa, 0xdc, 0x2d, 0x25, 0x94, 0x9c, 0x90, 0x03, 0x7e, 0x71, 0xe3,
                0xe5, 0x50, 0x72, 0x6d, 0x21, 0x0a, 0x2c, 0x68, 0x83, 0x42, 0xe5, 0x24, 0x40, 0x63,
                0x5e, 0x9c, 0xc1, 0x4a, 0xfe, 0x10, 0x10, 0x26, 0x21, 0xa9, 0xc9, 0xac, 0xcb, 0x78,
                0x2e, 0x9e, 0x4a, 0x5f, 0xa8, 0x7f, 0x0a, 0x95, 0x6f, 0x5b, 0x85, 0x50, 0x99, 0x60,
                0x28, 0x5c, 0x22, 0x62, 0x7c, 0x59, 0x48, 0x3a, 0x5a, 0x4c, 0x28, 0xcc, 0xe4, 0xb1,
                0x56, 0xe5, 0x51, 0x40, 0x6a, 0x7e, 0xe8, 0x35, 0x56, 0x56, 0xa2, 0x1e, 0x43, 0xe3,
                0x8c, 0xe1, 0x29, 0xfd, 0xad, 0xb7, 0x59, 0xed, 0xdf, 0xa0, 0x8f, 0x00, 0xfc, 0x8e,
                0x56, 0x7c, 0xef, 0x93, 0xc6, 0x79, 0x2d, 0x01, 0xdf, 0x05, 0xe6, 0xd5, 0x80, 0xf4,
                0xd5, 0xd4, 0x8d, 0xf0, 0x42, 0x45, 0x1a, 0x33, 0x59, 0x0d, 0x3e, 0x8c, 0xf4, 0x9b,
                0x26, 0x27, 0x21, 0x8f, 0x0c, 0x29, 0x2f, 0xa6, 0x6a, 0xda, 0x94, 0x5f, 0xa5, 0x5b,
                0xb2, 0x35, 0x48, 0xe3, 0x3a, 0x83, 0xa5, 0x62, 0x95, 0x7a, 0x31, 0x49, 0xa9, 0x93,
                0xcc, 0x47, 0x23, 0x62, 0x29, 0x87, 0x36, 0xa8, 0xb7, 0x78, 0xd9, 0x7c, 0xe4, 0x23,
                0x01, 0x3d, 0x64, 0xb3, 0x2c, 0xd1, 0x72, 0xef, 0xa5, 0x51, 0xbf, 0x7f, 0x36, 0x8f,
                0x04, 0xbd, 0xae, 0xc6, 0x09, 0x1a, 0x30, 0x04, 0xa7, 0x57, 0x59, 0x8b, 0x80, 0x1d,
                0xcf, 0x67, 0x5c, 0xb8, 0x3e, 0x43, 0xa5, 0x3a,
            ],
            cv_net: [
                0xfd, 0xab, 0xa2, 0xd8, 0x84, 0xcd, 0xcc, 0xac, 0x48, 0x58, 0x58, 0x66, 0xc0, 0x6a,
                0x10, 0x9f, 0x12, 0xfe, 0x0f, 0xf2, 0x53, 0x31, 0x0d, 0xee, 0x06, 0xd6, 0x7a, 0x8d,
                0xdd, 0x27, 0xbe, 0xab,
            ],
            rho: [
                0x9a, 0x09, 0xe4, 0x72, 0xe8, 0xe9, 0x96, 0xfc, 0xc3, 0x0e, 0xd5, 0x23, 0x72, 0x08,
                0xdb, 0xb0, 0x01, 0x71, 0x32, 0x0e, 0x6b, 0xea, 0x43, 0x91, 0x86, 0x00, 0x9d, 0xad,
                0x21, 0x38, 0xab, 0x29,
            ],
            cmx: [
                0x18, 0x28, 0x68, 0x41, 0xc5, 0xce, 0x1f, 0x68, 0x68, 0xd7, 0x7f, 0x86, 0x09, 0x9f,
                0xb5, 0x1f, 0xb9, 0xa6, 0x93, 0x6a, 0x5a, 0x92, 0x94, 0xaa, 0xac, 0x89, 0x34, 0xe3,
                0x97, 0xb2, 0x73, 0x01,
            ],
            esk: [
                0x9f, 0xb2, 0xa6, 0x43, 0xa4, 0x8a, 0x23, 0xe4, 0x73, 0xd8, 0xf4, 0x6d, 0xa1, 0x9d,
                0xca, 0xa6, 0x2d, 0xff, 0x4c, 0xa4, 0xe4, 0xe6, 0x77, 0x1a, 0x0c, 0x0f, 0x5c, 0x48,
                0xee, 0xbf, 0x02, 0x34,
            ],
            ephemeral_key: [
                0x6a, 0xd7, 0x29, 0x61, 0x8d, 0x86, 0xff, 0xaf, 0x04, 0xe8, 0x91, 0x2e, 0x80, 0x6a,
                0x4a, 0x69, 0x31, 0x39, 0xe8, 0xfc, 0xc1, 0x6a, 0xdc, 0xf4, 0x50, 0x5e, 0x41, 0x8b,
                0x34, 0xf1, 0x83, 0x07,
            ],
            shared_secret: [
                0x14, 0xe2, 0x5f, 0xa9, 0x35, 0x31, 0x64, 0x2a, 0x25, 0x5a, 0x69, 0x3d, 0x2d, 0x23,
                0x98, 0x8a, 0x6f, 0x24, 0xd3, 0xc9, 0xcb, 0x34, 0x1e, 0xd4, 0x54, 0x5a, 0xdf, 0xd4,
                0x94, 0xc3, 0xdf, 0x2d,
            ],
            k_enc: [
                0x4d, 0x65, 0xcb, 0x25, 0xa2, 0x41, 0xf2, 0xd2, 0xc5, 0x60, 0xf2, 0x1b, 0x10, 0x53,
                0x10, 0x9d, 0x5c, 0xcc, 0x21, 0x99, 0xcd, 0xfe, 0xb0, 0xc9, 0xa7, 0x5f, 0xff, 0x29,
                0x35, 0xfc, 0x56, 0x4b,
            ],
            p_enc: [
                0x02, 0x5a, 0x57, 0x97, 0xd9, 0x8c, 0x97, 0xff, 0xb9, 0xf0, 0x51, 0x78, 0xe8, 0xb2,
                0x54, 0xd3, 0x33, 0xbc, 0xda, 0x20, 0x7b, 0xea, 0x1a, 0x24, 0xae, 0x7b, 0xed, 0x65,
                0xb4, 0xaf, 0xdc, 0x8f, 0x12, 0x78, 0xc3, 0x0e, 0x2d, 0xb9, 0x8f, 0xd1, 0x72, 0x73,
                0x0a, 0xc6, 0xbb, 0xed, 0x4f, 0x11, 0x27, 0xcd, 0x32, 0xb0, 0xff, 0x4a, 0x95, 0xb2,
                0x05, 0x52, 0x6c, 0xfc, 0xb4, 0xc4, 0xe1, 0xcc, 0x95, 0x51, 0x75, 0xb3, 0xe8, 0xde,
                0x1f, 0x5d, 0x81, 0xb1, 0x86, 0x69, 0x69, 0x23, 0x50, 0xaa, 0xa1, 0xa1, 0xd7, 0x97,
                0x61, 0x75, 0x82, 0xe5, 0x4d, 0x7a, 0x5b, 0x57, 0xa6, 0x83, 0xb3, 0x2f, 0xb1, 0x09,
                0x80, 0x62, 0xda, 0xd7, 0xb0, 0xc2, 0xeb, 0x51, 0x8f, 0x68, 0x62, 0xe8, 0x3d, 0xb2,
                0x5e, 0x3d, 0xba, 0xf7, 0xae, 0xd5, 0x04, 0xde, 0x93, 0x2a, 0xcb, 0x99, 0xd7, 0x35,
                0x99, 0x2c, 0xe6, 0x2b, 0xae, 0x9e, 0xf8, 0x93, 0xff, 0x6a, 0xcc, 0x0f, 0xfc, 0xf8,
                0xe3, 0x48, 0x3e, 0x14, 0x6b, 0x9d, 0x49, 0xdd, 0x8c, 0x78, 0x35, 0xf4, 0x3a, 0x37,
                0xdc, 0xa0, 0x78, 0x7e, 0x3e, 0xc9, 0xf6, 0x60, 0x52, 0x23, 0xd5, 0xba, 0x7a, 0xe0,
                0xab, 0x90, 0x25, 0xb7, 0x3b, 0xc0, 0x3f, 0x7f, 0xac, 0x36, 0xc0, 0x09, 0xa5, 0x6d,
                0x4d, 0x95, 0xd1, 0xe8, 0x1d, 0x3b, 0x3e, 0xbc, 0xa7, 0xe5, 0x4c, 0xc1, 0xa1, 0x2d,
                0x12, 0x7b, 0x57, 0xc8, 0x13, 0x89, 0x76, 0xe7, 0x91, 0x01, 0x3b, 0x01, 0x5f, 0x06,
                0xa6, 0x24, 0xf5, 0x21, 0xb6, 0xee, 0x04, 0xec, 0x98, 0x08, 0x93, 0xc7, 0xe5, 0xe0,
                0x1a, 0x33, 0x62, 0x03, 0x59, 0x40, 0x94, 0xf8, 0x28, 0x33, 0xd7, 0x44, 0x5f, 0xe2,
                0xd0, 0x91, 0x30, 0xf6, 0x35, 0x11, 0xda, 0x54, 0x83, 0x2d, 0xe9, 0x13, 0x6b, 0x39,
                0xf4, 0x59, 0x9f, 0x5a, 0xa5, 0xdf, 0xbb, 0x45, 0xda, 0x60, 0xcd, 0xce, 0xab, 0x7e,
                0xef, 0xde, 0x89, 0xbe, 0x63, 0xf3, 0xf7, 0xc0, 0xd2, 0x32, 0x48, 0x47, 0xcc, 0xe1,
                0x40, 0x5d, 0xef, 0x7c, 0x46, 0x9b, 0x0e, 0x27, 0x24, 0x94, 0xe5, 0xdf, 0x54, 0xf5,
                0x68, 0x65, 0x6c, 0xb9, 0xc8, 0x81, 0x8d, 0x92, 0xb7, 0x2b, 0x8b, 0xc3, 0x4d, 0xb7,
                0xbb, 0x31, 0x12, 0x48, 0x7e, 0x74, 0x6e, 0xef, 0xe4, 0xe8, 0x08, 0xbb, 0xb2, 0x87,
                0xd9, 0x9b, 0xf0, 0x7d, 0x00, 0xda, 0xbe, 0xde, 0xdc, 0x5e, 0x5f, 0x07, 0x4f, 0xfe,
                0xae, 0x0c, 0xba, 0x7d, 0xa3, 0xa5, 0x16, 0xc1, 0x73, 0xbe, 0x1c, 0x51, 0x33, 0x23,
                0xe1, 0x19, 0xf6, 0x35, 0xe8, 0x20, 0x9a, 0x07, 0x4b, 0x21, 0x6b, 0x70, 0x23, 0xfa,
                0xdc, 0x2d, 0x25, 0x94, 0x9c, 0x90, 0x03, 0x7e, 0x71, 0xe3, 0xe5, 0x50, 0x72, 0x6d,
                0x21, 0x0a, 0x2c, 0x68, 0x83, 0x42, 0xe5, 0x24, 0x40, 0x63, 0x5e, 0x9c, 0xc1, 0x4a,
                0xfe, 0x10, 0x10, 0x26, 0x21, 0xa9, 0xc9, 0xac, 0xcb, 0x78, 0x2e, 0x9e, 0x4a, 0x5f,
                0xa8, 0x7f, 0x0a, 0x95, 0x6f, 0x5b, 0x85, 0x50, 0x99, 0x60, 0x28, 0x5c, 0x22, 0x62,
                0x7c, 0x59, 0x48, 0x3a, 0x5a, 0x4c, 0x28, 0xcc, 0xe4, 0xb1, 0x56, 0xe5, 0x51, 0x40,
                0x6a, 0x7e, 0xe8, 0x35, 0x56, 0x56, 0xa2, 0x1e, 0x43, 0xe3, 0x8c, 0xe1, 0x29, 0xfd,
                0xad, 0xb7, 0x59, 0xed, 0xdf, 0xa0, 0x8f, 0x00, 0xfc, 0x8e, 0x56, 0x7c, 0xef, 0x93,
                0xc6, 0x79, 0x2d, 0x01, 0xdf, 0x05, 0xe6, 0xd5, 0x80, 0xf4, 0xd5, 0xd4, 0x8d, 0xf0,
                0x42, 0x45, 0x1a, 0x33, 0x59, 0x0d, 0x3e, 0x8c, 0xf4, 0x9b, 0x26, 0x27, 0x21, 0x8f,
                0x0c, 0x29, 0x2f, 0xa6, 0x6a, 0xda, 0x94, 0x5f, 0xa5, 0x5b, 0xb2, 0x35, 0x48, 0xe3,
                0x3a, 0x83, 0xa5, 0x62, 0x95, 0x7a, 0x31, 0x49, 0xa9, 0x93, 0xcc, 0x47, 0x23, 0x62,
                0x29, 0x87, 0x36, 0xa8, 0xb7, 0x78, 0xd9, 0x7c, 0xe4, 0x23, 0x01, 0x3d, 0x64, 0xb3,
                0x2c, 0xd1, 0x72, 0xef, 0xa5, 0x51, 0xbf, 0x7f, 0x36, 0x8f, 0x04, 0xbd, 0xae, 0xc6,
                0x09, 0x1a, 0x30, 0x04, 0xa7, 0x57, 0x59, 0x8b, 0x80, 0x1d, 0xcf, 0x67, 0x5c, 0xb8,
                0x3e, 0x43, 0xa5, 0x3a,
            ],
            c_enc: [
                0x3d, 0x5d, 0xcc, 0xff, 0xaf, 0xcc, 0xa0, 0x69, 0x34, 0xcc, 0x99, 0x04, 0x24, 0x0b,
                0xd7, 0xfb, 0xab, 0x28, 0x83, 0xe6, 0x64, 0x5f, 0x97, 0xde, 0x95, 0x63, 0xeb, 0x2e,
                0xed, 0xf5, 0xc1, 0xb2, 0x70, 0x18, 0x83, 0x3c, 0x3a, 0xec, 0x97, 0x55, 0x5d, 0x23,
                0x92, 0xf7, 0xad, 0x74, 0x90, 0x89, 0xd4, 0xaf, 0x42, 0x6a, 0x38, 0x15, 0x83, 0x7a,
                0x77, 0x83, 0x63, 0x4a, 0x9e, 0xf6, 0xd5, 0xde, 0xdf, 0x95, 0xdf, 0xa9, 0x3f, 0x62,
                0xec, 0xe0, 0xda, 0x45, 0xe3, 0x37, 0x36, 0x0d, 0x0b, 0xae, 0x24, 0x65, 0x27, 0xe3,
                0xcd, 0x67, 0xe5, 0xae, 0x66, 0xc0, 0x1c, 0x76, 0x56, 0x2e, 0xc4, 0xf9, 0x72, 0xaf,
                0x88, 0xc5, 0x86, 0x8d, 0x55, 0xca, 0x05, 0x96, 0xe1, 0x65, 0x8c, 0x54, 0x13, 0xba,
                0xe2, 0xe7, 0x20, 0x5f, 0x85, 0x36, 0x92, 0x24, 0x91, 0x8f, 0x07, 0x75, 0xc8, 0x7c,
                0x8a, 0xa1, 0x25, 0x98, 0x1e, 0x2f, 0xdf, 0x0b, 0x57, 0x14, 0xf9, 0x25, 0x51, 0x98,
                0xd5, 0xe4, 0x8e, 0x03, 0x2e, 0xaf, 0xb6, 0xc9, 0x53, 0x90, 0xdb, 0xc3, 0x27, 0x36,
                0x76, 0x32, 0xcc, 0x0e, 0xed, 0xd5, 0x10, 0xe6, 0x51, 0x0a, 0x8e, 0xc6, 0x03, 0xe8,
                0x6b, 0x67, 0x1e, 0xfc, 0xae, 0x6d, 0x90, 0x74, 0x1c, 0xda, 0xf2, 0xdb, 0xb4, 0x7f,
                0x68, 0xb4, 0x95, 0x90, 0x2d, 0x26, 0xe0, 0xa7, 0x8b, 0x9f, 0xdd, 0x68, 0xaa, 0x91,
                0xbc, 0x80, 0x79, 0x22, 0xa3, 0x16, 0xb8, 0xaf, 0x47, 0xa0, 0xd5, 0x2e, 0x7a, 0x3e,
                0x4b, 0x33, 0xd6, 0x97, 0x5d, 0x10, 0x02, 0x77, 0x35, 0xf5, 0xbc, 0x88, 0xa9, 0xd7,
                0xfc, 0x2c, 0x2f, 0x4c, 0xd0, 0xe1, 0x8a, 0x7e, 0xbb, 0x50, 0x8a, 0x83, 0xce, 0x9a,
                0xbf, 0xbd, 0x07, 0x7d, 0x2d, 0xd4, 0x5a, 0x4c, 0x0b, 0x21, 0x53, 0x6e, 0xea, 0xfd,
                0x87, 0xc2, 0xb5, 0x38, 0x5e, 0x31, 0xed, 0x8a, 0xcd, 0x58, 0x7f, 0x5c, 0x5a, 0xb8,
                0x7d, 0xe3, 0x63, 0x61, 0x1d, 0xf0, 0xac, 0x30, 0xa6, 0x18, 0xf4, 0x10, 0x87, 0xd5,
                0x95, 0x15, 0x0a, 0x9c, 0xab, 0x0a, 0x36, 0x01, 0x4d, 0xff, 0x2b, 0x2f, 0x0b, 0xb6,
                0x00, 0xd0, 0x1f, 0x69, 0xe2, 0x9c, 0xd9, 0x8e, 0x8e, 0x16, 0x02, 0xa2, 0xef, 0x2c,
                0x04, 0x30, 0xe5, 0xf6, 0x24, 0x45, 0x66, 0x2e, 0xc4, 0xa1, 0x22, 0x3a, 0xe7, 0xc2,
                0x51, 0x1d, 0xdc, 0x86, 0x11, 0xa6, 0xcc, 0x4f, 0x41, 0xd1, 0x2b, 0xcb, 0xc8, 0x73,
                0xb4, 0x33, 0x7d, 0x34, 0xf4, 0xec, 0x48, 0xa9, 0xb6, 0xb9, 0x67, 0x19, 0xd2, 0x9d,
                0x45, 0x01, 0x0e, 0xe7, 0x7c, 0xcd, 0x6b, 0x6a, 0x43, 0x35, 0x8c, 0x54, 0xa1, 0xd7,
                0x8e, 0xc1, 0xd7, 0xa6, 0x11, 0xef, 0x47, 0x1b, 0x39, 0xb0, 0x64, 0x60, 0x47, 0x3b,
                0x6b, 0x68, 0xd4, 0x4f, 0x0a, 0x5c, 0x1b, 0xef, 0xa2, 0x48, 0x71, 0x14, 0x19, 0xcc,
                0x91, 0xc0, 0x55, 0x34, 0xea, 0x62, 0x67, 0xaa, 0x6d, 0x3a, 0xb8, 0x06, 0x8d, 0x6d,
                0x86, 0xc4, 0xac, 0xcd, 0x36, 0x7b, 0xe4, 0xe1, 0xb3, 0xcf, 0x94, 0xc8, 0x82, 0x72,
                0x69, 0x46, 0x89, 0xbc, 0xbc, 0xae, 0x28, 0x1f, 0xb6, 0x61, 0x16, 0xe2, 0x9e, 0xf0,
                0xbf, 0x45, 0xcd, 0x0e, 0xe3, 0x64, 0x47, 0x6a, 0x28, 0x50, 0xee, 0xa0, 0x75, 0x8a,
                0x7e, 0x26, 0x4d, 0x40, 0x27, 0x08, 0xa6, 0xf1, 0x05, 0xdb, 0x43, 0x65, 0x6e, 0x00,
                0xbf, 0x45, 0x0a, 0x9b, 0xf9, 0x12, 0x76, 0xe3, 0xab, 0x95, 0x67, 0x10, 0x82, 0x57,
                0x02, 0xd0, 0x67, 0x20, 0xf6, 0x7b, 0x1d, 0xf8, 0xff, 0x67, 0xa2, 0xd1, 0x29, 0xd9,
                0xea, 0x33, 0xf9, 0x41, 0xd4, 0x9a, 0xe6, 0x37, 0xfc, 0xfa, 0x7f, 0xed, 0xfd, 0xc5,
                0xec, 0xdb, 0xba, 0x95, 0xc0, 0xee, 0xba, 0xb5, 0x94, 0x19, 0xd9, 0x03, 0x66, 0x5a,
                0xf0, 0x82, 0xec, 0x7c, 0x3e, 0xc4, 0xf5, 0xfa, 0x27, 0x71, 0xe1, 0xe0, 0xde, 0xdf,
                0x64, 0x8b, 0x2c, 0x90, 0xed, 0x03, 0xf0, 0xe0, 0xa6, 0xcc, 0x25, 0x1e, 0x51, 0x33,
                0x9b, 0xdc, 0x79, 0xf2, 0x0f, 0xf6, 0xb9, 0x63, 0x2e, 0xd1, 0x2b, 0xaf, 0xb6, 0xbb,
                0x23, 0xf8, 0x2f, 0x6c, 0x42, 0xf1, 0x73, 0x0b, 0xc7, 0x24, 0xbb, 0x82, 0xce, 0x92,
                0x5c, 0x0c, 0x7a, 0xb3, 0xb1, 0x9f,
            ],
            ock: [
                0x9f, 0x44, 0x63, 0x66, 0x9f, 0x27, 0x11, 0x10, 0xfc, 0xa1, 0x12, 0x8a, 0xa0, 0x5f,
                0x06, 0x7d, 0x17, 0x5c, 0xbe, 0xcd, 0xe4, 0x49, 0x5f, 0x51, 0x89, 0xf9, 0x6b, 0x80,
                0x82, 0x79, 0x3a, 0x77,
            ],
            op: [
                0xfb, 0xb7, 0x25, 0x06, 0xba, 0x12, 0xd4, 0xca, 0x99, 0x8f, 0x9a, 0x62, 0x43, 0x06,
                0x83, 0x64, 0xe0, 0x5b, 0x84, 0x04, 0x8e, 0x4c, 0x99, 0xd1, 0xbf, 0x63, 0xc0, 0x93,
                0x04, 0x6a, 0xd7, 0xad, 0x9f, 0xb2, 0xa6, 0x43, 0xa4, 0x8a, 0x23, 0xe4, 0x73, 0xd8,
                0xf4, 0x6d, 0xa1, 0x9d, 0xca, 0xa6, 0x2d, 0xff, 0x4c, 0xa4, 0xe4, 0xe6, 0x77, 0x1a,
                0x0c, 0x0f, 0x5c, 0x48, 0xee, 0xbf, 0x02, 0x34,
            ],
            c_out: [
                0x59, 0xb3, 0xcf, 0xa0, 0xd4, 0x71, 0xb9, 0xb4, 0xad, 0x3d, 0xfb, 0xc6, 0x2e, 0x50,
                0x79, 0x13, 0xf6, 0xc1, 0xff, 0x2c, 0xb0, 0x8f, 0x11, 0x15, 0x30, 0xa5, 0xff, 0x5e,
                0xe4, 0xfd, 0x23, 0x41, 0x15, 0xf9, 0xad, 0x9a, 0xc8, 0xf6, 0x05, 0xde, 0x6a, 0xf4,
                0x55, 0x88, 0x8c, 0x48, 0x1f, 0x96, 0x27, 0x0d, 0x97, 0xa8, 0xd4, 0xae, 0x74, 0xfa,
                0xfd, 0xfa, 0xb3, 0x2f, 0xd0, 0x8d, 0xf4, 0x47, 0x1c, 0x60, 0xe7, 0xe8, 0x3a, 0x62,
                0xa4, 0x30, 0x24, 0xdf, 0x38, 0xb9, 0xed, 0x45, 0x3f, 0x1c,
            ],
        },
        TestVector {
            incoming_viewing_key: [
                0x1f, 0xd7, 0x5d, 0x76, 0x17, 0x24, 0x8f, 0x4e, 0x71, 0xa4, 0xc0, 0x7b, 0xc7, 0x72,
                0xc6, 0x59, 0xc2, 0x2d, 0xde, 0xeb, 0x3c, 0x84, 0x2f, 0xf2, 0x80, 0x72, 0xae, 0x94,
                0x3d, 0xba, 0xb6, 0x10, 0x22, 0x05, 0x24, 0x39, 0xe7, 0x21, 0xa9, 0x71, 0x79, 0x8f,
                0x1b, 0xc6, 0x6a, 0xf5, 0x84, 0x93, 0x7b, 0x33, 0x3a, 0xb4, 0x73, 0x56, 0xe4, 0x98,
                0x60, 0xba, 0x67, 0x22, 0xc4, 0x2b, 0x73, 0x15,
            ],
            ovk: [
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
                0x00, 0x00, 0x00, 0x00,
            ],
            default_d: [
                0x53, 0x69, 0xca, 0xbb, 0xf9, 0x1e, 0xb1, 0x94, 0x65, 0xd6, 0xbd,
            ],
            default_pk_d: [
                0x54, 0x13, 0xcc, 0x6c, 0xaa, 0xe4, 0xaa, 0x16, 0xc9, 0x0f, 0x58, 0xfb, 0x6c, 0x88,
                0x19, 0x54, 0x5d, 0x19, 0x66, 0xd8, 0x3e, 0xe3, 0x99, 0x1a, 0x63, 0x19, 0x0c, 0xe8,
                0x8b, 0xa8, 0xa0, 0xac,
            ],
            v: 15057875082412072133,
            rseed: [
                0xea, 0x31, 0x49, 0x5a, 0xf8, 0x19, 0xa0, 0x16, 0xcc, 0x41, 0x9e, 0x07, 0xc5, 0x01,
                0xaa, 0x83, 0x09, 0xb2, 0xe6, 0xc8, 0x5b, 0x79, 0xb2, 0x76, 0x37, 0x33, 0xa3, 0x7b,
                0xbc, 0x04, 0x20, 0xd4,
            ],
            memo: [
                0xff, 0x25, 0x37, 0xb8, 0x71, 0xb4, 0x29, 0x4a, 0x65, 0xd3, 0xe0, 0x55, 0xff, 0x71,
                0x8d, 0xd9, 0xdc, 0x8c, 0x75, 0xe7, 0xe5, 0xb2, 0xef, 0xe4, 0x42, 0x63, 0x73, 0x71,
                0xb7, 0xc4, 0x8f, 0x6e, 0xe9, 0x9e, 0x3e, 0xa3, 0x8a, 0x4b, 0x0f, 0x2f, 0x67, 0xfc,
                0x2b, 0x90, 0x8c, 0xda, 0x65, 0x7e, 0xae, 0x75, 0x4e, 0x03, 0x7e, 0x26, 0x2e, 0x9a,
                0x9f, 0x9b, 0xd7, 0xec, 0x42, 0x67, 0xed, 0x8e, 0x96, 0x93, 0x0e, 0x10, 0x84, 0x78,
                0x3c, 0x37, 0xd6, 0xf9, 0xdd, 0x15, 0xfd, 0x29, 0xf4, 0xcc, 0x47, 0x7e, 0x66, 0xf1,
                0x30, 0xd6, 0x30, 0x43, 0x0d, 0xcc, 0x01, 0x04, 0x89, 0x9b, 0x4f, 0x9f, 0x46, 0xeb,
                0x09, 0x0e, 0xf7, 0xfc, 0x90, 0xb4, 0x79, 0xab, 0xf6, 0x1f, 0x93, 0x95, 0x5e, 0xe0,
                0x0e, 0x6a, 0x18, 0x48, 0xf1, 0xab, 0x14, 0xad, 0x33, 0x4f, 0x2b, 0x68, 0x03, 0x58,
                0x08, 0xcd, 0xf1, 0xbb, 0x9e, 0x9d, 0x9a, 0x81, 0x6b, 0xaf, 0x72, 0x8a, 0x95, 0x5b,
                0x96, 0x0b, 0x77, 0x01, 0xfa, 0x62, 0x66, 0x87, 0xdc, 0x3c, 0x9c, 0xba, 0x64, 0x63,
                0x37, 0xb5, 0x3e, 0x29, 0x81, 0x6e, 0x94, 0x82, 0xdd, 0xf5, 0x57, 0x8a, 0x87, 0x68,
                0xaa, 0xe4, 0x77, 0xfc, 0xe4, 0x10, 0xac, 0x2d, 0x5d, 0xe6, 0x09, 0x58, 0x61, 0xc1,
                0x11, 0xd7, 0xfe, 0xb3, 0xe6, 0xbb, 0x4f, 0xbb, 0x5a, 0x54, 0x95, 0x54, 0x95, 0x97,
                0x27, 0x98, 0x35, 0x0a, 0x25, 0x3f, 0x05, 0xf6, 0x6c, 0x2e, 0xcf, 0xcb, 0xc0, 0xed,
                0x43, 0xf5, 0xec, 0x2e, 0x6d, 0x8d, 0xba, 0x15, 0xa5, 0x12, 0x54, 0xd9, 0x7b, 0x18,
                0x21, 0x10, 0x7c, 0x07, 0xdd, 0x9a, 0x16, 0xef, 0x84, 0x06, 0xf9, 0x43, 0xe2, 0x82,
                0xb9, 0x5d, 0x4b, 0x36, 0x25, 0x30, 0xc9, 0x13, 0xd6, 0xba, 0x42, 0x1d, 0xf6, 0x02,
                0x7d, 0xe5, 0xaf, 0x1e, 0x47, 0x45, 0xd5, 0x86, 0x81, 0x06, 0x95, 0x4b, 0xe6, 0xc1,
                0x96, 0x27, 0x80, 0xa2, 0x94, 0x10, 0x72, 0xe9, 0x51, 0x31, 0xb1, 0x67, 0x9d, 0xf0,
                0x63, 0x76, 0x25, 0x04, 0x2c, 0x37, 0xd4, 0x8f, 0xfb, 0x15, 0x2e, 0x5e, 0xbc, 0x18,
                0x5c, 0x8a, 0x2b, 0x7d, 0x43, 0x85, 0xf1, 0xc9, 0x5a, 0xf9, 0x37, 0xdf, 0x78, 0xdf,
                0xd8, 0x75, 0x7f, 0xab, 0x43, 0x49, 0x68, 0xb0, 0xb5, 0x7c, 0x66, 0x57, 0x44, 0x68,
                0xf1, 0x60, 0xb4, 0x47, 0xac, 0x82, 0x21, 0xe5, 0x06, 0x06, 0x76, 0xa8, 0x42, 0xa1,
                0xc6, 0xb7, 0x17, 0x2d, 0xd3, 0x34, 0x0f, 0x76, 0x40, 0x70, 0xab, 0x1f, 0xe0, 0x91,
                0xc5, 0xc7, 0x4c, 0x95, 0xa5, 0xdc, 0x04, 0x33, 0x90, 0x72, 0x3a, 0x4c, 0x12, 0x7d,
                0xa1, 0x4c, 0xdd, 0xe1, 0xdc, 0x26, 0x75, 0xa6, 0x23, 0x40, 0xb3, 0xe6, 0xaf, 0xd0,
                0x52, 0x2a, 0x31, 0xde, 0x26, 0xe7, 0xd1, 0xec, 0x3a, 0x9c, 0x8a, 0x09, 0x1f, 0xfd,
                0xc7, 0x5b, 0x7e, 0xcf, 0xdc, 0x7c, 0x12, 0x99, 0x5a, 0x5e, 0x37, 0xce, 0x34, 0x88,
                0xbd, 0x29, 0xf8, 0x62, 0x9d, 0x68, 0xf6, 0x96, 0x49, 0x24, 0x48, 0xdd, 0x52, 0x66,
                0x97, 0x47, 0x6d, 0xc0, 0x61, 0x34, 0x6e, 0xbe, 0x3f, 0x67, 0x72, 0x17, 0xff, 0x9c,
                0x60, 0xef, 0xce, 0x94, 0x3a, 0xf2, 0x8d, 0xfd, 0x3f, 0x9e, 0x59, 0x69, 0x25, 0x98,
                0xa6, 0x04, 0x7c, 0x23, 0xc4, 0xc0, 0x14, 0x00, 0xf1, 0xab, 0x57, 0x30, 0xea, 0xc0,
                0xae, 0x8d, 0x58, 0x43, 0xd5, 0x05, 0x1c, 0x37, 0x62, 0x40, 0x17, 0x2a, 0xf2, 0x18,
                0xd7, 0xa1, 0xec, 0xfe, 0x65, 0xb4, 0xf7, 0x51, 0x00, 0x63, 0x89, 0x83, 0xc1, 0x4d,
                0xe4, 0x97, 0x47, 0x55, 0xda, 0xde, 0x80, 0x18, 0xc9, 0xb8, 0xf4, 0x54, 0x3f, 0xb0,
                0x95, 0x96, 0x15, 0x13, 0xe6, 0x7c, 0x61, 0xdb,
            ],
            cv_net: [
                0x9b, 0xc2, 0xf6, 0xa7, 0x65, 0x96, 0x44, 0xcd, 0x28, 0x62, 0x88, 0xca, 0xc6, 0xd7,
                0x53, 0xa7, 0x75, 0x96, 0xe1, 0xc6, 0x00, 0xf0, 0x39, 0xe2, 0xc0, 0x96, 0x57, 0x29,
                0x74, 0x15, 0xb7, 0x35,
            ],
            rho: [
                0x54, 0x3e, 0xa7, 0x11, 0x56, 0xc9, 0xa6, 0xf8, 0x04, 0x1f, 0xa7, 0x7e, 0xc1, 0xc5,
                0xaf, 0x90, 0x28, 0x8f, 0x27, 0x20, 0xf1, 0x3f, 0xf0, 0x93, 0xc6, 0x86, 0x26, 0x6b,
                0x92, 0xd7, 0xa0, 0x24,
            ],
            cmx: [
                0x99, 0x6f, 0xf9, 0x3b, 0x1a, 0x28, 0xe8, 0x84, 0xda, 0x9f, 0x78, 0xdf, 0xb5, 0x3e,
                0xd7, 0x67, 0x05, 0xba, 0x6d, 0xfe, 0x61, 0xa4, 0xf5, 0x24, 0x9f, 0x10, 0x47, 0x65,
                0x2a, 0x25, 0xcb, 0x03,
            ],
            esk: [
                0x49, 0xab, 0xcd, 0x2a, 0xeb, 0xb2, 0x8f, 0xed, 0xb0, 0x83, 0x88, 0x17, 0xd4, 0xa7,
                0xc1, 0x3f, 0x31, 0xe8, 0xef, 0x55, 0xeb, 0x89, 0xe4, 0xe1, 0x03, 0xf7, 0xc3, 0xfd,
                0xba, 0x56, 0x5d, 0x06,
            ],
            ephemeral_key: [
                0xe0, 0x93, 0x30, 0xf0, 0x46, 0x81, 0x91, 0xc6, 0x6b, 0x0a, 0x74, 0x65, 0xf3, 0x63,
                0x1f, 0x83, 0x14, 0xd5, 0x6a, 0xa0, 0xe5, 0xc7, 0x80, 0x89, 0x46, 0x53, 0x3e, 0xa3,
                0x5c, 0xdd, 0x60, 0x10,
            ],
            shared_secret: [
                0x54, 0x56, 0xfc, 0xf8, 0x54, 0x27, 0xba, 0xb4, 0x05, 0x52, 0xe6, 0x00, 0x32, 0x5a,
                0x0b, 0x73, 0x1b, 0x46, 0x84, 0x0f, 0x0c, 0x94, 0x64, 0x60, 0xcc, 0x66, 0x4f, 0x28,
                0xc0, 0xdc, 0x0c, 0xb6,
            ],
            k_enc: [
                0x56, 0xc4, 0x5b, 0x56, 0xf0, 0xf7, 0x10, 0xd7, 0xc2, 0xdf, 0x47, 0x53, 0x4b, 0x5c,
                0xce, 0x3e, 0x17, 0x81, 0xd6, 0x79, 0xb6, 0x10, 0xa1, 0x75, 0x24, 0xf6, 0xbf, 0xf2,
                0x68, 0x23, 0x44, 0xec,
            ],
            p_enc: [
                0x02, 0x53, 0x69, 0xca, 0xbb, 0xf9, 0x1e, 0xb1, 0x94, 0x65, 0xd6, 0xbd, 0xc5, 0x9c,
                0x60, 0x7f, 0x9b, 0x51, 0xf8, 0xd0, 0xea, 0x31, 0x49, 0x5a, 0xf8, 0x19, 0xa0, 0x16,
                0xcc, 0x41, 0x9e, 0x07, 0xc5, 0x01, 0xaa, 0x83, 0x09, 0xb2, 0xe6, 0xc8, 0x5b, 0x79,
                0xb2, 0x76, 0x37, 0x33, 0xa3, 0x7b, 0xbc, 0x04, 0x20, 0xd4, 0xff, 0x25, 0x37, 0xb8,
                0x71, 0xb4, 0x29, 0x4a, 0x65, 0xd3, 0xe0, 0x55, 0xff, 0x71, 0x8d, 0xd9, 0xdc, 0x8c,
                0x75, 0xe7, 0xe5, 0xb2, 0xef, 0xe4, 0x42, 0x63, 0x73, 0x71, 0xb7, 0xc4, 0x8f, 0x6e,
                0xe9, 0x9e, 0x3e, 0xa3, 0x8a, 0x4b, 0x0f, 0x2f, 0x67, 0xfc, 0x2b, 0x90, 0x8c, 0xda,
                0x65, 0x7e, 0xae, 0x75, 0x4e, 0x03, 0x7e, 0x26, 0x2e, 0x9a, 0x9f, 0x9b, 0xd7, 0xec,
                0x42, 0x67, 0xed, 0x8e, 0x96, 0x93, 0x0e, 0x10, 0x84, 0x78, 0x3c, 0x37, 0xd6, 0xf9,
                0xdd, 0x15, 0xfd, 0x29, 0xf4, 0xcc, 0x47, 0x7e, 0x66, 0xf1, 0x30, 0xd6, 0x30, 0x43,
                0x0d, 0xcc, 0x01, 0x04, 0x89, 0x9b, 0x4f, 0x9f, 0x46, 0xeb, 0x09, 0x0e, 0xf7, 0xfc,
                0x90, 0xb4, 0x79, 0xab, 0xf6, 0x1f, 0x93, 0x95, 0x5e, 0xe0, 0x0e, 0x6a, 0x18, 0x48,
                0xf1, 0xab, 0x14, 0xad, 0x33, 0x4f, 0x2b, 0x68, 0x03, 0x58, 0x08, 0xcd, 0xf1, 0xbb,
                0x9e, 0x9d, 0x9a, 0x81, 0x6b, 0xaf, 0x72, 0x8a, 0x95, 0x5b, 0x96, 0x0b, 0x77, 0x01,
                0xfa, 0x62, 0x66, 0x87, 0xdc, 0x3c, 0x9c, 0xba, 0x64, 0x63, 0x37, 0xb5, 0x3e, 0x29,
                0x81, 0x6e, 0x94, 0x82, 0xdd, 0xf5, 0x57, 0x8a, 0x87, 0x68, 0xaa, 0xe4, 0x77, 0xfc,
                0xe4, 0x10, 0xac, 0x2d, 0x5d, 0xe6, 0x09, 0x58, 0x61, 0xc1, 0x11, 0xd7, 0xfe, 0xb3,
                0xe6, 0xbb, 0x4f, 0xbb, 0x5a, 0x54, 0x95, 0x54, 0x95, 0x97, 0x27, 0x98, 0x35, 0x0a,
                0x25, 0x3f, 0x05, 0xf6, 0x6c, 0x2e, 0xcf, 0xcb, 0xc0, 0xed, 0x43, 0xf5, 0xec, 0x2e,
                0x6d, 0x8d, 0xba, 0x15, 0xa5, 0x12, 0x54, 0xd9, 0x7b, 0x18, 0x21, 0x10, 0x7c, 0x07,
                0xdd, 0x9a, 0x16, 0xef, 0x84, 0x06, 0xf9, 0x43, 0xe2, 0x82, 0xb9, 0x5d, 0x4b, 0x36,
                0x25, 0x30, 0xc9, 0x13, 0xd6, 0xba, 0x42, 0x1d, 0xf6, 0x02, 0x7d, 0xe5, 0xaf, 0x1e,
                0x47, 0x45, 0xd5, 0x86, 0x81, 0x06, 0x95, 0x4b, 0xe6, 0xc1, 0x96, 0x27, 0x80, 0xa2,
                0x94, 0x10, 0x72, 0xe9, 0x51, 0x31, 0xb1, 0x67, 0x9d, 0xf0, 0x63, 0x76, 0x25, 0x04,
                0x2c, 0x37, 0xd4, 0x8f, 0xfb, 0x15, 0x2e, 0x5e, 0xbc, 0x18, 0x5c, 0x8a, 0x2b, 0x7d,
                0x43, 0x85, 0xf1, 0xc9, 0x5a, 0xf9, 0x37, 0xdf, 0x78, 0xdf, 0xd8, 0x75, 0x7f, 0xab,
                0x43, 0x49, 0x68, 0xb0, 0xb5, 0x7c, 0x66, 0x57, 0x44, 0x68, 0xf1, 0x60, 0xb4, 0x47,
                0xac, 0x82, 0x21, 0xe5, 0x06, 0x06, 0x76, 0xa8, 0x42, 0xa1, 0xc6, 0xb7, 0x17, 0x2d,
                0xd3, 0x34, 0x0f, 0x76, 0x40, 0x70, 0xab, 0x1f, 0xe0, 0x91, 0xc5, 0xc7, 0x4c, 0x95,
                0xa5, 0xdc, 0x04, 0x33, 0x90, 0x72, 0x3a, 0x4c, 0x12, 0x7d, 0xa1, 0x4c, 0xdd, 0xe1,
                0xdc, 0x26, 0x75, 0xa6, 0x23, 0x40, 0xb3, 0xe6, 0xaf, 0xd0, 0x52, 0x2a, 0x31, 0xde,
                0x26, 0xe7, 0xd1, 0xec, 0x3a, 0x9c, 0x8a, 0x09, 0x1f, 0xfd, 0xc7, 0x5b, 0x7e, 0xcf,
                0xdc, 0x7c, 0x12, 0x99, 0x5a, 0x5e, 0x37, 0xce, 0x34, 0x88, 0xbd, 0x29, 0xf8, 0x62,
                0x9d, 0x68, 0xf6, 0x96, 0x49, 0x24, 0x48, 0xdd, 0x52, 0x66, 0x97, 0x47, 0x6d, 0xc0,
                0x61, 0x34, 0x6e, 0xbe, 0x3f, 0x67, 0x72, 0x17, 0xff, 0x9c, 0x60, 0xef, 0xce, 0x94,
                0x3a, 0xf2, 0x8d, 0xfd, 0x3f, 0x9e, 0x59, 0x69, 0x25, 0x98, 0xa6, 0x04, 0x7c, 0x23,
                0xc4, 0xc0, 0x14, 0x00, 0xf1, 0xab, 0x57, 0x30, 0xea, 0xc0, 0xae, 0x8d, 0x58, 0x43,
                0xd5, 0x05, 0x1c, 0x37, 0x62, 0x40, 0x17, 0x2a, 0xf2, 0x18, 0xd7, 0xa1, 0xec, 0xfe,
                0x65, 0xb4, 0xf7, 0x51, 0x00, 0x63, 0x89, 0x83, 0xc1, 0x4d, 0xe4, 0x97, 0x47, 0x55,
                0xda, 0xde, 0x80, 0x18, 0xc9, 0xb8, 0xf4, 0x54, 0x3f, 0xb0, 0x95, 0x96, 0x15, 0x13,
                0xe6, 0x7c, 0x61, 0xdb,
            ],
            c_enc: [
                0xfd, 0xd6, 0xca, 0x06, 0x20, 0xec, 0xa1, 0x88, 0xb0, 0x1a, 0xf6, 0x38, 0x98, 0x56,
                0x39, 0x3c, 0x23, 0x3b, 0x42, 0xf9, 0xc4, 0x43, 0xe2, 0x5f, 0x1f, 0x8d, 0xdd, 0xb5,
                0xba, 0xae, 0x41, 0xe5, 0x12, 0x29, 0x65, 0x12, 0xaf, 0x3f, 0x44, 0x0d, 0x2f, 0xe6,
                0xdf, 0xe0, 0xa6, 0xf9, 0xd9, 0x20, 0xf9, 0x9b, 0x74, 0x57, 0x3e, 0x57, 0x07, 0xfc,
                0x5a, 0xd1, 0x24, 0xed, 0xa2, 0x69, 0x1d, 0x19, 0x1e, 0xe7, 0xf4, 0xb2, 0x43, 0x09,
                0x83, 0xa0, 0x2d, 0x06, 0xd3, 0xab, 0x93, 0x32, 0x89, 0x3c, 0x76, 0x52, 0xfc, 0x31,
                0x04, 0xee, 0x7d, 0xee, 0x40, 0x75, 0x40, 0x2f, 0x1c, 0xfb, 0xbb, 0x69, 0xe9, 0x06,
                0xad, 0x75, 0x71, 0x4a, 0xc7, 0xec, 0x83, 0x84, 0x1e, 0x3f, 0xd4, 0x52, 0xf1, 0xff,
                0x86, 0x3d, 0x46, 0x5c, 0x3f, 0xa6, 0xb2, 0xe3, 0x6f, 0x88, 0xda, 0x74, 0xe6, 0x34,
                0x28, 0x0b, 0x86, 0x86, 0x2d, 0xc3, 0xc0, 0x89, 0x3e, 0xe4, 0x42, 0x5c, 0x14, 0xc9,
                0x62, 0x91, 0x3d, 0x35, 0x27, 0xbb, 0x2d, 0x78, 0xf8, 0x56, 0x1d, 0x11, 0xba, 0x4b,
                0xd5, 0x4a, 0x6d, 0x3a, 0x03, 0x6c, 0x41, 0x81, 0x63, 0x19, 0x03, 0xf6, 0x33, 0xfe,
                0x33, 0x70, 0x73, 0xc2, 0x1d, 0x48, 0xbd, 0xd2, 0x8a, 0x1f, 0xda, 0x38, 0xaf, 0x03,
                0x6c, 0x55, 0x9d, 0xf6, 0xf5, 0x19, 0xb8, 0x94, 0x46, 0x96, 0x00, 0x4c, 0xc2, 0x7f,
                0x17, 0xa9, 0x7d, 0x03, 0xbb, 0x98, 0x3f, 0x92, 0x48, 0x4a, 0x37, 0x14, 0x2c, 0x7f,
                0xcf, 0x22, 0x4f, 0x07, 0xf0, 0x97, 0x3b, 0xf6, 0x83, 0xe2, 0xa6, 0x8b, 0x47, 0x30,
                0xdf, 0x64, 0x88, 0xff, 0x92, 0x69, 0x16, 0x76, 0x9b, 0xf2, 0xc1, 0x73, 0x4d, 0x67,
                0xfa, 0x27, 0x4f, 0xec, 0xae, 0x84, 0x71, 0x71, 0x24, 0xf2, 0x57, 0x47, 0xcc, 0xf5,
                0x8e, 0x45, 0xa4, 0xf1, 0x85, 0xac, 0xd9, 0x51, 0xf9, 0x87, 0x97, 0x77, 0x3c, 0x90,
                0x2d, 0xaa, 0x33, 0x23, 0x39, 0xd3, 0xdd, 0xe6, 0x87, 0xe5, 0x1f, 0x1a, 0x2b, 0x6a,
                0xab, 0xfe, 0x46, 0x95, 0x1c, 0xbf, 0x3a, 0xe8, 0x81, 0x65, 0x82, 0xfd, 0x1c, 0x9b,
                0xd9, 0x34, 0xc5, 0x4e, 0x00, 0xf6, 0xd2, 0xc9, 0x87, 0xd6, 0x4f, 0xbd, 0x41, 0xc8,
                0xf2, 0xdf, 0x6e, 0xf3, 0x9c, 0x9e, 0x4f, 0xef, 0x91, 0x32, 0x6f, 0x36, 0x0f, 0xa0,
                0xc1, 0x9c, 0x3a, 0x0e, 0x42, 0x04, 0x0b, 0x5b, 0x56, 0xeb, 0xb3, 0xaa, 0x85, 0xe9,
                0xaf, 0xd0, 0x1c, 0xb7, 0x30, 0xbc, 0xf7, 0x83, 0xd1, 0xdb, 0x80, 0x4c, 0x33, 0xa1,
                0x3b, 0xa8, 0x54, 0xd1, 0x40, 0xc9, 0x52, 0x06, 0xf4, 0xf9, 0x66, 0x75, 0xd7, 0x7d,
                0x4e, 0x39, 0x74, 0x0d, 0x31, 0x0e, 0xf4, 0x7e, 0x77, 0x2a, 0x77, 0x60, 0x26, 0x1f,
                0x1b, 0xb7, 0xf6, 0x68, 0xe0, 0x35, 0x7f, 0xcd, 0x39, 0xd1, 0xcf, 0xfe, 0x17, 0x14,
                0xce, 0x15, 0x30, 0x54, 0x9f, 0x5a, 0x58, 0x54, 0xb0, 0xd6, 0xb6, 0x0b, 0x6b, 0xd3,
                0x5b, 0xb7, 0xc6, 0xae, 0xe4, 0x52, 0xa8, 0xc9, 0x7d, 0x6a, 0x91, 0x0c, 0x81, 0x72,
                0x0d, 0xe6, 0xdb, 0x44, 0x25, 0x50, 0x34, 0x0b, 0x73, 0x2f, 0x77, 0x6d, 0x3d, 0x6a,
                0x44, 0xae, 0x26, 0x7b, 0xac, 0x46, 0x99, 0xd6, 0x70, 0xde, 0xc3, 0xa3, 0x6a, 0xcb,
                0xe9, 0x38, 0x9e, 0x10, 0xf5, 0x91, 0xab, 0xc7, 0x94, 0x4a, 0x6c, 0x02, 0x76, 0x8f,
                0xd5, 0x4d, 0x9b, 0x36, 0xad, 0x5d, 0x98, 0x5e, 0x64, 0x0f, 0x10, 0xe7, 0x18, 0xf3,
                0x1b, 0xb4, 0xc6, 0x87, 0x69, 0xc4, 0x44, 0x71, 0x10, 0x97, 0x67, 0xcb, 0x10, 0x2a,
                0x0a, 0x04, 0x02, 0x97, 0x7d, 0xab, 0x8a, 0xbc, 0xc7, 0x1c, 0x8b, 0x63, 0xe9, 0x75,
                0xd9, 0x36, 0xaa, 0x74, 0x5b, 0x45, 0x98, 0x2c, 0x44, 0x7c, 0x89, 0x2d, 0x3b, 0x85,
                0x58, 0x2a, 0xfb, 0x90, 0x21, 0x21, 0xa4, 0xd5, 0xd9, 0xac, 0xea, 0xe5, 0x19, 0x9e,
                0xbb, 0x4e, 0x41, 0x6b, 0x3f, 0x73, 0x9f, 0x24, 0xda, 0x51, 0x4a, 0x85, 0xcd, 0xa2,
                0x2b, 0xd9, 0x30, 0x30, 0x92, 0x74, 0x3b, 0xc6, 0xb9, 0x2d, 0x3f, 0x7e, 0xb9, 0x60,
                0x04, 0x54, 0xba, 0xbd, 0x9c, 0x6f, 0x47, 0x15, 0xe7, 0xf0, 0x37, 0x00, 0x23, 0xfa,
                0x5d, 0xb8, 0x48, 0x04, 0x10, 0x1f,
            ],
            ock: [
                0xd0, 0xc3, 0x4d, 0x28, 0x7c, 0xbd, 0x33, 0x4d, 0xa2, 0x49, 0x26, 0xc3, 0x02, 0xda,
                0xab, 0x51, 0xdf, 0xb2, 0x00, 0xde, 0xbc, 0x30, 0x4e, 0xed, 0x36, 0x6d, 0x0b, 0xd2,
                0xea, 0xe0, 0x36, 0x97,
            ],
            op: [
                0x54, 0x13, 0xcc, 0x6c, 0xaa, 0xe4, 0xaa, 0x16, 0xc9, 0x0f, 0x58, 0xfb, 0x6c, 0x88,
                0x19, 0x54, 0x5d, 0x19, 0x66, 0xd8, 0x3e, 0xe3, 0x99, 0x1a, 0x63, 0x19, 0x0c, 0xe8,
                0x8b, 0xa8, 0xa0, 0xac, 0x49, 0xab, 0xcd, 0x2a, 0xeb, 0xb2, 0x8f, 0xed, 0xb0, 0x83,
                0x88, 0x17, 0xd4, 0xa7, 0xc1, 0x3f, 0x31, 0xe8, 0xef, 0x55, 0xeb, 0x89, 0xe4, 0xe1,
                0x03, 0xf7, 0xc3, 0xfd, 0xba, 0x56, 0x5d, 0x06,
            ],
            c_out: [
                0xca, 0x19, 0x6d, 0x41, 0x1d, 0xcc, 0xf8, 0xc1, 0x32, 0x61, 0x88, 0xfb, 0xb0, 0x9d,
                0xef, 0xa7, 0xde, 0xe3, 0xf8, 0xcb, 0x86, 0x0f, 0xdc, 0x2d, 0xe5, 0xa4, 0x79, 0xf9,
                0x83, 0x94, 0x30, 0xd8, 0x58, 0xcb, 0xfc, 0x1f, 0xb5, 0x13, 0xbb, 0x34, 0x78, 0xf4,
                0x71, 0xac, 0xac, 0xfe, 0x01, 0xd1, 0xcf, 0x5b, 0x17, 0xfc, 0xa7, 0xd7, 0x2c, 0x2e,
                0xde, 0x34, 0x78, 0x29, 0x15, 0x34, 0xea, 0xff, 0x6d, 0x20, 0xca, 0x7a, 0x8b, 0xda,
                0x92, 0x3c, 0x33, 0xb8, 0xb1, 0x8b, 0x4c, 0x5f, 0x1f, 0xf4,
            ],
        },
        TestVector {
            incoming_viewing_key: [
                0x14, 0x61, 0x86, 0x9f, 0xbb, 0x78, 0xe3, 0xd9, 0x14, 0x6a, 0x0f, 0x41, 0x83, 0x90,
                0x8d, 0x70, 0xcb, 0x3b, 0xe7, 0x39, 0x18, 0x9a, 0x6d, 0xf0, 0xa9, 0x3a, 0x61, 0x0e,
                0xb7, 0x2b, 0xe5, 0x28, 0xfc, 0xaa, 0x50, 0xa1, 0x07, 0x35, 0x8c, 0x53, 0x38, 0x69,
                0x5f, 0x7f, 0xcb, 0x52, 0xb5, 0x8c, 0xbf, 0x5e, 0x91, 0xfd, 0x78, 0x2f, 0x07, 0xcd,
                0xeb, 0xdb, 0x0a, 0x11, 0xe0, 0x87, 0xb8, 0x3b,
            ],
            ovk: [
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
                0x00, 0x00, 0x00, 0x00,
            ],
            default_d: [
                0x6c, 0x55, 0xdc, 0x91, 0xfb, 0x27, 0x20, 0xff, 0x6c, 0xea, 0xe5,
            ],
            default_pk_d: [
                0xf3, 0x2a, 0x1c, 0xda, 0x15, 0xa8, 0xac, 0x6c, 0x28, 0x2b, 0xe8, 0xdc, 0x2a, 0x5d,
                0xc1, 0x52, 0x75, 0x0a, 0xdb, 0x5f, 0x1d, 0x69, 0xe6, 0xa9, 0x99, 0x87, 0x47, 0x89,
                0x3e, 0x2e, 0x80, 0xb0,
            ],
            v: 14069495244536201203,
            rseed: [
                0x43, 0x2d, 0xc8, 0xb0, 0x48, 0xc7, 0x3c, 0x00, 0x18, 0xca, 0x5b, 0x69, 0x41, 0x12,
                0x97, 0x73, 0x2a, 0x4e, 0x1a, 0xa9, 0x9a, 0x92, 0x8c, 0x71, 0xe7, 0xa2, 0x4f, 0xd2,
                0x77, 0x85, 0x6a, 0xa4,
            ],
            memo: [
                0xff, 0x25, 0x01, 0xe5, 0x1b, 0x01, 0x2a, 0xea, 0x94, 0x46, 0xa2, 0x10, 0x4e, 0x93,
                0xf8, 0x15, 0xa0, 0xb3, 0xa2, 0x9b, 0x45, 0x83, 0x14, 0xf3, 0xd8, 0xbe, 0x2b, 0x98,
                0x23, 0xd3, 0x42, 0xf4, 0x62, 0x13, 0xe9, 0x42, 0xa7, 0xe1, 0x9a, 0x46, 0xe9, 0x70,
                0xb5, 0xc5, 0x06, 0x70, 0x84, 0x30, 0x31, 0x7b, 0x1b, 0xb3, 0xb3, 0x5d, 0xf6, 0x8a,
                0xe3, 0x3a, 0x49, 0x26, 0xa0, 0x3e, 0x6b, 0xfe, 0xb5, 0x51, 0x04, 0x16, 0xfc, 0xbb,
                0x05, 0x24, 0xc9, 0xca, 0x50, 0x74, 0x15, 0x6c, 0xc5, 0xa5, 0xd6, 0xfe, 0x1c, 0x99,
                0x5e, 0xdc, 0x60, 0xa2, 0xf5, 0x50, 0x41, 0x1a, 0xa4, 0x1e, 0x3d, 0xa3, 0xbd, 0xcf,
                0x64, 0xbc, 0xf0, 0x4a, 0x05, 0x10, 0x57, 0x1b, 0x93, 0x6d, 0x47, 0xe5, 0x5c, 0xec,
                0x03, 0x30, 0xee, 0x8d, 0xfe, 0x73, 0x56, 0x34, 0x04, 0xf0, 0x47, 0xd7, 0xf3, 0xa8,
                0xa3, 0xd7, 0x74, 0x3b, 0xc5, 0x54, 0x95, 0x52, 0x10, 0xf1, 0xeb, 0x0d, 0x08, 0x59,
                0x9e, 0xa7, 0x7d, 0x5f, 0x97, 0x4d, 0x87, 0x17, 0x6d, 0x37, 0xd9, 0x8b, 0x9c, 0x0a,
                0xd4, 0x40, 0x40, 0x72, 0x09, 0xed, 0x6a, 0x9f, 0x08, 0x46, 0x4d, 0x56, 0x55, 0x93,
                0xe1, 0xa6, 0x3b, 0x93, 0x85, 0x36, 0xb4, 0x92, 0x44, 0xe9, 0x7d, 0x88, 0x01, 0x73,
                0xb6, 0x40, 0xf2, 0xdd, 0xb7, 0x4d, 0x06, 0x8e, 0xcb, 0x46, 0xcf, 0x28, 0x9b, 0x7d,
                0x89, 0x13, 0x07, 0xbb, 0xa3, 0x70, 0x54, 0xcf, 0x91, 0xb3, 0x1f, 0xc8, 0x2f, 0x74,
                0xd5, 0xfc, 0xc0, 0x00, 0x94, 0x2e, 0xde, 0x91, 0x18, 0x25, 0xf5, 0x3f, 0xe6, 0x09,
                0x68, 0x6f, 0x46, 0x32, 0x23, 0xb1, 0xe9, 0xbc, 0x03, 0xbd, 0xe8, 0x95, 0xd1, 0x23,
                0x8f, 0xad, 0x04, 0xa3, 0xbf, 0xce, 0x68, 0xa0, 0x75, 0xe8, 0xa3, 0x7c, 0x0e, 0x87,
                0xbf, 0x46, 0xdd, 0x01, 0x55, 0x45, 0xf9, 0xb4, 0xfb, 0x0e, 0xec, 0x64, 0x5f, 0xfc,
                0xbb, 0xe0, 0xca, 0x5f, 0x8c, 0x56, 0x1b, 0x25, 0x7d, 0x52, 0xd6, 0x02, 0xd8, 0xc9,
                0x4c, 0x50, 0x28, 0x73, 0xa0, 0x1d, 0x92, 0x51, 0xd8, 0xc8, 0x60, 0xc0, 0x41, 0x52,
                0x5b, 0x3b, 0xf4, 0xe3, 0xa2, 0xeb, 0x92, 0x72, 0x81, 0x5c, 0x75, 0x86, 0x76, 0x84,
                0x28, 0xb4, 0xc2, 0xb2, 0x5e, 0x37, 0x45, 0xf0, 0x09, 0xc5, 0xdc, 0xe2, 0x0b, 0x69,
                0xd5, 0xd7, 0xc4, 0x3c, 0xeb, 0x73, 0x6b, 0x68, 0x31, 0xe8, 0xc1, 0x10, 0xf1, 0x6c,
                0xfd, 0xb3, 0xa4, 0x67, 0xe9, 0x41, 0x4c, 0x00, 0xec, 0xf1, 0x37, 0x31, 0x50, 0x08,
                0x94, 0x55, 0x56, 0x78, 0xc4, 0x97, 0xfa, 0xba, 0x9a, 0x95, 0xd0, 0x1c, 0xc4, 0x64,
                0x39, 0x0f, 0xc4, 0xa7, 0x6b, 0xfa, 0x8b, 0x0e, 0x1c, 0x68, 0xa5, 0x25, 0xd7, 0x06,
                0xd6, 0x60, 0x4b, 0x23, 0x30, 0xb6, 0xb3, 0x48, 0x52, 0x15, 0xf6, 0x06, 0xf1, 0x88,
                0x3a, 0x75, 0x15, 0x88, 0xc7, 0xef, 0xa5, 0x06, 0xc3, 0xe8, 0xd0, 0xc6, 0x01, 0x92,
                0xe8, 0x47, 0x6b, 0xd1, 0x17, 0x5d, 0x95, 0x62, 0x08, 0x7b, 0xdb, 0x81, 0x8e, 0x66,
                0x21, 0x62, 0x86, 0xba, 0xfe, 0x47, 0xff, 0x4d, 0xbc, 0xce, 0xd5, 0x14, 0x44, 0x48,
                0x0a, 0x9a, 0x56, 0x73, 0xec, 0xe7, 0xfa, 0xc7, 0x3a, 0x0e, 0xd4, 0x1a, 0xb0, 0x05,
                0x17, 0x53, 0xa7, 0xca, 0xa8, 0x9b, 0xe3, 0x13, 0x9a, 0xfd, 0x97, 0x93, 0xb3, 0xe0,
                0x2f, 0x27, 0xf0, 0x40, 0x04, 0x65, 0x95, 0xac, 0xd4, 0x7b, 0xf1, 0x3f, 0xd0, 0xda,
                0x27, 0xf0, 0x9e, 0xda, 0x48, 0x03, 0x6d, 0x3e, 0xe4, 0x37, 0xf2, 0xee, 0x8f, 0x86,
                0x06, 0xea, 0x97, 0x34, 0x3c, 0x33, 0x58, 0x46, 0x57, 0xf4, 0x6d, 0xba, 0x99, 0xdb,
                0x5c, 0xfe, 0x6c, 0xa1, 0x76, 0xfa, 0xb7, 0xb0,
            ],
            cv_net: [
                0x00, 0xf7, 0x66, 0x7f, 0x16, 0xec, 0xb6, 0x7f, 0x81, 0x62, 0x23, 0x57, 0x2e, 0xb0,
                0xbe, 0xa1, 0xc8, 0x7f, 0x41, 0xf0, 0x9f, 0x5b, 0x13, 0xdd, 0xa2, 0x0c, 0x84, 0xfe,
                0x26, 0x26, 0x42, 0xaa,
            ],
            rho: [
                0xbd, 0xda, 0xe8, 0xdf, 0xf1, 0x20, 0x5e, 0x04, 0x96, 0x8f, 0xae, 0x1f, 0xd9, 0xbe,
                0x51, 0xd8, 0x25, 0xf5, 0xd8, 0x78, 0x1d, 0x93, 0x3d, 0x0f, 0x5b, 0xce, 0x9c, 0xa8,
                0x3e, 0xe8, 0xed, 0x20,
            ],
            cmx: [
                0x27, 0x17, 0x29, 0x28, 0xe6, 0x2a, 0x6d, 0xa9, 0x23, 0xf1, 0x32, 0xe9, 0x3d, 0x1f,
                0xca, 0x69, 0x23, 0x20, 0x68, 0xc9, 0x59, 0x75, 0xb2, 0x07, 0x75, 0xe2, 0xc3, 0xeb,
                0x87, 0x99, 0xe0, 0x30,
            ],
            esk: [
                0x99, 0x04, 0xc7, 0x16, 0x39, 0x7a, 0x7f, 0x2f, 0xd0, 0xc8, 0x15, 0x83, 0x03, 0xf0,
                0x13, 0x39, 0x72, 0xcf, 0x75, 0x39, 0xd9, 0xc3, 0x11, 0xdd, 0x34, 0x62, 0xda, 0x00,
                0x19, 0xdc, 0x4e, 0x02,
            ],
            ephemeral_key: [
                0x66, 0xc2, 0xf0, 0xa9, 0xc1, 0x22, 0xaf, 0x91, 0x0f, 0x25, 0xd2, 0x67, 0xe3, 0x2a,
                0xa6, 0x70, 0x9e, 0xec, 0xd8, 0x00, 0x79, 0x3d, 0x3a, 0x6b, 0x88, 0xed, 0x01, 0x95,
                0x90, 0x84, 0x74, 0x24,
            ],
            shared_secret: [
                0x0a, 0x61, 0x65, 0xdf, 0xa4, 0xb3, 0x38, 0x6b, 0xb4, 0x9d, 0xbb, 0x05, 0xeb, 0xcd,
                0x3e, 0x8d, 0x53, 0x68, 0x14, 0xb0, 0xaa, 0x36, 0xcd, 0xac, 0xbd, 0xb0, 0x02, 0x5a,
                0x33, 0x5d, 0x4f, 0x99,
            ],
            k_enc: [
                0x6f, 0x86, 0x76, 0x38, 0x31, 0x1e, 0x3b, 0xf8, 0x7d, 0xeb, 0x6a, 0x8f, 0xd1, 0x04,
                0x09, 0x2a, 0x2a, 0x15, 0x2b, 0x9c, 0xf6, 0x30, 0x87, 0x59, 0xaf, 0xfc, 0xeb, 0xa2,
                0x6f, 0xa4, 0x93, 0x3d,
            ],
            p_enc: [
                0x02, 0x6c, 0x55, 0xdc, 0x91, 0xfb, 0x27, 0x20, 0xff, 0x6c, 0xea, 0xe5, 0xf3, 0xbf,
                0xa0, 0xab, 0x61, 0xe3, 0x40, 0xc3, 0x43, 0x2d, 0xc8, 0xb0, 0x48, 0xc7, 0x3c, 0x00,
                0x18, 0xca, 0x5b, 0x69, 0x41, 0x12, 0x97, 0x73, 0x2a, 0x4e, 0x1a, 0xa9, 0x9a, 0x92,
                0x8c, 0x71, 0xe7, 0xa2, 0x4f, 0xd2, 0x77, 0x85, 0x6a, 0xa4, 0xff, 0x25, 0x01, 0xe5,
                0x1b, 0x01, 0x2a, 0xea, 0x94, 0x46, 0xa2, 0x10, 0x4e, 0x93, 0xf8, 0x15, 0xa0, 0xb3,
                0xa2, 0x9b, 0x45, 0x83, 0x14, 0xf3, 0xd8, 0xbe, 0x2b, 0x98, 0x23, 0xd3, 0x42, 0xf4,
                0x62, 0x13, 0xe9, 0x42, 0xa7, 0xe1, 0x9a, 0x46, 0xe9, 0x70, 0xb5, 0xc5, 0x06, 0x70,
                0x84, 0x30, 0x31, 0x7b, 0x1b, 0xb3, 0xb3, 0x5d, 0xf6, 0x8a, 0xe3, 0x3a, 0x49, 0x26,
                0xa0, 0x3e, 0x6b, 0xfe, 0xb5, 0x51, 0x04, 0x16, 0xfc, 0xbb, 0x05, 0x24, 0xc9, 0xca,
                0x50, 0x74, 0x15, 0x6c, 0xc5, 0xa5, 0xd6, 0xfe, 0x1c, 0x99, 0x5e, 0xdc, 0x60, 0xa2,
                0xf5, 0x50, 0x41, 0x1a, 0xa4, 0x1e, 0x3d, 0xa3, 0xbd, 0xcf, 0x64, 0xbc, 0xf0, 0x4a,
                0x05, 0x10, 0x57, 0x1b, 0x93, 0x6d, 0x47, 0xe5, 0x5c, 0xec, 0x03, 0x30, 0xee, 0x8d,
                0xfe, 0x73, 0x56, 0x34, 0x04, 0xf0, 0x47, 0xd7, 0xf3, 0xa8, 0xa3, 0xd7, 0x74, 0x3b,
                0xc5, 0x54, 0x95, 0x52, 0x10, 0xf1, 0xeb, 0x0d, 0x08, 0x59, 0x9e, 0xa7, 0x7d, 0x5f,
                0x97, 0x4d, 0x87, 0x17, 0x6d, 0x37, 0xd9, 0x8b, 0x9c, 0x0a, 0xd4, 0x40, 0x40, 0x72,
                0x09, 0xed, 0x6a, 0x9f, 0x08, 0x46, 0x4d, 0x56, 0x55, 0x93, 0xe1, 0xa6, 0x3b, 0x93,
                0x85, 0x36, 0xb4, 0x92, 0x44, 0xe9, 0x7d, 0x88, 0x01, 0x73, 0xb6, 0x40, 0xf2, 0xdd,
                0xb7, 0x4d, 0x06, 0x8e, 0xcb, 0x46, 0xcf, 0x28, 0x9b, 0x7d, 0x89, 0x13, 0x07, 0xbb,
                0xa3, 0x70, 0x54, 0xcf, 0x91, 0xb3, 0x1f, 0xc8, 0x2f, 0x74, 0xd5, 0xfc, 0xc0, 0x00,
                0x94, 0x2e, 0xde, 0x91, 0x18, 0x25, 0xf5, 0x3f, 0xe6, 0x09, 0x68, 0x6f, 0x46, 0x32,
                0x23, 0xb1, 0xe9, 0xbc, 0x03, 0xbd, 0xe8, 0x95, 0xd1, 0x23, 0x8f, 0xad, 0x04, 0xa3,
                0xbf, 0xce, 0x68, 0xa0, 0x75, 0xe8, 0xa3, 0x7c, 0x0e, 0x87, 0xbf, 0x46, 0xdd, 0x01,
                0x55, 0x45, 0xf9, 0xb4, 0xfb, 0x0e, 0xec, 0x64, 0x5f, 0xfc, 0xbb, 0xe0, 0xca, 0x5f,
                0x8c, 0x56, 0x1b, 0x25, 0x7d, 0x52, 0xd6, 0x02, 0xd8, 0xc9, 0x4c, 0x50, 0x28, 0x73,
                0xa0, 0x1d, 0x92, 0x51, 0xd8, 0xc8, 0x60, 0xc0, 0x41, 0x52, 0x5b, 0x3b, 0xf4, 0xe3,
                0xa2, 0xeb, 0x92, 0x72, 0x81, 0x5c, 0x75, 0x86, 0x76, 0x84, 0x28, 0xb4, 0xc2, 0xb2,
                0x5e, 0x37, 0x45, 0xf0, 0x09, 0xc5, 0xdc, 0xe2, 0x0b, 0x69, 0xd5, 0xd7, 0xc4, 0x3c,
                0xeb, 0x73, 0x6b, 0x68, 0x31, 0xe8, 0xc1, 0x10, 0xf1, 0x6c, 0xfd, 0xb3, 0xa4, 0x67,
                0xe9, 0x41, 0x4c, 0x00, 0xec, 0xf1, 0x37, 0x31, 0x50, 0x08, 0x94, 0x55, 0x56, 0x78,
                0xc4, 0x97, 0xfa, 0xba, 0x9a, 0x95, 0xd0, 0x1c, 0xc4, 0x64, 0x39, 0x0f, 0xc4, 0xa7,
                0x6b, 0xfa, 0x8b, 0x0e, 0x1c, 0x68, 0xa5, 0x25, 0xd7, 0x06, 0xd6, 0x60, 0x4b, 0x23,
                0x30, 0xb6, 0xb3, 0x48, 0x52, 0x15, 0xf6, 0x06, 0xf1, 0x88, 0x3a, 0x75, 0x15, 0x88,
                0xc7, 0xef, 0xa5, 0x06, 0xc3, 0xe8, 0xd0, 0xc6, 0x01, 0x92, 0xe8, 0x47, 0x6b, 0xd1,
                0x17, 0x5d, 0x95, 0x62, 0x08, 0x7b, 0xdb, 0x81, 0x8e, 0x66, 0x21, 0x62, 0x86, 0xba,
                0xfe, 0x47, 0xff, 0x4d, 0xbc, 0xce, 0xd5, 0x14, 0x44, 0x48, 0x0a, 0x9a, 0x56, 0x73,
                0xec, 0xe7, 0xfa, 0xc7, 0x3a, 0x0e, 0xd4, 0x1a, 0xb0, 0x05, 0x17, 0x53, 0xa7, 0xca,
                0xa8, 0x9b, 0xe3, 0x13, 0x9a, 0xfd, 0x97, 0x93, 0xb3, 0xe0, 0x2f, 0x27, 0xf0, 0x40,
                0x04, 0x65, 0x95, 0xac, 0xd4, 0x7b, 0xf1, 0x3f, 0xd0, 0xda, 0x27, 0xf0, 0x9e, 0xda,
                0x48, 0x03, 0x6d, 0x3e, 0xe4, 0x37, 0xf2, 0xee, 0x8f, 0x86, 0x06, 0xea, 0x97, 0x34,
                0x3c, 0x33, 0x58, 0x46, 0x57, 0xf4, 0x6d, 0xba, 0x99, 0xdb, 0x5c, 0xfe, 0x6c, 0xa1,
                0x76, 0xfa, 0xb7, 0xb0,
            ],
            c_enc: [
                0x44, 0x2b, 0x76, 0x78, 0x83, 0x98, 0xc8, 0x3c, 0x84, 0x0f, 0xe0, 0x5c, 0x0c, 0x77,
                0xfd, 0x95, 0x27, 0x09, 0x74, 0x63, 0xc5, 0xa1, 0x2e, 0x5e, 0xae, 0x92, 0xd2, 0x17,
                0x02, 0xbd, 0x27, 0x9a, 0xbf, 0x02, 0x43, 0x5d, 0x73, 0xeb, 0x56, 0x19, 0x67, 0x51,
                0x39, 0x93, 0xfe, 0xc1, 0xcc, 0x18, 0x7f, 0xaa, 0x7d, 0xd2, 0x9a, 0x31, 0x36, 0x24,
                0x03, 0xcb, 0xe0, 0x2f, 0x74, 0x69, 0x30, 0x03, 0xac, 0xc9, 0x64, 0xbe, 0x07, 0xc2,
                0x7d, 0xcb, 0xf4, 0x9e, 0xd3, 0x53, 0xaf, 0x0f, 0x98, 0x24, 0x20, 0xdc, 0x18, 0x40,
                0xd5, 0x8b, 0xa8, 0x86, 0x80, 0xfb, 0x0c, 0xae, 0x74, 0x97, 0xb5, 0x34, 0x8e, 0xe1,
                0x4c, 0x81, 0x0a, 0xfb, 0xf6, 0x21, 0x8b, 0x39, 0xb0, 0xf2, 0x1a, 0xef, 0xf5, 0xb9,
                0xa9, 0x88, 0xe1, 0xab, 0x46, 0x56, 0xe9, 0xd7, 0x17, 0x84, 0x83, 0xbb, 0x39, 0xbb,
                0x87, 0x57, 0xb7, 0xa7, 0x03, 0x75, 0x78, 0x92, 0xfa, 0xfc, 0x5f, 0x7e, 0x88, 0xab,
                0xc5, 0xdb, 0xf0, 0xd0, 0x3d, 0x67, 0x66, 0xdb, 0xd3, 0xdf, 0x5d, 0xe6, 0xb4, 0x41,
                0x4f, 0xfa, 0xae, 0x32, 0xbc, 0xc1, 0xa1, 0xcc, 0x0b, 0x03, 0x79, 0x29, 0x10, 0x0f,
                0xbc, 0xad, 0x12, 0xdd, 0x3f, 0xb8, 0x7f, 0x64, 0x02, 0x38, 0x4c, 0x93, 0x43, 0xe1,
                0x2f, 0x8c, 0x93, 0xbd, 0x3a, 0x32, 0xc3, 0x8e, 0x49, 0x44, 0xce, 0x50, 0xda, 0x11,
                0x94, 0x1a, 0xe4, 0x02, 0x85, 0x4d, 0x9c, 0x93, 0x86, 0xc1, 0x79, 0xda, 0x51, 0xd0,
                0xa9, 0x6a, 0x52, 0x88, 0x19, 0x3d, 0x98, 0xef, 0x91, 0xad, 0x24, 0x76, 0x9d, 0x7e,
                0x62, 0xdc, 0xcb, 0x81, 0xba, 0xcd, 0xbe, 0x18, 0x5c, 0xce, 0x3b, 0x91, 0x3a, 0x53,
                0xce, 0x2f, 0x97, 0x62, 0xe4, 0x01, 0x8f, 0xd4, 0xa3, 0xef, 0xd8, 0xf6, 0xb0, 0x09,
                0x96, 0x86, 0x2a, 0xc6, 0x6e, 0x76, 0x76, 0x47, 0x49, 0x91, 0x73, 0xd7, 0xb2, 0xa5,
                0x13, 0x69, 0xdc, 0x4d, 0x16, 0x16, 0x9b, 0xb0, 0xf0, 0x7d, 0xcc, 0xe8, 0xc5, 0x33,
                0xeb, 0x95, 0x27, 0xbb, 0x19, 0x54, 0x88, 0x98, 0xcc, 0x97, 0x46, 0x20, 0xbb, 0x17,
                0x9b, 0xec, 0xdb, 0x4b, 0xd5, 0x02, 0xb6, 0xc6, 0x8c, 0xab, 0xba, 0xa4, 0xbf, 0xe9,
                0x85, 0xef, 0x87, 0xf7, 0x1d, 0xe4, 0x62, 0xd8, 0x45, 0x0d, 0x87, 0x26, 0xcf, 0x7a,
                0x75, 0x8c, 0x6b, 0xfa, 0xef, 0x3a, 0x1e, 0x33, 0x64, 0x04, 0x78, 0x01, 0xa4, 0xb0,
                0x48, 0x1a, 0x92, 0x4c, 0x2c, 0x6c, 0x8c, 0x9b, 0xea, 0x2b, 0x23, 0x99, 0x7c, 0x65,
                0x0a, 0x26, 0x8e, 0xfa, 0xdb, 0x27, 0x14, 0xb3, 0x07, 0x0b, 0x89, 0xfe, 0x61, 0x12,
                0x63, 0xd3, 0x05, 0xba, 0xb1, 0x9b, 0xa1, 0xd9, 0x2f, 0x6d, 0x75, 0xb7, 0x2b, 0xd7,
                0x3a, 0x3d, 0xc0, 0xca, 0xb1, 0x3e, 0x33, 0x3f, 0x06, 0x17, 0x02, 0x89, 0x2f, 0x5b,
                0x74, 0xa5, 0xfb, 0xb1, 0x79, 0x72, 0xd9, 0x7f, 0xc3, 0xbc, 0x87, 0x05, 0xc5, 0x63,
                0xb8, 0xc5, 0xdb, 0xb8, 0xb7, 0xcc, 0x99, 0x65, 0xae, 0x53, 0xbb, 0x51, 0xa8, 0x02,
                0xa5, 0xb6, 0x61, 0xb2, 0xce, 0xda, 0x31, 0x39, 0x2b, 0x78, 0x4f, 0xfb, 0x0f, 0x76,
                0x52, 0x52, 0x03, 0x4d, 0x05, 0x6a, 0x77, 0x07, 0x75, 0x93, 0x6a, 0xc6, 0x11, 0x09,
                0x36, 0xbc, 0x32, 0x2b, 0xf8, 0x95, 0x2f, 0x36, 0x0b, 0xf7, 0x2d, 0xb6, 0xa6, 0xa5,
                0xe1, 0x3d, 0xf5, 0x27, 0xa6, 0x0c, 0x05, 0xa9, 0x25, 0x03, 0x35, 0x1c, 0xd0, 0x38,
                0x61, 0x63, 0x33, 0xb2, 0x6e, 0x2e, 0x7c, 0x3c, 0x91, 0xb4, 0x00, 0x77, 0x77, 0xb8,
                0x0f, 0x28, 0x78, 0x69, 0x4f, 0x04, 0x7e, 0xb9, 0xc4, 0xca, 0x38, 0xfb, 0xed, 0x39,
                0x7e, 0x5d, 0xc4, 0x6b, 0x9e, 0xd5, 0xc4, 0x07, 0x9e, 0x8e, 0x18, 0x83, 0x8b, 0x2c,
                0x9f, 0x39, 0xe8, 0x65, 0xd6, 0xb4, 0x9c, 0x35, 0xc4, 0xba, 0xa1, 0x77, 0x81, 0x25,
                0x9f, 0xb3, 0x14, 0x0b, 0x5a, 0x20, 0x03, 0xa3, 0x67, 0xdb, 0x12, 0xb7, 0x5b, 0x18,
                0xc7, 0x44, 0x1f, 0x74, 0x0f, 0xc6, 0x7a, 0x3d, 0x7f, 0x89, 0xbd, 0x76, 0x60, 0x9c,
                0x36, 0xe7, 0x38, 0x8b, 0xca, 0xf0, 0xc5, 0x08, 0xf8, 0x41, 0xfd, 0xd1, 0xfd, 0x14,
                0xf4, 0xbd, 0xfd, 0xd1, 0x92, 0xee,
            ],
            ock: [
                0x1a, 0xeb, 0xa4, 0xd2, 0x58, 0x8a, 0x2c, 0xbd, 0x76, 0xb5, 0x2d, 0xa2, 0x81, 0x1c,
                0xcc, 0x6c, 0x63, 0x03, 0x6b, 0xeb, 0x3a, 0x8a, 0x1b, 0x49, 0x09, 0x71, 0xff, 0x59,
                0x61, 0x35, 0x6d, 0xc0,
            ],
            op: [
                0xf3, 0x2a, 0x1c, 0xda, 0x15, 0xa8, 0xac, 0x6c, 0x28, 0x2b, 0xe8, 0xdc, 0x2a, 0x5d,
                0xc1, 0x52, 0x75, 0x0a, 0xdb, 0x5f, 0x1d, 0x69, 0xe6, 0xa9, 0x99, 0x87, 0x47, 0x89,
                0x3e, 0x2e, 0x80, 0xb0, 0x99, 0x04, 0xc7, 0x16, 0x39, 0x7a, 0x7f, 0x2f, 0xd0, 0xc8,
                0x15, 0x83, 0x03, 0xf0, 0x13, 0x39, 0x72, 0xcf, 0x75, 0x39, 0xd9, 0xc3, 0x11, 0xdd,
                0x34, 0x62, 0xda, 0x00, 0x19, 0xdc, 0x4e, 0x02,
            ],
            c_out: [
                0x8f, 0x00, 0x70, 0x34, 0x65, 0x1c, 0xf2, 0x88, 0xcf, 0xc5, 0xcb, 0x39, 0xf3, 0x98,
                0x5d, 0x91, 0x01, 0x61, 0x39, 0xf6, 0xac, 0x42, 0x4d, 0x06, 0xa9, 0x70, 0x36, 0x36,
                0x91, 0xe6, 0x3d, 0x62, 0x60, 0xaa, 0x38, 0x4a, 0x2e, 0x44, 0x9d, 0x79, 0x83, 0xfb,
                0x1c, 0x1a, 0xb5, 0xc6, 0xf7, 0xfd, 0xe0, 0x92, 0x2d, 0x13, 0xfc, 0x05, 0x2a, 0x7b,
                0xee, 0x38, 0x98, 0x41, 0xae, 0xd4, 0xcf, 0xed, 0x14, 0xb8, 0x05, 0x95, 0x74, 0x9e,
                0xc2, 0x8e, 0x2d, 0xb4, 0x41, 0x99, 0x6f, 0x9e, 0x0e, 0xdd,
            ],
        },
        TestVector {
            incoming_viewing_key: [
                0x96, 0x48, 0x38, 0xb0, 0x5d, 0xcc, 0xfb, 0x7c, 0xaa, 0xd6, 0xe2, 0xc6, 0x8c, 0xaa,
                0xc7, 0xe1, 0xc0, 0x87, 0xf1, 0x38, 0x3c, 0x68, 0x36, 0x2f, 0xe4, 0xf7, 0xf3, 0xb7,
                0x1a, 0x97, 0xd2, 0x58, 0xc6, 0x6e, 0x59, 0xf7, 0x4b, 0xc6, 0x9e, 0xad, 0xc6, 0x4d,
                0x42, 0x8a, 0x38, 0xfd, 0x9d, 0xfa, 0xc5, 0x04, 0xc9, 0xf3, 0x6f, 0x35, 0xea, 0xca,
                0xea, 0x09, 0xd6, 0x0d, 0xd7, 0x3e, 0xf4, 0x04,
            ],
            ovk: [
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
                0x00, 0x00, 0x00, 0x00,
            ],
            default_d: [
                0x5c, 0xc7, 0xf5, 0x56, 0x79, 0x14, 0x86, 0x88, 0x0b, 0xf6, 0x73,
            ],
            default_pk_d: [
                0x5d, 0x47, 0x85, 0xa9, 0xfc, 0xc2, 0xf9, 0xba, 0xea, 0x34, 0x30, 0xd7, 0x2a, 0xbf,
                0xf7, 0x6b, 0xa7, 0xcd, 0xc6, 0x14, 0x6a, 0x6d, 0x31, 0x03, 0x84, 0x8f, 0x8a, 0xc9,
                0x22, 0x24, 0x5a, 0x32,
            ],
            v: 5805053981422670580,
            rseed: [
                0x96, 0x53, 0x26, 0x20, 0x20, 0xc3, 0x3b, 0xf7, 0x80, 0x31, 0xb8, 0xee, 0x07, 0x07,
                0xde, 0x07, 0x20, 0x68, 0xc1, 0x70, 0x57, 0x03, 0x27, 0xe6, 0xd9, 0xf5, 0xc6, 0xdd,
                0xc3, 0x35, 0x40, 0x2e,
            ],
            memo: [
                0xff, 0xfc, 0x54, 0x88, 0x62, 0xf5, 0xa0, 0x70, 0x94, 0xfd, 0x42, 0x8a, 0x7b, 0xbc,
                0x15, 0xd7, 0xb3, 0x8d, 0x05, 0x36, 0x2c, 0x9c, 0xa9, 0x85, 0xf5, 0x8a, 0x76, 0x64,
                0x7d, 0x2b, 0xe4, 0xc2, 0xcd, 0x6b, 0x3d, 0x17, 0xd6, 0x87, 0x09, 0x71, 0xd7, 0xa0,
                0x98, 0xba, 0xf7, 0x2c, 0x6f, 0x6f, 0x12, 0x14, 0xcf, 0x1f, 0xaa, 0xe4, 0x88, 0xbd,
                0x7d, 0xe2, 0x59, 0xd3, 0x41, 0x5c, 0x2f, 0x0d, 0xde, 0xc7, 0x45, 0x70, 0x04, 0xf3,
                0x57, 0x08, 0xd1, 0xec, 0xcc, 0xcc, 0x0d, 0xf6, 0x5a, 0x04, 0x94, 0x3a, 0xd5, 0xcb,
                0xc1, 0x3f, 0x29, 0x5f, 0x00, 0x0f, 0xe0, 0x56, 0xc4, 0x0b, 0x2d, 0x88, 0xf2, 0x7d,
                0xc3, 0x4c, 0xfe, 0xb8, 0x03, 0xbe, 0x34, 0x83, 0xa9, 0xeb, 0xf9, 0xb5, 0xa9, 0x02,
                0x60, 0x57, 0x72, 0x5d, 0x63, 0xea, 0xd2, 0xc0, 0xc0, 0xff, 0x1f, 0xe2, 0x6a, 0xc1,
                0xe7, 0xbd, 0xfc, 0xd6, 0xfa, 0xd8, 0x75, 0x84, 0x2d, 0x19, 0x4f, 0x33, 0x17, 0x50,
                0x46, 0x2c, 0x06, 0xb8, 0xd7, 0x98, 0x2d, 0x67, 0x99, 0x5e, 0xd5, 0xd3, 0xae, 0x96,
                0xa0, 0x5a, 0xe0, 0x06, 0x7f, 0x4e, 0xb1, 0xc7, 0xc9, 0x32, 0x31, 0xbd, 0x39, 0x77,
                0x3c, 0xbe, 0x0a, 0x9d, 0x66, 0xb0, 0xc9, 0xaa, 0x8c, 0xff, 0x6a, 0x37, 0x6e, 0x1f,
                0x37, 0x2e, 0xac, 0x6a, 0xc4, 0xe4, 0x6c, 0xc0, 0x94, 0x22, 0x45, 0xd4, 0xc2, 0xdc,
                0xf0, 0x2d, 0x76, 0x40, 0xff, 0xcc, 0x5a, 0x6a, 0xc3, 0xa8, 0x7f, 0x5c, 0x41, 0x15,
                0x51, 0xbc, 0xc2, 0xf2, 0x6c, 0xb9, 0x49, 0x61, 0xd5, 0x3f, 0x95, 0xdd, 0xb1, 0x9a,
                0xe9, 0x30, 0xc8, 0xd7, 0x0f, 0x03, 0x1b, 0x29, 0xa5, 0xdf, 0x99, 0xff, 0x36, 0x69,
                0x5e, 0x80, 0x2c, 0xbc, 0xb6, 0xb5, 0x8c, 0x1b, 0xa7, 0xed, 0x5e, 0xac, 0xfa, 0x76,
                0x41, 0x4a, 0x41, 0xad, 0x4a, 0x44, 0xf7, 0x1f, 0x1b, 0x58, 0x0d, 0x34, 0xc3, 0xa9,
                0x52, 0x92, 0x0b, 0x25, 0x4a, 0x14, 0x5f, 0xea, 0x51, 0x7f, 0x5b, 0x42, 0xb2, 0xf6,
                0x5e, 0xcd, 0x0f, 0x82, 0x59, 0x54, 0x78, 0xd8, 0x0a, 0xe5, 0xc8, 0xce, 0xea, 0x12,
                0xa1, 0x61, 0xcc, 0xbb, 0x5e, 0xac, 0x09, 0x99, 0x0f, 0xc6, 0x19, 0xa4, 0x60, 0x80,
                0x43, 0x6d, 0xbd, 0x08, 0xd7, 0x47, 0x84, 0xaf, 0x00, 0x2d, 0x58, 0xe0, 0x6f, 0xaf,
                0x7f, 0x3c, 0xea, 0xe7, 0xd3, 0x41, 0x9b, 0x1f, 0xca, 0x26, 0x5a, 0x55, 0x59, 0xcf,
                0x9e, 0x2d, 0x3b, 0x60, 0x97, 0x8d, 0x81, 0xa6, 0x78, 0xb9, 0xed, 0x8e, 0x44, 0x86,
                0xb4, 0xd1, 0x46, 0x09, 0xd6, 0xc1, 0x27, 0xc0, 0xc2, 0xfb, 0xff, 0xe3, 0x0a, 0x60,
                0xf7, 0xbf, 0xf1, 0xd9, 0xfb, 0x83, 0x00, 0xed, 0x00, 0x92, 0x53, 0xba, 0x9b, 0x99,
                0x6f, 0xa0, 0x52, 0x41, 0xb1, 0x0f, 0x5a, 0xc9, 0xa8, 0x40, 0x8e, 0x92, 0x5b, 0x62,
                0x6b, 0xb2, 0x1a, 0x47, 0x1f, 0xe3, 0xbe, 0xde, 0x52, 0xbb, 0xa0, 0x97, 0xb2, 0xa9,
                0x9a, 0x9b, 0xa5, 0xa8, 0x66, 0x58, 0xc3, 0xfd, 0x9e, 0xc5, 0x5b, 0xfa, 0x9b, 0x32,
                0x85, 0x67, 0x25, 0x4a, 0xb3, 0x6d, 0x2c, 0x7f, 0x44, 0xd2, 0xc7, 0xe1, 0x3e, 0xb5,
                0x4b, 0xeb, 0x70, 0xea, 0x8f, 0xa9, 0x4b, 0x6c, 0x6e, 0x01, 0x2d, 0x79, 0xe3, 0xf5,
                0x36, 0x89, 0xc2, 0xb1, 0xa1, 0x8e, 0xaf, 0x2d, 0x47, 0x1d, 0x13, 0xc1, 0xab, 0x39,
                0xd9, 0x19, 0x4a, 0xe8, 0x43, 0xab, 0x1d, 0x28, 0xff, 0xa8, 0xf6, 0x9d, 0xc7, 0xe1,
                0x5c, 0xc3, 0x8b, 0x12, 0xe8, 0xfc, 0xd7, 0x92, 0x55, 0xb7, 0x21, 0x60, 0x56, 0xd9,
                0xed, 0xb7, 0x48, 0x2f, 0xb9, 0x8a, 0xa0, 0x33, 0xb6, 0x5e, 0x51, 0xc1, 0xa0, 0x8b,
                0x8a, 0x11, 0xd8, 0x4d, 0x04, 0x09, 0xb7, 0x34,
            ],
            cv_net: [
                0xd6, 0x1e, 0xff, 0xdd, 0xf1, 0xe6, 0x65, 0xe7, 0xcf, 0x29, 0xfa, 0xf4, 0x95, 0x07,
                0x5e, 0xd7, 0xb8, 0x66, 0xa7, 0x4a, 0x50, 0xd6, 0x26, 0x65, 0x1f, 0x5e, 0x7b, 0xc9,
                0x62, 0xf3, 0x9b, 0xac,
            ],
            rho: [
                0xc2, 0x79, 0xfa, 0x9d, 0x1c, 0x84, 0x11, 0x93, 0xd3, 0x32, 0xf8, 0xcc, 0xf4, 0xd0,
                0xb1, 0xe4, 0x56, 0x01, 0xa8, 0xaf, 0x66, 0x76, 0xd7, 0x62, 0xfb, 0xa7, 0x31, 0x33,
                0x45, 0x89, 0x35, 0x14,
            ],
            cmx: [
                0x40, 0xda, 0x0c, 0xf1, 0xa9, 0xc1, 0x7d, 0x99, 0xd2, 0x42, 0x9c, 0x60, 0x48, 0xcc,
                0x42, 0xef, 0x5b, 0xbc, 0x54, 0x6e, 0x01, 0xcc, 0xed, 0x46, 0xc3, 0x65, 0xeb, 0xc7,
                0x7c, 0x48, 0x2c, 0x27,
            ],
            esk: [
                0x28, 0xba, 0xbd, 0x59, 0x76, 0x8d, 0xaa, 0x17, 0x5d, 0xd2, 0x99, 0xc2, 0x7a, 0x9d,
                0x65, 0xad, 0xe0, 0xb2, 0x84, 0x53, 0x82, 0x77, 0xd8, 0x70, 0x13, 0x0e, 0x6c, 0xee,
                0x66, 0xf9, 0x65, 0x0b,
            ],
            ephemeral_key: [
                0xeb, 0xd8, 0x51, 0x19, 0xe5, 0x4f, 0xf8, 0xd8, 0xe6, 0x16, 0xdb, 0x46, 0x6f, 0xb6,
                0x9a, 0x0a, 0x76, 0xe7, 0xf9, 0x6f, 0xd9, 0x28, 0x4f, 0xf5, 0xd3, 0xea, 0xe0, 0x99,
                0x64, 0x0a, 0x7a, 0x30,
            ],
            shared_secret: [
                0xb1, 0xe4, 0xbd, 0xda, 0x5d, 0x3e, 0x37, 0xbc, 0xfb, 0xa4, 0x29, 0x95, 0xaa, 0x94,
                0x59, 0x04, 0x12, 0x2b, 0x1a, 0x3f, 0xee, 0x38, 0xd6, 0x1b, 0xdc, 0x1e, 0x5f, 0x93,
                0xd3, 0xa6, 0x57, 0x82,
            ],
            k_enc: [
                0x64, 0x89, 0xd0, 0x7d, 0x3c, 0xe5, 0x8d, 0x23, 0x6b, 0xd2, 0x6c, 0xfd, 0xe4, 0xd8,
                0x9c, 0x43, 0x8e, 0xa0, 0xcc, 0x76, 0xf0, 0x56, 0x08, 0x36, 0xb8, 0x3c, 0xe2, 0x87,
                0x70, 0xe5, 0x96, 0xfb,
            ],
            p_enc: [
                0x02, 0x5c, 0xc7, 0xf5, 0x56, 0x79, 0x14, 0x86, 0x88, 0x0b, 0xf6, 0x73, 0xf4, 0x52,
                0xaa, 0xf0, 0xd6, 0xb1, 0x8f, 0x50, 0x96, 0x53, 0x26, 0x20, 0x20, 0xc3, 0x3b, 0xf7,
                0x80, 0x31, 0xb8, 0xee, 0x07, 0x07, 0xde, 0x07, 0x20, 0x68, 0xc1, 0x70, 0x57, 0x03,
                0x27, 0xe6, 0xd9, 0xf5, 0xc6, 0xdd, 0xc3, 0x35, 0x40, 0x2e, 0xff, 0xfc, 0x54, 0x88,
                0x62, 0xf5, 0xa0, 0x70, 0x94, 0xfd, 0x42, 0x8a, 0x7b, 0xbc, 0x15, 0xd7, 0xb3, 0x8d,
                0x05, 0x36, 0x2c, 0x9c, 0xa9, 0x85, 0xf5, 0x8a, 0x76, 0x64, 0x7d, 0x2b, 0xe4, 0xc2,
                0xcd, 0x6b, 0x3d, 0x17, 0xd6, 0x87, 0x09, 0x71, 0xd7, 0xa0, 0x98, 0xba, 0xf7, 0x2c,
                0x6f, 0x6f, 0x12, 0x14, 0xcf, 0x1f, 0xaa, 0xe4, 0x88, 0xbd, 0x7d, 0xe2, 0x59, 0xd3,
                0x41, 0x5c, 0x2f, 0x0d, 0xde, 0xc7, 0x45, 0x70, 0x04, 0xf3, 0x57, 0x08, 0xd1, 0xec,
                0xcc, 0xcc, 0x0d, 0xf6, 0x5a, 0x04, 0x94, 0x3a, 0xd5, 0xcb, 0xc1, 0x3f, 0x29, 0x5f,
                0x00, 0x0f, 0xe0, 0x56, 0xc4, 0x0b, 0x2d, 0x88, 0xf2, 0x7d, 0xc3, 0x4c, 0xfe, 0xb8,
                0x03, 0xbe, 0x34, 0x83, 0xa9, 0xeb, 0xf9, 0xb5, 0xa9, 0x02, 0x60, 0x57, 0x72, 0x5d,
                0x63, 0xea, 0xd2, 0xc0, 0xc0, 0xff, 0x1f, 0xe2, 0x6a, 0xc1, 0xe7, 0xbd, 0xfc, 0xd6,
                0xfa, 0xd8, 0x75, 0x84, 0x2d, 0x19, 0x4f, 0x33, 0x17, 0x50, 0x46, 0x2c, 0x06, 0xb8,
                0xd7, 0x98, 0x2d, 0x67, 0x99, 0x5e, 0xd5, 0xd3, 0xae, 0x96, 0xa0, 0x5a, 0xe0, 0x06,
                0x7f, 0x4e, 0xb1, 0xc7, 0xc9, 0x32, 0x31, 0xbd, 0x39, 0x77, 0x3c, 0xbe, 0x0a, 0x9d,
                0x66, 0xb0, 0xc9, 0xaa, 0x8c, 0xff, 0x6a, 0x37, 0x6e, 0x1f, 0x37, 0x2e, 0xac, 0x6a,
                0xc4, 0xe4, 0x6c, 0xc0, 0x94, 0x22, 0x45, 0xd4, 0xc2, 0xdc, 0xf0, 0x2d, 0x76, 0x40,
                0xff, 0xcc, 0x5a, 0x6a, 0xc3, 0xa8, 0x7f, 0x5c, 0x41, 0x15, 0x51, 0xbc, 0xc2, 0xf2,
                0x6c, 0xb9, 0x49, 0x61, 0xd5, 0x3f, 0x95, 0xdd, 0xb1, 0x9a, 0xe9, 0x30, 0xc8, 0xd7,
                0x0f, 0x03, 0x1b, 0x29, 0xa5, 0xdf, 0x99, 0xff, 0x36, 0x69, 0x5e, 0x80, 0x2c, 0xbc,
                0xb6, 0xb5, 0x8c, 0x1b, 0xa7, 0xed, 0x5e, 0xac, 0xfa, 0x76, 0x41, 0x4a, 0x41, 0xad,
                0x4a, 0x44, 0xf7, 0x1f, 0x1b, 0x58, 0x0d, 0x34, 0xc3, 0xa9, 0x52, 0x92, 0x0b, 0x25,
                0x4a, 0x14, 0x5f, 0xea, 0x51, 0x7f, 0x5b, 0x42, 0xb2, 0xf6, 0x5e, 0xcd, 0x0f, 0x82,
                0x59, 0x54, 0x78, 0xd8, 0x0a, 0xe5, 0xc8, 0xce, 0xea, 0x12, 0xa1, 0x61, 0xcc, 0xbb,
                0x5e, 0xac, 0x09, 0x99, 0x0f, 0xc6, 0x19, 0xa4, 0x60, 0x80, 0x43, 0x6d, 0xbd, 0x08,
                0xd7, 0x47, 0x84, 0xaf, 0x00, 0x2d, 0x58, 0xe0, 0x6f, 0xaf, 0x7f, 0x3c, 0xea, 0xe7,
                0xd3, 0x41, 0x9b, 0x1f, 0xca, 0x26, 0x5a, 0x55, 0x59, 0xcf, 0x9e, 0x2d, 0x3b, 0x60,
                0x97, 0x8d, 0x81, 0xa6, 0x78, 0xb9, 0xed, 0x8e, 0x44, 0x86, 0xb4, 0xd1, 0x46, 0x09,
                0xd6, 0xc1, 0x27, 0xc0, 0xc2, 0xfb, 0xff, 0xe3, 0x0a, 0x60, 0xf7, 0xbf, 0xf1, 0xd9,
                0xfb, 0x83, 0x00, 0xed, 0x00, 0x92, 0x53, 0xba, 0x9b, 0x99, 0x6f, 0xa0, 0x52, 0x41,
                0xb1, 0x0f, 0x5a, 0xc9, 0xa8, 0x40, 0x8e, 0x92, 0x5b, 0x62, 0x6b, 0xb2, 0x1a, 0x47,
                0x1f, 0xe3, 0xbe, 0xde, 0x52, 0xbb, 0xa0, 0x97, 0xb2, 0xa9, 0x9a, 0x9b, 0xa5, 0xa8,
                0x66, 0x58, 0xc3, 0xfd, 0x9e, 0xc5, 0x5b, 0xfa, 0x9b, 0x32, 0x85, 0x67, 0x25, 0x4a,
                0xb3, 0x6d, 0x2c, 0x7f, 0x44, 0xd2, 0xc7, 0xe1, 0x3e, 0xb5, 0x4b, 0xeb, 0x70, 0xea,
                0x8f, 0xa9, 0x4b, 0x6c, 0x6e, 0x01, 0x2d, 0x79, 0xe3, 0xf5, 0x36, 0x89, 0xc2, 0xb1,
                0xa1, 0x8e, 0xaf, 0x2d, 0x47, 0x1d, 0x13, 0xc1, 0xab, 0x39, 0xd9, 0x19, 0x4a, 0xe8,
                0x43, 0xab, 0x1d, 0x28, 0xff, 0xa8, 0xf6, 0x9d, 0xc7, 0xe1, 0x5c, 0xc3, 0x8b, 0x12,
                0xe8, 0xfc, 0xd7, 0x92, 0x55, 0xb7, 0x21, 0x60, 0x56, 0xd9, 0xed, 0xb7, 0x48, 0x2f,
                0xb9, 0x8a, 0xa0, 0x33, 0xb6, 0x5e, 0x51, 0xc1, 0xa0, 0x8b, 0x8a, 0x11, 0xd8, 0x4d,
                0x04, 0x09, 0xb7, 0x34,
            ],
            c_enc: [
                0x42, 0xcf, 0x0e, 0x82, 0x75, 0x06, 0xfb, 0x0d, 0xcb, 0x95, 0x9c, 0x83, 0x2e, 0xe8,
                0xbd, 0x83, 0x37, 0x4f, 0xbd, 0x1b, 0x78, 0x3b, 0x39, 0x68, 0x18, 0x49, 0x0b, 0x4b,
                0xc5, 0x1f, 0x6e, 0xe5, 0x30, 0xf0, 0x69, 0x9f, 0xf7, 0xaf, 0x93, 0xcb, 0x59, 0x67,
                0x2d, 0x44, 0xc5, 0x94, 0x0b, 0xf3, 0x4a, 0x90, 0xc8, 0xaf, 0x62, 0x13, 0x85, 0x9b,
                0xfa, 0x50, 0x44, 0x28, 0x1a, 0x43, 0x85, 0x0b, 0x9d, 0x1a, 0x4a, 0xcd, 0x78, 0x5a,
                0xd6, 0x79, 0x80, 0xe0, 0x6b, 0xa9, 0x3c, 0x98, 0xcc, 0xba, 0xc9, 0x59, 0x76, 0xba,
                0x51, 0x96, 0x28, 0x04, 0x92, 0x19, 0x2f, 0x6a, 0xfb, 0xef, 0xc2, 0xbe, 0x94, 0x71,
                0x32, 0x9a, 0xec, 0x15, 0x4d, 0xe2, 0xb3, 0x27, 0x78, 0x0f, 0xf2, 0x6f, 0x24, 0x3c,
                0xa5, 0x6b, 0xcb, 0x97, 0xb8, 0x67, 0xf4, 0xa4, 0x1d, 0x51, 0x2d, 0x21, 0xaf, 0x2a,
                0x12, 0x52, 0xe9, 0x80, 0x71, 0x94, 0x23, 0x66, 0x7c, 0x73, 0x96, 0xdb, 0xfb, 0x0e,
                0x0f, 0x0f, 0x21, 0x94, 0x23, 0x09, 0x3f, 0x81, 0x34, 0x2d, 0xfe, 0x8b, 0xf0, 0x32,
                0x4a, 0x4a, 0x70, 0x9b, 0x34, 0xca, 0xed, 0x1d, 0xe5, 0xcb, 0x43, 0xd3, 0x97, 0xbe,
                0x40, 0xe2, 0xe3, 0xde, 0x92, 0x6d, 0xdd, 0x86, 0x99, 0x95, 0x67, 0x36, 0x21, 0xd1,
                0xa1, 0xd2, 0x2a, 0x00, 0x23, 0xd4, 0xc7, 0x4c, 0x1e, 0xc1, 0xed, 0x90, 0x37, 0x7e,
                0x0a, 0x03, 0xe2, 0x8f, 0xed, 0x4b, 0x9d, 0xfd, 0x1f, 0xde, 0x82, 0x82, 0xd7, 0x9f,
                0x8c, 0x4d, 0xb8, 0x0a, 0x51, 0x71, 0xc2, 0xe7, 0xb4, 0x1e, 0x7d, 0x89, 0x02, 0x46,
                0xb9, 0x54, 0x53, 0xba, 0x96, 0x96, 0x36, 0x53, 0x6d, 0x3c, 0xc3, 0xf6, 0xc4, 0x11,
                0x58, 0xb3, 0xeb, 0x56, 0x23, 0x79, 0x0e, 0x56, 0xb0, 0x53, 0x8f, 0xe1, 0xbc, 0x3a,
                0x76, 0x14, 0xda, 0xe4, 0x6f, 0x6f, 0xcd, 0xcc, 0xf1, 0x46, 0x0d, 0x7a, 0x79, 0x70,
                0xda, 0xea, 0xaf, 0x58, 0x3f, 0xf6, 0x6e, 0xb2, 0x47, 0x63, 0x10, 0xa3, 0xd6, 0xd3,
                0xe4, 0x9b, 0xfd, 0x67, 0x0c, 0x90, 0x32, 0x06, 0xcc, 0xf1, 0xa9, 0xc1, 0xcc, 0x27,
                0x49, 0x30, 0xd6, 0x7f, 0x5d, 0x70, 0x55, 0x7b, 0xeb, 0xf4, 0x6e, 0x74, 0x2e, 0xfb,
                0xdb, 0x13, 0xa3, 0x77, 0x7b, 0xf3, 0x0b, 0xc8, 0x1e, 0x6c, 0x01, 0x66, 0xd2, 0xb0,
                0x0e, 0xed, 0x10, 0x25, 0x98, 0x6f, 0x0f, 0x4c, 0xba, 0x89, 0x88, 0x7b, 0xf8, 0x09,
                0x1d, 0x72, 0xaa, 0x13, 0xe4, 0x5f, 0x8b, 0x3b, 0x78, 0x92, 0xaf, 0x6e, 0x3e, 0x25,
                0x3b, 0xff, 0x57, 0x2d, 0xa0, 0x48, 0xff, 0x06, 0xb6, 0x46, 0xda, 0xb9, 0x46, 0x6b,
                0xc6, 0xe4, 0x69, 0x4b, 0x46, 0x9d, 0x8c, 0x92, 0x00, 0x05, 0xc4, 0x93, 0xb9, 0x09,
                0xdb, 0x93, 0xd7, 0x87, 0x04, 0xca, 0x32, 0x79, 0xd6, 0x7f, 0x03, 0x1d, 0x35, 0xce,
                0x66, 0xb2, 0xb8, 0x0a, 0x45, 0x2d, 0xb7, 0xe7, 0x8e, 0x19, 0x8f, 0xc9, 0x9b, 0x40,
                0x26, 0x03, 0xd7, 0xf2, 0xb6, 0x5e, 0x17, 0x23, 0x95, 0x12, 0x97, 0x81, 0x28, 0xd3,
                0x73, 0x02, 0xc6, 0xa3, 0x56, 0x06, 0x90, 0x14, 0xc2, 0xca, 0xf2, 0xff, 0xf5, 0xb6,
                0xbf, 0xc3, 0x75, 0xa8, 0x3c, 0x1e, 0xb4, 0xe8, 0x01, 0x34, 0xcc, 0xcb, 0x25, 0x26,
                0x57, 0x80, 0x84, 0x1d, 0xed, 0x51, 0x8e, 0x4b, 0x52, 0x8b, 0x86, 0xcc, 0xb8, 0x96,
                0x20, 0xb1, 0x26, 0x83, 0x92, 0x5c, 0x97, 0x15, 0x46, 0x9f, 0x0a, 0xe8, 0x7d, 0x0f,
                0xd1, 0xf3, 0x52, 0x11, 0x01, 0x4d, 0xff, 0x95, 0xf9, 0xcb, 0xb3, 0x36, 0x31, 0x88,
                0x7c, 0x1b, 0x85, 0x95, 0x77, 0x87, 0xb2, 0xe9, 0xb4, 0x38, 0x67, 0x01, 0x28, 0x9f,
                0xdb, 0x4f, 0x31, 0xee, 0xbf, 0xe8, 0xde, 0x9c, 0x23, 0xf1, 0x27, 0xf5, 0xa6, 0x42,
                0xe1, 0x7e, 0x8b, 0xdb, 0x57, 0x26, 0xce, 0x2e, 0xa7, 0xcc, 0xe5, 0x31, 0x2d, 0x2f,
                0xf5, 0xe6, 0x2f, 0xda, 0xdc, 0x9f, 0x82, 0x30, 0x1f, 0xa8, 0x99, 0x21, 0x83, 0xc4,
                0x39, 0xc5, 0x47, 0xad, 0x2a, 0x9a, 0x1f, 0xbd, 0x33, 0xcb, 0x11, 0x5e, 0x21, 0x90,
                0x5f, 0xf5, 0x04, 0x78, 0x55, 0xff, 0x02, 0x41, 0xd8, 0xa1, 0x31, 0xf4, 0xf3, 0x97,
                0xaf, 0xe8, 0x70, 0x6a, 0x00, 0x21,
            ],
            ock: [
                0x56, 0xcf, 0x7d, 0xcb, 0x6a, 0x23, 0x3b, 0x88, 0x8f, 0x12, 0x97, 0x39, 0x2b, 0x92,
                0x49, 0xce, 0xee, 0x18, 0xdf, 0x4d, 0x35, 0x16, 0xe8, 0x9d, 0x76, 0x70, 0x8c, 0x4e,
                0xc9, 0xd0, 0xec, 0xdf,
            ],
            op: [
                0x5d, 0x47, 0x85, 0xa9, 0xfc, 0xc2, 0xf9, 0xba, 0xea, 0x34, 0x30, 0xd7, 0x2a, 0xbf,
                0xf7, 0x6b, 0xa7, 0xcd, 0xc6, 0x14, 0x6a, 0x6d, 0x31, 0x03, 0x84, 0x8f, 0x8a, 0xc9,
                0x22, 0x24, 0x5a, 0x32, 0x28, 0xba, 0xbd, 0x59, 0x76, 0x8d, 0xaa, 0x17, 0x5d, 0xd2,
                0x99, 0xc2, 0x7a, 0x9d, 0x65, 0xad, 0xe0, 0xb2, 0x84, 0x53, 0x82, 0x77, 0xd8, 0x70,
                0x13, 0x0e, 0x6c, 0xee, 0x66, 0xf9, 0x65, 0x0b,
            ],
            c_out: [
                0xb8, 0x82, 0x7e, 0x5b, 0x3e, 0x4d, 0x7a, 0xb5, 0x93, 0xde, 0x42, 0xf5, 0xb2, 0x37,
                0x11, 0xde, 0x4f, 0xeb, 0x21, 0x2c, 0x17, 0xa4, 0xf4, 0xd9, 0x5d, 0xe5, 0xaf, 0x48,
                0x9e, 0x58, 0x9e, 0x03, 0xe2, 0x52, 0x21, 0xb6, 0xb5, 0xbc, 0x89, 0xa4, 0xce, 0x7f,
                0x44, 0x48, 0xb3, 0xb8, 0xfe, 0xa6, 0xdb, 0x79, 0x58, 0x38, 0xc8, 0x3f, 0x82, 0xa5,
                0xe4, 0xd6, 0x12, 0xc7, 0xff, 0x9b, 0x8e, 0x7d, 0xe9, 0xc4, 0x42, 0x37, 0x6b, 0x2d,
                0xae, 0xa8, 0x7f, 0xb6, 0x12, 0x7a, 0x66, 0xfd, 0xe8, 0x1c,
            ],
        },
        TestVector {
            incoming_viewing_key: [
                0x28, 0x5c, 0xda, 0x8b, 0x58, 0xa3, 0xa9, 0x87, 0x97, 0x9a, 0x86, 0x47, 0xe0, 0xed,
                0xc7, 0x69, 0x56, 0xfe, 0xcb, 0x7f, 0x45, 0x87, 0xa7, 0xd2, 0x91, 0x1b, 0xe8, 0xfc,
                0x99, 0xda, 0x16, 0xa4, 0x09, 0x07, 0x5b, 0x24, 0x12, 0xdd, 0x96, 0x85, 0x19, 0x5e,
                0x79, 0xa2, 0xad, 0x89, 0xfa, 0x21, 0x09, 0x7e, 0xda, 0x28, 0xc4, 0x61, 0xa9, 0x79,
                0x94, 0xed, 0xfc, 0xd6, 0x41, 0xee, 0xec, 0x3b,
            ],
            ovk: [
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
                0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
                0x00, 0x00, 0x00, 0x00,
            ],
            default_d: [
                0xe3, 0x0b, 0xce, 0x5a, 0xae, 0x45, 0x51, 0x7b, 0x8a, 0x0d, 0xb1,
            ],
            default_pk_d: [
                0x87, 0x92, 0x94, 0x3b, 0x94, 0x6a, 0xdb, 0xe4, 0x4f, 0x82, 0x13, 0xd6, 0x55, 0xf7,
                0xb0, 0x78, 0x9a, 0x6c, 0x63, 0x50, 0x8c, 0xce, 0x55, 0x80, 0x83, 0xe4, 0xeb, 0x29,
                0x42, 0xbb, 0x7d, 0x88,
            ],
            v: 7880286546227755774,
            rseed: [
                0x78, 0x3c, 0xce, 0x3a, 0xae, 0x11, 0xfa, 0x43, 0x22, 0x62, 0x54, 0x88, 0x56, 0x18,
                0x3e, 0xe6, 0x82, 0xd5, 0xdc, 0x31, 0xbe, 0xb3, 0x8f, 0x06, 0x1c, 0xbd, 0xec, 0xa7,
                0x02, 0x1a, 0x44, 0x4e,
            ],
            memo: [
                0xff, 0x2d, 0xd4, 0x17, 0xdf, 0x26, 0xdc, 0xd2, 0x20, 0xf2, 0xb7, 0x31, 0x77, 0x2b,
                0x43, 0x9e, 0x96, 0xd6, 0x14, 0xe1, 0xfa, 0xcb, 0x48, 0x6c, 0x7a, 0x7d, 0x51, 0x71,
                0xb1, 0xde, 0x35, 0x9f, 0x6a, 0xd3, 0xa9, 0x6f, 0x64, 0x9c, 0x96, 0x91, 0x02, 0xa1,
                0x96, 0x4f, 0xb4, 0xb4, 0xa1, 0xa4, 0x27, 0x9c, 0x68, 0xe6, 0xc3, 0x72, 0xe4, 0x21,
                0x87, 0xd7, 0x54, 0xe8, 0x04, 0xa6, 0x16, 0x53, 0x09, 0x20, 0x69, 0xfb, 0x9b, 0x6d,
                0x25, 0x26, 0x68, 0x90, 0x80, 0x8b, 0x01, 0x5d, 0xf2, 0x8c, 0x80, 0x10, 0x65, 0xda,
                0x6f, 0xeb, 0xdc, 0x1a, 0x56, 0xbf, 0xd0, 0x02, 0x62, 0x5a, 0xcf, 0xaa, 0x53, 0x73,
                0xfd, 0xe1, 0x49, 0xc1, 0xcf, 0xc3, 0x64, 0x9b, 0x48, 0x69, 0x69, 0x6d, 0x44, 0xec,
                0xb1, 0x24, 0x79, 0xc5, 0xeb, 0xef, 0x99, 0x5f, 0x10, 0x02, 0x9f, 0x8b, 0x53, 0x0e,
                0xeb, 0x3f, 0xdc, 0x2e, 0x50, 0xe8, 0x75, 0x7f, 0xc0, 0xbb, 0x9e, 0x26, 0x30, 0x23,
                0xdb, 0x82, 0xf8, 0x78, 0xd9, 0xac, 0x7f, 0xfb, 0x0b, 0xd4, 0x39, 0x1d, 0xf1, 0xd8,
                0x79, 0x89, 0x9a, 0x3e, 0xf5, 0x7b, 0xfd, 0x0d, 0x1f, 0x77, 0x55, 0x64, 0x8e, 0xdd,
                0x85, 0xbb, 0x05, 0x2a, 0x6e, 0xdf, 0x71, 0xcd, 0x26, 0x28, 0xc9, 0x87, 0x42, 0x9f,
                0x36, 0xdc, 0x50, 0x5c, 0xcc, 0x43, 0xf3, 0x0e, 0x7a, 0x86, 0x9c, 0x9e, 0x25, 0x5e,
                0x2a, 0xf9, 0xfc, 0xf3, 0x0c, 0x12, 0x17, 0x96, 0xd1, 0x90, 0x00, 0x09, 0x60, 0xcb,
                0x6f, 0xe2, 0xf1, 0xbf, 0x24, 0x61, 0x18, 0xb4, 0x98, 0xf3, 0x24, 0x7f, 0x9d, 0x48,
                0x4c, 0x73, 0xcf, 0x09, 0x39, 0x30, 0x39, 0xe4, 0x53, 0x26, 0xb8, 0xff, 0xff, 0xb3,
                0xe7, 0xe6, 0x15, 0x9c, 0x46, 0x69, 0x9f, 0x10, 0x07, 0x92, 0xd4, 0x67, 0x29, 0x50,
                0x34, 0x8a, 0x90, 0x55, 0x2e, 0x45, 0x94, 0x3b, 0xee, 0xac, 0xf0, 0x3f, 0x32, 0x16,
                0xf9, 0x4e, 0x27, 0x4d, 0x63, 0xd6, 0x37, 0xd9, 0xf1, 0x90, 0xe8, 0xa2, 0x66, 0xcd,
                0xee, 0xf1, 0x53, 0x53, 0x0b, 0xee, 0x5c, 0xb8, 0x35, 0x52, 0x60, 0x50, 0x5c, 0x2c,
                0x2e, 0x5d, 0x99, 0x0f, 0xff, 0xdc, 0x34, 0xec, 0x0f, 0xf7, 0xf1, 0xaf, 0x81, 0xb2,
                0x4c, 0xed, 0x0e, 0xfa, 0x62, 0x13, 0xda, 0x6c, 0x7c, 0x60, 0xc4, 0x87, 0xf5, 0xf7,
                0xb0, 0x3f, 0x81, 0x60, 0xa0, 0x57, 0xf4, 0x6d, 0x05, 0xbf, 0x82, 0x18, 0xb3, 0xad,
                0xd9, 0xc0, 0x68, 0x93, 0xbd, 0x02, 0xdb, 0x9b, 0x61, 0x19, 0x1d, 0xfb, 0x13, 0x3b,
                0xfa, 0xbe, 0x48, 0x58, 0xe4, 0x7a, 0x4c, 0xc3, 0x2e, 0x41, 0x6e, 0xc0, 0x8b, 0x8a,
                0xc7, 0x91, 0x5a, 0x43, 0x73, 0x3f, 0x44, 0x06, 0xe9, 0xd9, 0x67, 0xc5, 0x60, 0xf3,
                0x44, 0xd7, 0xe9, 0x04, 0xa2, 0x80, 0x45, 0xd9, 0x9f, 0x3a, 0xf8, 0xc8, 0x2e, 0x97,
                0xe1, 0xb9, 0xc1, 0xb2, 0x05, 0xe5, 0x85, 0xfb, 0xeb, 0xb4, 0x8f, 0xaf, 0x58, 0xf1,
                0xb6, 0x5d, 0xca, 0x24, 0x97, 0xe0, 0x9a, 0x70, 0xaa, 0xd4, 0x86, 0x5f, 0x85, 0x71,
                0x5a, 0x28, 0x0e, 0x18, 0x6f, 0x3f, 0xc1, 0x74, 0x0d, 0x81, 0x84, 0xd3, 0x3e, 0x83,
                0x22, 0x16, 0x95, 0x21, 0xcd, 0xc1, 0x32, 0x21, 0x29, 0x39, 0xc8, 0x4a, 0x10, 0x89,
                0x64, 0xe2, 0xde, 0x74, 0xb6, 0xea, 0x55, 0xb4, 0xcb, 0x8f, 0x6f, 0x9b, 0xee, 0x98,
                0xb1, 0x0d, 0x41, 0x51, 0x09, 0x45, 0x5f, 0x48, 0xb7, 0x76, 0x08, 0x2d, 0xc3, 0x0b,
                0x4b, 0xc7, 0x34, 0x77, 0x07, 0x55, 0x11, 0x70, 0x03, 0x08, 0x15, 0x8c, 0xe2, 0xf2,
                0xf9, 0xbf, 0x0f, 0x69, 0x1b, 0x2c, 0xe5, 0x3e, 0x61, 0x14, 0x2c, 0xb7, 0x40, 0xc1,
                0x5b, 0x7b, 0x62, 0x3c, 0xf4, 0x8b, 0x3f, 0x7b,
            ],
            cv_net: [
                0x8d, 0xc1, 0xdf, 0x96, 0x3d, 0x17, 0xdc, 0xa4, 0x2e, 0x77, 0x24, 0xc6, 0xce, 0xd2,
                0x39, 0x6b, 0x8b, 0xec, 0xe6, 0x77, 0x79, 0xb6, 0xbb, 0x91, 0xdf, 0x6b, 0x34, 0xa5,
                0xe0, 0x3c, 0x33, 0x27,
            ],
            rho: [
                0xea, 0x38, 0x44, 0x75, 0x9a, 0x9a, 0x1c, 0xc5, 0x28, 0xb2, 0x95, 0xce, 0x70, 0x13,
                0x7a, 0x85, 0xf9, 0xf0, 0x8e, 0x41, 0xa5, 0xc7, 0xc1, 0xca, 0xc1, 0x55, 0xa6, 0x69,
                0xa3, 0x18, 0x53, 0x3e,
            ],
            cmx: [
                0x0e, 0x1c, 0xd9, 0x6c, 0x85, 0x61, 0x88, 0x37, 0x7a, 0xde, 0xf1, 0x23, 0xc9, 0x29,
                0x9a, 0xa1, 0xbd, 0xce, 0x80, 0x45, 0x64, 0x6f, 0x37, 0xe2, 0x97, 0xe7, 0xfe, 0xee,
                0x35, 0x1c, 0x3d, 0x37,
            ],
            esk: [
                0x31, 0x7b, 0xe4, 0x9a, 0xa7, 0x3a, 0xcd, 0x74, 0xca, 0x19, 0x20, 0x66, 0xfb, 0x68,
                0x21, 0x45, 0x03, 0x45, 0x06, 0xd1, 0x91, 0xaf, 0xa5, 0xd9, 0x04, 0x1d, 0x6d, 0x77,
                0xf2, 0x59, 0x00, 0x36,
            ],
            ephemeral_key: [
                0x92, 0x6c, 0xa8, 0xeb, 0xa8, 0x3d, 0xb8, 0xdc, 0xcf, 0x27, 0xfb, 0xb0, 0x34, 0xff,
                0x3f, 0x46, 0xad, 0x81, 0x77, 0xb2, 0x50, 0xc9, 0xe3, 0x49, 0x27, 0xbc, 0x7f, 0xfd,
                0xb6, 0x3a, 0x8e, 0x3c,
            ],
            shared_secret: [
                0xbd, 0xdd, 0xf4, 0x40, 0x07, 0xf2, 0xc7, 0x28, 0x1c, 0xec, 0xb7, 0x01, 0x93, 0xb9,
                0x49, 0xc2, 0xe0, 0x17, 0x77, 0xa2, 0x89, 0x4e, 0xe3, 0xc3, 0xdc, 0x5b, 0xd6, 0xe9,
                0xfa, 0x87, 0x04, 0x00,
            ],
            k_enc: [
                0x6c, 0xda, 0x58, 0xa3, 0xf1, 0xf3, 0xd5, 0xc1, 0x7d, 0x90, 0x2b, 0x43, 0xb2, 0x9e,
                0xe3, 0x8f, 0x07, 0x9b, 0x91, 0x65, 0x57, 0xf3, 0xdd, 0x42, 0x2c, 0xdc, 0xe6, 0xbb,
                0x05, 0x51, 0xba, 0xf8,
            ],
            p_enc: [
                0x02, 0xe3, 0x0b, 0xce, 0x5a, 0xae, 0x45, 0x51, 0x7b, 0x8a, 0x0d, 0xb1, 0xfe, 0xfa,
                0x31, 0xbc, 0xdc, 0x66, 0x5c, 0x6d, 0x78, 0x3c, 0xce, 0x3a, 0xae, 0x11, 0xfa, 0x43,
                0x22, 0x62, 0x54, 0x88, 0x56, 0x18, 0x3e, 0xe6, 0x82, 0xd5, 0xdc, 0x31, 0xbe, 0xb3,
                0x8f, 0x06, 0x1c, 0xbd, 0xec, 0xa7, 0x02, 0x1a, 0x44, 0x4e, 0xff, 0x2d, 0xd4, 0x17,
                0xdf, 0x26, 0xdc, 0xd2, 0x20, 0xf2, 0xb7, 0x31, 0x77, 0x2b, 0x43, 0x9e, 0x96, 0xd6,
                0x14, 0xe1, 0xfa, 0xcb, 0x48, 0x6c, 0x7a, 0x7d, 0x51, 0x71, 0xb1, 0xde, 0x35, 0x9f,
                0x6a, 0xd3, 0xa9, 0x6f, 0x64, 0x9c, 0x96, 0x91, 0x02, 0xa1, 0x96, 0x4f, 0xb4, 0xb4,
                0xa1, 0xa4, 0x27, 0x9c, 0x68, 0xe6, 0xc3, 0x72, 0xe4, 0x21, 0x87, 0xd7, 0x54, 0xe8,
                0x04, 0xa6, 0x16, 0x53, 0x09, 0x20, 0x69, 0xfb, 0x9b, 0x6d, 0x25, 0x26, 0x68, 0x90,
                0x80, 0x8b, 0x01, 0x5d, 0xf2, 0x8c, 0x80, 0x10, 0x65, 0xda, 0x6f, 0xeb, 0xdc, 0x1a,
                0x56, 0xbf, 0xd0, 0x02, 0x62, 0x5a, 0xcf, 0xaa, 0x53, 0x73, 0xfd, 0xe1, 0x49, 0xc1,
                0xcf, 0xc3, 0x64, 0x9b, 0x48, 0x69, 0x69, 0x6d, 0x44, 0xec, 0xb1, 0x24, 0x79, 0xc5,
                0xeb, 0xef, 0x99, 0x5f, 0x10, 0x02, 0x9f, 0x8b, 0x53, 0x0e, 0xeb, 0x3f, 0xdc, 0x2e,
                0x50, 0xe8, 0x75, 0x7f, 0xc0, 0xbb, 0x9e, 0x26, 0x30, 0x23, 0xdb, 0x82, 0xf8, 0x78,
                0xd9, 0xac, 0x7f, 0xfb, 0x0b, 0xd4, 0x39, 0x1d, 0xf1, 0xd8, 0x79, 0x89, 0x9a, 0x3e,
                0xf5, 0x7b, 0xfd, 0x0d, 0x1f, 0x77, 0x55, 0x64, 0x8e, 0xdd, 0x85, 0xbb, 0x05, 0x2a,
                0x6e, 0xdf, 0x71, 0xcd, 0x26, 0x28, 0xc9, 0x87, 0x42, 0x9f, 0x36, 0xdc, 0x50, 0x5c,
                0xcc, 0x43, 0xf3, 0x0e, 0x7a, 0x86, 0x9c, 0x9e, 0x25, 0x5e, 0x2a, 0xf9, 0xfc, 0xf3,
                0x0c, 0x12, 0x17, 0x96, 0xd1, 0x90, 0x00, 0x09, 0x60, 0xcb, 0x6f, 0xe2, 0xf1, 0xbf,
                0x24, 0x61, 0x18, 0xb4, 0x98, 0xf3, 0x24, 0x7f, 0x9d, 0x48, 0x4c, 0x73, 0xcf, 0x09,
                0x39, 0x30, 0x39, 0xe4, 0x53, 0x26, 0xb8, 0xff, 0xff, 0xb3, 0xe7, 0xe6, 0x15, 0x9c,
                0x46, 0x69, 0x9f, 0x10, 0x07, 0x92, 0xd4, 0x67, 0x29, 0x50, 0x34, 0x8a, 0x90, 0x55,
                0x2e, 0x45, 0x94, 0x3b, 0xee, 0xac, 0xf0, 0x3f, 0x32, 0x16, 0xf9, 0x4e, 0x27, 0x4d,
                0x63, 0xd6, 0x37, 0xd9, 0xf1, 0x90, 0xe8, 0xa2, 0x66, 0xcd, 0xee, 0xf1, 0x53, 0x53,
                0x0b, 0xee, 0x5c, 0xb8, 0x35, 0x52, 0x60, 0x50, 0x5c, 0x2c, 0x2e, 0x5d, 0x99, 0x0f,
                0xff, 0xdc, 0x34, 0xec, 0x0f, 0xf7, 0xf1, 0xaf, 0x81, 0xb2, 0x4c, 0xed, 0x0e, 0xfa,
                0x62, 0x13, 0xda, 0x6c, 0x7c, 0x60, 0xc4, 0x87, 0xf5, 0xf7, 0xb0, 0x3f, 0x81, 0x60,
                0xa0, 0x57, 0xf4, 0x6d, 0x05, 0xbf, 0x82, 0x18, 0xb3, 0xad, 0xd9, 0xc0, 0x68, 0x93,
                0xbd, 0x02, 0xdb, 0x9b, 0x61, 0x19, 0x1d, 0xfb, 0x13, 0x3b, 0xfa, 0xbe, 0x48, 0x58,
                0xe4, 0x7a, 0x4c, 0xc3, 0x2e, 0x41, 0x6e, 0xc0, 0x8b, 0x8a, 0xc7, 0x91, 0x5a, 0x43,
                0x73, 0x3f, 0x44, 0x06, 0xe9, 0xd9, 0x67, 0xc5, 0x60, 0xf3, 0x44, 0xd7, 0xe9, 0x04,
                0xa2, 0x80, 0x45, 0xd9, 0x9f, 0x3a, 0xf8, 0xc8, 0x2e, 0x97, 0xe1, 0xb9, 0xc1, 0xb2,
                0x05, 0xe5, 0x85, 0xfb, 0xeb, 0xb4, 0x8f, 0xaf, 0x58, 0xf1, 0xb6, 0x5d, 0xca, 0x24,
                0x97, 0xe0, 0x9a, 0x70, 0xaa, 0xd4, 0x86, 0x5f, 0x85, 0x71, 0x5a, 0x28, 0x0e, 0x18,
                0x6f, 0x3f, 0xc1, 0x74, 0x0d, 0x81, 0x84, 0xd3, 0x3e, 0x83, 0x22, 0x16, 0x95, 0x21,
                0xcd, 0xc1, 0x32, 0x21, 0x29, 0x39, 0xc8, 0x4a, 0x10, 0x89, 0x64, 0xe2, 0xde, 0x74,
                0xb6, 0xea, 0x55, 0xb4, 0xcb, 0x8f, 0x6f, 0x9b, 0xee, 0x98, 0xb1, 0x0d, 0x41, 0x51,
                0x09, 0x45, 0x5f, 0x48, 0xb7, 0x76, 0x08, 0x2d, 0xc3, 0x0b, 0x4b, 0xc7, 0x34, 0x77,
                0x07, 0x55, 0x11, 0x70, 0x03, 0x08, 0x15, 0x8c, 0xe2, 0xf2, 0xf9, 0xbf, 0x0f, 0x69,
                0x1b, 0x2c, 0xe5, 0x3e, 0x61, 0x14, 0x2c, 0xb7, 0x40, 0xc1, 0x5b, 0x7b, 0x62, 0x3c,
                0xf4, 0x8b, 0x3f, 0x7b,
            ],
            c_enc: [
                0x7e, 0xff, 0x8b, 0x07, 0xed, 0x38, 0xd3, 0x30, 0xac, 0x63, 0x9e, 0x97, 0x2b, 0x3b,
                0x3d, 0xd3, 0x2a, 0xbc, 0x29, 0xa7, 0x85, 0x50, 0xa9, 0xbf, 0x08, 0x4d, 0xf1, 0x45,
                0x27, 0xf4, 0xd9, 0x21, 0x75, 0x45, 0xaa, 0xda, 0x01, 0x46, 0xfd, 0x33, 0x5e, 0x79,
                0x8e, 0x9b, 0xe4, 0xba, 0x35, 0xec, 0x63, 0x61, 0xd1, 0x05, 0xe8, 0xc2, 0x62, 0x8a,
                0xeb, 0xf2, 0x9b, 0xfc, 0x50, 0x9d, 0x34, 0x40, 0x88, 0x82, 0x03, 0x05, 0x99, 0xe3,
                0x2a, 0xfe, 0x33, 0x5d, 0xb6, 0x1c, 0x1d, 0x89, 0x84, 0xde, 0x06, 0x71, 0xf0, 0x8a,
                0x8a, 0x9f, 0x93, 0xfd, 0x0b, 0x2e, 0xe6, 0x80, 0x85, 0x26, 0x64, 0xc3, 0x85, 0xac,
                0xb0, 0xf9, 0xc4, 0x24, 0xa6, 0xd7, 0x4c, 0x15, 0xf2, 0x30, 0x3f, 0xc9, 0x84, 0xf9,
                0x4f, 0xae, 0xef, 0x72, 0x0e, 0x91, 0xce, 0x80, 0xd3, 0x17, 0x2f, 0x23, 0x02, 0x39,
                0x27, 0x38, 0xa0, 0x74, 0x32, 0xa2, 0xc1, 0x33, 0xf4, 0x7d, 0x4c, 0xca, 0x24, 0x73,
                0x68, 0x35, 0x2a, 0xd8, 0xa2, 0x05, 0xaa, 0x7e, 0x62, 0x11, 0x51, 0xc0, 0xd0, 0x3a,
                0x7a, 0x7b, 0x8a, 0xb9, 0xe2, 0xf4, 0xc9, 0x26, 0x30, 0x38, 0xba, 0xdc, 0x76, 0x89,
                0xa6, 0x20, 0xe9, 0xc6, 0x10, 0x6c, 0x8f, 0x74, 0xe4, 0x6b, 0x2e, 0x5c, 0xca, 0x95,
                0x29, 0x85, 0x1f, 0x67, 0x29, 0x68, 0x21, 0x2c, 0xd6, 0x51, 0x27, 0x0f, 0xe5, 0x48,
                0x3b, 0x37, 0x45, 0x74, 0x69, 0x77, 0xf8, 0x77, 0xd0, 0xe6, 0x86, 0xa0, 0x8d, 0x1a,
                0x59, 0x94, 0xa1, 0x8e, 0x48, 0xd2, 0x9b, 0xfc, 0xca, 0x9d, 0xea, 0x4d, 0x68, 0xe6,
                0x59, 0xfd, 0x51, 0x3c, 0x08, 0x15, 0xf9, 0x5a, 0x80, 0xf4, 0x6a, 0x98, 0xee, 0x19,
                0x87, 0x5e, 0xa1, 0x5c, 0x2e, 0x8c, 0x09, 0x26, 0x87, 0xf1, 0x8d, 0x2a, 0x91, 0x3d,
                0xdd, 0x1c, 0x74, 0x8a, 0x08, 0x67, 0xf7, 0x9d, 0x4c, 0x55, 0x06, 0x9d, 0xe9, 0x99,
                0x73, 0xdf, 0x96, 0xfa, 0xca, 0xd2, 0xd8, 0xc9, 0x0d, 0xd2, 0xc3, 0x7b, 0xc5, 0x49,
                0xcb, 0xff, 0x51, 0x21, 0x38, 0xb0, 0xad, 0x03, 0xc3, 0xee, 0x72, 0x13, 0xe5, 0x04,
                0xbe, 0xe9, 0xa3, 0x1e, 0x4a, 0xd2, 0xfc, 0x4f, 0xea, 0x34, 0x8c, 0x26, 0x68, 0x3c,
                0x46, 0x0f, 0x9c, 0xb2, 0xbf, 0xe6, 0xc9, 0xc6, 0x6b, 0x0e, 0x4b, 0x02, 0x0b, 0x82,
                0x16, 0x30, 0x7f, 0x11, 0x11, 0x6a, 0x0d, 0x47, 0xc6, 0x0f, 0x39, 0x16, 0x54, 0xa8,
                0x19, 0x78, 0xcd, 0x86, 0x8b, 0xa4, 0xdc, 0xcb, 0x36, 0x3c, 0x10, 0xf7, 0x8d, 0xe6,
                0x57, 0x39, 0x5f, 0xf3, 0x1a, 0xbc, 0x01, 0x40, 0x75, 0x12, 0x5d, 0x80, 0x35, 0x1e,
                0x3d, 0xb0, 0xc1, 0xbc, 0x08, 0x5f, 0xc7, 0x48, 0xd0, 0x0d, 0x8f, 0xe0, 0x23, 0x4e,
                0x0f, 0x78, 0xe4, 0x24, 0x57, 0x9d, 0x83, 0x79, 0x57, 0xad, 0x2e, 0x23, 0x78, 0x48,
                0x5c, 0x60, 0x49, 0xf9, 0x4c, 0xe6, 0x25, 0xbc, 0xb4, 0xb7, 0x82, 0xcb, 0x55, 0x15,
                0xc4, 0x1b, 0x25, 0x1a, 0x09, 0xc6, 0x9f, 0xf5, 0x52, 0x53, 0x8b, 0xaf, 0x63, 0x14,
                0x87, 0xc5, 0x98, 0xfb, 0xb0, 0xb0, 0xb9, 0x5e, 0xe1, 0xe1, 0xc9, 0x38, 0xee, 0x44,
                0x39, 0x7c, 0x18, 0xde, 0x07, 0x2a, 0xdd, 0xb1, 0xd0, 0x32, 0xf8, 0xad, 0x93, 0xbd,
                0xb4, 0x99, 0xd2, 0x6c, 0x84, 0xe5, 0xad, 0x37, 0xf2, 0xd5, 0x79, 0xac, 0x63, 0x11,
                0x99, 0xe5, 0x12, 0x64, 0xb0, 0xbb, 0x33, 0x61, 0xc4, 0xb3, 0xa2, 0xe9, 0x33, 0x95,
                0x72, 0xc3, 0x54, 0xfd, 0x26, 0x42, 0xf3, 0xe8, 0xe9, 0x11, 0xfd, 0x5d, 0x35, 0x30,
                0x6a, 0xda, 0x87, 0xc5, 0x4e, 0x80, 0x37, 0xeb, 0x45, 0x00, 0x38, 0x74, 0x54, 0xf3,
                0x5e, 0x8e, 0x1b, 0x29, 0x32, 0xde, 0x6a, 0x55, 0x93, 0x16, 0xb8, 0xdc, 0x18, 0x56,
                0x73, 0x5d, 0x5a, 0xde, 0x6d, 0xb2, 0x14, 0xbf, 0x0a, 0xc2, 0xa0, 0x12, 0x9f, 0x2a,
                0x5b, 0xb0, 0x07, 0x63, 0x05, 0x0a, 0xca, 0x2b, 0x9f, 0x12, 0x51, 0x3a, 0xb0, 0x64,
                0x1d, 0xff, 0x2c, 0xaa, 0xa5, 0x20, 0x1e, 0x8a, 0xa7, 0xa0, 0x61, 0x11, 0xd5, 0x33,
                0x58, 0x4c, 0x7d, 0x4c, 0x19, 0xce, 0xa7, 0xf9, 0xe3, 0xfa, 0x3d, 0xad, 0xc2, 0xda,
                0x9e, 0xf0, 0x60, 0xbf, 0xb9, 0x31,
            ],
            ock: [
                0xe5, 0xff, 0x28, 0x45, 0x5a, 0x0c, 0x1b, 0xbd, 0xca, 0x52, 0xfa, 0x22, 0x0b, 0xb8,
                0x23, 0xc2, 0x3b, 0x5f, 0x41, 0x7d, 0x03, 0x84, 0x27, 0xe1, 0x7d, 0x4f, 0xcd, 0x08,
                0x5e, 0x3b, 0x3f, 0xc6,
            ],
            op: [
                0x87, 0x92, 0x94, 0x3b, 0x94, 0x6a, 0xdb, 0xe4, 0x4f, 0x82, 0x13, 0xd6, 0x55, 0xf7,
                0xb0, 0x78, 0x9a, 0x6c, 0x63, 0x50, 0x8c, 0xce, 0x55, 0x80, 0x83, 0xe4, 0xeb, 0x29,
                0x42, 0xbb, 0x7d, 0x88, 0x31, 0x7b, 0xe4, 0x9a, 0xa7, 0x3a, 0xcd, 0x74, 0xca, 0x19,
                0x20, 0x66, 0xfb, 0x68, 0x21, 0x45, 0x03, 0x45, 0x06, 0xd1, 0x91, 0xaf, 0xa5, 0xd9,
                0x04, 0x1d, 0x6d, 0x77, 0xf2, 0x59, 0x00, 0x36,
            ],
            c_out: [
                0xca, 0x22, 0x9d, 0x67, 0xbe, 0xb2, 0xcf, 0x67, 0x38, 0x9c, 0x54, 0x72, 0x56, 0xf7,
                0x04, 0xa1, 0x94, 0xcc, 0xc1, 0xde, 0x18, 0x47, 0x05, 0x1d, 0x83, 0xcb, 0xaa, 0xd9,
                0x20, 0x24, 0x41, 0x19, 0x21, 0x10, 0x19, 0x79, 0xb9, 0xa7, 0x82, 0xbd, 0xb7, 0x86,
                0xa5, 0xa9, 0xfd, 0x79, 0x3d, 0xee, 0xbc, 0x62, 0xa1, 0x42, 0xce, 0xc7, 0x95, 0x3f,
                0x5c, 0x92, 0xa4, 0xed, 0x0f, 0x69, 0xd6, 0xfa, 0xab, 0xca, 0xce, 0xe9, 0x43, 0xd0,
                0x8c, 0xb0, 0x5d, 0x94, 0xf2, 0xb8, 0xd3, 0xc6, 0x1b, 0x4e,
            ],
        },
    ];


    /// Array of random Orchard note encryptions.
    // From https://github.com/zcash-hackworks/zcash-test-vectors/blob/master/orchard_note_encryption.py
    pub static ref ORCHARD_NOTE_ENCRYPTION_VECTOR: Vec<TestVector> = vec![
        TestVector {
            incoming_viewing_key: [
                0x10, 0x39, 0xd8, 0xe6, 0x4a, 0x80, 0x90, 0x2e, 0x10, 0x59, 0x47, 0x81, 0x7d, 0xf3,
                0xbd, 0xfb, 0x7d, 0xf7, 0x03, 0x0e, 0x68, 0x73, 0x9f, 0x9c, 0x53, 0x3a, 0x36, 0xbf,
                0x5a, 0x6a, 0x80, 0x72, 0x43, 0x10, 0x6d, 0xe9, 0xa7, 0xec, 0x54, 0xdd, 0x36, 0xdf,
                0xa7, 0x0b, 0xdb, 0xd9, 0x07, 0x2d, 0xbd, 0xda, 0xb5, 0xe0, 0x66, 0xaa, 0xef, 0xfc,
                0xf9, 0xbb, 0xa3, 0x20, 0xd4, 0xff, 0xf7, 0x12,
            ],
            ovk: [
                0x5d, 0x7a, 0x8f, 0x73, 0x9a, 0x2d, 0x9e, 0x94, 0x5b, 0x0c, 0xe1, 0x52, 0xa8, 0x04,
                0x9e, 0x29, 0x4c, 0x4d, 0x6e, 0x66, 0xb1, 0x64, 0x93, 0x9d, 0xaf, 0xfa, 0x2e, 0xf6,
                0xee, 0x69, 0x21, 0x48,
            ],
            default_d: [
                0x56, 0xe8, 0x4b, 0x1a, 0xdc, 0x94, 0x23, 0xc3, 0x67, 0x6c, 0x04,
            ],
            default_pk_d: [
                0x63, 0xf7, 0x12, 0x5d, 0xf4, 0x83, 0x6f, 0xd2, 0x81, 0x6b, 0x02, 0x4e, 0xe7, 0x0e,
                0xfe, 0x09, 0xfb, 0x9a, 0x7b, 0x38, 0x63, 0xc6, 0xea, 0xcd, 0xf9, 0x5e, 0x03, 0x89,
                0x49, 0x50, 0x69, 0x2c,
            ],
            v: 8567075990963576717,
            rseed: [
                0xbf, 0x69, 0xb8, 0x25, 0x0c, 0x18, 0xef, 0x41, 0x29, 0x4c, 0xa9, 0x79, 0x93, 0xdb,
                0x54, 0x6c, 0x1f, 0xe0, 0x1f, 0x7e, 0x9c, 0x8e, 0x36, 0xd6, 0xa5, 0xe2, 0x9d, 0x4e,
                0x30, 0xa7, 0x35, 0x94,
            ],
            memo: [
                0xff, 0xbf, 0x50, 0x98, 0x42, 0x1c, 0x69, 0x37, 0x8a, 0xf1, 0xe4, 0x0f, 0x64, 0xe1,
                0x25, 0x94, 0x6f, 0x62, 0xc2, 0xfa, 0x7b, 0x2f, 0xec, 0xbc, 0xb6, 0x4b, 0x69, 0x68,
                0x91, 0x2a, 0x63, 0x81, 0xce, 0x3d, 0xc1, 0x66, 0xd5, 0x6a, 0x1d, 0x62, 0xf5, 0xa8,
                0xd7, 0x55, 0x1d, 0xb5, 0xfd, 0x93, 0x13, 0xe8, 0xc7, 0x20, 0x3d, 0x99, 0x6a, 0xf7,
                0xd4, 0x77, 0x08, 0x37, 0x56, 0xd5, 0x9a, 0xf8, 0x0d, 0x06, 0xa7, 0x45, 0xf4, 0x4a,
                0xb0, 0x23, 0x75, 0x2c, 0xb5, 0xb4, 0x06, 0xed, 0x89, 0x85, 0xe1, 0x81, 0x30, 0xab,
                0x33, 0x36, 0x26, 0x97, 0xb0, 0xe4, 0xe4, 0xc7, 0x63, 0xcc, 0xb8, 0xf6, 0x76, 0x49,
                0x5c, 0x22, 0x2f, 0x7f, 0xba, 0x1e, 0x31, 0xde, 0xfa, 0x3d, 0x5a, 0x57, 0xef, 0xc2,
                0xe1, 0xe9, 0xb0, 0x1a, 0x03, 0x55, 0x87, 0xd5, 0xfb, 0x1a, 0x38, 0xe0, 0x1d, 0x94,
                0x90, 0x3d, 0x3c, 0x3e, 0x0a, 0xd3, 0x36, 0x0c, 0x1d, 0x37, 0x10, 0xac, 0xd2, 0x0b,
                0x18, 0x3e, 0x31, 0xd4, 0x9f, 0x25, 0xc9, 0xa1, 0x38, 0xf4, 0x9b, 0x1a, 0x53, 0x7e,
                0xdc, 0xf0, 0x4b, 0xe3, 0x4a, 0x98, 0x51, 0xa7, 0xaf, 0x9d, 0xb6, 0x99, 0x0e, 0xd8,
                0x3d, 0xd6, 0x4a, 0xf3, 0x59, 0x7c, 0x04, 0x32, 0x3e, 0xa5, 0x1b, 0x00, 0x52, 0xad,
                0x80, 0x84, 0xa8, 0xb9, 0xda, 0x94, 0x8d, 0x32, 0x0d, 0xad, 0xd6, 0x4f, 0x54, 0x31,
                0xe6, 0x1d, 0xdf, 0x65, 0x8d, 0x24, 0xae, 0x67, 0xc2, 0x2c, 0x8d, 0x13, 0x09, 0x13,
                0x1f, 0xc0, 0x0f, 0xe7, 0xf2, 0x35, 0x73, 0x42, 0x76, 0xd3, 0x8d, 0x47, 0xf1, 0xe1,
                0x91, 0xe0, 0x0c, 0x7a, 0x1d, 0x48, 0xaf, 0x04, 0x68, 0x27, 0x59, 0x1e, 0x97, 0x33,
                0xa9, 0x7f, 0xa6, 0xb6, 0x79, 0xf3, 0xdc, 0x60, 0x1d, 0x00, 0x82, 0x85, 0xed, 0xcb,
                0xda, 0xe6, 0x9c, 0xe8, 0xfc, 0x1b, 0xe4, 0xaa, 0xc0, 0x0f, 0xf2, 0x71, 0x1e, 0xbd,
                0x93, 0x1d, 0xe5, 0x18, 0x85, 0x68, 0x78, 0xf7, 0x34, 0x76, 0xf2, 0x1a, 0x48, 0x2e,
                0xc9, 0x37, 0x83, 0x65, 0xc8, 0xf7, 0x39, 0x3c, 0x94, 0xe2, 0x88, 0x53, 0x15, 0xeb,
                0x46, 0x71, 0x09, 0x8b, 0x79, 0x53, 0x5e, 0x79, 0x0f, 0xe5, 0x3e, 0x29, 0xfe, 0xf2,
                0xb3, 0x76, 0x66, 0x97, 0xac, 0x32, 0xb4, 0xf4, 0x73, 0xf4, 0x68, 0xa0, 0x08, 0xe7,
                0x23, 0x89, 0xfc, 0x03, 0x88, 0x0d, 0x78, 0x0c, 0xb0, 0x7f, 0xcf, 0xaa, 0xbe, 0x3f,
                0x1a, 0x84, 0xb2, 0x7d, 0xb5, 0x9a, 0x4a, 0x15, 0x3d, 0x88, 0x2d, 0x2b, 0x21, 0x03,
                0x59, 0x65, 0x55, 0xed, 0x94, 0x94, 0xc6, 0xac, 0x89, 0x3c, 0x49, 0x72, 0x38, 0x33,
                0xec, 0x89, 0x26, 0xc1, 0x03, 0x95, 0x86, 0xa7, 0xaf, 0xcf, 0x4a, 0x0d, 0x9c, 0x73,
                0x1e, 0x98, 0x5d, 0x99, 0x58, 0x9c, 0x8b, 0xb8, 0x38, 0xe8, 0xaa, 0xf7, 0x45, 0x53,
                0x3e, 0xd9, 0xe8, 0xae, 0x3a, 0x1c, 0xd0, 0x74, 0xa5, 0x1a, 0x20, 0xda, 0x8a, 0xba,
                0x18, 0xd1, 0xdb, 0xeb, 0xbc, 0x86, 0x2d, 0xed, 0x42, 0x43, 0x5e, 0x92, 0x47, 0x69,
                0x30, 0xd0, 0x69, 0x89, 0x6c, 0xff, 0x30, 0xeb, 0x41, 0x4f, 0x72, 0x7b, 0x89, 0xe0,
                0x01, 0xaf, 0xa2, 0xfb, 0x8d, 0xc3, 0x43, 0x6d, 0x75, 0xa4, 0xa6, 0xf2, 0x65, 0x72,
                0x50, 0x4b, 0x19, 0x22, 0x32, 0xec, 0xb9, 0xf0, 0xc0, 0x24, 0x11, 0xe5, 0x25, 0x96,
                0xbc, 0x5e, 0x90, 0x45, 0x7e, 0x74, 0x59, 0x39, 0xff, 0xed, 0xbd, 0x12, 0x86, 0x3c,
                0xe7, 0x1a, 0x02, 0xaf, 0x11, 0x7d, 0x41, 0x7a, 0xdb, 0x3d, 0x15, 0xcc, 0x54, 0xdc,
                0xb1, 0xfc, 0xe4, 0x67, 0x50, 0x0c, 0x6b, 0x8f, 0xb8, 0x6b, 0x12, 0xb5, 0x6d, 0xa9,
                0xc3, 0x82, 0x85, 0x7d, 0xee, 0xcc, 0x40, 0xa9,
            ],
            cv_net: [
                0xdd, 0xba, 0x24, 0xf3, 0x9f, 0x70, 0x8e, 0xd7, 0xa7, 0x48, 0x57, 0x13, 0x71, 0x11,
                0x42, 0xc2, 0x38, 0x51, 0x38, 0x15, 0x30, 0x2d, 0xf0, 0xf4, 0x83, 0x04, 0x21, 0xa6,
                0xc1, 0x3e, 0x71, 0x01,
            ],
            rho: [
                0xca, 0x1f, 0xeb, 0x30, 0xca, 0x11, 0x17, 0x76, 0xc0, 0x41, 0x74, 0x66, 0xbd, 0x69,
                0xb3, 0xd2, 0x13, 0x88, 0x2e, 0xef, 0x55, 0xe6, 0x0b, 0x6d, 0x9e, 0x2a, 0x98, 0xe7,
                0x05, 0xee, 0xf3, 0x27,
            ],
            cmx: [
                0x23, 0x75, 0x7c, 0x51, 0x58, 0x21, 0xcb, 0xc1, 0x84, 0x3c, 0x9a, 0x45, 0x7b, 0x7e,
                0x6a, 0xe6, 0x01, 0xad, 0xd2, 0xea, 0x10, 0xb9, 0xc8, 0x6d, 0x6b, 0x31, 0x7c, 0xe2,
                0xf1, 0x7b, 0xd9, 0x21,
            ],
            esk: [
                0x5b, 0xfe, 0x46, 0x9c, 0x33, 0xe4, 0x47, 0xba, 0x45, 0x6b, 0x8b, 0xfe, 0x9b, 0x38,
                0x5b, 0x39, 0x31, 0xb4, 0xba, 0xeb, 0x8f, 0x70, 0x23, 0xfe, 0x8e, 0x33, 0x35, 0x4f,
                0xff, 0xf1, 0xbd, 0x1a,
            ],
            ephemeral_key: [
                0x8a, 0x5e, 0x13, 0x2c, 0x3a, 0x07, 0x04, 0xf2, 0x45, 0x6f, 0xbd, 0x77, 0x7a, 0x13,
                0xd6, 0xec, 0x57, 0x65, 0x56, 0x71, 0xdb, 0x07, 0x2a, 0x7d, 0x27, 0x6a, 0xd9, 0x69,
                0xf5, 0xec, 0x45, 0x17,
            ],
            shared_secret: [
                0x36, 0xd5, 0x4c, 0xab, 0xc6, 0x7f, 0x6c, 0xc7, 0x26, 0xa7, 0x30, 0xf3, 0xa0, 0xce,
                0xed, 0x58, 0x53, 0xf0, 0x8c, 0xd3, 0x81, 0x46, 0xc8, 0x34, 0x25, 0x98, 0x98, 0x7c,
                0x21, 0x50, 0x48, 0xa5,
            ],
            k_enc: [
                0x82, 0xc4, 0x32, 0x65, 0x33, 0x7f, 0x1a, 0xb3, 0x7b, 0x18, 0xdf, 0x27, 0x75, 0x48,
                0x61, 0x82, 0x63, 0xb8, 0x02, 0x4d, 0x9b, 0x14, 0x5a, 0x05, 0xad, 0xe2, 0xeb, 0x54,
                0x79, 0x18, 0x03, 0x20,
            ],
            p_enc: [
                0x02, 0x56, 0xe8, 0x4b, 0x1a, 0xdc, 0x94, 0x23, 0xc3, 0x67, 0x6c, 0x04, 0x8d, 0x5f,
                0x29, 0x35, 0x39, 0x5e, 0xe4, 0x76, 0xbf, 0x69, 0xb8, 0x25, 0x0c, 0x18, 0xef, 0x41,
                0x29, 0x4c, 0xa9, 0x79, 0x93, 0xdb, 0x54, 0x6c, 0x1f, 0xe0, 0x1f, 0x7e, 0x9c, 0x8e,
                0x36, 0xd6, 0xa5, 0xe2, 0x9d, 0x4e, 0x30, 0xa7, 0x35, 0x94, 0xff, 0xbf, 0x50, 0x98,
                0x42, 0x1c, 0x69, 0x37, 0x8a, 0xf1, 0xe4, 0x0f, 0x64, 0xe1, 0x25, 0x94, 0x6f, 0x62,
                0xc2, 0xfa, 0x7b, 0x2f, 0xec, 0xbc, 0xb6, 0x4b, 0x69, 0x68, 0x91, 0x2a, 0x63, 0x81,
                0xce, 0x3d, 0xc1, 0x66, 0xd5, 0x6a, 0x1d, 0x62, 0xf5, 0xa8, 0xd7, 0x55, 0x1d, 0xb5,
                0xfd, 0x93, 0x13, 0xe8, 0xc7, 0x20, 0x3d, 0x99, 0x6a, 0xf7, 0xd4, 0x77, 0x08, 0x37,
                0x56, 0xd5, 0x9a, 0xf8, 0x0d, 0x06, 0xa7, 0x45, 0xf4, 0x4a, 0xb0, 0x23, 0x75, 0x2c,
                0xb5, 0xb4, 0x06, 0xed, 0x89, 0x85, 0xe1, 0x81, 0x30, 0xab, 0x33, 0x36, 0x26, 0x97,
                0xb0, 0xe4, 0xe4, 0xc7, 0x63, 0xcc, 0xb8, 0xf6, 0x76, 0x49, 0x5c, 0x22, 0x2f, 0x7f,
                0xba, 0x1e, 0x31, 0xde, 0xfa, 0x3d, 0x5a, 0x57, 0xef, 0xc2, 0xe1, 0xe9, 0xb0, 0x1a,
                0x03, 0x55, 0x87, 0xd5, 0xfb, 0x1a, 0x38, 0xe0, 0x1d, 0x94, 0x90, 0x3d, 0x3c, 0x3e,
                0x0a, 0xd3, 0x36, 0x0c, 0x1d, 0x37, 0x10, 0xac, 0xd2, 0x0b, 0x18, 0x3e, 0x31, 0xd4,
                0x9f, 0x25, 0xc9, 0xa1, 0x38, 0xf4, 0x9b, 0x1a, 0x53, 0x7e, 0xdc, 0xf0, 0x4b, 0xe3,
                0x4a, 0x98, 0x51, 0xa7, 0xaf, 0x9d, 0xb6, 0x99, 0x0e, 0xd8, 0x3d, 0xd6, 0x4a, 0xf3,
                0x59, 0x7c, 0x04, 0x32, 0x3e, 0xa5, 0x1b, 0x00, 0x52, 0xad, 0x80, 0x84, 0xa8, 0xb9,
                0xda, 0x94, 0x8d, 0x32, 0x0d, 0xad, 0xd6, 0x4f, 0x54, 0x31, 0xe6, 0x1d, 0xdf, 0x65,
                0x8d, 0x24, 0xae, 0x67, 0xc2, 0x2c, 0x8d, 0x13, 0x09, 0x13, 0x1f, 0xc0, 0x0f, 0xe7,
                0xf2, 0x35, 0x73, 0x42, 0x76, 0xd3, 0x8d, 0x47, 0xf1, 0xe1, 0x91, 0xe0, 0x0c, 0x7a,
                0x1d, 0x48, 0xaf, 0x04, 0x68, 0x27, 0x59, 0x1e, 0x97, 0x33, 0xa9, 0x7f, 0xa6, 0xb6,
                0x79, 0xf3, 0xdc, 0x60, 0x1d, 0x00, 0x82, 0x85, 0xed, 0xcb, 0xda, 0xe6, 0x9c, 0xe8,
                0xfc, 0x1b, 0xe4, 0xaa, 0xc0, 0x0f, 0xf2, 0x71, 0x1e, 0xbd, 0x93, 0x1d, 0xe5, 0x18,
                0x85, 0x68, 0x78, 0xf7, 0x34, 0x76, 0xf2, 0x1a, 0x48, 0x2e, 0xc9, 0x37, 0x83, 0x65,
                0xc8, 0xf7, 0x39, 0x3c, 0x94, 0xe2, 0x88, 0x53, 0x15, 0xeb, 0x46, 0x71, 0x09, 0x8b,
                0x79, 0x53, 0x5e, 0x79, 0x0f, 0xe5, 0x3e, 0x29, 0xfe, 0xf2, 0xb3, 0x76, 0x66, 0x97,
                0xac, 0x32, 0xb4, 0xf4, 0x73, 0xf4, 0x68, 0xa0, 0x08, 0xe7, 0x23, 0x89, 0xfc, 0x03,
                0x88, 0x0d, 0x78, 0x0c, 0xb0, 0x7f, 0xcf, 0xaa, 0xbe, 0x3f, 0x1a, 0x84, 0xb2, 0x7d,
                0xb5, 0x9a, 0x4a, 0x15, 0x3d, 0x88, 0x2d, 0x2b, 0x21, 0x03, 0x59, 0x65, 0x55, 0xed,
                0x94, 0x94, 0xc6, 0xac, 0x89, 0x3c, 0x49, 0x72, 0x38, 0x33, 0xec, 0x89, 0x26, 0xc1,
                0x03, 0x95, 0x86, 0xa7, 0xaf, 0xcf, 0x4a, 0x0d, 0x9c, 0x73, 0x1e, 0x98, 0x5d, 0x99,
                0x58, 0x9c, 0x8b, 0xb8, 0x38, 0xe8, 0xaa, 0xf7, 0x45, 0x53, 0x3e, 0xd9, 0xe8, 0xae,
                0x3a, 0x1c, 0xd0, 0x74, 0xa5, 0x1a, 0x20, 0xda, 0x8a, 0xba, 0x18, 0xd1, 0xdb, 0xeb,
                0xbc, 0x86, 0x2d, 0xed, 0x42, 0x43, 0x5e, 0x92, 0x47, 0x69, 0x30, 0xd0, 0x69, 0x89,
                0x6c, 0xff, 0x30, 0xeb, 0x41, 0x4f, 0x72, 0x7b, 0x89, 0xe0, 0x01, 0xaf, 0xa2, 0xfb,
                0x8d, 0xc3, 0x43, 0x6d, 0x75, 0xa4, 0xa6, 0xf2, 0x65, 0x72, 0x50, 0x4b, 0x19, 0x22,
                0x32, 0xec, 0xb9, 0xf0, 0xc0, 0x24, 0x11, 0xe5, 0x25, 0x96, 0xbc, 0x5e, 0x90, 0x45,
                0x7e, 0x74, 0x59, 0x39, 0xff, 0xed, 0xbd, 0x12, 0x86, 0x3c, 0xe7, 0x1a, 0x02, 0xaf,
                0x11, 0x7d, 0x41, 0x7a, 0xdb, 0x3d, 0x15, 0xcc, 0x54, 0xdc, 0xb1, 0xfc, 0xe4, 0x67,
                0x50, 0x0c, 0x6b, 0x8f, 0xb8, 0x6b, 0x12, 0xb5, 0x6d, 0xa9, 0xc3, 0x82, 0x85, 0x7d,
                0xee, 0xcc, 0x40, 0xa9,
            ],
            c_enc: [
                0x93, 0xe0, 0x48, 0x74, 0xb5, 0x83, 0x7c, 0x26, 0x1d, 0xaf, 0x1a, 0x27, 0xb7, 0x83,
                0xec, 0x48, 0x65, 0xd3, 0xbb, 0x72, 0x8e, 0xb1, 0x61, 0xda, 0xed, 0xb8, 0x44, 0x6a,
                0xb3, 0x8f, 0x07, 0x8e, 0xa8, 0x66, 0x2e, 0x4d, 0x2e, 0x9d, 0x00, 0xa3, 0x95, 0x27,
                0xdc, 0xde, 0x51, 0x7a, 0xc3, 0xdb, 0xf9, 0xd2, 0x7e, 0x3c, 0x79, 0xfa, 0x88, 0x1a,
                0xbb, 0x48, 0xb7, 0x0d, 0xbc, 0x28, 0xdd, 0xf4, 0xaf, 0x81, 0xae, 0xed, 0x2a, 0x29,
                0x86, 0x00, 0x51, 0x08, 0x48, 0xed, 0xbd, 0xc4, 0x2e, 0x88, 0x95, 0x48, 0x70, 0xd5,
                0xd6, 0x01, 0xcd, 0xf2, 0x90, 0x18, 0x1b, 0x53, 0x91, 0x05, 0xb9, 0xf6, 0x13, 0x86,
                0xcb, 0x07, 0x84, 0x6b, 0xc8, 0xe3, 0x19, 0xdf, 0xab, 0x8e, 0x10, 0x97, 0x66, 0xa2,
                0x8c, 0x1e, 0x0b, 0xbf, 0x91, 0x32, 0x02, 0xce, 0xcd, 0x1b, 0x48, 0x17, 0xa2, 0x28,
                0x2f, 0xc2, 0x9e, 0xd4, 0x4d, 0x9b, 0x04, 0x04, 0x9d, 0xe5, 0x5a, 0xcf, 0x54, 0x99,
                0xe5, 0xf5, 0x65, 0xd4, 0x8b, 0x8f, 0x19, 0x72, 0xc0, 0x43, 0x84, 0x77, 0x96, 0x23,
                0x0d, 0xc6, 0x8f, 0x32, 0x57, 0xc0, 0x85, 0x29, 0x14, 0x8c, 0x8e, 0x0c, 0x32, 0x7b,
                0x25, 0xb4, 0x59, 0x87, 0x7c, 0xde, 0xd9, 0x8f, 0xf7, 0x8e, 0x81, 0xfa, 0x69, 0x2e,
                0x14, 0xf8, 0xfd, 0xa1, 0xfe, 0x52, 0x4f, 0xf1, 0x50, 0x18, 0x1f, 0x73, 0x6e, 0xd3,
                0xa8, 0x8e, 0xc7, 0x89, 0xdc, 0x15, 0x95, 0x4a, 0x02, 0x63, 0x9a, 0x8a, 0x20, 0xca,
                0x38, 0xd8, 0x99, 0xbf, 0xd1, 0xc5, 0x73, 0xb0, 0x41, 0xee, 0x7b, 0xf2, 0x2b, 0x96,
                0x75, 0xbd, 0xa8, 0xc4, 0xb0, 0x58, 0xa0, 0x5a, 0x49, 0x33, 0x03, 0xb1, 0x1f, 0x35,
                0x81, 0xc1, 0x9d, 0x2d, 0xa9, 0x96, 0x6a, 0x71, 0x06, 0x6e, 0xc1, 0x7d, 0xcc, 0xd3,
                0x48, 0x20, 0x7e, 0xb3, 0x14, 0xf6, 0xcf, 0xc9, 0xd0, 0x6a, 0x62, 0x14, 0xc6, 0x72,
                0x10, 0x97, 0xa5, 0x2e, 0x27, 0x76, 0x66, 0x7c, 0x6b, 0xe9, 0xc8, 0x86, 0x2b, 0x17,
                0x3d, 0xb0, 0xe8, 0x04, 0xb1, 0x2c, 0xaa, 0xe9, 0xd9, 0xfa, 0x09, 0xf3, 0xf4, 0x8c,
                0xaf, 0x4b, 0xf7, 0x56, 0xa2, 0x78, 0x95, 0x0a, 0x25, 0x4e, 0xc4, 0x14, 0x76, 0x77,
                0xaa, 0xca, 0x21, 0x42, 0x96, 0x08, 0x1a, 0x2f, 0x62, 0x4a, 0x92, 0x78, 0x94, 0x6e,
                0x68, 0x9d, 0xd9, 0x14, 0x02, 0x90, 0x92, 0xe7, 0xfa, 0x8f, 0xbc, 0x8a, 0x04, 0x46,
                0x7d, 0x60, 0xed, 0xff, 0x5d, 0x97, 0xcb, 0x65, 0x09, 0xa0, 0xc7, 0x2c, 0xed, 0x77,
                0xac, 0xa8, 0x71, 0x30, 0x8e, 0x7d, 0xe2, 0xbe, 0xb1, 0x52, 0x0a, 0x34, 0x17, 0xd7,
                0x21, 0x3a, 0x9a, 0xbd, 0x47, 0x35, 0x8c, 0x4f, 0x32, 0x9f, 0x0f, 0x64, 0x41, 0x92,
                0x10, 0xa9, 0x9d, 0xb2, 0xde, 0x6e, 0x6d, 0x89, 0x21, 0xb0, 0xf4, 0xf9, 0x9f, 0xd6,
                0x45, 0xfa, 0xe0, 0xd6, 0x29, 0xce, 0x22, 0x11, 0x90, 0x5f, 0x25, 0xf4, 0x0d, 0x12,
                0x0b, 0x63, 0x27, 0x93, 0x75, 0xb5, 0x43, 0xc3, 0x1e, 0x3b, 0x55, 0x7e, 0x57, 0xa7,
                0xa8, 0x7c, 0x61, 0x79, 0xeb, 0xd3, 0x4f, 0x6d, 0xbb, 0x92, 0x0e, 0xc5, 0xe0, 0x5d,
                0x6a, 0x77, 0xec, 0xdf, 0x36, 0xb4, 0x57, 0xba, 0xb4, 0x56, 0x6c, 0x40, 0x8f, 0xb5,
                0x7d, 0xfc, 0xdd, 0xda, 0xa4, 0x2c, 0x51, 0x34, 0xaf, 0x3e, 0x97, 0x8d, 0xbf, 0xd0,
                0xdf, 0xb0, 0xca, 0x4f, 0xfa, 0xf1, 0x65, 0x0a, 0xbe, 0xe1, 0x62, 0x5f, 0x7f, 0x4b,
                0xf8, 0x25, 0x06, 0x01, 0x00, 0x64, 0x5b, 0x54, 0xc0, 0x04, 0x1f, 0xbf, 0xbd, 0xef,
                0xf7, 0xb9, 0x38, 0x04, 0xe9, 0xcc, 0x0c, 0xcd, 0x6f, 0x27, 0xbe, 0x40, 0x01, 0x6c,
                0x32, 0xd4, 0x2f, 0xe3, 0x66, 0xfa, 0xaa, 0x86, 0x87, 0xc2, 0xd1, 0x92, 0x61, 0x9f,
                0x56, 0x5b, 0x0c, 0x70, 0xea, 0x6a, 0x3f, 0x79, 0xd5, 0x3a, 0x52, 0x41, 0xe6, 0x9c,
                0x3c, 0xa6, 0x87, 0xa1, 0x12, 0xfb, 0x16, 0xc2, 0x5c, 0xc0, 0x83, 0x17, 0xdb, 0xa4,
                0x23, 0x97, 0x0c, 0x32, 0xdf, 0xb4, 0xbd, 0x69, 0x22, 0xe3, 0x36, 0xab, 0xf2, 0xfd,
                0xe2, 0xc3, 0xaa, 0x5d, 0xb2, 0x93, 0xef, 0x27, 0x47, 0x87, 0x6c, 0x8b, 0xd8, 0x6e,
                0xa1, 0x87, 0xcb, 0x60, 0x1a, 0xf7,
            ],
            ock: [
                0xb3, 0x25, 0xeb, 0xe5, 0x7a, 0x2c, 0x40, 0xa8, 0xb2, 0x11, 0xcf, 0xdf, 0x72, 0xa1,
                0xa2, 0x44, 0xf1, 0x53, 0x42, 0x85, 0x98, 0x88, 0xa3, 0x64, 0x52, 0x3e, 0xfd, 0x2a,
                0xc6, 0x6a, 0x1a, 0xd6,
            ],
            op: [
                0x63, 0xf7, 0x12, 0x5d, 0xf4, 0x83, 0x6f, 0xd2, 0x81, 0x6b, 0x02, 0x4e, 0xe7, 0x0e,
                0xfe, 0x09, 0xfb, 0x9a, 0x7b, 0x38, 0x63, 0xc6, 0xea, 0xcd, 0xf9, 0x5e, 0x03, 0x89,
                0x49, 0x50, 0x69, 0x2c, 0x5b, 0xfe, 0x46, 0x9c, 0x33, 0xe4, 0x47, 0xba, 0x45, 0x6b,
                0x8b, 0xfe, 0x9b, 0x38, 0x5b, 0x39, 0x31, 0xb4, 0xba, 0xeb, 0x8f, 0x70, 0x23, 0xfe,
                0x8e, 0x33, 0x35, 0x4f, 0xff, 0xf1, 0xbd, 0x1a,
            ],
            c_out: [
                0x55, 0xb8, 0x90, 0x7c, 0x6d, 0x45, 0x4b, 0x83, 0x63, 0x4f, 0x1b, 0x9a, 0x1a, 0xa3,
                0xc3, 0xc9, 0x8a, 0xdc, 0x77, 0xd9, 0x6c, 0x2f, 0x62, 0x49, 0xec, 0x66, 0xdb, 0xae,
                0x4d, 0x0c, 0xc9, 0x40, 0xd7, 0x26, 0xbc, 0xd1, 0xec, 0x91, 0x18, 0x9f, 0xd3, 0x04,
                0x9a, 0x33, 0xf2, 0xea, 0x7d, 0x8b, 0x74, 0xaa, 0xc1, 0x7c, 0xda, 0x38, 0x83, 0x80,
                0x2d, 0xb5, 0x96, 0x9d, 0x8d, 0x2f, 0x32, 0x25, 0x91, 0x9c, 0xe3, 0x88, 0x26, 0x41,
                0x5c, 0xc6, 0xb3, 0x38, 0x94, 0x4b, 0x48, 0x99, 0x54, 0x8b,
            ],
        },
        TestVector {
            incoming_viewing_key: [
                0xfd, 0x9e, 0x9a, 0x1f, 0x38, 0x1c, 0xbe, 0x75, 0xcd, 0x8d, 0x6a, 0xe1, 0x2f, 0xca,
                0x87, 0x2e, 0x94, 0x00, 0xf0, 0x02, 0x72, 0xb0, 0x29, 0x65, 0x2e, 0x65, 0x6c, 0x8f,
                0x3c, 0x4b, 0xf0, 0x37, 0xee, 0xef, 0x96, 0x42, 0x1b, 0x2f, 0xab, 0x2f, 0xb3, 0xad,
                0x1e, 0x0a, 0xd8, 0x50, 0x2d, 0x74, 0xe6, 0xf0, 0x8f, 0x0d, 0xd5, 0x18, 0xf8, 0xfa,
                0x82, 0x2a, 0x65, 0xbe, 0x27, 0x40, 0xc0, 0x21,
            ],
            ovk: [
                0xe7, 0x30, 0x81, 0xef, 0x8d, 0x62, 0xcb, 0x78, 0x0a, 0xb6, 0x88, 0x3a, 0x50, 0xa0,
                0xd4, 0x70, 0x19, 0x0d, 0xfb, 0xa1, 0x0a, 0x85, 0x7f, 0x82, 0x84, 0x2d, 0x38, 0x25,
                0xb3, 0xd6, 0xda, 0x05,
            ],
            default_d: [
                0x55, 0x6e, 0x5e, 0x1b, 0xf5, 0x1b, 0xc6, 0xa6, 0x11, 0x58, 0xf7,
            ],
            default_pk_d: [
                0xb4, 0xca, 0xc5, 0x6f, 0x06, 0x2b, 0xfb, 0x2e, 0x27, 0x15, 0xea, 0xf9, 0xc8, 0xfc,
                0xdb, 0xc2, 0x0c, 0x86, 0x79, 0x3f, 0x23, 0x57, 0xdd, 0xd0, 0x4a, 0xad, 0x39, 0xf9,
                0x4a, 0xd7, 0xc7, 0x84,
            ],
            v: 9072946746592546880,
            rseed: [
                0xae, 0xab, 0x01, 0x6b, 0x6b, 0xc1, 0xec, 0x14, 0x4b, 0x4e, 0x55, 0x3a, 0xcf, 0xd6,
                0x70, 0xf7, 0x7e, 0x75, 0x5f, 0xc8, 0x8e, 0x06, 0x77, 0xe3, 0x1b, 0xa4, 0x59, 0xb4,
                0x4e, 0x30, 0x77, 0x68,
            ],
            memo: [
                0xff, 0x95, 0x8f, 0xe3, 0x78, 0x9d, 0x41, 0xc2, 0xb1, 0xff, 0x43, 0x4c, 0xb3, 0x0e,
                0x15, 0x91, 0x4f, 0x01, 0xbc, 0x6b, 0xc2, 0x30, 0x7b, 0x48, 0x8d, 0x25, 0x56, 0xd7,
                0xb7, 0x38, 0x0e, 0xa4, 0xff, 0xd7, 0x12, 0xf6, 0xb0, 0x2f, 0xe8, 0x06, 0xb9, 0x45,
                0x69, 0xcd, 0x40, 0x59, 0xf3, 0x96, 0xbf, 0x29, 0xb9, 0x9d, 0x0a, 0x40, 0xe5, 0xe1,
                0x71, 0x1c, 0xa9, 0x44, 0xf7, 0x2d, 0x43, 0x6a, 0x10, 0x2f, 0xca, 0x4b, 0x97, 0x69,
                0x3d, 0xa0, 0xb0, 0x86, 0xfe, 0x9d, 0x2e, 0x71, 0x62, 0x47, 0x0d, 0x02, 0xe0, 0xf0,
                0x5d, 0x4b, 0xec, 0x95, 0x12, 0xbf, 0xb3, 0xf3, 0x83, 0x27, 0x29, 0x6e, 0xfa, 0xa7,
                0x43, 0x28, 0xb1, 0x18, 0xc2, 0x74, 0x02, 0xc7, 0x0c, 0x3a, 0x90, 0xb4, 0x9a, 0xd4,
                0xbb, 0xc6, 0x8e, 0x37, 0xc0, 0xaa, 0x7d, 0x9b, 0x3f, 0xe1, 0x77, 0x99, 0xd7, 0x3b,
                0x84, 0x1e, 0x75, 0x17, 0x13, 0xa0, 0x29, 0x43, 0x90, 0x5a, 0xae, 0x08, 0x03, 0xfd,
                0x69, 0x44, 0x2e, 0xb7, 0x68, 0x1e, 0xc2, 0xa0, 0x56, 0x00, 0x05, 0x4e, 0x92, 0xee,
                0xd5, 0x55, 0x02, 0x8f, 0x21, 0xb6, 0xa1, 0x55, 0x26, 0x8a, 0x2d, 0xd6, 0x64, 0x0a,
                0x69, 0x30, 0x1a, 0x52, 0xa3, 0x8d, 0x4d, 0x9f, 0x9f, 0x95, 0x7a, 0xe3, 0x5a, 0xf7,
                0x16, 0x71, 0x18, 0x14, 0x1c, 0xe4, 0xc9, 0xbe, 0x0a, 0x6a, 0x49, 0x2f, 0xe7, 0x9f,
                0x15, 0x81, 0xa1, 0x55, 0xfa, 0x3a, 0x2b, 0x9d, 0xaf, 0xd8, 0x2e, 0x65, 0x0b, 0x38,
                0x6a, 0xd3, 0xa0, 0x8c, 0xb6, 0xb8, 0x31, 0x31, 0xac, 0x30, 0x0b, 0x08, 0x46, 0x35,
                0x4a, 0x7e, 0xef, 0x9c, 0x41, 0x0e, 0x4b, 0x62, 0xc4, 0x7c, 0x54, 0x26, 0x90, 0x7d,
                0xfc, 0x66, 0x85, 0xc5, 0xc9, 0x9b, 0x71, 0x41, 0xac, 0x62, 0x6a, 0xb4, 0x76, 0x1f,
                0xd3, 0xf4, 0x1e, 0x72, 0x8e, 0x1a, 0x28, 0xf8, 0x9d, 0xb8, 0x9f, 0xfd, 0xec, 0xa3,
                0x64, 0xdd, 0x2f, 0x0f, 0x07, 0x39, 0xf0, 0x53, 0x45, 0x56, 0x48, 0x31, 0x99, 0xc7,
                0x1f, 0x18, 0x93, 0x41, 0xac, 0x9b, 0x78, 0xa2, 0x69, 0x16, 0x42, 0x06, 0xa0, 0xea,
                0x1c, 0xe7, 0x3b, 0xfb, 0x2a, 0x94, 0x2e, 0x73, 0x70, 0xb2, 0x47, 0xc0, 0x46, 0xf8,
                0xe7, 0x5e, 0xf8, 0xe3, 0xf8, 0xbd, 0x82, 0x1c, 0xf5, 0x77, 0x49, 0x18, 0x64, 0xe2,
                0x0e, 0x6d, 0x08, 0xfd, 0x2e, 0x32, 0xb5, 0x55, 0xc9, 0x2c, 0x66, 0x1f, 0x19, 0x58,
                0x8b, 0x72, 0xa8, 0x95, 0x99, 0x71, 0x0a, 0x88, 0x06, 0x12, 0x53, 0xca, 0x28, 0x5b,
                0x63, 0x04, 0xb3, 0x7d, 0xa2, 0xb5, 0x29, 0x4f, 0x5c, 0xb3, 0x54, 0xa8, 0x94, 0x32,
                0x28, 0x48, 0xcc, 0xbd, 0xc7, 0xc2, 0x54, 0x5b, 0x7d, 0xa5, 0x68, 0xaf, 0xac, 0x87,
                0xff, 0xa0, 0x05, 0xc3, 0x12, 0x24, 0x1c, 0x2d, 0x57, 0xf4, 0xb4, 0x5d, 0x64, 0x19,
                0xf0, 0xd2, 0xe2, 0xc5, 0xaf, 0x33, 0xae, 0x24, 0x37, 0x85, 0xb3, 0x25, 0xcd, 0xab,
                0x95, 0x40, 0x4f, 0xc7, 0xae, 0xd7, 0x05, 0x25, 0xcd, 0xdb, 0x41, 0x87, 0x2c, 0xfc,
                0xc2, 0x14, 0xb1, 0x32, 0x32, 0xed, 0xc7, 0x86, 0x09, 0x75, 0x3d, 0xbf, 0xf9, 0x30,
                0xeb, 0x0d, 0xc1, 0x56, 0x61, 0x2b, 0x9c, 0xb4, 0x34, 0xbc, 0x4b, 0x69, 0x33, 0x92,
                0xde, 0xb8, 0x7c, 0x53, 0x04, 0x35, 0x31, 0x2e, 0xdc, 0xed, 0xc6, 0xa9, 0x61, 0x13,
                0x33, 0x38, 0xd7, 0x86, 0xc4, 0xa3, 0xe1, 0x03, 0xf6, 0x01, 0x10, 0xa1, 0x6b, 0x13,
                0x37, 0x12, 0x97, 0x04, 0xbf, 0x47, 0x54, 0xff, 0x6b, 0xa9, 0xfb, 0xe6, 0x59, 0x51,
                0xe6, 0x10, 0x62, 0x0f, 0x71, 0xcd, 0xa8, 0xfc, 0x87, 0x76, 0x25, 0xf2, 0xc5, 0xbb,
                0x04, 0xcb, 0xe1, 0x22, 0x8b, 0x1e, 0x88, 0x6f,
            ],
            cv_net: [
                0x15, 0x49, 0x70, 0x7e, 0x1e, 0xd2, 0xb2, 0xeb, 0x66, 0x15, 0x65, 0x0b, 0xec, 0x45,
                0xa2, 0x17, 0x64, 0x10, 0x4a, 0x23, 0xea, 0xf6, 0xba, 0x49, 0x6c, 0xb9, 0xb8, 0xe8,
                0x25, 0x7a, 0xd8, 0xb3,
            ],
            rho: [
                0xc1, 0xe1, 0x59, 0x5b, 0x8d, 0xe7, 0x55, 0x97, 0x66, 0xe5, 0xa6, 0x72, 0x5f, 0x5b,
                0xe5, 0x74, 0x2f, 0x43, 0xbf, 0x40, 0x62, 0x3b, 0x71, 0x49, 0xca, 0xe2, 0x67, 0x5c,
                0x4d, 0xb2, 0xc7, 0x31,
            ],
            cmx: [
                0x59, 0xb6, 0xf3, 0xd4, 0x03, 0x22, 0x3d, 0x6c, 0xe4, 0x3d, 0xed, 0xae, 0xe2, 0x35,
                0xfc, 0xa9, 0x5c, 0xc8, 0xb2, 0x49, 0x94, 0x1c, 0xcd, 0xb6, 0x6f, 0x3f, 0x61, 0x1c,
                0xc5, 0xe9, 0xf9, 0x0f,
            ],
            esk: [
                0x10, 0x87, 0x4a, 0x74, 0x22, 0x7a, 0xc7, 0x99, 0x5e, 0xdd, 0xdd, 0x73, 0x4d, 0x0e,
                0x00, 0xdc, 0xc9, 0xf4, 0x8a, 0x01, 0xdd, 0x5c, 0x4c, 0xb1, 0x22, 0xc0, 0x61, 0xe0,
                0xbd, 0xc9, 0xce, 0x14,
            ],
            ephemeral_key: [
                0xd2, 0x9e, 0x0d, 0x00, 0x1e, 0xe7, 0x1e, 0x05, 0x99, 0x08, 0x65, 0x04, 0xd8, 0x62,
                0xc7, 0xf5, 0x2b, 0x08, 0x60, 0x77, 0x0d, 0x8a, 0x4b, 0x42, 0xa8, 0x68, 0x11, 0xac,
                0x31, 0x69, 0x85, 0x8c,
            ],
            shared_secret: [
                0x11, 0xa0, 0xac, 0x79, 0x9a, 0x29, 0xb0, 0xed, 0x19, 0x5e, 0xd8, 0x7b, 0x13, 0x83,
                0x22, 0x26, 0x3b, 0xbb, 0x9c, 0x31, 0x00, 0x8c, 0x29, 0x59, 0xaf, 0x2f, 0xc6, 0x36,
                0x68, 0x7e, 0xd9, 0xb0,
            ],
            k_enc: [
                0x4b, 0xbf, 0x80, 0xe7, 0xa1, 0x70, 0x3a, 0xc1, 0x4a, 0xd7, 0xb5, 0x44, 0x8a, 0x2e,
                0x8e, 0x79, 0x49, 0x30, 0x49, 0xd1, 0x9a, 0x6a, 0x51, 0x31, 0x67, 0xd5, 0x5b, 0xdd,
                0x58, 0x6a, 0xc0, 0xd9,
            ],
            p_enc: [
                0x02, 0x55, 0x6e, 0x5e, 0x1b, 0xf5, 0x1b, 0xc6, 0xa6, 0x11, 0x58, 0xf7, 0x40, 0x50,
                0xaf, 0xd8, 0xfe, 0x94, 0xe9, 0x7d, 0xae, 0xab, 0x01, 0x6b, 0x6b, 0xc1, 0xec, 0x14,
                0x4b, 0x4e, 0x55, 0x3a, 0xcf, 0xd6, 0x70, 0xf7, 0x7e, 0x75, 0x5f, 0xc8, 0x8e, 0x06,
                0x77, 0xe3, 0x1b, 0xa4, 0x59, 0xb4, 0x4e, 0x30, 0x77, 0x68, 0xff, 0x95, 0x8f, 0xe3,
                0x78, 0x9d, 0x41, 0xc2, 0xb1, 0xff, 0x43, 0x4c, 0xb3, 0x0e, 0x15, 0x91, 0x4f, 0x01,
                0xbc, 0x6b, 0xc2, 0x30, 0x7b, 0x48, 0x8d, 0x25, 0x56, 0xd7, 0xb7, 0x38, 0x0e, 0xa4,
                0xff, 0xd7, 0x12, 0xf6, 0xb0, 0x2f, 0xe8, 0x06, 0xb9, 0x45, 0x69, 0xcd, 0x40, 0x59,
                0xf3, 0x96, 0xbf, 0x29, 0xb9, 0x9d, 0x0a, 0x40, 0xe5, 0xe1, 0x71, 0x1c, 0xa9, 0x44,
                0xf7, 0x2d, 0x43, 0x6a, 0x10, 0x2f, 0xca, 0x4b, 0x97, 0x69, 0x3d, 0xa0, 0xb0, 0x86,
                0xfe, 0x9d, 0x2e, 0x71, 0x62, 0x47, 0x0d, 0x02, 0xe0, 0xf0, 0x5d, 0x4b, 0xec, 0x95,
                0x12, 0xbf, 0xb3, 0xf3, 0x83, 0x27, 0x29, 0x6e, 0xfa, 0xa7, 0x43, 0x28, 0xb1, 0x18,
                0xc2, 0x74, 0x02, 0xc7, 0x0c, 0x3a, 0x90, 0xb4, 0x9a, 0xd4, 0xbb, 0xc6, 0x8e, 0x37,
                0xc0, 0xaa, 0x7d, 0x9b, 0x3f, 0xe1, 0x77, 0x99, 0xd7, 0x3b, 0x84, 0x1e, 0x75, 0x17,
                0x13, 0xa0, 0x29, 0x43, 0x90, 0x5a, 0xae, 0x08, 0x03, 0xfd, 0x69, 0x44, 0x2e, 0xb7,
                0x68, 0x1e, 0xc2, 0xa0, 0x56, 0x00, 0x05, 0x4e, 0x92, 0xee, 0xd5, 0x55, 0x02, 0x8f,
                0x21, 0xb6, 0xa1, 0x55, 0x26, 0x8a, 0x2d, 0xd6, 0x64, 0x0a, 0x69, 0x30, 0x1a, 0x52,
                0xa3, 0x8d, 0x4d, 0x9f, 0x9f, 0x95, 0x7a, 0xe3, 0x5a, 0xf7, 0x16, 0x71, 0x18, 0x14,
                0x1c, 0xe4, 0xc9, 0xbe, 0x0a, 0x6a, 0x49, 0x2f, 0xe7, 0x9f, 0x15, 0x81, 0xa1, 0x55,
                0xfa, 0x3a, 0x2b, 0x9d, 0xaf, 0xd8, 0x2e, 0x65, 0x0b, 0x38, 0x6a, 0xd3, 0xa0, 0x8c,
                0xb6, 0xb8, 0x31, 0x31, 0xac, 0x30, 0x0b, 0x08, 0x46, 0x35, 0x4a, 0x7e, 0xef, 0x9c,
                0x41, 0x0e, 0x4b, 0x62, 0xc4, 0x7c, 0x54, 0x26, 0x90, 0x7d, 0xfc, 0x66, 0x85, 0xc5,
                0xc9, 0x9b, 0x71, 0x41, 0xac, 0x62, 0x6a, 0xb4, 0x76, 0x1f, 0xd3, 0xf4, 0x1e, 0x72,
                0x8e, 0x1a, 0x28, 0xf8, 0x9d, 0xb8, 0x9f, 0xfd, 0xec, 0xa3, 0x64, 0xdd, 0x2f, 0x0f,
                0x07, 0x39, 0xf0, 0x53, 0x45, 0x56, 0x48, 0x31, 0x99, 0xc7, 0x1f, 0x18, 0x93, 0x41,
                0xac, 0x9b, 0x78, 0xa2, 0x69, 0x16, 0x42, 0x06, 0xa0, 0xea, 0x1c, 0xe7, 0x3b, 0xfb,
                0x2a, 0x94, 0x2e, 0x73, 0x70, 0xb2, 0x47, 0xc0, 0x46, 0xf8, 0xe7, 0x5e, 0xf8, 0xe3,
                0xf8, 0xbd, 0x82, 0x1c, 0xf5, 0x77, 0x49, 0x18, 0x64, 0xe2, 0x0e, 0x6d, 0x08, 0xfd,
                0x2e, 0x32, 0xb5, 0x55, 0xc9, 0x2c, 0x66, 0x1f, 0x19, 0x58, 0x8b, 0x72, 0xa8, 0x95,
                0x99, 0x71, 0x0a, 0x88, 0x06, 0x12, 0x53, 0xca, 0x28, 0x5b, 0x63, 0x04, 0xb3, 0x7d,
                0xa2, 0xb5, 0x29, 0x4f, 0x5c, 0xb3, 0x54, 0xa8, 0x94, 0x32, 0x28, 0x48, 0xcc, 0xbd,
                0xc7, 0xc2, 0x54, 0x5b, 0x7d, 0xa5, 0x68, 0xaf, 0xac, 0x87, 0xff, 0xa0, 0x05, 0xc3,
                0x12, 0x24, 0x1c, 0x2d, 0x57, 0xf4, 0xb4, 0x5d, 0x64, 0x19, 0xf0, 0xd2, 0xe2, 0xc5,
                0xaf, 0x33, 0xae, 0x24, 0x37, 0x85, 0xb3, 0x25, 0xcd, 0xab, 0x95, 0x40, 0x4f, 0xc7,
                0xae, 0xd7, 0x05, 0x25, 0xcd, 0xdb, 0x41, 0x87, 0x2c, 0xfc, 0xc2, 0x14, 0xb1, 0x32,
                0x32, 0xed, 0xc7, 0x86, 0x09, 0x75, 0x3d, 0xbf, 0xf9, 0x30, 0xeb, 0x0d, 0xc1, 0x56,
                0x61, 0x2b, 0x9c, 0xb4, 0x34, 0xbc, 0x4b, 0x69, 0x33, 0x92, 0xde, 0xb8, 0x7c, 0x53,
                0x04, 0x35, 0x31, 0x2e, 0xdc, 0xed, 0xc6, 0xa9, 0x61, 0x13, 0x33, 0x38, 0xd7, 0x86,
                0xc4, 0xa3, 0xe1, 0x03, 0xf6, 0x01, 0x10, 0xa1, 0x6b, 0x13, 0x37, 0x12, 0x97, 0x04,
                0xbf, 0x47, 0x54, 0xff, 0x6b, 0xa9, 0xfb, 0xe6, 0x59, 0x51, 0xe6, 0x10, 0x62, 0x0f,
                0x71, 0xcd, 0xa8, 0xfc, 0x87, 0x76, 0x25, 0xf2, 0xc5, 0xbb, 0x04, 0xcb, 0xe1, 0x22,
                0x8b, 0x1e, 0x88, 0x6f,
            ],
            c_enc: [
                0x1b, 0x42, 0x34, 0x80, 0xbf, 0x37, 0x67, 0xf5, 0xeb, 0xfc, 0x40, 0xb8, 0xc8, 0x9c,
                0xc5, 0x34, 0xf1, 0x65, 0xc3, 0x5d, 0x19, 0xc8, 0xda, 0x6c, 0x32, 0x10, 0xe9, 0x52,
                0xca, 0xd8, 0x23, 0xa7, 0x84, 0x60, 0x21, 0xc3, 0xde, 0x4a, 0x86, 0x93, 0xb7, 0x1e,
                0x28, 0x7f, 0x46, 0x86, 0xac, 0x0a, 0xdd, 0xce, 0xd9, 0x4e, 0xba, 0x81, 0x0a, 0x99,
                0x8b, 0x82, 0x3a, 0x4a, 0xd2, 0x41, 0xaa, 0x9f, 0x4a, 0x3a, 0xe4, 0x82, 0x5d, 0xe9,
                0x95, 0xdd, 0x58, 0x73, 0x56, 0x62, 0x44, 0xbb, 0xd8, 0x75, 0xd0, 0x1b, 0xf3, 0x28,
                0xe8, 0x22, 0xca, 0xfd, 0xb8, 0x3e, 0xd7, 0x75, 0x3a, 0x88, 0x85, 0xd7, 0xae, 0xf2,
                0x45, 0x5a, 0x15, 0x2e, 0x23, 0xdf, 0xa2, 0xd6, 0x99, 0xb3, 0x5c, 0x33, 0xd3, 0x61,
                0x07, 0x2a, 0xe5, 0xc5, 0x12, 0x43, 0x4d, 0x34, 0x6f, 0x6c, 0x56, 0xfb, 0x5f, 0x11,
                0xb0, 0xb6, 0x47, 0xcb, 0xca, 0xfe, 0x02, 0xd8, 0x84, 0x55, 0xa6, 0x30, 0xa3, 0x50,
                0x86, 0x2b, 0x3c, 0xd1, 0x51, 0x3b, 0x6d, 0x6e, 0x41, 0x17, 0xc7, 0x5e, 0xc4, 0xb1,
                0x2f, 0xd7, 0x5a, 0x90, 0xf8, 0x2d, 0xce, 0xa1, 0xc7, 0x71, 0xfd, 0xda, 0x24, 0xec,
                0xf0, 0xa3, 0xe5, 0xb2, 0xe8, 0xa2, 0x24, 0x23, 0x6e, 0xf0, 0x9a, 0x93, 0xab, 0x59,
                0xe5, 0x9b, 0xdf, 0xb8, 0x72, 0x86, 0x0c, 0xc2, 0xd9, 0x11, 0x34, 0xca, 0xf2, 0x13,
                0x98, 0x48, 0xe3, 0x9a, 0xa6, 0x4b, 0xa2, 0xe6, 0xd7, 0x25, 0x20, 0x54, 0xf3, 0x7a,
                0xd5, 0x5c, 0x2c, 0xe5, 0xf8, 0x1b, 0x33, 0xcc, 0xb6, 0x8a, 0x94, 0x73, 0x71, 0x24,
                0x3a, 0x77, 0xe8, 0x43, 0x67, 0xd9, 0xd3, 0x5b, 0x11, 0x68, 0x14, 0x10, 0xea, 0x79,
                0x8b, 0x03, 0x87, 0xb8, 0xf1, 0x0b, 0x1f, 0x89, 0xc6, 0x8a, 0xd1, 0xcc, 0xa9, 0xa3,
                0xe0, 0x32, 0xf3, 0x49, 0x98, 0x79, 0xc8, 0x9a, 0xe6, 0x38, 0x2f, 0x38, 0x97, 0x22,
                0x01, 0x1f, 0x49, 0x25, 0x14, 0x3e, 0xa8, 0x50, 0x73, 0xe4, 0xff, 0x0c, 0xcf, 0x6d,
                0x77, 0x9b, 0xc3, 0xbf, 0x4c, 0x1b, 0x95, 0xfc, 0x7c, 0xf7, 0xf9, 0x91, 0xa2, 0x16,
                0x2a, 0xb9, 0x45, 0x41, 0xf3, 0x99, 0x8e, 0xf6, 0xbc, 0x3f, 0xe8, 0x02, 0x54, 0xab,
                0xa4, 0x1f, 0x15, 0x23, 0x15, 0x03, 0x45, 0x1b, 0x15, 0xe1, 0x08, 0x52, 0xf8, 0x5b,
                0xd2, 0xd1, 0x15, 0x93, 0x53, 0x14, 0xcd, 0x80, 0xc1, 0x23, 0xbe, 0x0b, 0x53, 0x0f,
                0xaa, 0xd6, 0xb5, 0x07, 0x49, 0x68, 0x22, 0x1d, 0xa0, 0x4b, 0x54, 0x6d, 0x96, 0x21,
                0x63, 0x29, 0x9d, 0x52, 0xce, 0xf4, 0x1e, 0x29, 0x6d, 0xa5, 0x9c, 0xb0, 0x76, 0xdb,
                0xe8, 0x99, 0x70, 0x4b, 0x61, 0x73, 0x0c, 0x19, 0xbd, 0x22, 0x1a, 0xd2, 0xbd, 0x29,
                0x81, 0xea, 0x95, 0x1b, 0xe0, 0x2c, 0x9f, 0x5b, 0xdf, 0x92, 0xd9, 0x87, 0x07, 0x46,
                0xb2, 0xa5, 0x8c, 0x3d, 0x18, 0xa7, 0xd3, 0xe5, 0xe2, 0xc6, 0x3a, 0xc2, 0x61, 0x58,
                0x37, 0xbe, 0x1c, 0x6f, 0xe0, 0x03, 0x65, 0x6c, 0x1b, 0x3d, 0x71, 0x50, 0x5f, 0x5e,
                0x21, 0x88, 0x10, 0x4e, 0x98, 0x91, 0x1b, 0x6a, 0x5e, 0x3f, 0x52, 0x82, 0xfa, 0xc0,
                0xc8, 0xfa, 0x1b, 0xa3, 0x6f, 0xfc, 0x07, 0xdc, 0x7a, 0x40, 0x9d, 0xf2, 0xeb, 0xa8,
                0xc7, 0x5f, 0x70, 0xbd, 0x59, 0xa6, 0xf0, 0x65, 0x1d, 0xc1, 0xb1, 0xb5, 0x96, 0xde,
                0x6a, 0xce, 0xc7, 0x78, 0xe2, 0xe3, 0x2f, 0x1e, 0xd4, 0x6d, 0xf7, 0xa9, 0xae, 0xf5,
                0x1d, 0xfe, 0x5a, 0xa5, 0x24, 0x36, 0xea, 0x07, 0xf5, 0x05, 0xd3, 0x39, 0xf2, 0x03,
                0x45, 0x86, 0x61, 0xc8, 0x3a, 0x9a, 0x5a, 0x27, 0xaa, 0x48, 0xb5, 0xec, 0x47, 0xf8,
                0xd6, 0x0d, 0x2a, 0x41, 0x00, 0x1f, 0xce, 0x30, 0xff, 0x75, 0x3a, 0x8a, 0x8c, 0xe4,
                0x92, 0xef, 0xcd, 0x1f, 0x75, 0x3b, 0x7f, 0x4a, 0xd7, 0x36, 0x62, 0x64, 0x47, 0xd1,
                0xb6, 0xf0, 0x7a, 0x61, 0x7d, 0x4b, 0xfc, 0xdb, 0x48, 0xaf, 0xef, 0x08, 0x2d, 0xae,
                0x1d, 0x76, 0x54, 0x4e, 0x8b, 0x63, 0xad, 0xcb, 0xb6, 0x0e, 0x14, 0x96, 0x69, 0x32,
                0x60, 0xc7, 0x20, 0xe6, 0x72, 0x1e, 0x00, 0x20, 0xef, 0xa3, 0xf8, 0xd8, 0x8d, 0x15,
                0xb5, 0xaa, 0x48, 0xa1, 0xb2, 0x2c,
            ],
            ock: [
                0xab, 0xd0, 0xc2, 0x46, 0x97, 0xe4, 0x5b, 0x8b, 0xc4, 0x83, 0x0f, 0xb1, 0x46, 0x53,
                0x2e, 0xa0, 0xac, 0x84, 0x55, 0x81, 0xca, 0x35, 0x39, 0xd3, 0x41, 0x24, 0x73, 0x54,
                0x09, 0xd0, 0x15, 0xac,
            ],
            op: [
                0xb4, 0xca, 0xc5, 0x6f, 0x06, 0x2b, 0xfb, 0x2e, 0x27, 0x15, 0xea, 0xf9, 0xc8, 0xfc,
                0xdb, 0xc2, 0x0c, 0x86, 0x79, 0x3f, 0x23, 0x57, 0xdd, 0xd0, 0x4a, 0xad, 0x39, 0xf9,
                0x4a, 0xd7, 0xc7, 0x84, 0x10, 0x87, 0x4a, 0x74, 0x22, 0x7a, 0xc7, 0x99, 0x5e, 0xdd,
                0xdd, 0x73, 0x4d, 0x0e, 0x00, 0xdc, 0xc9, 0xf4, 0x8a, 0x01, 0xdd, 0x5c, 0x4c, 0xb1,
                0x22, 0xc0, 0x61, 0xe0, 0xbd, 0xc9, 0xce, 0x14,
            ],
            c_out: [
                0xea, 0xdf, 0x7e, 0xeb, 0x10, 0x2d, 0xb1, 0x88, 0x58, 0x54, 0xc2, 0x9e, 0xb7, 0xb0,
                0x5c, 0x7c, 0x96, 0xbb, 0xb8, 0x90, 0x00, 0x2c, 0x4e, 0xd1, 0x14, 0xed, 0x62, 0xf5,
                0xf9, 0xcc, 0xb4, 0x41, 0x6b, 0x5e, 0xdd, 0xd9, 0xad, 0xb5, 0x5c, 0xe9, 0xc7, 0xa0,
                0xd8, 0x44, 0x2b, 0xbc, 0x8a, 0xfa, 0x5c, 0x77, 0xb9, 0x90, 0xad, 0x6d, 0x46, 0x12,
                0x4d, 0xde, 0x70, 0x49, 0x48, 0x72, 0xb2, 0x20, 0x8a, 0x7c, 0x58, 0x02, 0xdf, 0xe9,
                0xbd, 0x1c, 0xa1, 0x9b, 0xef, 0x4b, 0x37, 0xc6, 0x13, 0xb2,
            ],
        },
        TestVector {
            incoming_viewing_key: [
                0x91, 0xee, 0x20, 0x54, 0x48, 0xc9, 0x8b, 0x69, 0xa3, 0x3e, 0xbf, 0x29, 0x35, 0x09,
                0x5d, 0x79, 0xc2, 0x53, 0x02, 0x9e, 0x5e, 0x5d, 0xc0, 0x2d, 0xf5, 0x8a, 0x10, 0x03,
                0xd1, 0xd8, 0x5c, 0x27, 0xf2, 0xde, 0xf5, 0xb1, 0x10, 0xfd, 0x43, 0xd7, 0x15, 0xe8,
                0xd5, 0x9e, 0xc4, 0xad, 0x0f, 0x41, 0x02, 0x0e, 0xc6, 0x60, 0xcd, 0x97, 0x33, 0xe7,
                0x79, 0xb5, 0x1a, 0x7a, 0xc2, 0xd5, 0xa6, 0x31,
            ],
            ovk: [
                0x18, 0x2f, 0x20, 0x7b, 0x31, 0x75, 0x96, 0x1f, 0x64, 0x11, 0xa4, 0x93, 0xbf, 0xfd,
                0x04, 0x8e, 0x7d, 0x0d, 0x87, 0xd8, 0x2f, 0xe6, 0xf9, 0x90, 0xa2, 0xb0, 0xa2, 0x5f,
                0x5a, 0xa0, 0x11, 0x1a,
            ],
            default_d: [
                0x08, 0xab, 0x2e, 0xe9, 0x9d, 0x4d, 0x9b, 0x98, 0x3d, 0xdd, 0x22,
            ],
            default_pk_d: [
                0x82, 0xfe, 0xf6, 0x43, 0xdb, 0xf4, 0x2d, 0xca, 0x51, 0x56, 0xfb, 0x51, 0xd4, 0xc4,
                0xee, 0x00, 0x8a, 0x72, 0xf0, 0xdb, 0xc3, 0xf3, 0x1e, 0xfa, 0xb0, 0x75, 0xf2, 0x75,
                0x15, 0x37, 0x14, 0x0d,
            ],
            v: 14400879385556610631,
            rseed: [
                0xd5, 0x07, 0xcd, 0xfe, 0x6f, 0xbd, 0xaa, 0x86, 0x16, 0x3e, 0x9c, 0xf5, 0xde, 0x31,
                0x00, 0xfb, 0xca, 0x7e, 0x8d, 0xa0, 0x47, 0xb0, 0x90, 0xdb, 0x9f, 0x37, 0x95, 0x2f,
                0xbf, 0xee, 0x76, 0xaf,
            ],
            memo: [
                0xff, 0x61, 0x66, 0x81, 0x90, 0xbd, 0x52, 0xed, 0x49, 0x0e, 0x67, 0x7b, 0x51, 0x5d,
                0x01, 0x43, 0x84, 0xaf, 0x07, 0x21, 0x9c, 0x7c, 0x0e, 0xe7, 0xfc, 0x7b, 0xfc, 0x79,
                0xf3, 0x25, 0x64, 0x4e, 0x4d, 0xf4, 0xc0, 0xd7, 0xdb, 0x08, 0xe9, 0xf0, 0xbd, 0x02,
                0x49, 0x43, 0xc7, 0x05, 0xab, 0xff, 0x89, 0x94, 0xbf, 0xa6, 0x05, 0xcf, 0xbc, 0x7e,
                0xd7, 0x46, 0xa7, 0xd3, 0xf7, 0xc3, 0x7d, 0x9e, 0x8b, 0xdc, 0x43, 0x3b, 0x7d, 0x79,
                0xe0, 0x8a, 0x12, 0xf7, 0x38, 0xa8, 0xf0, 0xdb, 0xdd, 0xfe, 0xf2, 0xf2, 0x65, 0x7e,
                0xf3, 0xe4, 0x7d, 0x1b, 0x0f, 0xd1, 0x1e, 0x6a, 0x13, 0x31, 0x1f, 0xb7, 0x99, 0xc7,
                0x9c, 0x64, 0x1d, 0x9d, 0xa4, 0x3b, 0x33, 0xe7, 0xad, 0x01, 0x2e, 0x28, 0x25, 0x53,
                0x98, 0x78, 0x92, 0x62, 0x27, 0x5f, 0x11, 0x75, 0xbe, 0x84, 0x62, 0xc0, 0x14, 0x91,
                0xc4, 0xd8, 0x42, 0x40, 0x6d, 0x0e, 0xc4, 0x28, 0x2c, 0x95, 0x26, 0x17, 0x4a, 0x09,
                0x87, 0x8f, 0xe8, 0xfd, 0xde, 0x33, 0xa2, 0x96, 0x04, 0xe5, 0xe5, 0xe7, 0xb2, 0xa0,
                0x25, 0xd6, 0x65, 0x0b, 0x97, 0xdb, 0xb5, 0x2b, 0xef, 0xb5, 0x9b, 0x1d, 0x30, 0xa5,
                0x74, 0x33, 0xb0, 0xa3, 0x51, 0x47, 0x44, 0x44, 0x09, 0x9d, 0xaa, 0x37, 0x10, 0x46,
                0x61, 0x32, 0x60, 0xcf, 0x33, 0x54, 0xcf, 0xcd, 0xad, 0xa6, 0x63, 0xec, 0xe8, 0x24,
                0xff, 0xd7, 0xe4, 0x43, 0x93, 0x88, 0x6a, 0x86, 0x16, 0x5d, 0xdd, 0xdf, 0x2b, 0x4c,
                0x41, 0x77, 0x35, 0x54, 0xc8, 0x69, 0x95, 0x26, 0x94, 0x08, 0xb1, 0x1e, 0x67, 0x37,
                0xa4, 0xc4, 0x47, 0x58, 0x6f, 0x69, 0x17, 0x34, 0x46, 0xd8, 0xe4, 0x8b, 0xf8, 0x4c,
                0xbc, 0x00, 0x0a, 0x80, 0x78, 0x99, 0x97, 0x3e, 0xb9, 0x3c, 0x5e, 0x81, 0x9a, 0xad,
                0x66, 0x94, 0x13, 0xf8, 0x38, 0x79, 0x33, 0xad, 0x15, 0x84, 0xaa, 0x35, 0xe4, 0x3f,
                0x4e, 0xcd, 0x1e, 0x2d, 0x04, 0x07, 0xc0, 0xb1, 0xb8, 0x99, 0x20, 0xff, 0xdf, 0xdb,
                0x9b, 0xea, 0x51, 0xac, 0x95, 0xb5, 0x57, 0xaf, 0x71, 0xb8, 0x9f, 0x90, 0x3f, 0x5d,
                0x98, 0x48, 0xf1, 0x4f, 0xcb, 0xeb, 0x18, 0x37, 0x57, 0x0f, 0x54, 0x4d, 0x63, 0x59,
                0xeb, 0x23, 0xfa, 0xf3, 0x8a, 0x08, 0x22, 0xda, 0x36, 0xce, 0x42, 0x6c, 0x4a, 0x2f,
                0xbe, 0xff, 0xeb, 0x0a, 0x8a, 0x2e, 0x29, 0x7a, 0x9d, 0x19, 0xba, 0x15, 0x02, 0x45,
                0x90, 0xe3, 0x32, 0x9d, 0x9f, 0xa9, 0x26, 0x1f, 0x99, 0x38, 0xa4, 0x03, 0x2d, 0xd3,
                0x46, 0x06, 0xc9, 0xcf, 0x9f, 0x3d, 0xd3, 0x3e, 0x57, 0x6f, 0x05, 0xcd, 0x1d, 0xd6,
                0x81, 0x1c, 0x62, 0x98, 0x75, 0x7d, 0x77, 0xd9, 0xe8, 0x10, 0xab, 0xdb, 0x22, 0x6a,
                0xfc, 0xaa, 0x43, 0x46, 0xa6, 0x56, 0x0f, 0x89, 0x32, 0xb3, 0x18, 0x1f, 0xd3, 0x55,
                0xd5, 0xd3, 0x91, 0x97, 0x61, 0x83, 0xf8, 0xd9, 0x93, 0x88, 0x83, 0x96, 0x32, 0xd6,
                0x35, 0x4f, 0x66, 0x6d, 0x09, 0xd3, 0xe5, 0x62, 0x9e, 0xa1, 0x97, 0x37, 0x38, 0x86,
                0x13, 0xd3, 0x8a, 0x34, 0xfd, 0x0f, 0x6e, 0x50, 0xee, 0x5a, 0x0c, 0xc9, 0x67, 0x71,
                0x77, 0xf5, 0x00, 0x28, 0xc1, 0x41, 0x37, 0x81, 0x87, 0xbd, 0x28, 0x19, 0x40, 0x3f,
                0xc5, 0x34, 0xf8, 0x00, 0x76, 0xe9, 0x38, 0x0c, 0xb4, 0x96, 0x4d, 0x3b, 0x6b, 0x45,
                0x81, 0x9d, 0x3b, 0x8e, 0x9c, 0xaf, 0x54, 0xf0, 0x51, 0x85, 0x2d, 0x67, 0x1b, 0xf8,
                0xc1, 0xff, 0xde, 0x2d, 0x15, 0x10, 0x75, 0x64, 0x18, 0xcb, 0x48, 0x10, 0x93, 0x6a,
                0xa5, 0x7e, 0x69, 0x65, 0xd6, 0xfb, 0x65, 0x6a, 0x76, 0x0b, 0x7f, 0x19, 0xad, 0xf9,
                0x6c, 0x17, 0x34, 0x88, 0x55, 0x21, 0x93, 0xb1,
            ],
            cv_net: [
                0xc3, 0x94, 0x68, 0x5d, 0x92, 0x95, 0x59, 0x7e, 0x21, 0x55, 0x7f, 0x21, 0x9f, 0x3c,
                0x9d, 0x5e, 0x64, 0x07, 0x19, 0xbc, 0xa5, 0xc8, 0xed, 0x49, 0x99, 0x97, 0x34, 0xe6,
                0xc5, 0xb3, 0x73, 0x3e,
            ],
            rho: [
                0xc8, 0x8d, 0x00, 0x84, 0x84, 0xc5, 0xd7, 0x98, 0x20, 0xab, 0x68, 0xc6, 0x7d, 0x08,
                0x36, 0x72, 0xb0, 0x7f, 0x72, 0x7d, 0x44, 0xd0, 0xcd, 0x14, 0x73, 0x88, 0x00, 0xf8,
                0x25, 0xb9, 0xff, 0x16,
            ],
            cmx: [
                0x0b, 0x74, 0x59, 0x61, 0x6f, 0xc6, 0x93, 0x95, 0xe6, 0x44, 0x36, 0xcf, 0x4a, 0xe9,
                0x44, 0x1d, 0x37, 0x4b, 0x29, 0x04, 0x9e, 0x4c, 0x86, 0x22, 0x3a, 0x03, 0x83, 0xf4,
                0xe0, 0x24, 0x69, 0x05,
            ],
            esk: [
                0xc4, 0x92, 0x42, 0xce, 0xe7, 0xe0, 0x86, 0x8f, 0x2a, 0x75, 0xa1, 0xc4, 0x12, 0xbc,
                0x44, 0xd5, 0x4c, 0x97, 0x09, 0xf6, 0x59, 0xde, 0xd3, 0x26, 0x95, 0x72, 0x92, 0x93,
                0x59, 0xe0, 0x4c, 0x3a,
            ],
            ephemeral_key: [
                0x0e, 0x04, 0xd8, 0x52, 0x5d, 0xd6, 0x8f, 0x7a, 0xe8, 0x68, 0xca, 0x81, 0x1e, 0x88,
                0x33, 0xa7, 0xf4, 0x7d, 0x7a, 0xad, 0xd3, 0x76, 0x03, 0xac, 0xe6, 0x07, 0xee, 0x6c,
                0x86, 0x6b, 0xce, 0x23,
            ],
            shared_secret: [
                0x4a, 0x7a, 0x54, 0xac, 0x00, 0x41, 0x95, 0x98, 0xb0, 0x76, 0x01, 0x53, 0xe2, 0x6a,
                0xcc, 0xd2, 0x15, 0x05, 0x24, 0x16, 0x65, 0x17, 0x13, 0xee, 0xa1, 0x89, 0x19, 0xf3,
                0xe2, 0x62, 0xd3, 0xb6,
            ],
            k_enc: [
                0x30, 0x62, 0x6d, 0x92, 0xeb, 0x62, 0x0f, 0xd4, 0xa9, 0x28, 0xb4, 0x3f, 0xd5, 0x50,
                0x69, 0x74, 0x71, 0x76, 0x7d, 0xe4, 0x49, 0x6c, 0xfd, 0xad, 0xb1, 0xda, 0x18, 0xfc,
                0x0c, 0xdd, 0x5a, 0xa6,
            ],
            p_enc: [
                0x02, 0x08, 0xab, 0x2e, 0xe9, 0x9d, 0x4d, 0x9b, 0x98, 0x3d, 0xdd, 0x22, 0x47, 0xee,
                0x58, 0x85, 0x80, 0x33, 0xda, 0xc7, 0xd5, 0x07, 0xcd, 0xfe, 0x6f, 0xbd, 0xaa, 0x86,
                0x16, 0x3e, 0x9c, 0xf5, 0xde, 0x31, 0x00, 0xfb, 0xca, 0x7e, 0x8d, 0xa0, 0x47, 0xb0,
                0x90, 0xdb, 0x9f, 0x37, 0x95, 0x2f, 0xbf, 0xee, 0x76, 0xaf, 0xff, 0x61, 0x66, 0x81,
                0x90, 0xbd, 0x52, 0xed, 0x49, 0x0e, 0x67, 0x7b, 0x51, 0x5d, 0x01, 0x43, 0x84, 0xaf,
                0x07, 0x21, 0x9c, 0x7c, 0x0e, 0xe7, 0xfc, 0x7b, 0xfc, 0x79, 0xf3, 0x25, 0x64, 0x4e,
                0x4d, 0xf4, 0xc0, 0xd7, 0xdb, 0x08, 0xe9, 0xf0, 0xbd, 0x02, 0x49, 0x43, 0xc7, 0x05,
                0xab, 0xff, 0x89, 0x94, 0xbf, 0xa6, 0x05, 0xcf, 0xbc, 0x7e, 0xd7, 0x46, 0xa7, 0xd3,
                0xf7, 0xc3, 0x7d, 0x9e, 0x8b, 0xdc, 0x43, 0x3b, 0x7d, 0x79, 0xe0, 0x8a, 0x12, 0xf7,
                0x38, 0xa8, 0xf0, 0xdb, 0xdd, 0xfe, 0xf2, 0xf2, 0x65, 0x7e, 0xf3, 0xe4, 0x7d, 0x1b,
                0x0f, 0xd1, 0x1e, 0x6a, 0x13, 0x31, 0x1f, 0xb7, 0x99, 0xc7, 0x9c, 0x64, 0x1d, 0x9d,
                0xa4, 0x3b, 0x33, 0xe7, 0xad, 0x01, 0x2e, 0x28, 0x25, 0x53, 0x98, 0x78, 0x92, 0x62,
                0x27, 0x5f, 0x11, 0x75, 0xbe, 0x84, 0x62, 0xc0, 0x14, 0x91, 0xc4, 0xd8, 0x42, 0x40,
                0x6d, 0x0e, 0xc4, 0x28, 0x2c, 0x95, 0x26, 0x17, 0x4a, 0x09, 0x87, 0x8f, 0xe8, 0xfd,
                0xde, 0x33, 0xa2, 0x96, 0x04, 0xe5, 0xe5, 0xe7, 0xb2, 0xa0, 0x25, 0xd6, 0x65, 0x0b,
                0x97, 0xdb, 0xb5, 0x2b, 0xef, 0xb5, 0x9b, 0x1d, 0x30, 0xa5, 0x74, 0x33, 0xb0, 0xa3,
                0x51, 0x47, 0x44, 0x44, 0x09, 0x9d, 0xaa, 0x37, 0x10, 0x46, 0x61, 0x32, 0x60, 0xcf,
                0x33, 0x54, 0xcf, 0xcd, 0xad, 0xa6, 0x63, 0xec, 0xe8, 0x24, 0xff, 0xd7, 0xe4, 0x43,
                0x93, 0x88, 0x6a, 0x86, 0x16, 0x5d, 0xdd, 0xdf, 0x2b, 0x4c, 0x41, 0x77, 0x35, 0x54,
                0xc8, 0x69, 0x95, 0x26, 0x94, 0x08, 0xb1, 0x1e, 0x67, 0x37, 0xa4, 0xc4, 0x47, 0x58,
                0x6f, 0x69, 0x17, 0x34, 0x46, 0xd8, 0xe4, 0x8b, 0xf8, 0x4c, 0xbc, 0x00, 0x0a, 0x80,
                0x78, 0x99, 0x97, 0x3e, 0xb9, 0x3c, 0x5e, 0x81, 0x9a, 0xad, 0x66, 0x94, 0x13, 0xf8,
                0x38, 0x79, 0x33, 0xad, 0x15, 0x84, 0xaa, 0x35, 0xe4, 0x3f, 0x4e, 0xcd, 0x1e, 0x2d,
                0x04, 0x07, 0xc0, 0xb1, 0xb8, 0x99, 0x20, 0xff, 0xdf, 0xdb, 0x9b, 0xea, 0x51, 0xac,
                0x95, 0xb5, 0x57, 0xaf, 0x71, 0xb8, 0x9f, 0x90, 0x3f, 0x5d, 0x98, 0x48, 0xf1, 0x4f,
                0xcb, 0xeb, 0x18, 0x37, 0x57, 0x0f, 0x54, 0x4d, 0x63, 0x59, 0xeb, 0x23, 0xfa, 0xf3,
                0x8a, 0x08, 0x22, 0xda, 0x36, 0xce, 0x42, 0x6c, 0x4a, 0x2f, 0xbe, 0xff, 0xeb, 0x0a,
                0x8a, 0x2e, 0x29, 0x7a, 0x9d, 0x19, 0xba, 0x15, 0x02, 0x45, 0x90, 0xe3, 0x32, 0x9d,
                0x9f, 0xa9, 0x26, 0x1f, 0x99, 0x38, 0xa4, 0x03, 0x2d, 0xd3, 0x46, 0x06, 0xc9, 0xcf,
                0x9f, 0x3d, 0xd3, 0x3e, 0x57, 0x6f, 0x05, 0xcd, 0x1d, 0xd6, 0x81, 0x1c, 0x62, 0x98,
                0x75, 0x7d, 0x77, 0xd9, 0xe8, 0x10, 0xab, 0xdb, 0x22, 0x6a, 0xfc, 0xaa, 0x43, 0x46,
                0xa6, 0x56, 0x0f, 0x89, 0x32, 0xb3, 0x18, 0x1f, 0xd3, 0x55, 0xd5, 0xd3, 0x91, 0x97,
                0x61, 0x83, 0xf8, 0xd9, 0x93, 0x88, 0x83, 0x96, 0x32, 0xd6, 0x35, 0x4f, 0x66, 0x6d,
                0x09, 0xd3, 0xe5, 0x62, 0x9e, 0xa1, 0x97, 0x37, 0x38, 0x86, 0x13, 0xd3, 0x8a, 0x34,
                0xfd, 0x0f, 0x6e, 0x50, 0xee, 0x5a, 0x0c, 0xc9, 0x67, 0x71, 0x77, 0xf5, 0x00, 0x28,
                0xc1, 0x41, 0x37, 0x81, 0x87, 0xbd, 0x28, 0x19, 0x40, 0x3f, 0xc5, 0x34, 0xf8, 0x00,
                0x76, 0xe9, 0x38, 0x0c, 0xb4, 0x96, 0x4d, 0x3b, 0x6b, 0x45, 0x81, 0x9d, 0x3b, 0x8e,
                0x9c, 0xaf, 0x54, 0xf0, 0x51, 0x85, 0x2d, 0x67, 0x1b, 0xf8, 0xc1, 0xff, 0xde, 0x2d,
                0x15, 0x10, 0x75, 0x64, 0x18, 0xcb, 0x48, 0x10, 0x93, 0x6a, 0xa5, 0x7e, 0x69, 0x65,
                0xd6, 0xfb, 0x65, 0x6a, 0x76, 0x0b, 0x7f, 0x19, 0xad, 0xf9, 0x6c, 0x17, 0x34, 0x88,
                0x55, 0x21, 0x93, 0xb1,
            ],
            c_enc: [
                0x81, 0x56, 0x2d, 0xbe, 0xf7, 0xbb, 0x35, 0x3a, 0x62, 0xe7, 0xc8, 0x1e, 0xbe, 0x68,
                0x15, 0x6c, 0xb7, 0x5c, 0x5c, 0x7e, 0x3d, 0x96, 0xbb, 0xcd, 0x7d, 0xaf, 0xf5, 0x0c,
                0xb0, 0x95, 0x7d, 0x33, 0xdd, 0x99, 0x77, 0x9f, 0x7d, 0x3d, 0x72, 0xb1, 0x8d, 0xeb,
                0x7a, 0x69, 0x75, 0x10, 0xe0, 0x13, 0x5b, 0x8d, 0xf4, 0x83, 0xa4, 0xd7, 0x1d, 0x1a,
                0xb1, 0x08, 0x09, 0x6e, 0x76, 0x08, 0x91, 0xd5, 0x31, 0x07, 0xf0, 0x3d, 0xea, 0x4a,
                0xe8, 0xe4, 0xd3, 0xfe, 0xbd, 0x98, 0x77, 0xf8, 0x57, 0x0a, 0xa3, 0x09, 0xd0, 0x97,
                0xd4, 0x23, 0xbb, 0x76, 0x3f, 0xb3, 0xe7, 0xe9, 0xbe, 0x3c, 0x8f, 0xa0, 0x34, 0xc0,
                0x1d, 0x66, 0x4f, 0x47, 0xa0, 0xe7, 0x13, 0x3c, 0xa1, 0x1a, 0x48, 0xcd, 0x0e, 0xea,
                0x46, 0x35, 0xfa, 0x77, 0x25, 0x0a, 0x17, 0xbd, 0xf7, 0xb7, 0x32, 0xc8, 0x98, 0x46,
                0x51, 0x57, 0x4f, 0xd4, 0xf9, 0x9f, 0x7a, 0xa0, 0xdb, 0x28, 0xc2, 0x97, 0x31, 0x52,
                0xbf, 0x42, 0x6e, 0xe9, 0xa4, 0xd8, 0x41, 0xa9, 0x1d, 0x5d, 0x33, 0x57, 0x18, 0xee,
                0xcb, 0xc9, 0xc8, 0xb2, 0xa2, 0x00, 0x15, 0x70, 0xfe, 0x8b, 0x77, 0x91, 0x43, 0xdf,
                0x22, 0x95, 0x98, 0xa5, 0xbe, 0x25, 0x48, 0xcf, 0x35, 0x84, 0x25, 0x18, 0xcc, 0x1d,
                0xbc, 0x78, 0xcc, 0x2f, 0x0f, 0xc8, 0xea, 0x35, 0x7c, 0xe6, 0xc1, 0x7e, 0xb9, 0x7c,
                0x61, 0x38, 0xd5, 0x3e, 0x6c, 0x8e, 0x00, 0xf0, 0x7f, 0x80, 0x01, 0x25, 0x18, 0x2b,
                0x25, 0xa5, 0xe8, 0x75, 0xc5, 0x37, 0x72, 0x09, 0x52, 0x72, 0x22, 0x37, 0x1f, 0x72,
                0xbf, 0xbd, 0x46, 0x28, 0x44, 0xab, 0x06, 0xf3, 0xb3, 0xa1, 0xeb, 0xa3, 0x44, 0x23,
                0xb6, 0x9a, 0xbf, 0x5d, 0xe6, 0x64, 0xba, 0x83, 0xcd, 0x43, 0xb6, 0xa8, 0xe9, 0xd5,
                0xb7, 0xc5, 0x2a, 0xdb, 0x86, 0x15, 0x04, 0x1b, 0x90, 0xd9, 0x08, 0x83, 0x1a, 0x6f,
                0xf9, 0x2d, 0xb4, 0x8a, 0x14, 0xac, 0x4d, 0xfa, 0x67, 0xd0, 0x2c, 0x72, 0xe0, 0xc8,
                0x63, 0x15, 0x7d, 0x98, 0xf8, 0xf5, 0x45, 0x37, 0x92, 0x97, 0x43, 0xc9, 0x69, 0xbc,
                0x91, 0xc2, 0xc1, 0x37, 0x52, 0x04, 0x98, 0x3c, 0x99, 0x99, 0x97, 0x5f, 0xfa, 0x5e,
                0xe5, 0xfe, 0x1f, 0x69, 0x71, 0x99, 0x40, 0x5f, 0x09, 0x66, 0xe3, 0x1f, 0x34, 0xe1,
                0x52, 0x38, 0x44, 0x38, 0x18, 0x44, 0x98, 0x2b, 0x2c, 0x3b, 0x49, 0xa2, 0x09, 0xff,
                0xa3, 0xce, 0xe9, 0x79, 0xa8, 0x5b, 0x19, 0xb8, 0x50, 0xf4, 0x1d, 0xcc, 0xc4, 0x63,
                0xe2, 0x2e, 0x24, 0xa3, 0x04, 0x9d, 0x37, 0xb1, 0xfb, 0x37, 0x0d, 0xeb, 0xdd, 0xf4,
                0xde, 0x05, 0x46, 0x24, 0x5e, 0x4f, 0x02, 0xa9, 0x84, 0x98, 0xaf, 0x53, 0x2e, 0x27,
                0xac, 0xae, 0x5c, 0x7e, 0xd1, 0x43, 0xe6, 0xe9, 0xcc, 0xfa, 0x74, 0x35, 0x16, 0x02,
                0x16, 0x57, 0xac, 0xb2, 0x5e, 0x44, 0x47, 0x84, 0x5c, 0x5f, 0x9c, 0x59, 0x64, 0x60,
                0x7c, 0x4a, 0x78, 0x72, 0x1d, 0x98, 0x1a, 0x7f, 0xf2, 0xfd, 0xf6, 0xc0, 0x33, 0x62,
                0x8b, 0xff, 0xd6, 0xf0, 0xb8, 0xde, 0x0c, 0xd6, 0x35, 0xec, 0x22, 0xf8, 0xb5, 0x0e,
                0xd6, 0x37, 0xfe, 0x4e, 0x00, 0xf9, 0xd3, 0xc3, 0xd4, 0xf1, 0x81, 0x0b, 0x09, 0xb7,
                0x5c, 0x96, 0xe2, 0xfc, 0xf1, 0x11, 0x85, 0x31, 0x7e, 0xdf, 0xa3, 0x9d, 0x19, 0x25,
                0xde, 0xd8, 0x14, 0xdd, 0xe0, 0xef, 0x00, 0xa3, 0xfb, 0x47, 0xaf, 0x5d, 0x81, 0x20,
                0x94, 0xaf, 0x13, 0xd0, 0x1c, 0x98, 0x56, 0x9f, 0xf7, 0x73, 0x57, 0x87, 0xfa, 0x9b,
                0xd0, 0x1f, 0xa0, 0x69, 0x28, 0x27, 0x5f, 0xdd, 0x10, 0x38, 0x96, 0x5f, 0xb0, 0x6f,
                0xb3, 0x5e, 0xdb, 0x73, 0x80, 0xdd, 0x3c, 0x42, 0x41, 0x9e, 0x0c, 0x0e, 0xde, 0x4c,
                0x48, 0x6a, 0x9d, 0xb4, 0x95, 0x38, 0x86, 0xae, 0xc6, 0xad, 0x30, 0x70, 0x28, 0xeb,
                0x26, 0xa3, 0x7e, 0xf4, 0x71, 0x56, 0x7a, 0xd4, 0xbd, 0x4e, 0xaa, 0xb7, 0xa8, 0x2c,
                0xb0, 0xd6, 0xb5, 0xf0, 0x5e, 0x89, 0x4e, 0x53, 0x25, 0x82, 0x1d, 0x92, 0xbe, 0xd2,
                0xb8, 0x6f, 0xb2, 0x43, 0x37, 0xd5, 0x79, 0x28, 0x8f, 0x6d, 0xf7, 0x34, 0x77, 0x1d,
                0x9e, 0xf8, 0x35, 0x8b, 0xa9, 0x1a,
            ],
            ock: [
                0xb6, 0x36, 0xc3, 0x9a, 0x6b, 0xad, 0x22, 0x63, 0xb2, 0x44, 0x1e, 0xd5, 0xbb, 0xdb,
                0x01, 0x35, 0x88, 0xfb, 0x46, 0x27, 0x01, 0xe6, 0xf8, 0x76, 0x64, 0x6c, 0x8c, 0x17,
                0xfa, 0x2e, 0xfd, 0xe8,
            ],
            op: [
                0x82, 0xfe, 0xf6, 0x43, 0xdb, 0xf4, 0x2d, 0xca, 0x51, 0x56, 0xfb, 0x51, 0xd4, 0xc4,
                0xee, 0x00, 0x8a, 0x72, 0xf0, 0xdb, 0xc3, 0xf3, 0x1e, 0xfa, 0xb0, 0x75, 0xf2, 0x75,
                0x15, 0x37, 0x14, 0x0d, 0xc4, 0x92, 0x42, 0xce, 0xe7, 0xe0, 0x86, 0x8f, 0x2a, 0x75,
                0xa1, 0xc4, 0x12, 0xbc, 0x44, 0xd5, 0x4c, 0x97, 0x09, 0xf6, 0x59, 0xde, 0xd3, 0x26,
                0x95, 0x72, 0x92, 0x93, 0x59, 0xe0, 0x4c, 0x3a,
            ],
            c_out: [
                0x46, 0xba, 0x14, 0xf8, 0x3f, 0xf5, 0xab, 0x76, 0x0f, 0x14, 0x20, 0xeb, 0xde, 0xd9,
                0x86, 0xfd, 0x93, 0x78, 0x27, 0xbc, 0x05, 0x69, 0x2e, 0xca, 0xdb, 0x65, 0x2e, 0xbb,
                0xc8, 0xf6, 0xd9, 0xb5, 0x2e, 0xc3, 0x97, 0x87, 0xd8, 0xeb, 0xdd, 0x50, 0x6c, 0xa1,
                0xa8, 0x5d, 0xc3, 0xd5, 0xba, 0x4c, 0x5b, 0x41, 0x52, 0x61, 0xb0, 0x75, 0x3a, 0xc1,
                0x0e, 0x01, 0x86, 0x45, 0x32, 0xa3, 0x57, 0x2c, 0x68, 0xaf, 0xe4, 0x0a, 0xc3, 0xc0,
                0x95, 0x7b, 0x7a, 0xfc, 0x23, 0xfd, 0x5e, 0x05, 0x17, 0xaa,
            ],
        },
        TestVector {
            incoming_viewing_key: [
                0xf1, 0x90, 0x42, 0xb9, 0xd1, 0x0c, 0xc4, 0x80, 0xa0, 0x8c, 0x04, 0x32, 0x2d, 0xb6,
                0xec, 0x4e, 0x41, 0x2e, 0xaa, 0x84, 0xc9, 0x71, 0x82, 0x8c, 0xcc, 0xd7, 0x33, 0xa1,
                0x1f, 0x25, 0x3e, 0xda, 0x8a, 0xc3, 0x0b, 0xa3, 0x1f, 0xbc, 0x89, 0x5d, 0x60, 0xb9,
                0x83, 0x06, 0x2a, 0x5f, 0x45, 0x33, 0x90, 0x79, 0x32, 0x26, 0xff, 0xd9, 0x21, 0xbd,
                0x64, 0xac, 0x39, 0x07, 0x03, 0x85, 0x6a, 0x0b,
            ],
            ovk: [
                0xda, 0xdc, 0x96, 0x6c, 0x8a, 0x54, 0x66, 0xb6, 0x1f, 0xc9, 0x98, 0xc3, 0x1f, 0x10,
                0x70, 0xd9, 0xa5, 0xc9, 0xa6, 0xd2, 0x68, 0xd3, 0x04, 0xfe, 0x6b, 0x8f, 0xd3, 0xb4,
                0x01, 0x03, 0x48, 0x61,
            ],
            default_d: [
                0xaa, 0x14, 0x92, 0x9c, 0x57, 0x89, 0x85, 0x85, 0xce, 0x66, 0x5a,
            ],
            default_pk_d: [
                0x78, 0xa4, 0xe3, 0x39, 0x88, 0xd7, 0x1d, 0x71, 0x8e, 0x59, 0x55, 0x55, 0x28, 0x4c,
                0x24, 0x9a, 0x62, 0xb7, 0x12, 0x88, 0x06, 0xa5, 0x4c, 0x3b, 0x36, 0xa3, 0xaa, 0x57,
                0x14, 0x93, 0x16, 0x36,
            ],
            v: 17936016275122962426,
            rseed: [
                0x49, 0x95, 0x0a, 0xfc, 0xb0, 0xef, 0x46, 0x2a, 0x2a, 0xe0, 0x24, 0xb0, 0xf0, 0x22,
                0x4d, 0xfd, 0x73, 0x68, 0x4b, 0x88, 0xc7, 0xfb, 0xe9, 0x2d, 0x02, 0xb6, 0x8f, 0x75,
                0x9c, 0x47, 0x52, 0x66,
            ],
            memo: [
                0xff, 0x3c, 0xd7, 0xb9, 0x7a, 0x14, 0x94, 0x36, 0x49, 0x30, 0x55, 0x21, 0x32, 0x6b,
                0xde, 0x08, 0x56, 0x30, 0x86, 0x46, 0x29, 0x29, 0x1b, 0xae, 0x25, 0xff, 0x88, 0x22,
                0xa1, 0x4c, 0x4b, 0x66, 0x6a, 0x92, 0x59, 0xad, 0x0d, 0xc4, 0x2a, 0x82, 0x90, 0xac,
                0x7b, 0xc7, 0xf5, 0x3a, 0x16, 0xf3, 0x79, 0xf7, 0x58, 0xe5, 0xde, 0x75, 0x0f, 0x04,
                0xfd, 0x7c, 0xad, 0x47, 0x70, 0x1c, 0x85, 0x97, 0xf9, 0x78, 0x88, 0xbe, 0xa6, 0xfa,
                0x0b, 0xf2, 0x99, 0x99, 0x56, 0xfb, 0xfd, 0x0e, 0xe6, 0x8e, 0xc3, 0x6e, 0x46, 0x88,
                0x80, 0x9a, 0xe2, 0x31, 0xeb, 0x8b, 0xc4, 0x36, 0x9f, 0x5f, 0xe1, 0x57, 0x3f, 0x57,
                0xe0, 0x99, 0xd9, 0xc0, 0x99, 0x01, 0xbf, 0x39, 0xca, 0xac, 0x48, 0xdc, 0x11, 0x95,
                0x6a, 0x8a, 0xe9, 0x05, 0xea, 0xd8, 0x69, 0x54, 0x54, 0x7c, 0x44, 0x8a, 0xe4, 0x3d,
                0x31, 0x5e, 0x66, 0x9c, 0x42, 0x42, 0xda, 0x56, 0x59, 0x38, 0xf4, 0x17, 0xbf, 0x43,
                0xce, 0x7b, 0x2b, 0x30, 0xb1, 0xcd, 0x40, 0x18, 0x38, 0x8e, 0x1a, 0x91, 0x0f, 0x0f,
                0xc4, 0x1f, 0xb0, 0x87, 0x7a, 0x59, 0x25, 0xe4, 0x66, 0x81, 0x9d, 0x37, 0x5b, 0x0a,
                0x91, 0x2d, 0x4f, 0xe8, 0x43, 0xb7, 0x6e, 0xf6, 0xf2, 0x23, 0xf0, 0xf7, 0xc8, 0x94,
                0xf3, 0x8f, 0x7a, 0xb7, 0x80, 0xdf, 0xd7, 0x5f, 0x66, 0x9c, 0x8c, 0x06, 0xcf, 0xfa,
                0x43, 0xeb, 0x47, 0x56, 0x5a, 0x50, 0xe3, 0xb1, 0xfa, 0x45, 0xad, 0x61, 0xce, 0x9a,
                0x1c, 0x47, 0x27, 0xb7, 0xaa, 0xa5, 0x35, 0x62, 0xf5, 0x23, 0xe7, 0x39, 0x52, 0xbb,
                0xf3, 0x3d, 0x8a, 0x41, 0x04, 0x07, 0x8a, 0xde, 0x3e, 0xaa, 0xa4, 0x96, 0x99, 0xa6,
                0x9f, 0xdf, 0x1c, 0x5a, 0xc7, 0x73, 0x21, 0x46, 0xee, 0x5e, 0x1d, 0x6b, 0x6c, 0xa9,
                0xb9, 0x18, 0x0f, 0x96, 0x4c, 0xc9, 0xd0, 0x87, 0x8a, 0xe1, 0x37, 0x35, 0x24, 0xd7,
                0xd5, 0x10, 0xe5, 0x82, 0x27, 0xdf, 0x6d, 0xe9, 0xd3, 0x0d, 0x27, 0x18, 0x67, 0x64,
                0x01, 0x77, 0xb0, 0xf1, 0x85, 0x6e, 0x28, 0xd5, 0xc8, 0xaf, 0xb0, 0x95, 0xef, 0x61,
                0x84, 0xfe, 0xd6, 0x51, 0x58, 0x90, 0x22, 0xee, 0xae, 0xa4, 0xc0, 0xce, 0x1f, 0xa6,
                0xf0, 0x85, 0x09, 0x2b, 0x04, 0x97, 0x94, 0x89, 0x17, 0x2b, 0x3e, 0xf8, 0x19, 0x4a,
                0x79, 0x8d, 0xf5, 0x72, 0x4d, 0x6b, 0x05, 0xf1, 0xae, 0x00, 0x00, 0x13, 0xa0, 0x8d,
                0x61, 0x2b, 0xca, 0x8a, 0x8c, 0x31, 0x44, 0x3c, 0x10, 0x34, 0x6d, 0xbf, 0x61, 0xde,
                0x84, 0x75, 0xc0, 0xbb, 0xec, 0x51, 0x04, 0xb4, 0x75, 0x56, 0xaf, 0x3d, 0x51, 0x44,
                0x58, 0xe2, 0x32, 0x1d, 0x14, 0x60, 0x71, 0x78, 0x9d, 0x23, 0x35, 0x93, 0x4a, 0x68,
                0x06, 0x14, 0xe8, 0x35, 0x62, 0xf8, 0x2d, 0xfd, 0x40, 0x5b, 0x54, 0xa4, 0x5e, 0xb3,
                0x2c, 0x16, 0x54, 0x48, 0xd4, 0xd5, 0xd6, 0x1c, 0xa2, 0x85, 0x95, 0x85, 0x36, 0x9f,
                0x53, 0xf1, 0xa1, 0x37, 0xe9, 0xe8, 0x2b, 0x67, 0xb8, 0xfd, 0xaf, 0x01, 0xbd, 0xa5,
                0x4a, 0x31, 0x73, 0x11, 0x89, 0x6a, 0xe1, 0x02, 0x80, 0xa0, 0x32, 0x44, 0x0c, 0x42,
                0x0a, 0x42, 0x1e, 0x94, 0x4d, 0x1e, 0x95, 0x2b, 0x70, 0xd5, 0x82, 0x6c, 0xd3, 0xb0,
                0x8b, 0x7d, 0xb9, 0x63, 0x0f, 0xe4, 0xfd, 0x5f, 0x22, 0x12, 0x5d, 0xe8, 0x40, 0xfc,
                0xc4, 0x0b, 0x98, 0x03, 0x8a, 0xf1, 0x1d, 0x55, 0xbe, 0x25, 0x43, 0x25, 0x97, 0xb4,
                0xb6, 0x5b, 0x9e, 0xc1, 0xc7, 0xa8, 0xbb, 0xfd, 0x05, 0x2c, 0xbf, 0x7e, 0x1c, 0x17,
                0x85, 0x31, 0x49, 0x34, 0xb2, 0x62, 0xd5, 0x85, 0x37, 0x54, 0xf1, 0xf1, 0x77, 0x71,
                0xcf, 0xb7, 0x50, 0x30, 0x72, 0x65, 0x57, 0x53,
            ],
            cv_net: [
                0xd4, 0x51, 0xb4, 0x62, 0x89, 0xba, 0x99, 0x8c, 0x0c, 0xce, 0xd1, 0xcc, 0x15, 0xb3,
                0xfa, 0xde, 0x94, 0xfa, 0x0b, 0x46, 0xe3, 0xb1, 0xa5, 0x73, 0x34, 0x99, 0x34, 0xe2,
                0x32, 0xb5, 0x0e, 0x96,
            ],
            rho: [
                0xa9, 0x0a, 0x9b, 0x8a, 0xb1, 0x35, 0x9d, 0xc9, 0x6b, 0xda, 0xe9, 0x0e, 0x52, 0x74,
                0x78, 0x8c, 0xb0, 0xc4, 0x26, 0xef, 0xf2, 0x60, 0x43, 0x61, 0x85, 0x39, 0x8b, 0xff,
                0xf5, 0x0e, 0x92, 0x37,
            ],
            cmx: [
                0x05, 0xb5, 0xe3, 0x20, 0x76, 0xda, 0xe0, 0x94, 0x83, 0x35, 0xac, 0x3d, 0x65, 0x1c,
                0x6d, 0xbe, 0xa6, 0x4c, 0xe9, 0x11, 0x42, 0x3e, 0x2f, 0x2c, 0x7c, 0x1b, 0xdf, 0xa6,
                0xb1, 0x41, 0x41, 0x30,
            ],
            esk: [
                0x8b, 0x14, 0x62, 0x2d, 0x2f, 0x91, 0xf1, 0x69, 0x8d, 0x53, 0xfe, 0x47, 0x9a, 0x1e,
                0x5c, 0x00, 0x64, 0x98, 0xb9, 0x8b, 0x85, 0xb4, 0x50, 0xbd, 0x92, 0x3a, 0x5d, 0x00,
                0xcb, 0x52, 0xa6, 0x13,
            ],
            ephemeral_key: [
                0x86, 0xee, 0x66, 0xa6, 0xc7, 0xd9, 0xb5, 0xc4, 0xf0, 0xe2, 0xd2, 0xa0, 0xe1, 0x56,
                0x1e, 0x2a, 0xfa, 0x55, 0x41, 0xa7, 0x24, 0xee, 0x02, 0x7f, 0xc7, 0x0b, 0xb7, 0xe8,
                0x0a, 0x2c, 0x60, 0x98,
            ],
            shared_secret: [
                0x88, 0xd1, 0x38, 0x2c, 0x14, 0x42, 0x02, 0xd0, 0xd7, 0x55, 0x75, 0x87, 0xb0, 0xd5,
                0xd0, 0x21, 0x69, 0x29, 0x2a, 0x25, 0x05, 0x43, 0xcb, 0x0a, 0x06, 0xc3, 0x4f, 0x45,
                0x2f, 0x7b, 0x3b, 0x36,
            ],
            k_enc: [
                0xe3, 0x73, 0xd8, 0x6e, 0xc9, 0xdd, 0xdd, 0x64, 0x5d, 0x9a, 0x6d, 0x06, 0xef, 0xce,
                0x22, 0xb8, 0x96, 0x42, 0x1d, 0x57, 0xa4, 0x4d, 0x37, 0xa6, 0x50, 0x4a, 0x5d, 0x19,
                0xdf, 0x21, 0x73, 0x73,
            ],
            p_enc: [
                0x02, 0xaa, 0x14, 0x92, 0x9c, 0x57, 0x89, 0x85, 0x85, 0xce, 0x66, 0x5a, 0xfa, 0x3f,
                0x54, 0xec, 0xc5, 0x87, 0xe9, 0xf8, 0x49, 0x95, 0x0a, 0xfc, 0xb0, 0xef, 0x46, 0x2a,
                0x2a, 0xe0, 0x24, 0xb0, 0xf0, 0x22, 0x4d, 0xfd, 0x73, 0x68, 0x4b, 0x88, 0xc7, 0xfb,
                0xe9, 0x2d, 0x02, 0xb6, 0x8f, 0x75, 0x9c, 0x47, 0x52, 0x66, 0xff, 0x3c, 0xd7, 0xb9,
                0x7a, 0x14, 0x94, 0x36, 0x49, 0x30, 0x55, 0x21, 0x32, 0x6b, 0xde, 0x08, 0x56, 0x30,
                0x86, 0x46, 0x29, 0x29, 0x1b, 0xae, 0x25, 0xff, 0x88, 0x22, 0xa1, 0x4c, 0x4b, 0x66,
                0x6a, 0x92, 0x59, 0xad, 0x0d, 0xc4, 0x2a, 0x82, 0x90, 0xac, 0x7b, 0xc7, 0xf5, 0x3a,
                0x16, 0xf3, 0x79, 0xf7, 0x58, 0xe5, 0xde, 0x75, 0x0f, 0x04, 0xfd, 0x7c, 0xad, 0x47,
                0x70, 0x1c, 0x85, 0x97, 0xf9, 0x78, 0x88, 0xbe, 0xa6, 0xfa, 0x0b, 0xf2, 0x99, 0x99,
                0x56, 0xfb, 0xfd, 0x0e, 0xe6, 0x8e, 0xc3, 0x6e, 0x46, 0x88, 0x80, 0x9a, 0xe2, 0x31,
                0xeb, 0x8b, 0xc4, 0x36, 0x9f, 0x5f, 0xe1, 0x57, 0x3f, 0x57, 0xe0, 0x99, 0xd9, 0xc0,
                0x99, 0x01, 0xbf, 0x39, 0xca, 0xac, 0x48, 0xdc, 0x11, 0x95, 0x6a, 0x8a, 0xe9, 0x05,
                0xea, 0xd8, 0x69, 0x54, 0x54, 0x7c, 0x44, 0x8a, 0xe4, 0x3d, 0x31, 0x5e, 0x66, 0x9c,
                0x42, 0x42, 0xda, 0x56, 0x59, 0x38, 0xf4, 0x17, 0xbf, 0x43, 0xce, 0x7b, 0x2b, 0x30,
                0xb1, 0xcd, 0x40, 0x18, 0x38, 0x8e, 0x1a, 0x91, 0x0f, 0x0f, 0xc4, 0x1f, 0xb0, 0x87,
                0x7a, 0x59, 0x25, 0xe4, 0x66, 0x81, 0x9d, 0x37, 0x5b, 0x0a, 0x91, 0x2d, 0x4f, 0xe8,
                0x43, 0xb7, 0x6e, 0xf6, 0xf2, 0x23, 0xf0, 0xf7, 0xc8, 0x94, 0xf3, 0x8f, 0x7a, 0xb7,
                0x80, 0xdf, 0xd7, 0x5f, 0x66, 0x9c, 0x8c, 0x06, 0xcf, 0xfa, 0x43, 0xeb, 0x47, 0x56,
                0x5a, 0x50, 0xe3, 0xb1, 0xfa, 0x45, 0xad, 0x61, 0xce, 0x9a, 0x1c, 0x47, 0x27, 0xb7,
                0xaa, 0xa5, 0x35, 0x62, 0xf5, 0x23, 0xe7, 0x39, 0x52, 0xbb, 0xf3, 0x3d, 0x8a, 0x41,
                0x04, 0x07, 0x8a, 0xde, 0x3e, 0xaa, 0xa4, 0x96, 0x99, 0xa6, 0x9f, 0xdf, 0x1c, 0x5a,
                0xc7, 0x73, 0x21, 0x46, 0xee, 0x5e, 0x1d, 0x6b, 0x6c, 0xa9, 0xb9, 0x18, 0x0f, 0x96,
                0x4c, 0xc9, 0xd0, 0x87, 0x8a, 0xe1, 0x37, 0x35, 0x24, 0xd7, 0xd5, 0x10, 0xe5, 0x82,
                0x27, 0xdf, 0x6d, 0xe9, 0xd3, 0x0d, 0x27, 0x18, 0x67, 0x64, 0x01, 0x77, 0xb0, 0xf1,
                0x85, 0x6e, 0x28, 0xd5, 0xc8, 0xaf, 0xb0, 0x95, 0xef, 0x61, 0x84, 0xfe, 0xd6, 0x51,
                0x58, 0x90, 0x22, 0xee, 0xae, 0xa4, 0xc0, 0xce, 0x1f, 0xa6, 0xf0, 0x85, 0x09, 0x2b,
                0x04, 0x97, 0x94, 0x89, 0x17, 0x2b, 0x3e, 0xf8, 0x19, 0x4a, 0x79, 0x8d, 0xf5, 0x72,
                0x4d, 0x6b, 0x05, 0xf1, 0xae, 0x00, 0x00, 0x13, 0xa0, 0x8d, 0x61, 0x2b, 0xca, 0x8a,
                0x8c, 0x31, 0x44, 0x3c, 0x10, 0x34, 0x6d, 0xbf, 0x61, 0xde, 0x84, 0x75, 0xc0, 0xbb,
                0xec, 0x51, 0x04, 0xb4, 0x75, 0x56, 0xaf, 0x3d, 0x51, 0x44, 0x58, 0xe2, 0x32, 0x1d,
                0x14, 0x60, 0x71, 0x78, 0x9d, 0x23, 0x35, 0x93, 0x4a, 0x68, 0x06, 0x14, 0xe8, 0x35,
                0x62, 0xf8, 0x2d, 0xfd, 0x40, 0x5b, 0x54, 0xa4, 0x5e, 0xb3, 0x2c, 0x16, 0x54, 0x48,
                0xd4, 0xd5, 0xd6, 0x1c, 0xa2, 0x85, 0x95, 0x85, 0x36, 0x9f, 0x53, 0xf1, 0xa1, 0x37,
                0xe9, 0xe8, 0x2b, 0x67, 0xb8, 0xfd, 0xaf, 0x01, 0xbd, 0xa5, 0x4a, 0x31, 0x73, 0x11,
                0x89, 0x6a, 0xe1, 0x02, 0x80, 0xa0, 0x32, 0x44, 0x0c, 0x42, 0x0a, 0x42, 0x1e, 0x94,
                0x4d, 0x1e, 0x95, 0x2b, 0x70, 0xd5, 0x82, 0x6c, 0xd3, 0xb0, 0x8b, 0x7d, 0xb9, 0x63,
                0x0f, 0xe4, 0xfd, 0x5f, 0x22, 0x12, 0x5d, 0xe8, 0x40, 0xfc, 0xc4, 0x0b, 0x98, 0x03,
                0x8a, 0xf1, 0x1d, 0x55, 0xbe, 0x25, 0x43, 0x25, 0x97, 0xb4, 0xb6, 0x5b, 0x9e, 0xc1,
                0xc7, 0xa8, 0xbb, 0xfd, 0x05, 0x2c, 0xbf, 0x7e, 0x1c, 0x17, 0x85, 0x31, 0x49, 0x34,
                0xb2, 0x62, 0xd5, 0x85, 0x37, 0x54, 0xf1, 0xf1, 0x77, 0x71, 0xcf, 0xb7, 0x50, 0x30,
                0x72, 0x65, 0x57, 0x53,
            ],
            c_enc: [
                0xe7, 0x67, 0x81, 0xae, 0x63, 0x84, 0x1f, 0xff, 0xea, 0x30, 0x21, 0x96, 0x15, 0x94,
                0xc2, 0x2a, 0x87, 0x20, 0xc7, 0xd8, 0xaa, 0x80, 0x8b, 0xc8, 0x6e, 0x71, 0xa3, 0x6a,
                0xd7, 0xf8, 0x6f, 0xf8, 0x7c, 0x07, 0xd3, 0xc6, 0x50, 0xa0, 0x8e, 0x23, 0xe9, 0xb5,
                0x4f, 0x00, 0xb4, 0x0b, 0xa0, 0x15, 0x91, 0x69, 0xdf, 0xca, 0x34, 0xc1, 0x40, 0xce,
                0x93, 0x40, 0x19, 0xb2, 0xea, 0xa8, 0xea, 0x84, 0x35, 0x80, 0xb3, 0x5f, 0x14, 0xea,
                0x51, 0x92, 0xde, 0x8a, 0x12, 0xf9, 0xab, 0xc9, 0x06, 0x10, 0x15, 0xe1, 0x47, 0x9e,
                0xf9, 0x8d, 0x19, 0xa5, 0x34, 0xe9, 0xe4, 0x61, 0x64, 0xc3, 0xca, 0xc4, 0xeb, 0x54,
                0x26, 0x4c, 0xed, 0xcd, 0x83, 0xaf, 0xc2, 0xac, 0x2e, 0x08, 0x7e, 0x39, 0xdf, 0xba,
                0xe7, 0x6b, 0xd5, 0x50, 0xcc, 0x64, 0xa4, 0x04, 0xd2, 0x0c, 0x22, 0xca, 0x00, 0x3b,
                0xf7, 0x5b, 0x12, 0xfb, 0xb8, 0xc7, 0x15, 0x13, 0x72, 0x70, 0x0b, 0x43, 0x9b, 0x3e,
                0x06, 0x57, 0xec, 0xc3, 0x07, 0x70, 0x8f, 0xc3, 0x74, 0x94, 0xbd, 0x06, 0x39, 0xe8,
                0xe1, 0xea, 0xea, 0x37, 0x8f, 0x27, 0xa1, 0x35, 0x74, 0xb7, 0x1f, 0xa4, 0x88, 0x3b,
                0x80, 0x71, 0x2c, 0x7b, 0xeb, 0x5c, 0x30, 0x5f, 0x8d, 0x67, 0xe9, 0x19, 0x97, 0xf8,
                0x03, 0x19, 0xdd, 0xb1, 0x15, 0xb9, 0x51, 0x23, 0x89, 0x7a, 0xae, 0x5f, 0x2d, 0x14,
                0xff, 0xcf, 0xac, 0x7f, 0x65, 0x49, 0xca, 0x54, 0x8f, 0x6e, 0xab, 0xdf, 0x74, 0x81,
                0x70, 0x27, 0xd4, 0x2d, 0x92, 0xd5, 0xcd, 0xf8, 0x8e, 0xd8, 0xd5, 0x11, 0xd1, 0xb5,
                0xc4, 0x32, 0x2f, 0x77, 0x79, 0x74, 0x88, 0x6c, 0x0e, 0xd0, 0x13, 0x99, 0x18, 0x0a,
                0xfa, 0x59, 0x7d, 0xd2, 0xb7, 0x7c, 0x58, 0xb2, 0x7c, 0x8a, 0x61, 0x20, 0x69, 0xe3,
                0x86, 0xad, 0x63, 0x4c, 0xb0, 0x17, 0xa8, 0xe9, 0xf4, 0x8e, 0x37, 0xc4, 0x3e, 0xe8,
                0x73, 0x3a, 0x0a, 0xcb, 0x69, 0xf8, 0xed, 0x9f, 0x6f, 0x30, 0x5f, 0x3b, 0xd1, 0xe9,
                0x82, 0xb9, 0x4b, 0x1e, 0x51, 0xf4, 0xba, 0x98, 0x5b, 0x20, 0xec, 0x97, 0x4a, 0xc9,
                0xa7, 0x93, 0xaa, 0x26, 0x4d, 0x61, 0x5b, 0x9d, 0xea, 0x48, 0x59, 0xa4, 0xd4, 0xca,
                0xa7, 0x0d, 0x7a, 0x6b, 0x65, 0x30, 0x76, 0x85, 0xab, 0x53, 0x4e, 0x54, 0x55, 0x63,
                0x1f, 0x6d, 0x68, 0xa4, 0x51, 0xd8, 0xaf, 0x2d, 0x41, 0x82, 0x52, 0x80, 0x0f, 0x68,
                0x42, 0x31, 0xaf, 0xc2, 0x6d, 0x1f, 0xef, 0xc4, 0x03, 0xd7, 0x5f, 0x2e, 0x12, 0x0f,
                0x5b, 0xe2, 0xb6, 0x74, 0x48, 0x60, 0x09, 0x26, 0x7c, 0xbc, 0x0c, 0xb0, 0x01, 0xbb,
                0x47, 0xf0, 0xff, 0x46, 0x97, 0xea, 0xf5, 0x3d, 0xc9, 0x9c, 0x10, 0x77, 0x3a, 0x38,
                0xcd, 0x06, 0xb4, 0x8b, 0xa3, 0x91, 0x19, 0xdb, 0x49, 0x84, 0xd0, 0x9a, 0x5b, 0xde,
                0x13, 0x89, 0x0e, 0xa0, 0x61, 0x3d, 0x0c, 0xe0, 0x04, 0x3e, 0xae, 0x9a, 0x20, 0x89,
                0x14, 0x1f, 0xd9, 0x46, 0x59, 0x13, 0xc1, 0xcc, 0x33, 0x27, 0xa5, 0x59, 0x42, 0xb9,
                0xfd, 0x8f, 0xb8, 0x1c, 0x84, 0x7d, 0x8f, 0xdd, 0xf8, 0xbd, 0xba, 0xcf, 0xa0, 0xfb,
                0x05, 0x52, 0xc1, 0xfe, 0x4c, 0xc4, 0xc0, 0x7f, 0x4d, 0xcf, 0x15, 0x1c, 0x5e, 0x74,
                0xe8, 0xd6, 0x9b, 0x2b, 0x8b, 0xf7, 0xfd, 0x95, 0xec, 0xeb, 0x65, 0x5e, 0x00, 0x53,
                0x58, 0x16, 0xd3, 0x8b, 0x4a, 0x28, 0xd4, 0xa9, 0xae, 0xeb, 0xb6, 0x9a, 0xb4, 0xdd,
                0x12, 0xbf, 0x13, 0xfd, 0x5a, 0x45, 0x9b, 0x6b, 0xb6, 0x83, 0xff, 0xd9, 0xdd, 0x7b,
                0x0d, 0x0c, 0xe7, 0x29, 0x67, 0x75, 0x80, 0x8a, 0x84, 0x3f, 0x3b, 0x8c, 0xc7, 0x89,
                0xfd, 0x5f, 0x43, 0xe0, 0x84, 0xd8, 0x7d, 0x6a, 0xda, 0x8d, 0x1f, 0x28, 0xc2, 0x64,
                0xe6, 0x44, 0xe9, 0xad, 0x96, 0x5c, 0x28, 0x08, 0x8a, 0x52, 0xe4, 0xb3, 0x56, 0x42,
                0xf9, 0xb5, 0xe0, 0x66, 0x49, 0x90, 0x96, 0x3b, 0xc2, 0x3b, 0x9b, 0xb4, 0x8f, 0x46,
                0x74, 0x73, 0x53, 0x58, 0x0e, 0xcc, 0x45, 0x20, 0xcf, 0xf1, 0xfa, 0x7f, 0x8f, 0xbc,
                0x03, 0x0e, 0x64, 0x7d, 0xf1, 0x44, 0xee, 0x6c, 0xa5, 0xb3, 0x16, 0xb3, 0xaf, 0x90,
                0x48, 0x9a, 0x80, 0x9d, 0x9c, 0x9f,
            ],
            ock: [
                0x85, 0x6e, 0x1a, 0x97, 0x09, 0xb0, 0xc4, 0x16, 0x93, 0x3f, 0x59, 0x70, 0x71, 0x5c,
                0x56, 0xe2, 0xe0, 0x5c, 0x2e, 0xa9, 0x7d, 0x81, 0x51, 0x25, 0x70, 0x14, 0x79, 0xc3,
                0x3a, 0x5d, 0x91, 0xcb,
            ],
            op: [
                0x78, 0xa4, 0xe3, 0x39, 0x88, 0xd7, 0x1d, 0x71, 0x8e, 0x59, 0x55, 0x55, 0x28, 0x4c,
                0x24, 0x9a, 0x62, 0xb7, 0x12, 0x88, 0x06, 0xa5, 0x4c, 0x3b, 0x36, 0xa3, 0xaa, 0x57,
                0x14, 0x93, 0x16, 0x36, 0x8b, 0x14, 0x62, 0x2d, 0x2f, 0x91, 0xf1, 0x69, 0x8d, 0x53,
                0xfe, 0x47, 0x9a, 0x1e, 0x5c, 0x00, 0x64, 0x98, 0xb9, 0x8b, 0x85, 0xb4, 0x50, 0xbd,
                0x92, 0x3a, 0x5d, 0x00, 0xcb, 0x52, 0xa6, 0x13,
            ],
            c_out: [
                0x72, 0x36, 0xea, 0xb9, 0xf0, 0x12, 0x98, 0xc8, 0x4f, 0x38, 0x28, 0xf6, 0xac, 0x15,
                0x42, 0x76, 0xb5, 0xb7, 0x64, 0x62, 0xf5, 0x74, 0x2d, 0x69, 0xdc, 0x47, 0x7a, 0x10,
                0x5d, 0xc2, 0x71, 0x1b, 0x12, 0xe9, 0xb5, 0x82, 0x8c, 0x01, 0x76, 0xfe, 0xf4, 0x4a,
                0x54, 0x0f, 0x60, 0x95, 0x8e, 0x5a, 0x3e, 0xd6, 0xa2, 0xcc, 0x5e, 0xdd, 0xe9, 0x13,
                0xd1, 0x4c, 0xf8, 0xe8, 0xe2, 0x8e, 0xa2, 0x5c, 0x18, 0x62, 0x7a, 0x84, 0xa2, 0xbe,
                0x96, 0x1f, 0x44, 0x72, 0x67, 0x67, 0xe9, 0xf8, 0x43, 0x1b,
            ],
        },
        TestVector {
            incoming_viewing_key: [
                0x0b, 0xb5, 0x6c, 0x49, 0xc0, 0x63, 0x2d, 0x4c, 0xc7, 0xe4, 0x85, 0x51, 0xdb, 0x46,
                0x42, 0x8f, 0x1b, 0x1a, 0x52, 0x66, 0x1e, 0x07, 0xe0, 0xc3, 0xbc, 0xc2, 0x31, 0x74,
                0xcc, 0xbb, 0xbd, 0xa1, 0xfa, 0x19, 0x24, 0xf4, 0x16, 0xcd, 0x48, 0x39, 0x0e, 0x2b,
                0x11, 0xc6, 0xe7, 0x82, 0x56, 0xd4, 0xc4, 0xc5, 0x64, 0x1a, 0xca, 0xd9, 0xa2, 0x0c,
                0x24, 0xfb, 0xe6, 0xcb, 0x4e, 0xe7, 0x81, 0x25,
            ],
            ovk: [
                0x21, 0xe9, 0x1a, 0x3c, 0x4a, 0xa3, 0xf2, 0x7f, 0xa1, 0xb6, 0x33, 0x96, 0xe2, 0xb4,
                0x1d, 0xb9, 0x08, 0xfd, 0xab, 0x8b, 0x18, 0xcc, 0x73, 0x04, 0xe9, 0x4e, 0x97, 0x05,
                0x68, 0xf9, 0x42, 0x1c,
            ],
            default_d: [
                0xe0, 0x66, 0xb5, 0xe7, 0x96, 0x86, 0xe9, 0xf3, 0x6e, 0xce, 0xc7,
            ],
            default_pk_d: [
                0x3b, 0x3e, 0x88, 0x3e, 0x95, 0x8c, 0xd6, 0xe0, 0x75, 0x4d, 0x74, 0xca, 0xae, 0x1e,
                0x5a, 0x43, 0x98, 0xab, 0xeb, 0x7d, 0x10, 0xee, 0x5f, 0x75, 0xa4, 0xab, 0x8e, 0xf7,
                0x03, 0x8e, 0x3d, 0xb3,
            ],
            v: 12119135386131850622,
            rseed: [
                0xc3, 0x6d, 0xcf, 0xd3, 0x4a, 0x0c, 0xb6, 0x63, 0x78, 0x76, 0x10, 0x5e, 0x79, 0xbf,
                0x3b, 0xd5, 0x8e, 0xc1, 0x48, 0xcb, 0x64, 0x97, 0x0e, 0x32, 0x23, 0xa9, 0x1f, 0x71,
                0xdf, 0xcf, 0xd5, 0xa0,
            ],
            memo: [
                0xff, 0x4b, 0x66, 0x7f, 0xba, 0xf3, 0xd4, 0xb3, 0xb9, 0x08, 0xb9, 0x82, 0x88, 0x20,
                0xdf, 0xec, 0xdd, 0x75, 0x37, 0x50, 0xb5, 0xf9, 0xd2, 0x21, 0x6e, 0x56, 0xc6, 0x15,
                0x27, 0x2f, 0x85, 0x44, 0x64, 0xc0, 0xca, 0x4b, 0x1e, 0x85, 0xae, 0xdd, 0x03, 0x82,
                0x92, 0xc4, 0xe1, 0xa5, 0x77, 0x44, 0xeb, 0xba, 0x01, 0x0b, 0x9e, 0xbf, 0xbb, 0x01,
                0x1b, 0xd6, 0xf0, 0xb7, 0x88, 0x05, 0x02, 0x5d, 0x27, 0xf3, 0xc1, 0x77, 0x46, 0xba,
                0xe1, 0x16, 0xc1, 0x5d, 0x9f, 0x47, 0x1f, 0x0f, 0x62, 0x88, 0xa1, 0x50, 0x64, 0x7b,
                0x2a, 0xfe, 0x9d, 0xf7, 0xcc, 0xcf, 0x01, 0xf5, 0xcd, 0xe5, 0xf0, 0x46, 0x80, 0xbb,
                0xfe, 0xd8, 0x7f, 0x6c, 0xf4, 0x29, 0xfb, 0x27, 0xad, 0x6b, 0xab, 0xe7, 0x91, 0x76,
                0x66, 0x11, 0xcf, 0x5b, 0xc2, 0x0e, 0x48, 0xbe, 0xf1, 0x19, 0x25, 0x9b, 0x9b, 0x8a,
                0x0e, 0x39, 0xc3, 0xdf, 0x28, 0xcb, 0x95, 0x82, 0xea, 0x33, 0x86, 0x01, 0xcd, 0xc4,
                0x81, 0xb3, 0x2f, 0xb8, 0x2a, 0xde, 0xeb, 0xb3, 0xda, 0xde, 0x25, 0xd1, 0xa3, 0xdf,
                0x20, 0xc3, 0x7e, 0x71, 0x25, 0x06, 0xb5, 0xd9, 0x96, 0xc4, 0x9a, 0x9f, 0x0f, 0x30,
                0xdd, 0xcb, 0x91, 0xfe, 0x90, 0x04, 0xe1, 0xe8, 0x32, 0x94, 0xa6, 0xc9, 0x20, 0x3d,
                0x94, 0xe8, 0xdc, 0x2c, 0xbb, 0x44, 0x9d, 0xe4, 0x15, 0x50, 0x32, 0x60, 0x4e, 0x47,
                0x99, 0x70, 0x16, 0xb3, 0x04, 0xfd, 0x43, 0x7d, 0x82, 0x35, 0x04, 0x5e, 0x25, 0x5a,
                0x19, 0xb7, 0x43, 0xa0, 0xa9, 0xf2, 0xe3, 0x36, 0xb4, 0x4c, 0xae, 0x30, 0x7b, 0xb3,
                0x98, 0x7b, 0xd3, 0xe4, 0xe7, 0x77, 0xfb, 0xb3, 0x4c, 0x0a, 0xb8, 0xcc, 0x3d, 0x67,
                0x46, 0x6c, 0x0a, 0x88, 0xdd, 0x4c, 0xca, 0xd1, 0x8a, 0x07, 0xa8, 0xd1, 0x06, 0x8d,
                0xf5, 0xb6, 0x29, 0xe5, 0x71, 0x8d, 0x0f, 0x6d, 0xf5, 0xc9, 0x57, 0xcf, 0x71, 0xbb,
                0x00, 0xa5, 0x17, 0x8f, 0x17, 0x5c, 0xac, 0xa9, 0x44, 0xe6, 0x35, 0xc5, 0x15, 0x9f,
                0x73, 0x8e, 0x24, 0x02, 0xa2, 0xd2, 0x1a, 0xa0, 0x81, 0xe1, 0x0e, 0x45, 0x6a, 0xfb,
                0x00, 0xb9, 0xf6, 0x24, 0x16, 0xc8, 0xb9, 0xc0, 0xf7, 0x22, 0x8f, 0x51, 0x07, 0x29,
                0xe0, 0xbe, 0x3f, 0x30, 0x53, 0x13, 0xd7, 0x7f, 0x73, 0x79, 0xdc, 0x2a, 0xf2, 0x48,
                0x69, 0xc6, 0xc7, 0x4e, 0xe4, 0x47, 0x14, 0x98, 0x86, 0x1d, 0x19, 0x2f, 0x0f, 0xf0,
                0xf5, 0x08, 0x28, 0x5d, 0xab, 0x6b, 0x6a, 0x36, 0xcc, 0xf7, 0xd1, 0x22, 0x56, 0xcc,
                0x76, 0xb9, 0x55, 0x03, 0x72, 0x0a, 0xc6, 0x72, 0xd0, 0x82, 0x68, 0xd2, 0xcf, 0x77,
                0x73, 0xb6, 0xba, 0x2a, 0x5f, 0x66, 0x48, 0x47, 0xbf, 0x70, 0x7f, 0x2f, 0xc1, 0x0c,
                0x98, 0xf2, 0xf0, 0x06, 0xec, 0x22, 0xcc, 0xb5, 0xa8, 0xc8, 0xb7, 0xc4, 0x0c, 0x7c,
                0x2d, 0x49, 0xa6, 0x63, 0x9b, 0x9f, 0x2c, 0xe3, 0x3c, 0x25, 0xc0, 0x4b, 0xc4, 0x61,
                0xe7, 0x44, 0xdf, 0xa5, 0x36, 0xb0, 0x0d, 0x94, 0xba, 0xdd, 0xf4, 0xf4, 0xd1, 0x40,
                0x44, 0xc6, 0x95, 0xa3, 0x38, 0x81, 0x47, 0x7d, 0xf1, 0x24, 0xf0, 0xfc, 0xf2, 0x06,
                0xa9, 0xfb, 0x2e, 0x65, 0xe3, 0x04, 0xcd, 0xbf, 0x0c, 0x4d, 0x23, 0x90, 0x17, 0x0c,
                0x13, 0x0a, 0xb8, 0x49, 0xc2, 0xf2, 0x2b, 0x5c, 0xdd, 0x39, 0x21, 0x64, 0x0c, 0x8c,
                0xf1, 0x97, 0x6a, 0xe1, 0x01, 0x0b, 0x0d, 0xfd, 0x9c, 0xb2, 0x54, 0x3e, 0x45, 0xf9,
                0x97, 0x49, 0xcc, 0x4d, 0x61, 0xf2, 0xe8, 0xaa, 0xbf, 0xe9, 0x8b, 0xd9, 0x05, 0xfa,
                0x39, 0x95, 0x1b, 0x33, 0xea, 0x76, 0x9c, 0x45, 0xab, 0x95, 0x31, 0xc5, 0x72, 0x09,
                0x86, 0x2a, 0xd1, 0x2f, 0xd7, 0x6b, 0xa4, 0x80,
            ],
            cv_net: [
                0xca, 0xf6, 0x40, 0x8d, 0xef, 0x1f, 0x0f, 0x2b, 0xaa, 0x17, 0xb1, 0x30, 0xc3, 0xae,
                0x72, 0x95, 0x89, 0xbe, 0x69, 0xd8, 0x28, 0xbe, 0x54, 0x30, 0x69, 0x16, 0x41, 0x3c,
                0xd2, 0x50, 0x21, 0x17,
            ],
            rho: [
                0x8d, 0x67, 0xe3, 0xba, 0x4d, 0xbc, 0x9d, 0xa5, 0xe8, 0x38, 0x23, 0xa1, 0x23, 0x11,
                0x63, 0x96, 0x51, 0xa4, 0xff, 0xa9, 0x5f, 0x27, 0xc1, 0x83, 0x0d, 0x91, 0xd8, 0xb7,
                0x3c, 0xfb, 0xf1, 0x31,
            ],
            cmx: [
                0xea, 0x7c, 0x13, 0xf7, 0xe1, 0x20, 0x5e, 0x78, 0xc8, 0xce, 0x4e, 0xe4, 0xfd, 0xcd,
                0xb7, 0xee, 0x76, 0x92, 0x8d, 0xdf, 0x6d, 0xbe, 0x1b, 0x2d, 0x6f, 0x69, 0x81, 0xb7,
                0xc9, 0x65, 0x79, 0x10,
            ],
            esk: [
                0x85, 0x7b, 0xa2, 0x47, 0xd4, 0x68, 0xe1, 0x8d, 0xfe, 0x96, 0x73, 0xe9, 0x05, 0x99,
                0x23, 0xc2, 0x2e, 0x9b, 0x70, 0x0d, 0x56, 0x3d, 0xf8, 0xa9, 0x89, 0xcc, 0x63, 0x00,
                0x06, 0x15, 0xb2, 0x0d,
            ],
            ephemeral_key: [
                0x89, 0xfd, 0x2c, 0xf3, 0x79, 0x56, 0xba, 0xaf, 0x11, 0x27, 0xbb, 0x0e, 0x33, 0x40,
                0x01, 0x09, 0xdb, 0x03, 0x50, 0xf4, 0xab, 0xb7, 0xd6, 0xd8, 0x1f, 0xa5, 0x84, 0x8e,
                0x1b, 0xb1, 0x69, 0x26,
            ],
            shared_secret: [
                0xdb, 0xa6, 0x37, 0x94, 0xb6, 0x7c, 0x49, 0x6d, 0x01, 0x1c, 0xfb, 0x6b, 0xba, 0x29,
                0x7c, 0xa5, 0x7d, 0x18, 0xc7, 0xa9, 0xad, 0xdf, 0xfb, 0xc8, 0x37, 0x17, 0x6a, 0xcf,
                0x3a, 0x30, 0x1e, 0x23,
            ],
            k_enc: [
                0x80, 0xe7, 0x52, 0x2c, 0xb0, 0x32, 0x51, 0xc8, 0x55, 0x34, 0x1f, 0x06, 0xf9, 0x41,
                0x33, 0x41, 0xe1, 0x6e, 0x83, 0xb4, 0x89, 0xe1, 0x5a, 0x0a, 0x00, 0x65, 0xc3, 0x3b,
                0xf3, 0x81, 0x58, 0xc4,
            ],
            p_enc: [
                0x02, 0xe0, 0x66, 0xb5, 0xe7, 0x96, 0x86, 0xe9, 0xf3, 0x6e, 0xce, 0xc7, 0x7e, 0x65,
                0x41, 0x7b, 0x6c, 0xd1, 0x2f, 0xa8, 0xc3, 0x6d, 0xcf, 0xd3, 0x4a, 0x0c, 0xb6, 0x63,
                0x78, 0x76, 0x10, 0x5e, 0x79, 0xbf, 0x3b, 0xd5, 0x8e, 0xc1, 0x48, 0xcb, 0x64, 0x97,
                0x0e, 0x32, 0x23, 0xa9, 0x1f, 0x71, 0xdf, 0xcf, 0xd5, 0xa0, 0xff, 0x4b, 0x66, 0x7f,
                0xba, 0xf3, 0xd4, 0xb3, 0xb9, 0x08, 0xb9, 0x82, 0x88, 0x20, 0xdf, 0xec, 0xdd, 0x75,
                0x37, 0x50, 0xb5, 0xf9, 0xd2, 0x21, 0x6e, 0x56, 0xc6, 0x15, 0x27, 0x2f, 0x85, 0x44,
                0x64, 0xc0, 0xca, 0x4b, 0x1e, 0x85, 0xae, 0xdd, 0x03, 0x82, 0x92, 0xc4, 0xe1, 0xa5,
                0x77, 0x44, 0xeb, 0xba, 0x01, 0x0b, 0x9e, 0xbf, 0xbb, 0x01, 0x1b, 0xd6, 0xf0, 0xb7,
                0x88, 0x05, 0x02, 0x5d, 0x27, 0xf3, 0xc1, 0x77, 0x46, 0xba, 0xe1, 0x16, 0xc1, 0x5d,
                0x9f, 0x47, 0x1f, 0x0f, 0x62, 0x88, 0xa1, 0x50, 0x64, 0x7b, 0x2a, 0xfe, 0x9d, 0xf7,
                0xcc, 0xcf, 0x01, 0xf5, 0xcd, 0xe5, 0xf0, 0x46, 0x80, 0xbb, 0xfe, 0xd8, 0x7f, 0x6c,
                0xf4, 0x29, 0xfb, 0x27, 0xad, 0x6b, 0xab, 0xe7, 0x91, 0x76, 0x66, 0x11, 0xcf, 0x5b,
                0xc2, 0x0e, 0x48, 0xbe, 0xf1, 0x19, 0x25, 0x9b, 0x9b, 0x8a, 0x0e, 0x39, 0xc3, 0xdf,
                0x28, 0xcb, 0x95, 0x82, 0xea, 0x33, 0x86, 0x01, 0xcd, 0xc4, 0x81, 0xb3, 0x2f, 0xb8,
                0x2a, 0xde, 0xeb, 0xb3, 0xda, 0xde, 0x25, 0xd1, 0xa3, 0xdf, 0x20, 0xc3, 0x7e, 0x71,
                0x25, 0x06, 0xb5, 0xd9, 0x96, 0xc4, 0x9a, 0x9f, 0x0f, 0x30, 0xdd, 0xcb, 0x91, 0xfe,
                0x90, 0x04, 0xe1, 0xe8, 0x32, 0x94, 0xa6, 0xc9, 0x20, 0x3d, 0x94, 0xe8, 0xdc, 0x2c,
                0xbb, 0x44, 0x9d, 0xe4, 0x15, 0x50, 0x32, 0x60, 0x4e, 0x47, 0x99, 0x70, 0x16, 0xb3,
                0x04, 0xfd, 0x43, 0x7d, 0x82, 0x35, 0x04, 0x5e, 0x25, 0x5a, 0x19, 0xb7, 0x43, 0xa0,
                0xa9, 0xf2, 0xe3, 0x36, 0xb4, 0x4c, 0xae, 0x30, 0x7b, 0xb3, 0x98, 0x7b, 0xd3, 0xe4,
                0xe7, 0x77, 0xfb, 0xb3, 0x4c, 0x0a, 0xb8, 0xcc, 0x3d, 0x67, 0x46, 0x6c, 0x0a, 0x88,
                0xdd, 0x4c, 0xca, 0xd1, 0x8a, 0x07, 0xa8, 0xd1, 0x06, 0x8d, 0xf5, 0xb6, 0x29, 0xe5,
                0x71, 0x8d, 0x0f, 0x6d, 0xf5, 0xc9, 0x57, 0xcf, 0x71, 0xbb, 0x00, 0xa5, 0x17, 0x8f,
                0x17, 0x5c, 0xac, 0xa9, 0x44, 0xe6, 0x35, 0xc5, 0x15, 0x9f, 0x73, 0x8e, 0x24, 0x02,
                0xa2, 0xd2, 0x1a, 0xa0, 0x81, 0xe1, 0x0e, 0x45, 0x6a, 0xfb, 0x00, 0xb9, 0xf6, 0x24,
                0x16, 0xc8, 0xb9, 0xc0, 0xf7, 0x22, 0x8f, 0x51, 0x07, 0x29, 0xe0, 0xbe, 0x3f, 0x30,
                0x53, 0x13, 0xd7, 0x7f, 0x73, 0x79, 0xdc, 0x2a, 0xf2, 0x48, 0x69, 0xc6, 0xc7, 0x4e,
                0xe4, 0x47, 0x14, 0x98, 0x86, 0x1d, 0x19, 0x2f, 0x0f, 0xf0, 0xf5, 0x08, 0x28, 0x5d,
                0xab, 0x6b, 0x6a, 0x36, 0xcc, 0xf7, 0xd1, 0x22, 0x56, 0xcc, 0x76, 0xb9, 0x55, 0x03,
                0x72, 0x0a, 0xc6, 0x72, 0xd0, 0x82, 0x68, 0xd2, 0xcf, 0x77, 0x73, 0xb6, 0xba, 0x2a,
                0x5f, 0x66, 0x48, 0x47, 0xbf, 0x70, 0x7f, 0x2f, 0xc1, 0x0c, 0x98, 0xf2, 0xf0, 0x06,
                0xec, 0x22, 0xcc, 0xb5, 0xa8, 0xc8, 0xb7, 0xc4, 0x0c, 0x7c, 0x2d, 0x49, 0xa6, 0x63,
                0x9b, 0x9f, 0x2c, 0xe3, 0x3c, 0x25, 0xc0, 0x4b, 0xc4, 0x61, 0xe7, 0x44, 0xdf, 0xa5,
                0x36, 0xb0, 0x0d, 0x94, 0xba, 0xdd, 0xf4, 0xf4, 0xd1, 0x40, 0x44, 0xc6, 0x95, 0xa3,
                0x38, 0x81, 0x47, 0x7d, 0xf1, 0x24, 0xf0, 0xfc, 0xf2, 0x06, 0xa9, 0xfb, 0x2e, 0x65,
                0xe3, 0x04, 0xcd, 0xbf, 0x0c, 0x4d, 0x23, 0x90, 0x17, 0x0c, 0x13, 0x0a, 0xb8, 0x49,
                0xc2, 0xf2, 0x2b, 0x5c, 0xdd, 0x39, 0x21, 0x64, 0x0c, 0x8c, 0xf1, 0x97, 0x6a, 0xe1,
                0x01, 0x0b, 0x0d, 0xfd, 0x9c, 0xb2, 0x54, 0x3e, 0x45, 0xf9, 0x97, 0x49, 0xcc, 0x4d,
                0x61, 0xf2, 0xe8, 0xaa, 0xbf, 0xe9, 0x8b, 0xd9, 0x05, 0xfa, 0x39, 0x95, 0x1b, 0x33,
                0xea, 0x76, 0x9c, 0x45, 0xab, 0x95, 0x31, 0xc5, 0x72, 0x09, 0x86, 0x2a, 0xd1, 0x2f,
                0xd7, 0x6b, 0xa4, 0x80,
            ],
            c_enc: [
                0x3f, 0x4e, 0x9b, 0x18, 0x56, 0xe7, 0xbf, 0xba, 0x7a, 0xbb, 0xc9, 0x4a, 0x72, 0xb4,
                0xab, 0xb1, 0xd8, 0x46, 0x26, 0x79, 0x30, 0x77, 0xe8, 0x37, 0xda, 0xf3, 0x3f, 0xff,
                0xa2, 0x7c, 0x7a, 0x33, 0x97, 0x8a, 0x54, 0x32, 0x51, 0x0d, 0x99, 0x3c, 0x7d, 0x92,
                0x24, 0xc0, 0x97, 0xac, 0xc5, 0x25, 0x88, 0x1c, 0x76, 0x08, 0x3c, 0x1b, 0x65, 0x1a,
                0x9d, 0xe1, 0xb5, 0xc1, 0xa6, 0xe0, 0x48, 0x2f, 0xae, 0x8f, 0x98, 0x6a, 0xb5, 0x9f,
                0xa7, 0xcd, 0x43, 0x98, 0x99, 0x6e, 0x2b, 0xc0, 0x3a, 0xdc, 0xa9, 0x90, 0x32, 0x3b,
                0xaa, 0xbd, 0xda, 0xae, 0x40, 0xb0, 0x56, 0xb7, 0xac, 0x17, 0xf8, 0x20, 0xd1, 0x1c,
                0x0d, 0xec, 0xba, 0x14, 0xf2, 0x57, 0xa6, 0xcf, 0x09, 0x18, 0x19, 0x8f, 0x38, 0x9c,
                0xdb, 0x29, 0x55, 0x77, 0x25, 0x96, 0x92, 0x7c, 0xbf, 0x55, 0x88, 0x56, 0x13, 0x35,
                0xe7, 0xd6, 0x2e, 0x6a, 0x8a, 0xf7, 0xbc, 0x33, 0xb9, 0x9a, 0x55, 0xaf, 0xa1, 0xb7,
                0xef, 0x20, 0xeb, 0x4e, 0xd6, 0xde, 0x89, 0x69, 0xd2, 0x9f, 0x04, 0x21, 0xcd, 0x4d,
                0x99, 0x06, 0x66, 0xfd, 0xcf, 0x1e, 0xbd, 0x09, 0x06, 0x57, 0x02, 0x13, 0x4d, 0x31,
                0xc3, 0x29, 0x26, 0xa3, 0x8b, 0x6b, 0x6b, 0x48, 0xfd, 0xc9, 0xb3, 0xc7, 0x64, 0xc3,
                0xcd, 0x95, 0xb9, 0x72, 0xe7, 0x68, 0xeb, 0xd8, 0xaa, 0xe9, 0x0d, 0x6a, 0x4a, 0x98,
                0xb2, 0xd9, 0x2f, 0xd9, 0xdf, 0xa2, 0xa2, 0x99, 0xd0, 0x60, 0xe8, 0x5e, 0xf5, 0x68,
                0x3f, 0x51, 0xd0, 0x51, 0x4a, 0x6e, 0xba, 0x72, 0x57, 0x3f, 0x7b, 0xae, 0x84, 0xa2,
                0xfd, 0x92, 0xbe, 0x64, 0x24, 0x1c, 0x27, 0xa6, 0xe5, 0xce, 0xac, 0xbf, 0x37, 0xb2,
                0xd9, 0xa9, 0x75, 0xdf, 0x7a, 0xee, 0xbb, 0xa1, 0x4d, 0x8c, 0x81, 0x15, 0x8e, 0xcf,
                0x5a, 0x0a, 0x25, 0xe1, 0x2f, 0x98, 0x5d, 0x08, 0xfb, 0xb4, 0xa1, 0xc1, 0x3f, 0x76,
                0x1f, 0x3f, 0xfe, 0xe8, 0xd5, 0x38, 0xe3, 0x93, 0xf3, 0x58, 0x0b, 0x73, 0x82, 0xcd,
                0x0b, 0xf5, 0x17, 0xce, 0x78, 0x87, 0x1c, 0x19, 0xac, 0xf8, 0xca, 0x06, 0x5d, 0x7c,
                0x83, 0x87, 0xce, 0xcd, 0x0d, 0x37, 0xae, 0x21, 0x7f, 0x44, 0x06, 0x94, 0x77, 0x2a,
                0xbd, 0x4b, 0x36, 0x55, 0x56, 0x85, 0x4b, 0xaa, 0x8b, 0xcc, 0xa9, 0xc4, 0xfe, 0xf7,
                0x18, 0x99, 0x12, 0xf9, 0x8a, 0x25, 0x27, 0x68, 0x92, 0x76, 0xa4, 0x00, 0x8c, 0x83,
                0x8f, 0xe7, 0x4f, 0x7c, 0x2b, 0x75, 0x9f, 0xc2, 0xab, 0x7a, 0xfe, 0x37, 0x82, 0x80,
                0x6e, 0x31, 0xb1, 0xc5, 0x30, 0xcc, 0x46, 0x20, 0x3b, 0xb3, 0xa5, 0x66, 0xca, 0xf4,
                0xd1, 0x5b, 0x99, 0x40, 0xb4, 0x3f, 0x33, 0xa8, 0x6a, 0x65, 0xd4, 0x9d, 0xa8, 0xb6,
                0x78, 0x7d, 0xe0, 0x96, 0x38, 0xb4, 0x81, 0xf3, 0xa8, 0x10, 0x8a, 0x96, 0x9e, 0xca,
                0xdf, 0x90, 0x98, 0xbf, 0xf2, 0x14, 0x0c, 0x4b, 0x42, 0xe2, 0xb0, 0xfb, 0x10, 0xb9,
                0x02, 0x89, 0xb0, 0xc6, 0xdb, 0x8b, 0xc0, 0x85, 0xe8, 0xaf, 0xe9, 0x5d, 0xd3, 0x6a,
                0x45, 0x36, 0xea, 0xd7, 0xe9, 0x5c, 0x99, 0x66, 0x2c, 0xd9, 0x28, 0xc2, 0x2c, 0x3e,
                0xbf, 0x39, 0x79, 0x15, 0x78, 0xbc, 0x66, 0xfe, 0xa3, 0x01, 0x4d, 0x22, 0x92, 0x94,
                0x30, 0x83, 0xe7, 0x46, 0x81, 0x24, 0x52, 0xb0, 0x0b, 0xc2, 0xf3, 0xe4, 0x7c, 0x49,
                0x47, 0x46, 0xce, 0xd5, 0x57, 0xb1, 0x3a, 0xe3, 0x03, 0x0d, 0x8a, 0x95, 0x78, 0x10,
                0x2b, 0xba, 0xd2, 0xfc, 0x3b, 0x84, 0x5f, 0x31, 0xae, 0x16, 0xf8, 0xd8, 0x0b, 0x77,
                0xf8, 0x43, 0x15, 0x84, 0xa3, 0x7e, 0x8f, 0x30, 0xb0, 0xb9, 0x5c, 0xc4, 0x55, 0x5a,
                0xbc, 0x05, 0x3a, 0x0b, 0x4f, 0xf9, 0x13, 0xb0, 0x03, 0x69, 0xf1, 0x74, 0x7b, 0x1f,
                0x1c, 0x0a, 0xc8, 0x75, 0x4f, 0x01, 0x7e, 0x99, 0x47, 0xca, 0x63, 0x25, 0x5b, 0x3c,
                0x23, 0xf4, 0x56, 0xe2, 0x3f, 0x96, 0x76, 0x13, 0x99, 0x60, 0x1f, 0xd8, 0xda, 0xdb,
                0x5e, 0x3f, 0x90, 0xab, 0x1b, 0x20, 0x13, 0x81, 0x80, 0xed, 0x69, 0x73, 0x22, 0x39,
                0xc8, 0xc2, 0x15, 0xd9, 0xcc, 0x8a, 0xc8, 0x05, 0x9b, 0xde, 0x81, 0x63, 0x27, 0xd2,
                0x20, 0xb9, 0xa8, 0xec, 0xba, 0x5d,
            ],
            ock: [
                0xe6, 0xb7, 0x05, 0x50, 0xe1, 0xd7, 0xa2, 0xbe, 0x73, 0x04, 0x39, 0x64, 0x41, 0xec,
                0x6a, 0xc0, 0x47, 0x45, 0x99, 0xf9, 0xea, 0xd7, 0x55, 0xc2, 0xcf, 0x27, 0x6b, 0x87,
                0x50, 0xc5, 0xcf, 0x2d,
            ],
            op: [
                0x3b, 0x3e, 0x88, 0x3e, 0x95, 0x8c, 0xd6, 0xe0, 0x75, 0x4d, 0x74, 0xca, 0xae, 0x1e,
                0x5a, 0x43, 0x98, 0xab, 0xeb, 0x7d, 0x10, 0xee, 0x5f, 0x75, 0xa4, 0xab, 0x8e, 0xf7,
                0x03, 0x8e, 0x3d, 0xb3, 0x85, 0x7b, 0xa2, 0x47, 0xd4, 0x68, 0xe1, 0x8d, 0xfe, 0x96,
                0x73, 0xe9, 0x05, 0x99, 0x23, 0xc2, 0x2e, 0x9b, 0x70, 0x0d, 0x56, 0x3d, 0xf8, 0xa9,
                0x89, 0xcc, 0x63, 0x00, 0x06, 0x15, 0xb2, 0x0d,
            ],
            c_out: [
                0x02, 0xb1, 0x37, 0x3e, 0xb1, 0x89, 0x56, 0x32, 0x2b, 0x47, 0xa1, 0x70, 0x0d, 0xb7,
                0x43, 0x31, 0x6e, 0xde, 0x46, 0x44, 0xd6, 0x59, 0x3c, 0xd7, 0x94, 0x22, 0xd7, 0x51,
                0x3d, 0x1b, 0x80, 0xe6, 0x85, 0x05, 0xdf, 0xe9, 0xd6, 0x86, 0x2e, 0x79, 0x4e, 0x30,
                0x28, 0x8b, 0xae, 0xa8, 0xb0, 0xbc, 0xb3, 0x8b, 0x35, 0x49, 0x77, 0xaa, 0xee, 0x57,
                0x2e, 0xe8, 0x86, 0x8b, 0x2d, 0xa0, 0x7d, 0xa2, 0x99, 0x2c, 0x6d, 0x9f, 0xb8, 0xbd,
                0x59, 0x0b, 0x8d, 0xa0, 0x28, 0x11, 0xb5, 0x09, 0xe8, 0xc6,
            ],
        },
        TestVector {
            incoming_viewing_key: [
                0xeb, 0xd4, 0x80, 0x6d, 0x81, 0x25, 0x49, 0x89, 0xfa, 0xdb, 0xa8, 0xcd, 0x58, 0x96,
                0x7d, 0x6f, 0xd8, 0x73, 0x83, 0xbc, 0x09, 0x38, 0x63, 0xd5, 0xab, 0xfc, 0xdd, 0xd3,
                0x8f, 0x15, 0x39, 0xfa, 0xb7, 0xe5, 0xd4, 0xf0, 0x61, 0x91, 0x67, 0xb8, 0xd4, 0x82,
                0xcb, 0x54, 0x8c, 0xb5, 0x59, 0x83, 0x49, 0x6f, 0x77, 0xd3, 0xdc, 0xaf, 0xf5, 0x6e,
                0x32, 0x41, 0x0b, 0xfe, 0xc1, 0xf2, 0x68, 0x11,
            ],
            ovk: [
                0xb2, 0x5f, 0x30, 0x3f, 0x58, 0x15, 0xc4, 0x53, 0x31, 0x24, 0xac, 0xf9, 0xd1, 0x89,
                0x40, 0xe7, 0x75, 0x22, 0xac, 0x5d, 0xc4, 0xb9, 0x57, 0x0a, 0xae, 0x8f, 0x47, 0xb7,
                0xf5, 0x7f, 0xd8, 0x76,
            ],
            default_d: [
                0x1c, 0xa7, 0xb6, 0x49, 0x39, 0x9e, 0x13, 0xe4, 0x39, 0x44, 0x62,
            ],
            default_pk_d: [
                0x3f, 0xeb, 0x34, 0x5a, 0xec, 0xd3, 0x42, 0x9a, 0x16, 0xe1, 0x0f, 0x3d, 0x13, 0x20,
                0xbc, 0x99, 0x71, 0xb5, 0x9e, 0x63, 0x9d, 0x62, 0xb6, 0x96, 0x1a, 0xea, 0x78, 0x15,
                0x67, 0xa8, 0x60, 0x9e,
            ],
            v: 9624581763228770449,
            rseed: [
                0x4a, 0x95, 0xb2, 0x05, 0x52, 0x6c, 0xfc, 0xb4, 0xc4, 0xe1, 0xcc, 0x95, 0x51, 0x75,
                0xb3, 0xe8, 0xde, 0x1f, 0x5d, 0x81, 0xb1, 0x86, 0x69, 0x69, 0x23, 0x50, 0xaa, 0xa1,
                0xa1, 0xd7, 0x97, 0x61,
            ],
            memo: [
                0xff, 0x75, 0x82, 0xe5, 0x4d, 0x7a, 0x5b, 0x57, 0xa6, 0x83, 0xb3, 0x2f, 0xb1, 0x09,
                0x80, 0x62, 0xda, 0xd7, 0xb0, 0xc2, 0xeb, 0x51, 0x8f, 0x68, 0x62, 0xe8, 0x3d, 0xb2,
                0x5e, 0x3d, 0xba, 0xf7, 0xae, 0xd5, 0x04, 0xde, 0x93, 0x2a, 0xcb, 0x99, 0xd7, 0x35,
                0x99, 0x2c, 0xe6, 0x2b, 0xae, 0x9e, 0xf8, 0x93, 0xff, 0x6a, 0xcc, 0x0f, 0xfc, 0xf8,
                0xe3, 0x48, 0x3e, 0x14, 0x6b, 0x9d, 0x49, 0xdd, 0x8c, 0x78, 0x35, 0xf4, 0x3a, 0x37,
                0xdc, 0xa0, 0x78, 0x7e, 0x3e, 0xc9, 0xf6, 0x60, 0x52, 0x23, 0xd5, 0xba, 0x7a, 0xe0,
                0xab, 0x90, 0x25, 0xb7, 0x3b, 0xc0, 0x3f, 0x7f, 0xac, 0x36, 0xc0, 0x09, 0xa5, 0x6d,
                0x4d, 0x95, 0xd1, 0xe8, 0x1d, 0x3b, 0x3e, 0xbc, 0xa7, 0xe5, 0x4c, 0xc1, 0xa1, 0x2d,
                0x12, 0x7b, 0x57, 0xc8, 0x13, 0x89, 0x76, 0xe7, 0x91, 0x01, 0x3b, 0x01, 0x5f, 0x06,
                0xa6, 0x24, 0xf5, 0x21, 0xb6, 0xee, 0x04, 0xec, 0x98, 0x08, 0x93, 0xc7, 0xe5, 0xe0,
                0x1a, 0x33, 0x62, 0x03, 0x59, 0x40, 0x94, 0xf8, 0x28, 0x33, 0xd7, 0x44, 0x5f, 0xe2,
                0xd0, 0x91, 0x30, 0xf6, 0x35, 0x11, 0xda, 0x54, 0x83, 0x2d, 0xe9, 0x13, 0x6b, 0x39,
                0xf4, 0x59, 0x9f, 0x5a, 0xa5, 0xdf, 0xbb, 0x45, 0xda, 0x60, 0xcd, 0xce, 0xab, 0x7e,
                0xef, 0xde, 0x89, 0xbe, 0x63, 0xf3, 0xf7, 0xc0, 0xd2, 0x32, 0x48, 0x47, 0xcc, 0xe1,
                0x40, 0x5d, 0xef, 0x7c, 0x46, 0x9b, 0x0e, 0x27, 0x24, 0x94, 0xe5, 0xdf, 0x54, 0xf5,
                0x68, 0x65, 0x6c, 0xb9, 0xc8, 0x81, 0x8d, 0x92, 0xb7, 0x2b, 0x8b, 0xc3, 0x4d, 0xb7,
                0xbb, 0x31, 0x12, 0x48, 0x7e, 0x74, 0x6e, 0xef, 0xe4, 0xe8, 0x08, 0xbb, 0xb2, 0x87,
                0xd9, 0x9b, 0xf0, 0x7d, 0x00, 0xda, 0xbe, 0xde, 0xdc, 0x5e, 0x5f, 0x07, 0x4f, 0xfe,
                0xae, 0x0c, 0xba, 0x7d, 0xa3, 0xa5, 0x16, 0xc1, 0x73, 0xbe, 0x1c, 0x51, 0x33, 0x23,
                0xe1, 0x19, 0xf6, 0x35, 0xe8, 0x20, 0x9a, 0x07, 0x4b, 0x21, 0x6b, 0x70, 0x23, 0xfa,
                0xdc, 0x2d, 0x25, 0x94, 0x9c, 0x90, 0x03, 0x7e, 0x71, 0xe3, 0xe5, 0x50, 0x72, 0x6d,
                0x21, 0x0a, 0x2c, 0x68, 0x83, 0x42, 0xe5, 0x24, 0x40, 0x63, 0x5e, 0x9c, 0xc1, 0x4a,
                0xfe, 0x10, 0x10, 0x26, 0x21, 0xa9, 0xc9, 0xac, 0xcb, 0x78, 0x2e, 0x9e, 0x4a, 0x5f,
                0xa8, 0x7f, 0x0a, 0x95, 0x6f, 0x5b, 0x85, 0x50, 0x99, 0x60, 0x28, 0x5c, 0x22, 0x62,
                0x7c, 0x59, 0x48, 0x3a, 0x5a, 0x4c, 0x28, 0xcc, 0xe4, 0xb1, 0x56, 0xe5, 0x51, 0x40,
                0x6a, 0x7e, 0xe8, 0x35, 0x56, 0x56, 0xa2, 0x1e, 0x43, 0xe3, 0x8c, 0xe1, 0x29, 0xfd,
                0xad, 0xb7, 0x59, 0xed, 0xdf, 0xa0, 0x8f, 0x00, 0xfc, 0x8e, 0x56, 0x7c, 0xef, 0x93,
                0xc6, 0x79, 0x2d, 0x01, 0xdf, 0x05, 0xe6, 0xd5, 0x80, 0xf4, 0xd5, 0xd4, 0x8d, 0xf0,
                0x42, 0x45, 0x1a, 0x33, 0x59, 0x0d, 0x3e, 0x8c, 0xf4, 0x9b, 0x26, 0x27, 0x21, 0x8f,
                0x0c, 0x29, 0x2f, 0xa6, 0x6a, 0xda, 0x94, 0x5f, 0xa5, 0x5b, 0xb2, 0x35, 0x48, 0xe3,
                0x3a, 0x83, 0xa5, 0x62, 0x95, 0x7a, 0x31, 0x49, 0xa9, 0x93, 0xcc, 0x47, 0x23, 0x62,
                0x29, 0x87, 0x36, 0xa8, 0xb7, 0x78, 0xd9, 0x7c, 0xe4, 0x23, 0x01, 0x3d, 0x64, 0xb3,
                0x2c, 0xd1, 0x72, 0xef, 0xa5, 0x51, 0xbf, 0x7f, 0x36, 0x8f, 0x04, 0xbd, 0xae, 0xc6,
                0x09, 0x1a, 0x30, 0x04, 0xa7, 0x57, 0x59, 0x8b, 0x80, 0x1d, 0xcf, 0x67, 0x5c, 0xb8,
                0x3e, 0x43, 0xa5, 0x3a, 0xe8, 0xb2, 0x54, 0xd3, 0x33, 0xbc, 0xda, 0x20, 0xd4, 0x81,
                0x7d, 0x34, 0x77, 0xab, 0xfb, 0xa2, 0x5b, 0xb8, 0x3d, 0xf5, 0x94, 0x9c, 0x12, 0x6f,
                0x14, 0x9b, 0x1d, 0x99, 0x34, 0x1e, 0x4e, 0x6f,
            ],
            cv_net: [
                0xd2, 0xf9, 0xad, 0xff, 0x53, 0x1b, 0x65, 0x43, 0x2b, 0xa2, 0xd7, 0xda, 0xa6, 0xd8,
                0x6e, 0x62, 0xe4, 0xed, 0xc7, 0x86, 0xd9, 0xe0, 0xb2, 0x7d, 0x26, 0x62, 0x8b, 0x79,
                0xda, 0x6b, 0x15, 0x14,
            ],
            rho: [
                0x9a, 0x09, 0xe4, 0x72, 0xe8, 0xe9, 0x96, 0xfc, 0xc3, 0x0e, 0xd5, 0x23, 0x72, 0x08,
                0xdb, 0xb0, 0x01, 0x71, 0x32, 0x0e, 0x6b, 0xea, 0x43, 0x91, 0x86, 0x00, 0x9d, 0xad,
                0x21, 0x38, 0xab, 0x29,
            ],
            cmx: [
                0x18, 0xfc, 0xbd, 0x40, 0xac, 0xf1, 0xa7, 0xf4, 0xd6, 0x09, 0x87, 0x9a, 0x5f, 0x5e,
                0x3b, 0x39, 0x70, 0x09, 0x4f, 0xf8, 0xbe, 0x84, 0x18, 0x60, 0x70, 0x16, 0xc6, 0xa6,
                0x97, 0xf8, 0x9c, 0x20,
            ],
            esk: [
                0x3b, 0xc1, 0x7a, 0x58, 0x0d, 0x53, 0x0f, 0x89, 0x30, 0xa3, 0x6b, 0x8d, 0x6f, 0xea,
                0x67, 0x85, 0x7f, 0x7b, 0x85, 0x20, 0xfd, 0x2e, 0x0a, 0xb5, 0xd5, 0xcb, 0xab, 0x1a,
                0xcc, 0xd5, 0x4e, 0x3a,
            ],
            ephemeral_key: [
                0xcf, 0xe0, 0x3e, 0xb2, 0xd3, 0x36, 0x76, 0xb7, 0x73, 0x83, 0x7d, 0xa8, 0x39, 0x17,
                0x2d, 0x33, 0x33, 0x31, 0x88, 0xc9, 0xdf, 0xef, 0x05, 0xc8, 0x32, 0xa2, 0x5c, 0x86,
                0xd3, 0xbf, 0x0e, 0x8f,
            ],
            shared_secret: [
                0xd2, 0xc2, 0x88, 0x9e, 0x03, 0x7e, 0xac, 0x60, 0x60, 0x58, 0x68, 0x2b, 0xaa, 0x38,
                0x86, 0xa4, 0xc2, 0xdd, 0x44, 0xea, 0xdf, 0x8b, 0x2c, 0xe4, 0x39, 0x95, 0xde, 0xd7,
                0x61, 0xfd, 0xaf, 0xb5,
            ],
            k_enc: [
                0xfe, 0xe3, 0xe3, 0xb5, 0xfd, 0x6c, 0xd8, 0x54, 0x44, 0x2b, 0x2a, 0xc2, 0x97, 0x70,
                0xfb, 0x0e, 0x39, 0x32, 0xf4, 0x71, 0x52, 0x43, 0x26, 0xda, 0x4a, 0x57, 0xc2, 0x56,
                0x18, 0x06, 0x9e, 0x99,
            ],
            p_enc: [
                0x02, 0x1c, 0xa7, 0xb6, 0x49, 0x39, 0x9e, 0x13, 0xe4, 0x39, 0x44, 0x62, 0x91, 0x20,
                0xf4, 0xd4, 0x1e, 0x62, 0x91, 0x85, 0x4a, 0x95, 0xb2, 0x05, 0x52, 0x6c, 0xfc, 0xb4,
                0xc4, 0xe1, 0xcc, 0x95, 0x51, 0x75, 0xb3, 0xe8, 0xde, 0x1f, 0x5d, 0x81, 0xb1, 0x86,
                0x69, 0x69, 0x23, 0x50, 0xaa, 0xa1, 0xa1, 0xd7, 0x97, 0x61, 0xff, 0x75, 0x82, 0xe5,
                0x4d, 0x7a, 0x5b, 0x57, 0xa6, 0x83, 0xb3, 0x2f, 0xb1, 0x09, 0x80, 0x62, 0xda, 0xd7,
                0xb0, 0xc2, 0xeb, 0x51, 0x8f, 0x68, 0x62, 0xe8, 0x3d, 0xb2, 0x5e, 0x3d, 0xba, 0xf7,
                0xae, 0xd5, 0x04, 0xde, 0x93, 0x2a, 0xcb, 0x99, 0xd7, 0x35, 0x99, 0x2c, 0xe6, 0x2b,
                0xae, 0x9e, 0xf8, 0x93, 0xff, 0x6a, 0xcc, 0x0f, 0xfc, 0xf8, 0xe3, 0x48, 0x3e, 0x14,
                0x6b, 0x9d, 0x49, 0xdd, 0x8c, 0x78, 0x35, 0xf4, 0x3a, 0x37, 0xdc, 0xa0, 0x78, 0x7e,
                0x3e, 0xc9, 0xf6, 0x60, 0x52, 0x23, 0xd5, 0xba, 0x7a, 0xe0, 0xab, 0x90, 0x25, 0xb7,
                0x3b, 0xc0, 0x3f, 0x7f, 0xac, 0x36, 0xc0, 0x09, 0xa5, 0x6d, 0x4d, 0x95, 0xd1, 0xe8,
                0x1d, 0x3b, 0x3e, 0xbc, 0xa7, 0xe5, 0x4c, 0xc1, 0xa1, 0x2d, 0x12, 0x7b, 0x57, 0xc8,
                0x13, 0x89, 0x76, 0xe7, 0x91, 0x01, 0x3b, 0x01, 0x5f, 0x06, 0xa6, 0x24, 0xf5, 0x21,
                0xb6, 0xee, 0x04, 0xec, 0x98, 0x08, 0x93, 0xc7, 0xe5, 0xe0, 0x1a, 0x33, 0x62, 0x03,
                0x59, 0x40, 0x94, 0xf8, 0x28, 0x33, 0xd7, 0x44, 0x5f, 0xe2, 0xd0, 0x91, 0x30, 0xf6,
                0x35, 0x11, 0xda, 0x54, 0x83, 0x2d, 0xe9, 0x13, 0x6b, 0x39, 0xf4, 0x59, 0x9f, 0x5a,
                0xa5, 0xdf, 0xbb, 0x45, 0xda, 0x60, 0xcd, 0xce, 0xab, 0x7e, 0xef, 0xde, 0x89, 0xbe,
                0x63, 0xf3, 0xf7, 0xc0, 0xd2, 0x32, 0x48, 0x47, 0xcc, 0xe1, 0x40, 0x5d, 0xef, 0x7c,
                0x46, 0x9b, 0x0e, 0x27, 0x24, 0x94, 0xe5, 0xdf, 0x54, 0xf5, 0x68, 0x65, 0x6c, 0xb9,
                0xc8, 0x81, 0x8d, 0x92, 0xb7, 0x2b, 0x8b, 0xc3, 0x4d, 0xb7, 0xbb, 0x31, 0x12, 0x48,
                0x7e, 0x74, 0x6e, 0xef, 0xe4, 0xe8, 0x08, 0xbb, 0xb2, 0x87, 0xd9, 0x9b, 0xf0, 0x7d,
                0x00, 0xda, 0xbe, 0xde, 0xdc, 0x5e, 0x5f, 0x07, 0x4f, 0xfe, 0xae, 0x0c, 0xba, 0x7d,
                0xa3, 0xa5, 0x16, 0xc1, 0x73, 0xbe, 0x1c, 0x51, 0x33, 0x23, 0xe1, 0x19, 0xf6, 0x35,
                0xe8, 0x20, 0x9a, 0x07, 0x4b, 0x21, 0x6b, 0x70, 0x23, 0xfa, 0xdc, 0x2d, 0x25, 0x94,
                0x9c, 0x90, 0x03, 0x7e, 0x71, 0xe3, 0xe5, 0x50, 0x72, 0x6d, 0x21, 0x0a, 0x2c, 0x68,
                0x83, 0x42, 0xe5, 0x24, 0x40, 0x63, 0x5e, 0x9c, 0xc1, 0x4a, 0xfe, 0x10, 0x10, 0x26,
                0x21, 0xa9, 0xc9, 0xac, 0xcb, 0x78, 0x2e, 0x9e, 0x4a, 0x5f, 0xa8, 0x7f, 0x0a, 0x95,
                0x6f, 0x5b, 0x85, 0x50, 0x99, 0x60, 0x28, 0x5c, 0x22, 0x62, 0x7c, 0x59, 0x48, 0x3a,
                0x5a, 0x4c, 0x28, 0xcc, 0xe4, 0xb1, 0x56, 0xe5, 0x51, 0x40, 0x6a, 0x7e, 0xe8, 0x35,
                0x56, 0x56, 0xa2, 0x1e, 0x43, 0xe3, 0x8c, 0xe1, 0x29, 0xfd, 0xad, 0xb7, 0x59, 0xed,
                0xdf, 0xa0, 0x8f, 0x00, 0xfc, 0x8e, 0x56, 0x7c, 0xef, 0x93, 0xc6, 0x79, 0x2d, 0x01,
                0xdf, 0x05, 0xe6, 0xd5, 0x80, 0xf4, 0xd5, 0xd4, 0x8d, 0xf0, 0x42, 0x45, 0x1a, 0x33,
                0x59, 0x0d, 0x3e, 0x8c, 0xf4, 0x9b, 0x26, 0x27, 0x21, 0x8f, 0x0c, 0x29, 0x2f, 0xa6,
                0x6a, 0xda, 0x94, 0x5f, 0xa5, 0x5b, 0xb2, 0x35, 0x48, 0xe3, 0x3a, 0x83, 0xa5, 0x62,
                0x95, 0x7a, 0x31, 0x49, 0xa9, 0x93, 0xcc, 0x47, 0x23, 0x62, 0x29, 0x87, 0x36, 0xa8,
                0xb7, 0x78, 0xd9, 0x7c, 0xe4, 0x23, 0x01, 0x3d, 0x64, 0xb3, 0x2c, 0xd1, 0x72, 0xef,
                0xa5, 0x51, 0xbf, 0x7f, 0x36, 0x8f, 0x04, 0xbd, 0xae, 0xc6, 0x09, 0x1a, 0x30, 0x04,
                0xa7, 0x57, 0x59, 0x8b, 0x80, 0x1d, 0xcf, 0x67, 0x5c, 0xb8, 0x3e, 0x43, 0xa5, 0x3a,
                0xe8, 0xb2, 0x54, 0xd3, 0x33, 0xbc, 0xda, 0x20, 0xd4, 0x81, 0x7d, 0x34, 0x77, 0xab,
                0xfb, 0xa2, 0x5b, 0xb8, 0x3d, 0xf5, 0x94, 0x9c, 0x12, 0x6f, 0x14, 0x9b, 0x1d, 0x99,
                0x34, 0x1e, 0x4e, 0x6f,
            ],
            c_enc: [
                0xbe, 0x1d, 0xff, 0xd3, 0x37, 0x0c, 0x67, 0x56, 0x69, 0xcc, 0x9a, 0xe1, 0xd0, 0x30,
                0x2d, 0x7f, 0x90, 0x6d, 0x25, 0x23, 0x09, 0x3c, 0x24, 0xf4, 0x25, 0x7a, 0x83, 0xbc,
                0x4f, 0x36, 0x62, 0x3a, 0x08, 0x2c, 0xe6, 0xeb, 0x45, 0x21, 0x95, 0x71, 0x91, 0xd5,
                0x7e, 0x14, 0x11, 0xed, 0xe7, 0x1d, 0x44, 0xb5, 0x6c, 0x57, 0xcb, 0x22, 0x81, 0x4a,
                0x04, 0x69, 0x39, 0xd2, 0xff, 0xf9, 0x2b, 0x46, 0x62, 0x76, 0x2d, 0x4f, 0x21, 0xc0,
                0x78, 0x42, 0x74, 0x72, 0xb9, 0x18, 0x10, 0x10, 0x55, 0x56, 0xf4, 0xde, 0x0a, 0x27,
                0xe7, 0x70, 0x08, 0x47, 0x72, 0xcb, 0xfe, 0xbf, 0x87, 0xdb, 0x33, 0x14, 0xab, 0x70,
                0xf2, 0x6d, 0x11, 0xea, 0x5d, 0xe2, 0x67, 0xc3, 0xa9, 0xa8, 0xf4, 0x6b, 0xad, 0x13,
                0xc7, 0x36, 0x26, 0x10, 0xbd, 0xba, 0x81, 0x02, 0xd4, 0xb7, 0x26, 0xef, 0x26, 0xec,
                0x79, 0x4a, 0x15, 0x66, 0x57, 0x1b, 0xfd, 0xc1, 0x02, 0x47, 0x7d, 0xa5, 0xb4, 0x9b,
                0xbf, 0x9f, 0xe4, 0xb1, 0xa4, 0x4e, 0xd0, 0xb3, 0xbc, 0xed, 0x99, 0xba, 0x81, 0x9a,
                0x4f, 0x30, 0x22, 0x65, 0x49, 0x44, 0x5b, 0xc6, 0x1c, 0xff, 0x5c, 0x33, 0x16, 0x33,
                0x5f, 0x6b, 0xd4, 0xa9, 0xa4, 0x24, 0xc9, 0x4a, 0xe0, 0xb5, 0xcb, 0xe4, 0x8a, 0xfb,
                0x2b, 0x94, 0xd0, 0xc7, 0xe4, 0x4e, 0x32, 0x30, 0x95, 0xa7, 0x2e, 0x42, 0x64, 0xe9,
                0x1c, 0x48, 0x94, 0xb9, 0xe8, 0x45, 0xaf, 0x32, 0x35, 0x02, 0xda, 0xe8, 0xc1, 0x86,
                0x78, 0xa4, 0xf7, 0x40, 0xe5, 0xa6, 0x3a, 0x4c, 0x70, 0x29, 0x92, 0xfa, 0xcd, 0xd3,
                0x57, 0x35, 0xb1, 0xd1, 0x34, 0x8b, 0x91, 0x9c, 0x70, 0x0c, 0x42, 0xd3, 0x30, 0xd3,
                0x86, 0xaf, 0xb8, 0x73, 0xfa, 0xba, 0xd8, 0xcb, 0x32, 0x18, 0x15, 0x1b, 0x40, 0x18,
                0x01, 0xe3, 0x69, 0x34, 0x4f, 0xf2, 0x0a, 0xaa, 0x66, 0x73, 0x47, 0x4f, 0x4b, 0xfc,
                0x98, 0xd0, 0x7e, 0x36, 0x7b, 0xc4, 0x2e, 0xf1, 0xa0, 0x4f, 0xa1, 0xbc, 0x12, 0x52,
                0x18, 0x8d, 0xd9, 0xd3, 0xe0, 0x00, 0xe3, 0xf5, 0xe9, 0xdf, 0xc9, 0xe1, 0x3e, 0xe9,
                0xdb, 0x55, 0x04, 0x0d, 0x17, 0x22, 0x7d, 0xa4, 0x4a, 0x3e, 0x08, 0xfd, 0x5e, 0xc8,
                0x58, 0xc4, 0x9c, 0x2e, 0x6a, 0x71, 0x1f, 0x8e, 0x68, 0xd0, 0xa1, 0xdf, 0x88, 0xef,
                0x09, 0x40, 0xf7, 0x2e, 0xd7, 0x3e, 0xf4, 0x9e, 0x8a, 0x45, 0xae, 0x2e, 0x5e, 0x1b,
                0xf1, 0x37, 0xba, 0x58, 0xcf, 0xb9, 0x25, 0x79, 0xab, 0xb2, 0xa4, 0x93, 0x13, 0xa2,
                0xff, 0x3d, 0xb6, 0x16, 0x93, 0xd2, 0xb7, 0x58, 0xaf, 0x20, 0x47, 0x2a, 0xc6, 0x40,
                0x6b, 0xa3, 0x55, 0xb4, 0x8c, 0xee, 0x22, 0xe7, 0x0f, 0xb8, 0xf9, 0xd4, 0x8e, 0xa3,
                0x93, 0x4b, 0x62, 0x24, 0xac, 0xe2, 0x69, 0xb9, 0xef, 0x54, 0x6d, 0xbf, 0xc5, 0x2a,
                0xbe, 0xcf, 0xac, 0x59, 0x40, 0xf0, 0x40, 0xbd, 0x21, 0xe9, 0x0e, 0xfa, 0x82, 0x75,
                0x56, 0x1a, 0x88, 0xbc, 0x18, 0xe2, 0x6b, 0x98, 0x8d, 0x11, 0x79, 0xb7, 0xa2, 0xc3,
                0xaf, 0xd8, 0x6e, 0xf2, 0xa0, 0x90, 0x62, 0x52, 0x23, 0x23, 0x4b, 0x39, 0xc9, 0xe2,
                0x06, 0x8d, 0x94, 0x5d, 0xd7, 0x76, 0x3b, 0x01, 0x0c, 0x28, 0xc8, 0x9b, 0x72, 0xe2,
                0x55, 0x13, 0xb3, 0x9c, 0x3c, 0xe1, 0x17, 0x73, 0x42, 0x8a, 0xd3, 0x44, 0xe1, 0xd5,
                0xd5, 0x1b, 0x92, 0x00, 0x14, 0xf9, 0x17, 0x06, 0xff, 0xae, 0x3d, 0x86, 0x36, 0x14,
                0x77, 0xfd, 0x5d, 0xe0, 0x13, 0x42, 0x2c, 0x06, 0xa3, 0x32, 0xe3, 0x45, 0x79, 0x75,
                0xcf, 0x9b, 0xe9, 0xf9, 0xab, 0x3a, 0x06, 0x87, 0x2e, 0xf0, 0x71, 0x7d, 0x39, 0x08,
                0xbd, 0xeb, 0xf8, 0x41, 0x8c, 0xe5, 0x57, 0xd5, 0x2d, 0x51, 0xa2, 0x50, 0xc0, 0x8c,
                0x5b, 0x79, 0x3a, 0xd4, 0xbc, 0x0f, 0x16, 0xc6, 0x27, 0x89, 0xfe, 0xa2, 0xca, 0xb3,
                0x9c, 0xcc, 0xa4, 0x07, 0xee, 0x9e, 0x47, 0xf5, 0x6d, 0x20, 0xa7, 0x41, 0x91, 0x2c,
                0x6b, 0xad, 0xdb, 0xd7, 0xfa, 0x7b, 0x97, 0xe5, 0x46, 0x33, 0x61, 0x28, 0x74, 0x5a,
                0xe7, 0xd7, 0x30, 0xa5, 0x5a, 0x6a, 0xc7, 0xb8, 0xfc, 0xbd, 0x72, 0xce, 0x78, 0x95,
                0x9c, 0x7a, 0x79, 0x75, 0x21, 0x2c,
            ],
            ock: [
                0xeb, 0x3e, 0xd9, 0xfc, 0xb3, 0xaa, 0x91, 0xc4, 0xf5, 0xec, 0xfd, 0x43, 0xdb, 0xda,
                0x40, 0x33, 0x06, 0x93, 0xc3, 0xa6, 0x56, 0x75, 0x45, 0xfd, 0x23, 0x6a, 0xf1, 0x90,
                0x8e, 0x29, 0x42, 0xa3,
            ],
            op: [
                0x3f, 0xeb, 0x34, 0x5a, 0xec, 0xd3, 0x42, 0x9a, 0x16, 0xe1, 0x0f, 0x3d, 0x13, 0x20,
                0xbc, 0x99, 0x71, 0xb5, 0x9e, 0x63, 0x9d, 0x62, 0xb6, 0x96, 0x1a, 0xea, 0x78, 0x15,
                0x67, 0xa8, 0x60, 0x9e, 0x3b, 0xc1, 0x7a, 0x58, 0x0d, 0x53, 0x0f, 0x89, 0x30, 0xa3,
                0x6b, 0x8d, 0x6f, 0xea, 0x67, 0x85, 0x7f, 0x7b, 0x85, 0x20, 0xfd, 0x2e, 0x0a, 0xb5,
                0xd5, 0xcb, 0xab, 0x1a, 0xcc, 0xd5, 0x4e, 0x3a,
            ],
            c_out: [
                0x60, 0xf3, 0xe8, 0x94, 0xe3, 0x86, 0x4e, 0xfb, 0x48, 0xcc, 0xae, 0x50, 0xe1, 0x0d,
                0xa7, 0x73, 0xdc, 0xcf, 0x85, 0x62, 0x45, 0x5d, 0x1b, 0x73, 0x1a, 0xad, 0x44, 0xe1,
                0x5e, 0x3e, 0x40, 0x18, 0x31, 0xce, 0x6f, 0x92, 0xf4, 0x53, 0x2d, 0x90, 0x83, 0x92,
                0x59, 0xce, 0x9c, 0xb1, 0x44, 0x62, 0x1f, 0x12, 0x01, 0x77, 0x8f, 0x61, 0x5d, 0x09,
                0x87, 0x01, 0x0c, 0x8d, 0x13, 0x5c, 0x32, 0xd5, 0x6e, 0xe2, 0x84, 0x68, 0x65, 0xa2,
                0x61, 0xde, 0x14, 0x25, 0xd2, 0x3b, 0xcc, 0x51, 0xb8, 0xa0,
            ],
        },
        TestVector {
            incoming_viewing_key: [
                0xc3, 0x7c, 0x7d, 0xbb, 0xe5, 0x51, 0xd9, 0xd3, 0xb1, 0xa4, 0x96, 0x88, 0x7d, 0xb2,
                0xe8, 0x42, 0xdc, 0x94, 0x52, 0x01, 0xf4, 0x08, 0x10, 0xdf, 0x4d, 0x76, 0x39, 0x32,
                0xed, 0x5c, 0x76, 0x39, 0x8b, 0x35, 0x73, 0xfe, 0x23, 0xf1, 0xe8, 0xb7, 0xe7, 0x9f,
                0x1c, 0x16, 0x95, 0xc0, 0x97, 0xc1, 0x24, 0xff, 0x1f, 0x7d, 0x6e, 0x61, 0xf2, 0xc5,
                0x8f, 0x14, 0x39, 0xa7, 0x56, 0x96, 0x9d, 0x19,
            ],
            ovk: [
                0xa6, 0x68, 0xa0, 0xae, 0x2b, 0xb9, 0x34, 0xc8, 0x2c, 0x41, 0x42, 0xda, 0x69, 0xd1,
                0x2c, 0xa7, 0xde, 0x9a, 0x7d, 0xf7, 0x06, 0x40, 0x0e, 0xc7, 0x98, 0x78, 0xd8, 0x68,
                0xe1, 0x7e, 0x8f, 0x71,
            ],
            default_d: [
                0x56, 0x4f, 0xc3, 0x81, 0xfc, 0x4d, 0xc8, 0x11, 0x8d, 0xe4, 0x7c,
            ],
            default_pk_d: [
                0xae, 0xee, 0xa5, 0x0c, 0x6b, 0xb0, 0x2e, 0x5e, 0x22, 0x4d, 0xc2, 0x95, 0x9c, 0x22,
                0x9d, 0x0e, 0x3b, 0xb8, 0x79, 0xc4, 0xab, 0x00, 0xaa, 0x0a, 0xb2, 0x5a, 0x40, 0x10,
                0x6b, 0x80, 0xbb, 0xb7,
            ],
            v: 11137853725062838288,
            rseed: [
                0x25, 0x37, 0xb8, 0x71, 0xb4, 0x29, 0x4a, 0x65, 0xd3, 0xe0, 0x55, 0xff, 0x71, 0x8d,
                0xd9, 0xdc, 0x8c, 0x75, 0xe7, 0xe5, 0xb2, 0xef, 0xe4, 0x42, 0x63, 0x73, 0x71, 0xb7,
                0xc4, 0x8f, 0x6e, 0xe9,
            ],
            memo: [
                0xff, 0x9e, 0x3e, 0xa3, 0x8a, 0x4b, 0x0f, 0x2f, 0x67, 0xfc, 0x2b, 0x90, 0x8c, 0xda,
                0x65, 0x7e, 0xae, 0x75, 0x4e, 0x03, 0x7e, 0x26, 0x2e, 0x9a, 0x9f, 0x9b, 0xd7, 0xec,
                0x42, 0x67, 0xed, 0x8e, 0x96, 0x93, 0x0e, 0x10, 0x84, 0x78, 0x3c, 0x37, 0xd6, 0xf9,
                0xdd, 0x15, 0xfd, 0x29, 0xf4, 0xcc, 0x47, 0x7e, 0x66, 0xf1, 0x30, 0xd6, 0x30, 0x43,
                0x0d, 0xcc, 0x01, 0x04, 0x89, 0x9b, 0x4f, 0x9f, 0x46, 0xeb, 0x09, 0x0e, 0xf7, 0xfc,
                0x90, 0xb4, 0x79, 0xab, 0xf6, 0x1f, 0x93, 0x95, 0x5e, 0xe0, 0x0e, 0x6a, 0x18, 0x48,
                0xf1, 0xab, 0x14, 0xad, 0x33, 0x4f, 0x2b, 0x68, 0x03, 0x58, 0x08, 0xcd, 0xf1, 0xbb,
                0x9e, 0x9d, 0x9a, 0x81, 0x6b, 0xaf, 0x72, 0x8a, 0x95, 0x5b, 0x96, 0x0b, 0x77, 0x01,
                0xfa, 0x62, 0x66, 0x87, 0xdc, 0x3c, 0x9c, 0xba, 0x64, 0x63, 0x37, 0xb5, 0x3e, 0x29,
                0x81, 0x6e, 0x94, 0x82, 0xdd, 0xf5, 0x57, 0x8a, 0x87, 0x68, 0xaa, 0xe4, 0x77, 0xfc,
                0xe4, 0x10, 0xac, 0x2d, 0x5d, 0xe6, 0x09, 0x58, 0x61, 0xc1, 0x11, 0xd7, 0xfe, 0xb3,
                0xe6, 0xbb, 0x4f, 0xbb, 0x5a, 0x54, 0x95, 0x54, 0x95, 0x97, 0x27, 0x98, 0x35, 0x0a,
                0x25, 0x3f, 0x05, 0xf6, 0x6c, 0x2e, 0xcf, 0xcb, 0xc0, 0xed, 0x43, 0xf5, 0xec, 0x2e,
                0x6d, 0x8d, 0xba, 0x15, 0xa5, 0x12, 0x54, 0xd9, 0x7b, 0x18, 0x21, 0x10, 0x7c, 0x07,
                0xdd, 0x9a, 0x16, 0xef, 0x84, 0x06, 0xf9, 0x43, 0xe2, 0x82, 0xb9, 0x5d, 0x4b, 0x36,
                0x25, 0x30, 0xc9, 0x13, 0xd6, 0xba, 0x42, 0x1d, 0xf6, 0x02, 0x7d, 0xe5, 0xaf, 0x1e,
                0x47, 0x45, 0xd5, 0x86, 0x81, 0x06, 0x95, 0x4b, 0xe6, 0xc1, 0x96, 0x27, 0x80, 0xa2,
                0x94, 0x10, 0x72, 0xe9, 0x51, 0x31, 0xb1, 0x67, 0x9d, 0xf0, 0x63, 0x76, 0x25, 0x04,
                0x2c, 0x37, 0xd4, 0x8f, 0xfb, 0x15, 0x2e, 0x5e, 0xbc, 0x18, 0x5c, 0x8a, 0x2b, 0x7d,
                0x43, 0x85, 0xf1, 0xc9, 0x5a, 0xf9, 0x37, 0xdf, 0x78, 0xdf, 0xd8, 0x75, 0x7f, 0xab,
                0x43, 0x49, 0x68, 0xb0, 0xb5, 0x7c, 0x66, 0x57, 0x44, 0x68, 0xf1, 0x60, 0xb4, 0x47,
                0xac, 0x82, 0x21, 0xe5, 0x06, 0x06, 0x76, 0xa8, 0x42, 0xa1, 0xc6, 0xb7, 0x17, 0x2d,
                0xd3, 0x34, 0x0f, 0x76, 0x40, 0x70, 0xab, 0x1f, 0xe0, 0x91, 0xc5, 0xc7, 0x4c, 0x95,
                0xa5, 0xdc, 0x04, 0x33, 0x90, 0x72, 0x3a, 0x4c, 0x12, 0x7d, 0xa1, 0x4c, 0xdd, 0xe1,
                0xdc, 0x26, 0x75, 0xa6, 0x23, 0x40, 0xb3, 0xe6, 0xaf, 0xd0, 0x52, 0x2a, 0x31, 0xde,
                0x26, 0xe7, 0xd1, 0xec, 0x3a, 0x9c, 0x8a, 0x09, 0x1f, 0xfd, 0xc7, 0x5b, 0x7e, 0xcf,
                0xdc, 0x7c, 0x12, 0x99, 0x5a, 0x5e, 0x37, 0xce, 0x34, 0x88, 0xbd, 0x29, 0xf8, 0x62,
                0x9d, 0x68, 0xf6, 0x96, 0x49, 0x24, 0x48, 0xdd, 0x52, 0x66, 0x97, 0x47, 0x6d, 0xc0,
                0x61, 0x34, 0x6e, 0xbe, 0x3f, 0x67, 0x72, 0x17, 0xff, 0x9c, 0x60, 0xef, 0xce, 0x94,
                0x3a, 0xf2, 0x8d, 0xfd, 0x3f, 0x9e, 0x59, 0x69, 0x25, 0x98, 0xa6, 0x04, 0x7c, 0x23,
                0xc4, 0xc0, 0x14, 0x00, 0xf1, 0xab, 0x57, 0x30, 0xea, 0xc0, 0xae, 0x8d, 0x58, 0x43,
                0xd5, 0x05, 0x1c, 0x37, 0x62, 0x40, 0x17, 0x2a, 0xf2, 0x18, 0xd7, 0xa1, 0xec, 0xfe,
                0x65, 0xb4, 0xf7, 0x51, 0x00, 0x63, 0x89, 0x83, 0xc1, 0x4d, 0xe4, 0x97, 0x47, 0x55,
                0xda, 0xde, 0x80, 0x18, 0xc9, 0xb8, 0xf4, 0x54, 0x3f, 0xb0, 0x95, 0x96, 0x15, 0x13,
                0xe6, 0x7c, 0x61, 0xdb, 0xc5, 0x9c, 0x60, 0x7f, 0x9b, 0x51, 0xf8, 0xd0, 0x9b, 0xdc,
                0xad, 0x28, 0xbc, 0xfb, 0x9e, 0x5d, 0x27, 0x44, 0xea, 0x88, 0x48, 0xb2, 0x62, 0x3a,
                0xc0, 0x7f, 0x8e, 0xf6, 0x1a, 0x81, 0xa3, 0x59,
            ],
            cv_net: [
                0xb2, 0x7f, 0x48, 0x59, 0x15, 0x0d, 0x48, 0x45, 0xab, 0x57, 0x78, 0x82, 0x61, 0x50,
                0x0a, 0x12, 0x01, 0x2d, 0x63, 0xc0, 0x09, 0xc6, 0x77, 0x44, 0xba, 0xe0, 0xd5, 0x83,
                0x88, 0xff, 0xee, 0x2f,
            ],
            rho: [
                0x54, 0x3e, 0xa7, 0x11, 0x56, 0xc9, 0xa6, 0xf8, 0x04, 0x1f, 0xa7, 0x7e, 0xc1, 0xc5,
                0xaf, 0x90, 0x28, 0x8f, 0x27, 0x20, 0xf1, 0x3f, 0xf0, 0x93, 0xc6, 0x86, 0x26, 0x6b,
                0x92, 0xd7, 0xa0, 0x24,
            ],
            cmx: [
                0x1d, 0x51, 0xea, 0x92, 0xfa, 0x43, 0x55, 0x0a, 0x0e, 0xdd, 0xea, 0x23, 0x6e, 0x17,
                0xa0, 0x16, 0x93, 0xc2, 0x2d, 0x8d, 0xd8, 0x1c, 0x9c, 0x9e, 0xc8, 0x76, 0xa2, 0x4e,
                0x67, 0xd4, 0x93, 0x0b,
            ],
            esk: [
                0x19, 0xe0, 0x26, 0x4b, 0x82, 0x88, 0xf7, 0x3e, 0xbf, 0x97, 0x14, 0xb0, 0xdf, 0x85,
                0x8e, 0xf7, 0xab, 0x39, 0xec, 0x50, 0x2c, 0xd2, 0x98, 0xf2, 0xc4, 0x84, 0xa9, 0xf4,
                0xc7, 0xda, 0x74, 0x36,
            ],
            ephemeral_key: [
                0x8f, 0xbe, 0xb6, 0xb3, 0x03, 0x8e, 0x69, 0x49, 0x91, 0x6a, 0x2c, 0x06, 0x0e, 0xf9,
                0xa4, 0xb1, 0xfe, 0xf1, 0x3a, 0xce, 0x2f, 0xee, 0x00, 0x25, 0xda, 0x32, 0xc3, 0x6d,
                0x23, 0x1a, 0x61, 0x34,
            ],
            shared_secret: [
                0x67, 0xd6, 0x8a, 0x5a, 0x05, 0x93, 0xfd, 0x16, 0x7d, 0x38, 0x08, 0x2e, 0x49, 0xd2,
                0x30, 0x30, 0x86, 0xe5, 0x5a, 0x43, 0xc1, 0x24, 0xd5, 0xaa, 0xa8, 0x20, 0xab, 0x0c,
                0x3f, 0x5c, 0xc5, 0x37,
            ],
            k_enc: [
                0x6b, 0x8d, 0x83, 0xf2, 0xf1, 0xfd, 0x1e, 0xad, 0x7d, 0x45, 0x42, 0xb3, 0x63, 0x09,
                0x34, 0x07, 0xc5, 0x0a, 0x20, 0xed, 0x7f, 0x0e, 0x8c, 0xf2, 0xdb, 0x53, 0x6d, 0xb1,
                0xbe, 0x25, 0xe9, 0x8d,
            ],
            p_enc: [
                0x02, 0x56, 0x4f, 0xc3, 0x81, 0xfc, 0x4d, 0xc8, 0x11, 0x8d, 0xe4, 0x7c, 0x10, 0xb8,
                0xa1, 0xba, 0xf3, 0x9a, 0x91, 0x9a, 0x25, 0x37, 0xb8, 0x71, 0xb4, 0x29, 0x4a, 0x65,
                0xd3, 0xe0, 0x55, 0xff, 0x71, 0x8d, 0xd9, 0xdc, 0x8c, 0x75, 0xe7, 0xe5, 0xb2, 0xef,
                0xe4, 0x42, 0x63, 0x73, 0x71, 0xb7, 0xc4, 0x8f, 0x6e, 0xe9, 0xff, 0x9e, 0x3e, 0xa3,
                0x8a, 0x4b, 0x0f, 0x2f, 0x67, 0xfc, 0x2b, 0x90, 0x8c, 0xda, 0x65, 0x7e, 0xae, 0x75,
                0x4e, 0x03, 0x7e, 0x26, 0x2e, 0x9a, 0x9f, 0x9b, 0xd7, 0xec, 0x42, 0x67, 0xed, 0x8e,
                0x96, 0x93, 0x0e, 0x10, 0x84, 0x78, 0x3c, 0x37, 0xd6, 0xf9, 0xdd, 0x15, 0xfd, 0x29,
                0xf4, 0xcc, 0x47, 0x7e, 0x66, 0xf1, 0x30, 0xd6, 0x30, 0x43, 0x0d, 0xcc, 0x01, 0x04,
                0x89, 0x9b, 0x4f, 0x9f, 0x46, 0xeb, 0x09, 0x0e, 0xf7, 0xfc, 0x90, 0xb4, 0x79, 0xab,
                0xf6, 0x1f, 0x93, 0x95, 0x5e, 0xe0, 0x0e, 0x6a, 0x18, 0x48, 0xf1, 0xab, 0x14, 0xad,
                0x33, 0x4f, 0x2b, 0x68, 0x03, 0x58, 0x08, 0xcd, 0xf1, 0xbb, 0x9e, 0x9d, 0x9a, 0x81,
                0x6b, 0xaf, 0x72, 0x8a, 0x95, 0x5b, 0x96, 0x0b, 0x77, 0x01, 0xfa, 0x62, 0x66, 0x87,
                0xdc, 0x3c, 0x9c, 0xba, 0x64, 0x63, 0x37, 0xb5, 0x3e, 0x29, 0x81, 0x6e, 0x94, 0x82,
                0xdd, 0xf5, 0x57, 0x8a, 0x87, 0x68, 0xaa, 0xe4, 0x77, 0xfc, 0xe4, 0x10, 0xac, 0x2d,
                0x5d, 0xe6, 0x09, 0x58, 0x61, 0xc1, 0x11, 0xd7, 0xfe, 0xb3, 0xe6, 0xbb, 0x4f, 0xbb,
                0x5a, 0x54, 0x95, 0x54, 0x95, 0x97, 0x27, 0x98, 0x35, 0x0a, 0x25, 0x3f, 0x05, 0xf6,
                0x6c, 0x2e, 0xcf, 0xcb, 0xc0, 0xed, 0x43, 0xf5, 0xec, 0x2e, 0x6d, 0x8d, 0xba, 0x15,
                0xa5, 0x12, 0x54, 0xd9, 0x7b, 0x18, 0x21, 0x10, 0x7c, 0x07, 0xdd, 0x9a, 0x16, 0xef,
                0x84, 0x06, 0xf9, 0x43, 0xe2, 0x82, 0xb9, 0x5d, 0x4b, 0x36, 0x25, 0x30, 0xc9, 0x13,
                0xd6, 0xba, 0x42, 0x1d, 0xf6, 0x02, 0x7d, 0xe5, 0xaf, 0x1e, 0x47, 0x45, 0xd5, 0x86,
                0x81, 0x06, 0x95, 0x4b, 0xe6, 0xc1, 0x96, 0x27, 0x80, 0xa2, 0x94, 0x10, 0x72, 0xe9,
                0x51, 0x31, 0xb1, 0x67, 0x9d, 0xf0, 0x63, 0x76, 0x25, 0x04, 0x2c, 0x37, 0xd4, 0x8f,
                0xfb, 0x15, 0x2e, 0x5e, 0xbc, 0x18, 0x5c, 0x8a, 0x2b, 0x7d, 0x43, 0x85, 0xf1, 0xc9,
                0x5a, 0xf9, 0x37, 0xdf, 0x78, 0xdf, 0xd8, 0x75, 0x7f, 0xab, 0x43, 0x49, 0x68, 0xb0,
                0xb5, 0x7c, 0x66, 0x57, 0x44, 0x68, 0xf1, 0x60, 0xb4, 0x47, 0xac, 0x82, 0x21, 0xe5,
                0x06, 0x06, 0x76, 0xa8, 0x42, 0xa1, 0xc6, 0xb7, 0x17, 0x2d, 0xd3, 0x34, 0x0f, 0x76,
                0x40, 0x70, 0xab, 0x1f, 0xe0, 0x91, 0xc5, 0xc7, 0x4c, 0x95, 0xa5, 0xdc, 0x04, 0x33,
                0x90, 0x72, 0x3a, 0x4c, 0x12, 0x7d, 0xa1, 0x4c, 0xdd, 0xe1, 0xdc, 0x26, 0x75, 0xa6,
                0x23, 0x40, 0xb3, 0xe6, 0xaf, 0xd0, 0x52, 0x2a, 0x31, 0xde, 0x26, 0xe7, 0xd1, 0xec,
                0x3a, 0x9c, 0x8a, 0x09, 0x1f, 0xfd, 0xc7, 0x5b, 0x7e, 0xcf, 0xdc, 0x7c, 0x12, 0x99,
                0x5a, 0x5e, 0x37, 0xce, 0x34, 0x88, 0xbd, 0x29, 0xf8, 0x62, 0x9d, 0x68, 0xf6, 0x96,
                0x49, 0x24, 0x48, 0xdd, 0x52, 0x66, 0x97, 0x47, 0x6d, 0xc0, 0x61, 0x34, 0x6e, 0xbe,
                0x3f, 0x67, 0x72, 0x17, 0xff, 0x9c, 0x60, 0xef, 0xce, 0x94, 0x3a, 0xf2, 0x8d, 0xfd,
                0x3f, 0x9e, 0x59, 0x69, 0x25, 0x98, 0xa6, 0x04, 0x7c, 0x23, 0xc4, 0xc0, 0x14, 0x00,
                0xf1, 0xab, 0x57, 0x30, 0xea, 0xc0, 0xae, 0x8d, 0x58, 0x43, 0xd5, 0x05, 0x1c, 0x37,
                0x62, 0x40, 0x17, 0x2a, 0xf2, 0x18, 0xd7, 0xa1, 0xec, 0xfe, 0x65, 0xb4, 0xf7, 0x51,
                0x00, 0x63, 0x89, 0x83, 0xc1, 0x4d, 0xe4, 0x97, 0x47, 0x55, 0xda, 0xde, 0x80, 0x18,
                0xc9, 0xb8, 0xf4, 0x54, 0x3f, 0xb0, 0x95, 0x96, 0x15, 0x13, 0xe6, 0x7c, 0x61, 0xdb,
                0xc5, 0x9c, 0x60, 0x7f, 0x9b, 0x51, 0xf8, 0xd0, 0x9b, 0xdc, 0xad, 0x28, 0xbc, 0xfb,
                0x9e, 0x5d, 0x27, 0x44, 0xea, 0x88, 0x48, 0xb2, 0x62, 0x3a, 0xc0, 0x7f, 0x8e, 0xf6,
                0x1a, 0x81, 0xa3, 0x59,
            ],
            c_enc: [
                0x77, 0xc6, 0xef, 0xc8, 0xb5, 0x42, 0xa7, 0x07, 0xc0, 0xa5, 0xcf, 0x5c, 0xe3, 0xf3,
                0xb9, 0x6d, 0xe1, 0x91, 0x95, 0x7c, 0x9f, 0xa6, 0xe9, 0xbb, 0x4b, 0x8d, 0x89, 0x9e,
                0x1f, 0x19, 0xe0, 0x20, 0xba, 0x7b, 0xb3, 0xfe, 0xf1, 0x67, 0x81, 0xc8, 0x8c, 0xc5,
                0xd4, 0x4a, 0x5e, 0xf8, 0x17, 0x31, 0x47, 0xdc, 0x3d, 0x1b, 0x51, 0x6a, 0xf6, 0xdd,
                0x77, 0xdd, 0xb6, 0xee, 0x67, 0xaa, 0xf5, 0x42, 0xce, 0xe2, 0xbe, 0xd3, 0xe4, 0xa0,
                0x7e, 0xce, 0x42, 0x8f, 0x22, 0xa8, 0x01, 0xcf, 0x01, 0xba, 0xad, 0x18, 0x27, 0xfd,
                0x42, 0x57, 0x46, 0xc5, 0x45, 0x00, 0x1c, 0x35, 0x6d, 0x0a, 0xbe, 0xaa, 0xa5, 0xa4,
                0x22, 0xdf, 0xff, 0x0e, 0xe2, 0x18, 0xac, 0x37, 0xef, 0x83, 0x97, 0xc6, 0x2c, 0xa8,
                0x6f, 0xab, 0xeb, 0xb6, 0x88, 0xb3, 0x8f, 0xb4, 0xa6, 0x54, 0x29, 0x11, 0xbe, 0x1c,
                0x5e, 0x71, 0x77, 0x8b, 0x5e, 0xb5, 0x3a, 0xf1, 0xc4, 0xcb, 0x4d, 0xd9, 0x94, 0x72,
                0x4f, 0x61, 0x0f, 0x38, 0x72, 0x4a, 0x73, 0xdf, 0x09, 0x2b, 0xea, 0xe8, 0xb8, 0x7f,
                0x7f, 0x6a, 0x2b, 0xc0, 0x9d, 0xf2, 0xaa, 0x18, 0xc2, 0xf8, 0xee, 0xba, 0x63, 0xee,
                0x0d, 0x31, 0x35, 0x3b, 0x6f, 0x28, 0x3e, 0xf5, 0x9a, 0xc1, 0x53, 0x60, 0x73, 0xda,
                0x7a, 0x6d, 0x82, 0xbf, 0xdc, 0x09, 0x74, 0x02, 0x08, 0x0f, 0xa1, 0x03, 0xcb, 0x8b,
                0x3e, 0xfb, 0x94, 0x1e, 0xe5, 0x01, 0xf6, 0x41, 0x2c, 0xfb, 0xc2, 0x50, 0xaf, 0xad,
                0xbe, 0x54, 0x4a, 0xc5, 0x1f, 0xce, 0x41, 0x5a, 0x24, 0x93, 0xba, 0x83, 0x9e, 0x38,
                0x18, 0xb0, 0xfe, 0x30, 0x18, 0xbf, 0xa4, 0x37, 0xf0, 0x6e, 0x31, 0x86, 0x14, 0x8a,
                0xa4, 0x05, 0xba, 0xb8, 0x21, 0xa2, 0x6e, 0xa0, 0x7f, 0x93, 0xcf, 0xe7, 0x56, 0x8f,
                0xe3, 0xef, 0x08, 0xfa, 0x0b, 0x80, 0xfc, 0xec, 0x5b, 0xd5, 0x91, 0x5f, 0x68, 0x8c,
                0xf5, 0x99, 0x31, 0x5e, 0x79, 0xaa, 0xea, 0x34, 0xd5, 0x18, 0xd9, 0x55, 0xfe, 0xef,
                0x30, 0x3f, 0x69, 0xb2, 0x87, 0xc6, 0xd0, 0x51, 0x6d, 0xa2, 0x39, 0xfb, 0xbd, 0xdb,
                0xaf, 0x25, 0x56, 0xeb, 0xce, 0x77, 0xa3, 0xd5, 0x97, 0x23, 0x5c, 0x22, 0xd3, 0x8c,
                0x5b, 0x5e, 0xeb, 0x98, 0xc7, 0xc0, 0x8d, 0xa8, 0xd3, 0x76, 0xbb, 0xa1, 0xb5, 0x07,
                0x85, 0xbe, 0x82, 0xbf, 0xe0, 0x9a, 0xe7, 0x1c, 0xcc, 0xaf, 0x31, 0xa2, 0xf0, 0xcf,
                0xa0, 0x76, 0xd1, 0xe4, 0xd1, 0xb5, 0x2f, 0xee, 0x45, 0xc8, 0xed, 0x23, 0xdf, 0x33,
                0xa8, 0x1c, 0xb1, 0xa8, 0xac, 0xec, 0x9f, 0x53, 0x5d, 0xa4, 0x96, 0x70, 0xf9, 0x98,
                0x6d, 0x5c, 0x92, 0xc8, 0x2b, 0x0a, 0xd2, 0x20, 0xf8, 0x5f, 0x3b, 0x38, 0x72, 0xeb,
                0xe0, 0x53, 0xcd, 0xeb, 0x96, 0x1b, 0xd2, 0xd3, 0xab, 0x3b, 0xcd, 0x67, 0x6e, 0x6f,
                0xd7, 0xcb, 0xe9, 0x79, 0x5e, 0x1f, 0x2d, 0x82, 0x87, 0x00, 0x7c, 0x91, 0x0e, 0x7b,
                0x43, 0x01, 0x69, 0xe4, 0x51, 0xf0, 0xb2, 0xd7, 0x63, 0xe5, 0x43, 0x03, 0x3b, 0xc6,
                0xc7, 0x38, 0x9f, 0xa1, 0x61, 0x5b, 0xa1, 0x9d, 0x1f, 0x27, 0x48, 0xb2, 0x17, 0xc9,
                0x60, 0xfe, 0x05, 0x04, 0x07, 0xc8, 0xf4, 0x73, 0x35, 0x6b, 0xaa, 0x6e, 0x0c, 0x7d,
                0x77, 0xfa, 0xc6, 0xc7, 0xdb, 0x45, 0x12, 0xaf, 0x57, 0x96, 0xb3, 0xbc, 0xf1, 0x23,
                0xe0, 0x90, 0xb9, 0x80, 0xeb, 0xc2, 0xd6, 0x4b, 0x86, 0xdd, 0x24, 0xcb, 0x9a, 0x6d,
                0xab, 0x1d, 0xb4, 0x13, 0x04, 0x75, 0x38, 0x90, 0x2e, 0x2e, 0x49, 0x0e, 0x4f, 0xc8,
                0x78, 0xaa, 0x04, 0xdb, 0xef, 0x66, 0x99, 0x63, 0x9c, 0x3d, 0xab, 0x17, 0xc5, 0x14,
                0x70, 0x48, 0xac, 0x6d, 0x48, 0x49, 0x0d, 0xc4, 0x88, 0x5e, 0xd9, 0x86, 0x70, 0x63,
                0x35, 0xf4, 0x1b, 0xa4, 0x15, 0x59, 0x65, 0x9e, 0x1b, 0x53, 0xda, 0x76, 0x51, 0x4c,
                0xc4, 0x0a, 0xdb, 0x66, 0xc3, 0x5c, 0xe5, 0x6f, 0x3a, 0xbe, 0x39, 0xe1, 0xae, 0xe5,
                0x84, 0x9f, 0xff, 0xcc, 0x6e, 0x1f, 0x1b, 0xf8, 0x11, 0xce, 0xb6, 0x65, 0xa6, 0xfc,
                0xf8, 0x80, 0x6b, 0xbb, 0xba, 0x4a, 0x5b, 0x87, 0x38, 0xa1, 0x17, 0xdc, 0xaf, 0xfb,
                0x4f, 0xdf, 0x10, 0x08, 0x00, 0x6f,
            ],
            ock: [
                0xb4, 0xf8, 0x8a, 0x29, 0x2d, 0x09, 0xd9, 0x35, 0xb4, 0x77, 0x5a, 0x29, 0x30, 0xeb,
                0x38, 0xce, 0xbd, 0x5a, 0xf6, 0xff, 0x3f, 0x39, 0xef, 0x5b, 0xb2, 0x4c, 0xd5, 0x72,
                0x81, 0xf0, 0x8c, 0xfb,
            ],
            op: [
                0xae, 0xee, 0xa5, 0x0c, 0x6b, 0xb0, 0x2e, 0x5e, 0x22, 0x4d, 0xc2, 0x95, 0x9c, 0x22,
                0x9d, 0x0e, 0x3b, 0xb8, 0x79, 0xc4, 0xab, 0x00, 0xaa, 0x0a, 0xb2, 0x5a, 0x40, 0x10,
                0x6b, 0x80, 0xbb, 0xb7, 0x19, 0xe0, 0x26, 0x4b, 0x82, 0x88, 0xf7, 0x3e, 0xbf, 0x97,
                0x14, 0xb0, 0xdf, 0x85, 0x8e, 0xf7, 0xab, 0x39, 0xec, 0x50, 0x2c, 0xd2, 0x98, 0xf2,
                0xc4, 0x84, 0xa9, 0xf4, 0xc7, 0xda, 0x74, 0x36,
            ],
            c_out: [
                0x94, 0xe3, 0x7f, 0xd6, 0x62, 0x82, 0xc0, 0x2e, 0x90, 0xe7, 0x69, 0x91, 0x4c, 0xaf,
                0x95, 0xa4, 0x95, 0xf4, 0x89, 0x7f, 0x55, 0xa5, 0xae, 0x95, 0xad, 0xe8, 0xbf, 0x67,
                0x61, 0xe3, 0x1b, 0xa5, 0xd1, 0xcf, 0xeb, 0x30, 0x6f, 0x4e, 0x22, 0x01, 0x42, 0x51,
                0xcb, 0xe3, 0xf8, 0x72, 0x4b, 0xe7, 0x69, 0x21, 0xe2, 0xad, 0xa4, 0x6e, 0x3b, 0x14,
                0x5d, 0x1b, 0x04, 0x3e, 0xb1, 0x2a, 0x0e, 0xfa, 0xb5, 0x16, 0x09, 0x34, 0xbc, 0x75,
                0x9e, 0x02, 0x01, 0xd8, 0x66, 0xad, 0xa7, 0x44, 0x35, 0x71,
            ],
        },
        TestVector {
            incoming_viewing_key: [
                0x74, 0xa8, 0x41, 0x1a, 0x20, 0xbc, 0x3c, 0x53, 0xf7, 0xe7, 0xab, 0xb9, 0x31, 0x6c,
                0x44, 0x2b, 0x4b, 0x09, 0xcf, 0x88, 0xbb, 0xed, 0x4a, 0x90, 0xb9, 0x2f, 0x5a, 0x1c,
                0xed, 0x93, 0x16, 0x2b, 0xc3, 0x37, 0x34, 0x67, 0x20, 0xec, 0x0c, 0xd0, 0xea, 0x73,
                0x5d, 0x9e, 0x32, 0x3f, 0x20, 0xdb, 0x77, 0x8a, 0xd1, 0x8a, 0x84, 0xc7, 0x9e, 0xe6,
                0x28, 0x77, 0x99, 0xef, 0x02, 0x76, 0x41, 0x07,
            ],
            ovk: [
                0x0c, 0x81, 0x1e, 0x4c, 0x31, 0xfb, 0xb4, 0x9f, 0x3a, 0x90, 0xbb, 0xd0, 0x5d, 0xce,
                0x62, 0xf3, 0x44, 0xe7, 0x07, 0x75, 0x93, 0x15, 0x9a, 0xe3, 0x50, 0x50, 0xb0, 0x4c,
                0x9e, 0x6b, 0x86, 0xbc,
            ],
            default_d: [
                0xc6, 0xe8, 0xf0, 0xd5, 0x0a, 0xe8, 0x05, 0x87, 0x91, 0xdc, 0x0e,
            ],
            default_pk_d: [
                0x8e, 0x66, 0xb7, 0x92, 0xec, 0xb1, 0x56, 0xef, 0x68, 0x5e, 0xe8, 0xea, 0x35, 0xd3,
                0x82, 0x75, 0x8b, 0xa4, 0x15, 0x97, 0xa3, 0x3a, 0x93, 0xba, 0xf3, 0x81, 0xd6, 0x3c,
                0x17, 0x5b, 0xa9, 0x8b,
            ],
            v: 7387862906040043846,
            rseed: [
                0x25, 0x01, 0xe5, 0x1b, 0x01, 0x2a, 0xea, 0x94, 0x46, 0xa2, 0x10, 0x4e, 0x93, 0xf8,
                0x15, 0xa0, 0xb3, 0xa2, 0x9b, 0x45, 0x83, 0x14, 0xf3, 0xd8, 0xbe, 0x2b, 0x98, 0x23,
                0xd3, 0x42, 0xf4, 0x62,
            ],
            memo: [
                0xff, 0x13, 0xe9, 0x42, 0xa7, 0xe1, 0x9a, 0x46, 0xe9, 0x70, 0xb5, 0xc5, 0x06, 0x70,
                0x84, 0x30, 0x31, 0x7b, 0x1b, 0xb3, 0xb3, 0x5d, 0xf6, 0x8a, 0xe3, 0x3a, 0x49, 0x26,
                0xa0, 0x3e, 0x6b, 0xfe, 0xb5, 0x51, 0x04, 0x16, 0xfc, 0xbb, 0x05, 0x24, 0xc9, 0xca,
                0x50, 0x74, 0x15, 0x6c, 0xc5, 0xa5, 0xd6, 0xfe, 0x1c, 0x99, 0x5e, 0xdc, 0x60, 0xa2,
                0xf5, 0x50, 0x41, 0x1a, 0xa4, 0x1e, 0x3d, 0xa3, 0xbd, 0xcf, 0x64, 0xbc, 0xf0, 0x4a,
                0x05, 0x10, 0x57, 0x1b, 0x93, 0x6d, 0x47, 0xe5, 0x5c, 0xec, 0x03, 0x30, 0xee, 0x8d,
                0xfe, 0x73, 0x56, 0x34, 0x04, 0xf0, 0x47, 0xd7, 0xf3, 0xa8, 0xa3, 0xd7, 0x74, 0x3b,
                0xc5, 0x54, 0x95, 0x52, 0x10, 0xf1, 0xeb, 0x0d, 0x08, 0x59, 0x9e, 0xa7, 0x7d, 0x5f,
                0x97, 0x4d, 0x87, 0x17, 0x6d, 0x37, 0xd9, 0x8b, 0x9c, 0x0a, 0xd4, 0x40, 0x40, 0x72,
                0x09, 0xed, 0x6a, 0x9f, 0x08, 0x46, 0x4d, 0x56, 0x55, 0x93, 0xe1, 0xa6, 0x3b, 0x93,
                0x85, 0x36, 0xb4, 0x92, 0x44, 0xe9, 0x7d, 0x88, 0x01, 0x73, 0xb6, 0x40, 0xf2, 0xdd,
                0xb7, 0x4d, 0x06, 0x8e, 0xcb, 0x46, 0xcf, 0x28, 0x9b, 0x7d, 0x89, 0x13, 0x07, 0xbb,
                0xa3, 0x70, 0x54, 0xcf, 0x91, 0xb3, 0x1f, 0xc8, 0x2f, 0x74, 0xd5, 0xfc, 0xc0, 0x00,
                0x94, 0x2e, 0xde, 0x91, 0x18, 0x25, 0xf5, 0x3f, 0xe6, 0x09, 0x68, 0x6f, 0x46, 0x32,
                0x23, 0xb1, 0xe9, 0xbc, 0x03, 0xbd, 0xe8, 0x95, 0xd1, 0x23, 0x8f, 0xad, 0x04, 0xa3,
                0xbf, 0xce, 0x68, 0xa0, 0x75, 0xe8, 0xa3, 0x7c, 0x0e, 0x87, 0xbf, 0x46, 0xdd, 0x01,
                0x55, 0x45, 0xf9, 0xb4, 0xfb, 0x0e, 0xec, 0x64, 0x5f, 0xfc, 0xbb, 0xe0, 0xca, 0x5f,
                0x8c, 0x56, 0x1b, 0x25, 0x7d, 0x52, 0xd6, 0x02, 0xd8, 0xc9, 0x4c, 0x50, 0x28, 0x73,
                0xa0, 0x1d, 0x92, 0x51, 0xd8, 0xc8, 0x60, 0xc0, 0x41, 0x52, 0x5b, 0x3b, 0xf4, 0xe3,
                0xa2, 0xeb, 0x92, 0x72, 0x81, 0x5c, 0x75, 0x86, 0x76, 0x84, 0x28, 0xb4, 0xc2, 0xb2,
                0x5e, 0x37, 0x45, 0xf0, 0x09, 0xc5, 0xdc, 0xe2, 0x0b, 0x69, 0xd5, 0xd7, 0xc4, 0x3c,
                0xeb, 0x73, 0x6b, 0x68, 0x31, 0xe8, 0xc1, 0x10, 0xf1, 0x6c, 0xfd, 0xb3, 0xa4, 0x67,
                0xe9, 0x41, 0x4c, 0x00, 0xec, 0xf1, 0x37, 0x31, 0x50, 0x08, 0x94, 0x55, 0x56, 0x78,
                0xc4, 0x97, 0xfa, 0xba, 0x9a, 0x95, 0xd0, 0x1c, 0xc4, 0x64, 0x39, 0x0f, 0xc4, 0xa7,
                0x6b, 0xfa, 0x8b, 0x0e, 0x1c, 0x68, 0xa5, 0x25, 0xd7, 0x06, 0xd6, 0x60, 0x4b, 0x23,
                0x30, 0xb6, 0xb3, 0x48, 0x52, 0x15, 0xf6, 0x06, 0xf1, 0x88, 0x3a, 0x75, 0x15, 0x88,
                0xc7, 0xef, 0xa5, 0x06, 0xc3, 0xe8, 0xd0, 0xc6, 0x01, 0x92, 0xe8, 0x47, 0x6b, 0xd1,
                0x17, 0x5d, 0x95, 0x62, 0x08, 0x7b, 0xdb, 0x81, 0x8e, 0x66, 0x21, 0x62, 0x86, 0xba,
                0xfe, 0x47, 0xff, 0x4d, 0xbc, 0xce, 0xd5, 0x14, 0x44, 0x48, 0x0a, 0x9a, 0x56, 0x73,
                0xec, 0xe7, 0xfa, 0xc7, 0x3a, 0x0e, 0xd4, 0x1a, 0xb0, 0x05, 0x17, 0x53, 0xa7, 0xca,
                0xa8, 0x9b, 0xe3, 0x13, 0x9a, 0xfd, 0x97, 0x93, 0xb3, 0xe0, 0x2f, 0x27, 0xf0, 0x40,
                0x04, 0x65, 0x95, 0xac, 0xd4, 0x7b, 0xf1, 0x3f, 0xd0, 0xda, 0x27, 0xf0, 0x9e, 0xda,
                0x48, 0x03, 0x6d, 0x3e, 0xe4, 0x37, 0xf2, 0xee, 0x8f, 0x86, 0x06, 0xea, 0x97, 0x34,
                0x3c, 0x33, 0x58, 0x46, 0x57, 0xf4, 0x6d, 0xba, 0x99, 0xdb, 0x5c, 0xfe, 0x6c, 0xa1,
                0x76, 0xfa, 0xb7, 0xb0, 0xf3, 0xbf, 0xa0, 0xab, 0x61, 0xe3, 0x40, 0xc3, 0x4e, 0xb9,
                0xf1, 0x7c, 0x7e, 0xc2, 0xbe, 0x03, 0xb1, 0x80, 0xf0, 0xbb, 0x6f, 0x43, 0x4c, 0x2a,
                0x65, 0x42, 0xe0, 0x0e, 0x84, 0x37, 0x3f, 0x4f,
            ],
            cv_net: [
                0x47, 0x35, 0xa6, 0xfd, 0x21, 0x5c, 0x7b, 0x95, 0x03, 0x3d, 0xab, 0x62, 0xcc, 0xf9,
                0xcd, 0x51, 0x00, 0x89, 0x08, 0xa6, 0xcd, 0xd0, 0xaa, 0x02, 0x1b, 0x88, 0x8b, 0x98,
                0xe2, 0x3c, 0x39, 0x11,
            ],
            rho: [
                0xbd, 0xda, 0xe8, 0xdf, 0xf1, 0x20, 0x5e, 0x04, 0x96, 0x8f, 0xae, 0x1f, 0xd9, 0xbe,
                0x51, 0xd8, 0x25, 0xf5, 0xd8, 0x78, 0x1d, 0x93, 0x3d, 0x0f, 0x5b, 0xce, 0x9c, 0xa8,
                0x3e, 0xe8, 0xed, 0x20,
            ],
            cmx: [
                0xbe, 0x43, 0xee, 0x84, 0x70, 0x70, 0x75, 0xac, 0x48, 0x08, 0xd0, 0x97, 0x54, 0x07,
                0xc0, 0x27, 0x36, 0xd7, 0x66, 0x64, 0xf4, 0xe7, 0xae, 0xce, 0x01, 0xd9, 0xcc, 0x68,
                0x32, 0x4a, 0xe9, 0x04,
            ],
            esk: [
                0xf9, 0xf7, 0xa0, 0x10, 0x5e, 0xa9, 0xf4, 0x45, 0xfb, 0x7a, 0x14, 0x49, 0x72, 0x62,
                0xc6, 0xe4, 0xd7, 0x32, 0x89, 0x32, 0x7b, 0x8a, 0x2d, 0xf5, 0xe2, 0x63, 0xf3, 0xe3,
                0x99, 0x07, 0xea, 0x0c,
            ],
            ephemeral_key: [
                0xfa, 0x19, 0xa1, 0x52, 0x7b, 0x76, 0x04, 0x8f, 0xf3, 0x7f, 0xa4, 0xf8, 0x27, 0x89,
                0xfe, 0x80, 0xb0, 0xcd, 0xd3, 0x5d, 0x5d, 0xa9, 0xc2, 0xec, 0x3f, 0xe3, 0x04, 0x38,
                0x05, 0xc0, 0x61, 0x23,
            ],
            shared_secret: [
                0x2d, 0xb5, 0xb8, 0x92, 0xb6, 0x1b, 0x9c, 0x55, 0x3b, 0x6c, 0x9b, 0x7a, 0xcc, 0x7d,
                0x71, 0x05, 0xc1, 0xdd, 0x4c, 0x28, 0xc6, 0x7f, 0x97, 0x8b, 0x6d, 0x79, 0xc7, 0x1b,
                0x98, 0xa0, 0xd0, 0x00,
            ],
            k_enc: [
                0x16, 0xe3, 0xf9, 0x85, 0xc0, 0x7f, 0xef, 0xe5, 0x30, 0xd9, 0xe6, 0x94, 0x5e, 0xde,
                0xc1, 0x90, 0x3b, 0xb1, 0xca, 0x8d, 0xa5, 0xa2, 0x5b, 0xe9, 0x59, 0x78, 0x63, 0x7a,
                0x40, 0x8c, 0x2e, 0xfe,
            ],
            p_enc: [
                0x02, 0xc6, 0xe8, 0xf0, 0xd5, 0x0a, 0xe8, 0x05, 0x87, 0x91, 0xdc, 0x0e, 0x46, 0x49,
                0xcd, 0xa3, 0x2b, 0xf6, 0x86, 0x66, 0x25, 0x01, 0xe5, 0x1b, 0x01, 0x2a, 0xea, 0x94,
                0x46, 0xa2, 0x10, 0x4e, 0x93, 0xf8, 0x15, 0xa0, 0xb3, 0xa2, 0x9b, 0x45, 0x83, 0x14,
                0xf3, 0xd8, 0xbe, 0x2b, 0x98, 0x23, 0xd3, 0x42, 0xf4, 0x62, 0xff, 0x13, 0xe9, 0x42,
                0xa7, 0xe1, 0x9a, 0x46, 0xe9, 0x70, 0xb5, 0xc5, 0x06, 0x70, 0x84, 0x30, 0x31, 0x7b,
                0x1b, 0xb3, 0xb3, 0x5d, 0xf6, 0x8a, 0xe3, 0x3a, 0x49, 0x26, 0xa0, 0x3e, 0x6b, 0xfe,
                0xb5, 0x51, 0x04, 0x16, 0xfc, 0xbb, 0x05, 0x24, 0xc9, 0xca, 0x50, 0x74, 0x15, 0x6c,
                0xc5, 0xa5, 0xd6, 0xfe, 0x1c, 0x99, 0x5e, 0xdc, 0x60, 0xa2, 0xf5, 0x50, 0x41, 0x1a,
                0xa4, 0x1e, 0x3d, 0xa3, 0xbd, 0xcf, 0x64, 0xbc, 0xf0, 0x4a, 0x05, 0x10, 0x57, 0x1b,
                0x93, 0x6d, 0x47, 0xe5, 0x5c, 0xec, 0x03, 0x30, 0xee, 0x8d, 0xfe, 0x73, 0x56, 0x34,
                0x04, 0xf0, 0x47, 0xd7, 0xf3, 0xa8, 0xa3, 0xd7, 0x74, 0x3b, 0xc5, 0x54, 0x95, 0x52,
                0x10, 0xf1, 0xeb, 0x0d, 0x08, 0x59, 0x9e, 0xa7, 0x7d, 0x5f, 0x97, 0x4d, 0x87, 0x17,
                0x6d, 0x37, 0xd9, 0x8b, 0x9c, 0x0a, 0xd4, 0x40, 0x40, 0x72, 0x09, 0xed, 0x6a, 0x9f,
                0x08, 0x46, 0x4d, 0x56, 0x55, 0x93, 0xe1, 0xa6, 0x3b, 0x93, 0x85, 0x36, 0xb4, 0x92,
                0x44, 0xe9, 0x7d, 0x88, 0x01, 0x73, 0xb6, 0x40, 0xf2, 0xdd, 0xb7, 0x4d, 0x06, 0x8e,
                0xcb, 0x46, 0xcf, 0x28, 0x9b, 0x7d, 0x89, 0x13, 0x07, 0xbb, 0xa3, 0x70, 0x54, 0xcf,
                0x91, 0xb3, 0x1f, 0xc8, 0x2f, 0x74, 0xd5, 0xfc, 0xc0, 0x00, 0x94, 0x2e, 0xde, 0x91,
                0x18, 0x25, 0xf5, 0x3f, 0xe6, 0x09, 0x68, 0x6f, 0x46, 0x32, 0x23, 0xb1, 0xe9, 0xbc,
                0x03, 0xbd, 0xe8, 0x95, 0xd1, 0x23, 0x8f, 0xad, 0x04, 0xa3, 0xbf, 0xce, 0x68, 0xa0,
                0x75, 0xe8, 0xa3, 0x7c, 0x0e, 0x87, 0xbf, 0x46, 0xdd, 0x01, 0x55, 0x45, 0xf9, 0xb4,
                0xfb, 0x0e, 0xec, 0x64, 0x5f, 0xfc, 0xbb, 0xe0, 0xca, 0x5f, 0x8c, 0x56, 0x1b, 0x25,
                0x7d, 0x52, 0xd6, 0x02, 0xd8, 0xc9, 0x4c, 0x50, 0x28, 0x73, 0xa0, 0x1d, 0x92, 0x51,
                0xd8, 0xc8, 0x60, 0xc0, 0x41, 0x52, 0x5b, 0x3b, 0xf4, 0xe3, 0xa2, 0xeb, 0x92, 0x72,
                0x81, 0x5c, 0x75, 0x86, 0x76, 0x84, 0x28, 0xb4, 0xc2, 0xb2, 0x5e, 0x37, 0x45, 0xf0,
                0x09, 0xc5, 0xdc, 0xe2, 0x0b, 0x69, 0xd5, 0xd7, 0xc4, 0x3c, 0xeb, 0x73, 0x6b, 0x68,
                0x31, 0xe8, 0xc1, 0x10, 0xf1, 0x6c, 0xfd, 0xb3, 0xa4, 0x67, 0xe9, 0x41, 0x4c, 0x00,
                0xec, 0xf1, 0x37, 0x31, 0x50, 0x08, 0x94, 0x55, 0x56, 0x78, 0xc4, 0x97, 0xfa, 0xba,
                0x9a, 0x95, 0xd0, 0x1c, 0xc4, 0x64, 0x39, 0x0f, 0xc4, 0xa7, 0x6b, 0xfa, 0x8b, 0x0e,
                0x1c, 0x68, 0xa5, 0x25, 0xd7, 0x06, 0xd6, 0x60, 0x4b, 0x23, 0x30, 0xb6, 0xb3, 0x48,
                0x52, 0x15, 0xf6, 0x06, 0xf1, 0x88, 0x3a, 0x75, 0x15, 0x88, 0xc7, 0xef, 0xa5, 0x06,
                0xc3, 0xe8, 0xd0, 0xc6, 0x01, 0x92, 0xe8, 0x47, 0x6b, 0xd1, 0x17, 0x5d, 0x95, 0x62,
                0x08, 0x7b, 0xdb, 0x81, 0x8e, 0x66, 0x21, 0x62, 0x86, 0xba, 0xfe, 0x47, 0xff, 0x4d,
                0xbc, 0xce, 0xd5, 0x14, 0x44, 0x48, 0x0a, 0x9a, 0x56, 0x73, 0xec, 0xe7, 0xfa, 0xc7,
                0x3a, 0x0e, 0xd4, 0x1a, 0xb0, 0x05, 0x17, 0x53, 0xa7, 0xca, 0xa8, 0x9b, 0xe3, 0x13,
                0x9a, 0xfd, 0x97, 0x93, 0xb3, 0xe0, 0x2f, 0x27, 0xf0, 0x40, 0x04, 0x65, 0x95, 0xac,
                0xd4, 0x7b, 0xf1, 0x3f, 0xd0, 0xda, 0x27, 0xf0, 0x9e, 0xda, 0x48, 0x03, 0x6d, 0x3e,
                0xe4, 0x37, 0xf2, 0xee, 0x8f, 0x86, 0x06, 0xea, 0x97, 0x34, 0x3c, 0x33, 0x58, 0x46,
                0x57, 0xf4, 0x6d, 0xba, 0x99, 0xdb, 0x5c, 0xfe, 0x6c, 0xa1, 0x76, 0xfa, 0xb7, 0xb0,
                0xf3, 0xbf, 0xa0, 0xab, 0x61, 0xe3, 0x40, 0xc3, 0x4e, 0xb9, 0xf1, 0x7c, 0x7e, 0xc2,
                0xbe, 0x03, 0xb1, 0x80, 0xf0, 0xbb, 0x6f, 0x43, 0x4c, 0x2a, 0x65, 0x42, 0xe0, 0x0e,
                0x84, 0x37, 0x3f, 0x4f,
            ],
            c_enc: [
                0x2d, 0x40, 0x4a, 0x68, 0x81, 0xa6, 0xee, 0x76, 0x0c, 0xb5, 0x3b, 0x9c, 0xc2, 0x71,
                0x5c, 0xa7, 0x6a, 0x3a, 0x2f, 0xc9, 0x69, 0x3b, 0x1a, 0xbb, 0xcd, 0xc7, 0x5c, 0xb6,
                0xd6, 0xc3, 0x6e, 0xcf, 0x84, 0xd6, 0x93, 0x67, 0x2c, 0x53, 0xce, 0xd8, 0x79, 0x8c,
                0xc8, 0xf1, 0xe5, 0x3b, 0x8a, 0x9d, 0xe7, 0xbb, 0xb5, 0xe8, 0xc5, 0xa4, 0x6c, 0x3a,
                0x74, 0x12, 0xdf, 0x11, 0xc5, 0xda, 0x16, 0xb4, 0xdd, 0x22, 0x90, 0x1a, 0x59, 0x2b,
                0x0e, 0x93, 0x29, 0x77, 0xba, 0x06, 0x67, 0x3d, 0x6f, 0xd0, 0x38, 0xac, 0xba, 0xa9,
                0xbf, 0x79, 0xc1, 0x5b, 0xa6, 0x2b, 0x6e, 0x30, 0x74, 0xef, 0x95, 0x3b, 0x81, 0x4c,
                0xf1, 0xbd, 0xf0, 0x15, 0x77, 0xed, 0x3e, 0x3f, 0xae, 0xf4, 0x71, 0x55, 0xc9, 0x1c,
                0x68, 0xee, 0x32, 0x88, 0x1b, 0x73, 0x74, 0x94, 0xb3, 0xb4, 0x76, 0x08, 0x3b, 0x3b,
                0xd1, 0x77, 0x93, 0xc4, 0x98, 0x93, 0x1e, 0xaa, 0x92, 0xb1, 0x7c, 0x7d, 0x10, 0x47,
                0x58, 0xfc, 0x8b, 0x34, 0x93, 0xd2, 0x47, 0x41, 0x7f, 0x5e, 0xc1, 0x97, 0x9a, 0x35,
                0x28, 0x93, 0xe9, 0x95, 0x63, 0xb6, 0xc3, 0xab, 0x95, 0xcc, 0x5a, 0xfa, 0x37, 0x32,
                0xef, 0xae, 0xce, 0x9e, 0x74, 0x32, 0xc8, 0x04, 0x15, 0xe2, 0x5f, 0x55, 0x56, 0x53,
                0xc7, 0xda, 0x5d, 0xb0, 0xcc, 0x61, 0x08, 0x74, 0x21, 0x95, 0x9b, 0xb1, 0xdf, 0x80,
                0x03, 0xb7, 0x3d, 0xa0, 0xbe, 0xf0, 0x60, 0xf3, 0xa8, 0x4c, 0x8b, 0xc2, 0x4c, 0xc7,
                0x6d, 0x0d, 0x9e, 0x9c, 0x33, 0x76, 0x5c, 0x20, 0xf0, 0x7d, 0x80, 0xe2, 0x0f, 0xdf,
                0x27, 0x81, 0x5d, 0xbd, 0x9d, 0x71, 0x7c, 0x09, 0x66, 0xf8, 0x0b, 0x94, 0xb9, 0x59,
                0x15, 0x08, 0x1e, 0xa4, 0x55, 0x37, 0xa5, 0xa0, 0x74, 0xb9, 0xc9, 0x4b, 0x43, 0xdd,
                0xf4, 0xa9, 0xcb, 0xad, 0xe9, 0x04, 0x51, 0x0e, 0xaa, 0x96, 0x9e, 0x66, 0x6c, 0x94,
                0x34, 0xb9, 0xf6, 0x3e, 0xae, 0x62, 0xad, 0x58, 0x27, 0x99, 0x62, 0xe9, 0x41, 0x33,
                0x05, 0x5c, 0xbc, 0xc4, 0xb1, 0x55, 0xc0, 0x0f, 0x1b, 0x83, 0xff, 0x41, 0x28, 0xa8,
                0xab, 0xb4, 0xce, 0x68, 0xe9, 0xf1, 0xe3, 0x08, 0xe6, 0xf9, 0x7e, 0x51, 0x3a, 0xf5,
                0x95, 0x47, 0x1a, 0x16, 0x77, 0xef, 0x78, 0xe9, 0x77, 0x0f, 0x43, 0xad, 0xde, 0x1a,
                0x64, 0x58, 0x6d, 0xe6, 0xa5, 0x87, 0xc3, 0xd6, 0x93, 0xfe, 0xa8, 0xfc, 0xc6, 0xac,
                0xc8, 0x94, 0x96, 0x1e, 0x2f, 0x47, 0xb2, 0x02, 0xe8, 0x6a, 0x57, 0x38, 0x79, 0xb5,
                0xbf, 0xd7, 0x29, 0xda, 0x2f, 0xbe, 0xfc, 0x64, 0x5c, 0xfa, 0xb1, 0x88, 0x0d, 0x51,
                0x76, 0x40, 0xdf, 0x5f, 0x53, 0xe5, 0x7c, 0x72, 0xd6, 0x5a, 0x63, 0x3a, 0xa5, 0x36,
                0xb2, 0x98, 0x34, 0xbf, 0x28, 0x16, 0xb1, 0xf7, 0x16, 0xbf, 0x43, 0x6d, 0x6b, 0x2b,
                0x6e, 0x47, 0x73, 0x28, 0xc9, 0x58, 0xa6, 0xb8, 0xcf, 0x73, 0xb9, 0x5d, 0x22, 0xf6,
                0x99, 0x3b, 0x3f, 0xc5, 0x25, 0xdb, 0x62, 0x7f, 0x6f, 0x38, 0xd0, 0x77, 0x9a, 0x1d,
                0x39, 0xaf, 0x05, 0xed, 0x74, 0xfd, 0xfe, 0xff, 0x98, 0x7a, 0x95, 0x88, 0xd8, 0x0b,
                0x7e, 0x79, 0x69, 0x4a, 0xe4, 0x55, 0x29, 0x29, 0x88, 0x1c, 0x5b, 0xfe, 0x20, 0x49,
                0x2f, 0xd6, 0xf3, 0x37, 0xca, 0x88, 0xdf, 0xb5, 0x01, 0xe5, 0x45, 0xd2, 0x36, 0x73,
                0xac, 0xac, 0xbc, 0x3d, 0x33, 0x14, 0xa8, 0xbb, 0xf5, 0xec, 0x70, 0xb7, 0x05, 0xcc,
                0x9d, 0x26, 0x57, 0xbd, 0xd5, 0xa7, 0x09, 0x15, 0xbe, 0xf6, 0xd0, 0xf0, 0x39, 0xd3,
                0xeb, 0xa6, 0xbb, 0x71, 0x5b, 0xe5, 0x1e, 0xbf, 0x6e, 0xf6, 0x59, 0xea, 0x32, 0xff,
                0x80, 0xc8, 0x2c, 0x04, 0x21, 0x67, 0x5f, 0xe3, 0x71, 0xef, 0x49, 0xf1, 0xb9, 0xe3,
                0x8f, 0x43, 0x7b, 0x4a, 0x76, 0x55, 0xdc, 0x29, 0x16, 0xaa, 0x30, 0x86, 0xde, 0x6c,
                0x62, 0xa8, 0x2b, 0x36, 0x1c, 0x05, 0x3f, 0xc6, 0x34, 0x54, 0xcc, 0xd0, 0x2c, 0x22,
                0xd4, 0x1f, 0xf5, 0xbb, 0x83, 0x62, 0xde, 0xaa, 0x70, 0x82, 0x5a, 0xd2, 0xf9, 0x93,
                0x63, 0x9f, 0xc4, 0x46, 0x06, 0x9d, 0x78, 0xa6, 0x1d, 0x33, 0x8d, 0xf5, 0x8f, 0x77,
                0x63, 0xe3, 0x55, 0xe6, 0xa9, 0xff,
            ],
            ock: [
                0x8b, 0x0d, 0x29, 0x8e, 0xe8, 0xb4, 0x25, 0x34, 0xa4, 0x2f, 0xb9, 0x63, 0x5b, 0xa7,
                0x58, 0xea, 0x9f, 0x91, 0x8b, 0x83, 0x16, 0xc0, 0xe8, 0x94, 0xa9, 0x08, 0x48, 0x89,
                0x01, 0xd9, 0xfb, 0xa3,
            ],
            op: [
                0x8e, 0x66, 0xb7, 0x92, 0xec, 0xb1, 0x56, 0xef, 0x68, 0x5e, 0xe8, 0xea, 0x35, 0xd3,
                0x82, 0x75, 0x8b, 0xa4, 0x15, 0x97, 0xa3, 0x3a, 0x93, 0xba, 0xf3, 0x81, 0xd6, 0x3c,
                0x17, 0x5b, 0xa9, 0x8b, 0xf9, 0xf7, 0xa0, 0x10, 0x5e, 0xa9, 0xf4, 0x45, 0xfb, 0x7a,
                0x14, 0x49, 0x72, 0x62, 0xc6, 0xe4, 0xd7, 0x32, 0x89, 0x32, 0x7b, 0x8a, 0x2d, 0xf5,
                0xe2, 0x63, 0xf3, 0xe3, 0x99, 0x07, 0xea, 0x0c,
            ],
            c_out: [
                0xf3, 0xbf, 0x90, 0x76, 0xf3, 0xdb, 0x66, 0x32, 0x6d, 0xa6, 0x0c, 0xc7, 0x94, 0x3c,
                0x85, 0x4d, 0x8d, 0xe9, 0x9f, 0x57, 0x53, 0xf7, 0x0c, 0x32, 0xed, 0x01, 0xfb, 0x2e,
                0x84, 0x9c, 0x9d, 0xc7, 0x3f, 0x80, 0xb5, 0xcb, 0xaa, 0xb4, 0x99, 0x2d, 0xd7, 0xe7,
                0x38, 0xb9, 0x61, 0xfd, 0x75, 0x3f, 0x7c, 0x5b, 0x29, 0x24, 0xd1, 0xd9, 0x63, 0x06,
                0x61, 0x33, 0x92, 0x59, 0x28, 0x3e, 0x3a, 0x95, 0x3c, 0x57, 0xdf, 0x3a, 0x48, 0xca,
                0x82, 0x71, 0xfc, 0x5f, 0x26, 0x4d, 0x6f, 0x15, 0xb6, 0xb3,
            ],
        },
        TestVector {
            incoming_viewing_key: [
                0x73, 0xa2, 0x5e, 0xba, 0x9b, 0xd7, 0xa8, 0xed, 0x2b, 0x5b, 0x1b, 0x8d, 0x5a, 0x05,
                0x6b, 0xde, 0x8d, 0x05, 0xe6, 0xa2, 0x80, 0x67, 0xb3, 0x84, 0x57, 0x91, 0xbe, 0xbf,
                0xa7, 0xae, 0x2a, 0xcd, 0x36, 0x32, 0x6f, 0xe6, 0x27, 0xbe, 0xe8, 0x0e, 0x32, 0x92,
                0xe0, 0xe5, 0x13, 0x2d, 0xe1, 0x6c, 0xa4, 0xf8, 0x1e, 0x5a, 0x6f, 0xc0, 0x9c, 0x95,
                0xff, 0x13, 0xb5, 0x2e, 0x96, 0xb7, 0x89, 0x0f,
            ],
            ovk: [
                0xf5, 0xe8, 0xde, 0xd8, 0x18, 0x92, 0x51, 0x1c, 0xc2, 0x85, 0x1b, 0x00, 0xb8, 0x32,
                0x71, 0x2a, 0x6d, 0x3b, 0xa5, 0x66, 0x65, 0x17, 0xbc, 0xd3, 0x56, 0x76, 0x21, 0xa7,
                0xcf, 0x84, 0x45, 0x58,
            ],
            default_d: [
                0x81, 0xf2, 0x75, 0x7c, 0x53, 0x2e, 0xd3, 0xb6, 0x2e, 0x89, 0x01,
            ],
            default_pk_d: [
                0x55, 0xdb, 0x72, 0x90, 0x07, 0x3b, 0xa0, 0x06, 0x66, 0xe8, 0x7d, 0x25, 0x61, 0xb8,
                0x88, 0x3c, 0x66, 0x2c, 0x56, 0x78, 0xff, 0x27, 0x30, 0x2a, 0x82, 0xe2, 0x0a, 0x72,
                0x01, 0x70, 0x89, 0x1a,
            ],
            v: 17209482587585417762,
            rseed: [
                0xfc, 0x54, 0x88, 0x62, 0xf5, 0xa0, 0x70, 0x94, 0xfd, 0x42, 0x8a, 0x7b, 0xbc, 0x15,
                0xd7, 0xb3, 0x8d, 0x05, 0x36, 0x2c, 0x9c, 0xa9, 0x85, 0xf5, 0x8a, 0x76, 0x64, 0x7d,
                0x2b, 0xe4, 0xc2, 0xcd,
            ],
            memo: [
                0xff, 0x6b, 0x3d, 0x17, 0xd6, 0x87, 0x09, 0x71, 0xd7, 0xa0, 0x98, 0xba, 0xf7, 0x2c,
                0x6f, 0x6f, 0x12, 0x14, 0xcf, 0x1f, 0xaa, 0xe4, 0x88, 0xbd, 0x7d, 0xe2, 0x59, 0xd3,
                0x41, 0x5c, 0x2f, 0x0d, 0xde, 0xc7, 0x45, 0x70, 0x04, 0xf3, 0x57, 0x08, 0xd1, 0xec,
                0xcc, 0xcc, 0x0d, 0xf6, 0x5a, 0x04, 0x94, 0x3a, 0xd5, 0xcb, 0xc1, 0x3f, 0x29, 0x5f,
                0x00, 0x0f, 0xe0, 0x56, 0xc4, 0x0b, 0x2d, 0x88, 0xf2, 0x7d, 0xc3, 0x4c, 0xfe, 0xb8,
                0x03, 0xbe, 0x34, 0x83, 0xa9, 0xeb, 0xf9, 0xb5, 0xa9, 0x02, 0x60, 0x57, 0x72, 0x5d,
                0x63, 0xea, 0xd2, 0xc0, 0xc0, 0xff, 0x1f, 0xe2, 0x6a, 0xc1, 0xe7, 0xbd, 0xfc, 0xd6,
                0xfa, 0xd8, 0x75, 0x84, 0x2d, 0x19, 0x4f, 0x33, 0x17, 0x50, 0x46, 0x2c, 0x06, 0xb8,
                0xd7, 0x98, 0x2d, 0x67, 0x99, 0x5e, 0xd5, 0xd3, 0xae, 0x96, 0xa0, 0x5a, 0xe0, 0x06,
                0x7f, 0x4e, 0xb1, 0xc7, 0xc9, 0x32, 0x31, 0xbd, 0x39, 0x77, 0x3c, 0xbe, 0x0a, 0x9d,
                0x66, 0xb0, 0xc9, 0xaa, 0x8c, 0xff, 0x6a, 0x37, 0x6e, 0x1f, 0x37, 0x2e, 0xac, 0x6a,
                0xc4, 0xe4, 0x6c, 0xc0, 0x94, 0x22, 0x45, 0xd4, 0xc2, 0xdc, 0xf0, 0x2d, 0x76, 0x40,
                0xff, 0xcc, 0x5a, 0x6a, 0xc3, 0xa8, 0x7f, 0x5c, 0x41, 0x15, 0x51, 0xbc, 0xc2, 0xf2,
                0x6c, 0xb9, 0x49, 0x61, 0xd5, 0x3f, 0x95, 0xdd, 0xb1, 0x9a, 0xe9, 0x30, 0xc8, 0xd7,
                0x0f, 0x03, 0x1b, 0x29, 0xa5, 0xdf, 0x99, 0xff, 0x36, 0x69, 0x5e, 0x80, 0x2c, 0xbc,
                0xb6, 0xb5, 0x8c, 0x1b, 0xa7, 0xed, 0x5e, 0xac, 0xfa, 0x76, 0x41, 0x4a, 0x41, 0xad,
                0x4a, 0x44, 0xf7, 0x1f, 0x1b, 0x58, 0x0d, 0x34, 0xc3, 0xa9, 0x52, 0x92, 0x0b, 0x25,
                0x4a, 0x14, 0x5f, 0xea, 0x51, 0x7f, 0x5b, 0x42, 0xb2, 0xf6, 0x5e, 0xcd, 0x0f, 0x82,
                0x59, 0x54, 0x78, 0xd8, 0x0a, 0xe5, 0xc8, 0xce, 0xea, 0x12, 0xa1, 0x61, 0xcc, 0xbb,
                0x5e, 0xac, 0x09, 0x99, 0x0f, 0xc6, 0x19, 0xa4, 0x60, 0x80, 0x43, 0x6d, 0xbd, 0x08,
                0xd7, 0x47, 0x84, 0xaf, 0x00, 0x2d, 0x58, 0xe0, 0x6f, 0xaf, 0x7f, 0x3c, 0xea, 0xe7,
                0xd3, 0x41, 0x9b, 0x1f, 0xca, 0x26, 0x5a, 0x55, 0x59, 0xcf, 0x9e, 0x2d, 0x3b, 0x60,
                0x97, 0x8d, 0x81, 0xa6, 0x78, 0xb9, 0xed, 0x8e, 0x44, 0x86, 0xb4, 0xd1, 0x46, 0x09,
                0xd6, 0xc1, 0x27, 0xc0, 0xc2, 0xfb, 0xff, 0xe3, 0x0a, 0x60, 0xf7, 0xbf, 0xf1, 0xd9,
                0xfb, 0x83, 0x00, 0xed, 0x00, 0x92, 0x53, 0xba, 0x9b, 0x99, 0x6f, 0xa0, 0x52, 0x41,
                0xb1, 0x0f, 0x5a, 0xc9, 0xa8, 0x40, 0x8e, 0x92, 0x5b, 0x62, 0x6b, 0xb2, 0x1a, 0x47,
                0x1f, 0xe3, 0xbe, 0xde, 0x52, 0xbb, 0xa0, 0x97, 0xb2, 0xa9, 0x9a, 0x9b, 0xa5, 0xa8,
                0x66, 0x58, 0xc3, 0xfd, 0x9e, 0xc5, 0x5b, 0xfa, 0x9b, 0x32, 0x85, 0x67, 0x25, 0x4a,
                0xb3, 0x6d, 0x2c, 0x7f, 0x44, 0xd2, 0xc7, 0xe1, 0x3e, 0xb5, 0x4b, 0xeb, 0x70, 0xea,
                0x8f, 0xa9, 0x4b, 0x6c, 0x6e, 0x01, 0x2d, 0x79, 0xe3, 0xf5, 0x36, 0x89, 0xc2, 0xb1,
                0xa1, 0x8e, 0xaf, 0x2d, 0x47, 0x1d, 0x13, 0xc1, 0xab, 0x39, 0xd9, 0x19, 0x4a, 0xe8,
                0x43, 0xab, 0x1d, 0x28, 0xff, 0xa8, 0xf6, 0x9d, 0xc7, 0xe1, 0x5c, 0xc3, 0x8b, 0x12,
                0xe8, 0xfc, 0xd7, 0x92, 0x55, 0xb7, 0x21, 0x60, 0x56, 0xd9, 0xed, 0xb7, 0x48, 0x2f,
                0xb9, 0x8a, 0xa0, 0x33, 0xb6, 0x5e, 0x51, 0xc1, 0xa0, 0x8b, 0x8a, 0x11, 0xd8, 0x4d,
                0x04, 0x09, 0xb7, 0x34, 0xf4, 0x52, 0xaa, 0xf0, 0xd6, 0xb1, 0x8f, 0x50, 0x25, 0x86,
                0x83, 0xd3, 0xf9, 0xa7, 0x6d, 0x39, 0x9f, 0xd0, 0x47, 0xee, 0xe2, 0x88, 0xbb, 0x45,
                0x85, 0x85, 0x1d, 0xc9, 0x3e, 0xcc, 0xc6, 0x23,
            ],
            cv_net: [
                0xe8, 0x06, 0x5c, 0x40, 0x96, 0xd3, 0x54, 0x33, 0x40, 0x01, 0x1f, 0x58, 0x90, 0xb1,
                0x7e, 0xed, 0xd2, 0xa7, 0x06, 0x44, 0x07, 0x34, 0x78, 0x41, 0x01, 0xae, 0x2d, 0x8e,
                0x87, 0xe5, 0x05, 0xad,
            ],
            rho: [
                0xc2, 0x79, 0xfa, 0x9d, 0x1c, 0x84, 0x11, 0x93, 0xd3, 0x32, 0xf8, 0xcc, 0xf4, 0xd0,
                0xb1, 0xe4, 0x56, 0x01, 0xa8, 0xaf, 0x66, 0x76, 0xd7, 0x62, 0xfb, 0xa7, 0x31, 0x33,
                0x45, 0x89, 0x35, 0x14,
            ],
            cmx: [
                0x6d, 0x29, 0x97, 0xd1, 0xce, 0x0a, 0x94, 0x9a, 0x63, 0x70, 0x0f, 0x46, 0x1b, 0x57,
                0x12, 0xae, 0xeb, 0x43, 0xd4, 0x55, 0x04, 0xe3, 0x5b, 0xda, 0x16, 0x52, 0x97, 0x77,
                0xc7, 0x4d, 0x19, 0x1b,
            ],
            esk: [
                0x9d, 0xc4, 0xc8, 0xc0, 0x32, 0xd3, 0xbe, 0x66, 0xd2, 0x63, 0x6b, 0xa0, 0x02, 0x0c,
                0x63, 0xf4, 0x26, 0x53, 0x29, 0xff, 0xac, 0x2a, 0xe6, 0x35, 0x57, 0x32, 0x63, 0xf4,
                0x99, 0xbd, 0x4c, 0x13,
            ],
            ephemeral_key: [
                0xe4, 0x76, 0x95, 0x86, 0x30, 0x4a, 0x6a, 0x9b, 0x3a, 0x2a, 0xef, 0x3a, 0xf5, 0x8b,
                0x97, 0xda, 0xc2, 0xcc, 0x4a, 0xeb, 0x38, 0x9f, 0x68, 0xc1, 0x28, 0x87, 0x73, 0x1e,
                0x0e, 0x12, 0xbc, 0x1e,
            ],
            shared_secret: [
                0xf6, 0xba, 0x4b, 0x1f, 0xbe, 0x01, 0xfa, 0x2f, 0x1d, 0xd4, 0x09, 0x3c, 0x5c, 0xc4,
                0x85, 0xa9, 0xbf, 0xd9, 0xef, 0x0f, 0x57, 0x89, 0x49, 0xd6, 0xe1, 0x00, 0xb0, 0x05,
                0x5c, 0xb8, 0xf3, 0x31,
            ],
            k_enc: [
                0xd3, 0xc2, 0x20, 0x51, 0x00, 0x3e, 0x88, 0x2a, 0x5d, 0xdd, 0xfb, 0x48, 0x23, 0xd6,
                0x77, 0x26, 0x96, 0xa7, 0xe9, 0x9f, 0x26, 0xb1, 0xa6, 0xac, 0xd2, 0x4b, 0xee, 0xd5,
                0xf2, 0x2f, 0x9f, 0xf8,
            ],
            p_enc: [
                0x02, 0x81, 0xf2, 0x75, 0x7c, 0x53, 0x2e, 0xd3, 0xb6, 0x2e, 0x89, 0x01, 0x22, 0x92,
                0x4c, 0xd1, 0x3b, 0x5d, 0xd4, 0xee, 0xfc, 0x54, 0x88, 0x62, 0xf5, 0xa0, 0x70, 0x94,
                0xfd, 0x42, 0x8a, 0x7b, 0xbc, 0x15, 0xd7, 0xb3, 0x8d, 0x05, 0x36, 0x2c, 0x9c, 0xa9,
                0x85, 0xf5, 0x8a, 0x76, 0x64, 0x7d, 0x2b, 0xe4, 0xc2, 0xcd, 0xff, 0x6b, 0x3d, 0x17,
                0xd6, 0x87, 0x09, 0x71, 0xd7, 0xa0, 0x98, 0xba, 0xf7, 0x2c, 0x6f, 0x6f, 0x12, 0x14,
                0xcf, 0x1f, 0xaa, 0xe4, 0x88, 0xbd, 0x7d, 0xe2, 0x59, 0xd3, 0x41, 0x5c, 0x2f, 0x0d,
                0xde, 0xc7, 0x45, 0x70, 0x04, 0xf3, 0x57, 0x08, 0xd1, 0xec, 0xcc, 0xcc, 0x0d, 0xf6,
                0x5a, 0x04, 0x94, 0x3a, 0xd5, 0xcb, 0xc1, 0x3f, 0x29, 0x5f, 0x00, 0x0f, 0xe0, 0x56,
                0xc4, 0x0b, 0x2d, 0x88, 0xf2, 0x7d, 0xc3, 0x4c, 0xfe, 0xb8, 0x03, 0xbe, 0x34, 0x83,
                0xa9, 0xeb, 0xf9, 0xb5, 0xa9, 0x02, 0x60, 0x57, 0x72, 0x5d, 0x63, 0xea, 0xd2, 0xc0,
                0xc0, 0xff, 0x1f, 0xe2, 0x6a, 0xc1, 0xe7, 0xbd, 0xfc, 0xd6, 0xfa, 0xd8, 0x75, 0x84,
                0x2d, 0x19, 0x4f, 0x33, 0x17, 0x50, 0x46, 0x2c, 0x06, 0xb8, 0xd7, 0x98, 0x2d, 0x67,
                0x99, 0x5e, 0xd5, 0xd3, 0xae, 0x96, 0xa0, 0x5a, 0xe0, 0x06, 0x7f, 0x4e, 0xb1, 0xc7,
                0xc9, 0x32, 0x31, 0xbd, 0x39, 0x77, 0x3c, 0xbe, 0x0a, 0x9d, 0x66, 0xb0, 0xc9, 0xaa,
                0x8c, 0xff, 0x6a, 0x37, 0x6e, 0x1f, 0x37, 0x2e, 0xac, 0x6a, 0xc4, 0xe4, 0x6c, 0xc0,
                0x94, 0x22, 0x45, 0xd4, 0xc2, 0xdc, 0xf0, 0x2d, 0x76, 0x40, 0xff, 0xcc, 0x5a, 0x6a,
                0xc3, 0xa8, 0x7f, 0x5c, 0x41, 0x15, 0x51, 0xbc, 0xc2, 0xf2, 0x6c, 0xb9, 0x49, 0x61,
                0xd5, 0x3f, 0x95, 0xdd, 0xb1, 0x9a, 0xe9, 0x30, 0xc8, 0xd7, 0x0f, 0x03, 0x1b, 0x29,
                0xa5, 0xdf, 0x99, 0xff, 0x36, 0x69, 0x5e, 0x80, 0x2c, 0xbc, 0xb6, 0xb5, 0x8c, 0x1b,
                0xa7, 0xed, 0x5e, 0xac, 0xfa, 0x76, 0x41, 0x4a, 0x41, 0xad, 0x4a, 0x44, 0xf7, 0x1f,
                0x1b, 0x58, 0x0d, 0x34, 0xc3, 0xa9, 0x52, 0x92, 0x0b, 0x25, 0x4a, 0x14, 0x5f, 0xea,
                0x51, 0x7f, 0x5b, 0x42, 0xb2, 0xf6, 0x5e, 0xcd, 0x0f, 0x82, 0x59, 0x54, 0x78, 0xd8,
                0x0a, 0xe5, 0xc8, 0xce, 0xea, 0x12, 0xa1, 0x61, 0xcc, 0xbb, 0x5e, 0xac, 0x09, 0x99,
                0x0f, 0xc6, 0x19, 0xa4, 0x60, 0x80, 0x43, 0x6d, 0xbd, 0x08, 0xd7, 0x47, 0x84, 0xaf,
                0x00, 0x2d, 0x58, 0xe0, 0x6f, 0xaf, 0x7f, 0x3c, 0xea, 0xe7, 0xd3, 0x41, 0x9b, 0x1f,
                0xca, 0x26, 0x5a, 0x55, 0x59, 0xcf, 0x9e, 0x2d, 0x3b, 0x60, 0x97, 0x8d, 0x81, 0xa6,
                0x78, 0xb9, 0xed, 0x8e, 0x44, 0x86, 0xb4, 0xd1, 0x46, 0x09, 0xd6, 0xc1, 0x27, 0xc0,
                0xc2, 0xfb, 0xff, 0xe3, 0x0a, 0x60, 0xf7, 0xbf, 0xf1, 0xd9, 0xfb, 0x83, 0x00, 0xed,
                0x00, 0x92, 0x53, 0xba, 0x9b, 0x99, 0x6f, 0xa0, 0x52, 0x41, 0xb1, 0x0f, 0x5a, 0xc9,
                0xa8, 0x40, 0x8e, 0x92, 0x5b, 0x62, 0x6b, 0xb2, 0x1a, 0x47, 0x1f, 0xe3, 0xbe, 0xde,
                0x52, 0xbb, 0xa0, 0x97, 0xb2, 0xa9, 0x9a, 0x9b, 0xa5, 0xa8, 0x66, 0x58, 0xc3, 0xfd,
                0x9e, 0xc5, 0x5b, 0xfa, 0x9b, 0x32, 0x85, 0x67, 0x25, 0x4a, 0xb3, 0x6d, 0x2c, 0x7f,
                0x44, 0xd2, 0xc7, 0xe1, 0x3e, 0xb5, 0x4b, 0xeb, 0x70, 0xea, 0x8f, 0xa9, 0x4b, 0x6c,
                0x6e, 0x01, 0x2d, 0x79, 0xe3, 0xf5, 0x36, 0x89, 0xc2, 0xb1, 0xa1, 0x8e, 0xaf, 0x2d,
                0x47, 0x1d, 0x13, 0xc1, 0xab, 0x39, 0xd9, 0x19, 0x4a, 0xe8, 0x43, 0xab, 0x1d, 0x28,
                0xff, 0xa8, 0xf6, 0x9d, 0xc7, 0xe1, 0x5c, 0xc3, 0x8b, 0x12, 0xe8, 0xfc, 0xd7, 0x92,
                0x55, 0xb7, 0x21, 0x60, 0x56, 0xd9, 0xed, 0xb7, 0x48, 0x2f, 0xb9, 0x8a, 0xa0, 0x33,
                0xb6, 0x5e, 0x51, 0xc1, 0xa0, 0x8b, 0x8a, 0x11, 0xd8, 0x4d, 0x04, 0x09, 0xb7, 0x34,
                0xf4, 0x52, 0xaa, 0xf0, 0xd6, 0xb1, 0x8f, 0x50, 0x25, 0x86, 0x83, 0xd3, 0xf9, 0xa7,
                0x6d, 0x39, 0x9f, 0xd0, 0x47, 0xee, 0xe2, 0x88, 0xbb, 0x45, 0x85, 0x85, 0x1d, 0xc9,
                0x3e, 0xcc, 0xc6, 0x23,
            ],
            c_enc: [
                0x72, 0x29, 0xa0, 0xa5, 0x6a, 0x14, 0x4b, 0x04, 0x2c, 0x1e, 0xad, 0x91, 0x80, 0xac,
                0x54, 0xda, 0xc6, 0xc5, 0x5c, 0xf4, 0xc2, 0x2f, 0xbe, 0x7c, 0xde, 0x99, 0x96, 0x0b,
                0xc6, 0x20, 0xd4, 0xdd, 0x60, 0xe4, 0xbf, 0x18, 0xa0, 0xea, 0x7a, 0xd9, 0x09, 0x3b,
                0xcd, 0x3f, 0xf6, 0xd1, 0x61, 0x1c, 0x56, 0x5f, 0x88, 0xe7, 0x35, 0xef, 0x4c, 0x51,
                0x8c, 0x77, 0xd6, 0x22, 0x28, 0xe1, 0xe4, 0xa1, 0x35, 0xca, 0x6c, 0xb4, 0xed, 0x5a,
                0xbb, 0xdf, 0x3e, 0x81, 0xd0, 0x96, 0x50, 0xa8, 0xfa, 0x9b, 0x5c, 0x3d, 0x05, 0xb6,
                0xda, 0xcf, 0x3c, 0x3d, 0xb3, 0xb3, 0x63, 0xe4, 0x10, 0x57, 0x23, 0x70, 0x0c, 0x69,
                0x13, 0x9f, 0x81, 0xec, 0xc4, 0x8d, 0x88, 0x3d, 0xa0, 0x39, 0xdd, 0xed, 0x5e, 0xf6,
                0x04, 0x0a, 0xb2, 0x12, 0x0e, 0x53, 0x3b, 0x1f, 0xfd, 0x06, 0x74, 0xdb, 0x5b, 0x92,
                0x6e, 0x58, 0x7f, 0x16, 0xe7, 0xe8, 0x96, 0x2b, 0x12, 0x48, 0x35, 0xbd, 0x56, 0xcf,
                0xd8, 0xe7, 0x5b, 0xf6, 0xaa, 0x4d, 0xcd, 0x4d, 0x6f, 0x0b, 0x55, 0x61, 0x71, 0x9c,
                0x80, 0xaa, 0x82, 0xb3, 0xbc, 0xea, 0x16, 0x7a, 0x31, 0xc6, 0x69, 0x87, 0x61, 0xe2,
                0xd2, 0x6c, 0xb5, 0x6d, 0xd3, 0x04, 0x16, 0x72, 0x1c, 0x93, 0x37, 0x32, 0x92, 0x85,
                0x33, 0x58, 0xfa, 0xfe, 0x74, 0x95, 0x55, 0x8d, 0xb9, 0x9e, 0x47, 0xa3, 0xa1, 0x6e,
                0xd2, 0x2c, 0xdb, 0x9d, 0x7d, 0x16, 0xcf, 0xd9, 0xa7, 0xbb, 0x55, 0x9c, 0x72, 0x86,
                0xed, 0x84, 0xf8, 0x89, 0x9c, 0xb0, 0x52, 0x2e, 0x8a, 0x49, 0x7f, 0x3e, 0x14, 0x45,
                0x2b, 0xa8, 0xa9, 0x4a, 0x7f, 0x58, 0xe5, 0xde, 0x37, 0x1d, 0x76, 0xec, 0xc9, 0xef,
                0xe2, 0x0a, 0xe7, 0x9b, 0xee, 0x12, 0xbc, 0xe4, 0xe4, 0xb6, 0xf2, 0x35, 0x35, 0xe5,
                0xc3, 0xc4, 0x3a, 0x4c, 0xa2, 0x07, 0x6f, 0xd6, 0x73, 0xf0, 0x80, 0x6f, 0xa9, 0x85,
                0xc5, 0x88, 0xd1, 0x14, 0xc0, 0x7d, 0x8c, 0xe3, 0xa2, 0x33, 0xe5, 0x4d, 0x77, 0x11,
                0x6c, 0x8a, 0x2a, 0x56, 0xa6, 0x82, 0xe7, 0xa4, 0x85, 0xdf, 0x71, 0xb3, 0x02, 0xa0,
                0x36, 0xdd, 0xab, 0x21, 0x4d, 0xee, 0x77, 0x62, 0x19, 0xcc, 0x24, 0x25, 0x94, 0xf7,
                0x5b, 0x8e, 0xbd, 0x56, 0x6d, 0x74, 0xb1, 0x6c, 0x9e, 0xc0, 0x05, 0x8b, 0xca, 0x28,
                0x81, 0xb7, 0x9b, 0x10, 0xe8, 0xa8, 0x01, 0x08, 0x20, 0x61, 0x8a, 0xc6, 0x52, 0x6c,
                0xf9, 0x4b, 0x13, 0xd9, 0x75, 0x9f, 0x37, 0x33, 0x93, 0x34, 0xe8, 0xb2, 0xc6, 0xbd,
                0xd1, 0xd0, 0xf5, 0xe2, 0x46, 0x3c, 0xff, 0x2b, 0x8d, 0xa6, 0xd2, 0xc6, 0x86, 0xaa,
                0x98, 0x7c, 0xd1, 0xf0, 0x7e, 0x9a, 0xa2, 0x60, 0xdd, 0x04, 0x28, 0xa4, 0xff, 0x78,
                0xaa, 0x8f, 0xda, 0x47, 0x7a, 0xb3, 0x8a, 0xcf, 0xcc, 0xb1, 0x90, 0x91, 0x77, 0xb5,
                0x27, 0xe9, 0x38, 0xf1, 0xf9, 0xdc, 0xf3, 0x1f, 0x4f, 0x40, 0xa9, 0x62, 0x89, 0x51,
                0xfc, 0x2a, 0x7a, 0xbc, 0x04, 0x1e, 0x8c, 0x93, 0x36, 0x08, 0xbb, 0x47, 0xb4, 0x50,
                0xb2, 0x8f, 0xee, 0xe0, 0x41, 0x58, 0xa8, 0x17, 0x4b, 0xff, 0xe4, 0x97, 0x06, 0x02,
                0x48, 0x86, 0x42, 0xc1, 0x9e, 0x61, 0xd4, 0x73, 0xf3, 0xde, 0x0c, 0xb0, 0xb6, 0x4a,
                0x30, 0xd6, 0xf1, 0x46, 0x68, 0xd1, 0xb0, 0x17, 0x77, 0x56, 0x6f, 0xb5, 0xac, 0xc2,
                0xe9, 0x2e, 0x64, 0xd9, 0x75, 0x7f, 0xba, 0x13, 0xc1, 0xee, 0x9c, 0xd0, 0x3a, 0xbe,
                0x98, 0xbd, 0x7e, 0x8a, 0xd7, 0x04, 0x1c, 0x3f, 0xea, 0xe7, 0xc1, 0xa7, 0x24, 0x3a,
                0xe3, 0x61, 0x0a, 0xac, 0x64, 0xfe, 0xc6, 0xc9, 0xfc, 0x94, 0x3d, 0x6a, 0xbc, 0xe9,
                0x10, 0xad, 0xbe, 0x23, 0xb5, 0x46, 0xb4, 0xc2, 0x4a, 0xa9, 0xf2, 0xce, 0x5d, 0x97,
                0x06, 0x2e, 0xe0, 0xd1, 0xcc, 0xc4, 0x8c, 0xfd, 0x1f, 0xdb, 0xa7, 0xfd, 0xac, 0x0b,
                0x04, 0xd1, 0xb3, 0xdc, 0x7a, 0x70, 0x78, 0x1c, 0xdd, 0xa2, 0xa2, 0x70, 0x3d, 0xe0,
                0x03, 0xcd, 0x01, 0x51, 0xec, 0x65, 0xbf, 0x7d, 0x1a, 0xc6, 0x3b, 0xb7, 0x35, 0xbc,
                0x2b, 0xb6, 0x7a, 0xd2, 0xb0, 0x1e, 0xd6, 0xb9, 0xae, 0x2e, 0xbb, 0xd3, 0x7a, 0x8f,
                0x8e, 0xc1, 0xa6, 0x53, 0xa8, 0x7e,
            ],
            ock: [
                0x1b, 0xa4, 0xac, 0xd7, 0x75, 0x10, 0xc4, 0xf0, 0xc7, 0x66, 0xad, 0xf7, 0xc7, 0xdf,
                0x1d, 0x1c, 0x54, 0xd5, 0xbc, 0xe3, 0xd6, 0x0a, 0xf3, 0x5e, 0x8d, 0xd4, 0x8f, 0xdd,
                0x04, 0xa7, 0x8c, 0x0b,
            ],
            op: [
                0x55, 0xdb, 0x72, 0x90, 0x07, 0x3b, 0xa0, 0x06, 0x66, 0xe8, 0x7d, 0x25, 0x61, 0xb8,
                0x88, 0x3c, 0x66, 0x2c, 0x56, 0x78, 0xff, 0x27, 0x30, 0x2a, 0x82, 0xe2, 0x0a, 0x72,
                0x01, 0x70, 0x89, 0x1a, 0x9d, 0xc4, 0xc8, 0xc0, 0x32, 0xd3, 0xbe, 0x66, 0xd2, 0x63,
                0x6b, 0xa0, 0x02, 0x0c, 0x63, 0xf4, 0x26, 0x53, 0x29, 0xff, 0xac, 0x2a, 0xe6, 0x35,
                0x57, 0x32, 0x63, 0xf4, 0x99, 0xbd, 0x4c, 0x13,
            ],
            c_out: [
                0x43, 0x0d, 0xaa, 0x6b, 0x75, 0x63, 0x22, 0x80, 0xd5, 0xe6, 0xda, 0xcb, 0xd2, 0xa0,
                0xff, 0xe2, 0xaf, 0x98, 0x60, 0xc8, 0x3a, 0x3d, 0x2a, 0x87, 0xf1, 0x79, 0x62, 0x88,
                0xeb, 0xed, 0x64, 0xd0, 0xcd, 0xc4, 0x60, 0xe2, 0xc8, 0x61, 0xc4, 0xf9, 0x38, 0x7d,
                0x92, 0x59, 0xfc, 0x60, 0x01, 0xac, 0xd0, 0xe7, 0x6f, 0x3b, 0x0f, 0xdb, 0x5d, 0xac,
                0x97, 0x4c, 0x26, 0xb5, 0x1b, 0x85, 0x9f, 0xab, 0xe0, 0x2e, 0xab, 0xae, 0x96, 0x8a,
                0xab, 0x2e, 0x5e, 0x61, 0xef, 0xc2, 0xd4, 0x46, 0x2c, 0x1e,
            ],
        },
        TestVector {
            incoming_viewing_key: [
                0xa4, 0xd7, 0x9c, 0x81, 0x9a, 0x6c, 0x5e, 0x01, 0x67, 0xfc, 0xa9, 0x8c, 0xe2, 0x62,
                0x98, 0x15, 0xf9, 0xba, 0xc9, 0x26, 0xb6, 0x27, 0x18, 0xcf, 0xbe, 0x50, 0x45, 0xd9,
                0x2d, 0xd7, 0x1c, 0xd3, 0x36, 0x75, 0xd5, 0x56, 0xe0, 0x77, 0x1e, 0x40, 0xcc, 0x3d,
                0x61, 0x8d, 0x9b, 0xda, 0x13, 0x2f, 0x13, 0x95, 0x3d, 0x82, 0x43, 0x2e, 0x81, 0x59,
                0x4a, 0x97, 0x1e, 0x98, 0xb0, 0x71, 0x40, 0x39,
            ],
            ovk: [
                0x67, 0x79, 0x9a, 0x90, 0x01, 0xa2, 0xed, 0x36, 0x76, 0xa8, 0xb4, 0x03, 0xae, 0x25,
                0xff, 0xd7, 0x72, 0xf7, 0x08, 0x1e, 0x9a, 0x32, 0xbc, 0xc1, 0xc5, 0xe2, 0xed, 0xd4,
                0xe2, 0xa6, 0x57, 0x6b,
            ],
            default_d: [
                0xdd, 0xb7, 0xc5, 0xbc, 0x4d, 0xe9, 0xdf, 0x52, 0x1b, 0xb0, 0x4b,
            ],
            default_pk_d: [
                0x65, 0x3d, 0x07, 0xc9, 0x07, 0x94, 0x6a, 0xc3, 0x02, 0x0e, 0xbd, 0xe1, 0xb4, 0xf6,
                0x10, 0x21, 0x0c, 0x30, 0xc4, 0x50, 0xe4, 0x27, 0x12, 0x65, 0xa0, 0x5d, 0x6e, 0xce,
                0x44, 0x6d, 0xf4, 0x39,
            ],
            v: 7122345086698755501,
            rseed: [
                0x2d, 0xd4, 0x17, 0xdf, 0x26, 0xdc, 0xd2, 0x20, 0xf2, 0xb7, 0x31, 0x77, 0x2b, 0x43,
                0x9e, 0x96, 0xd6, 0x14, 0xe1, 0xfa, 0xcb, 0x48, 0x6c, 0x7a, 0x7d, 0x51, 0x71, 0xb1,
                0xde, 0x35, 0x9f, 0x6a,
            ],
            memo: [
                0xff, 0xd3, 0xa9, 0x6f, 0x64, 0x9c, 0x96, 0x91, 0x02, 0xa1, 0x96, 0x4f, 0xb4, 0xb4,
                0xa1, 0xa4, 0x27, 0x9c, 0x68, 0xe6, 0xc3, 0x72, 0xe4, 0x21, 0x87, 0xd7, 0x54, 0xe8,
                0x04, 0xa6, 0x16, 0x53, 0x09, 0x20, 0x69, 0xfb, 0x9b, 0x6d, 0x25, 0x26, 0x68, 0x90,
                0x80, 0x8b, 0x01, 0x5d, 0xf2, 0x8c, 0x80, 0x10, 0x65, 0xda, 0x6f, 0xeb, 0xdc, 0x1a,
                0x56, 0xbf, 0xd0, 0x02, 0x62, 0x5a, 0xcf, 0xaa, 0x53, 0x73, 0xfd, 0xe1, 0x49, 0xc1,
                0xcf, 0xc3, 0x64, 0x9b, 0x48, 0x69, 0x69, 0x6d, 0x44, 0xec, 0xb1, 0x24, 0x79, 0xc5,
                0xeb, 0xef, 0x99, 0x5f, 0x10, 0x02, 0x9f, 0x8b, 0x53, 0x0e, 0xeb, 0x3f, 0xdc, 0x2e,
                0x50, 0xe8, 0x75, 0x7f, 0xc0, 0xbb, 0x9e, 0x26, 0x30, 0x23, 0xdb, 0x82, 0xf8, 0x78,
                0xd9, 0xac, 0x7f, 0xfb, 0x0b, 0xd4, 0x39, 0x1d, 0xf1, 0xd8, 0x79, 0x89, 0x9a, 0x3e,
                0xf5, 0x7b, 0xfd, 0x0d, 0x1f, 0x77, 0x55, 0x64, 0x8e, 0xdd, 0x85, 0xbb, 0x05, 0x2a,
                0x6e, 0xdf, 0x71, 0xcd, 0x26, 0x28, 0xc9, 0x87, 0x42, 0x9f, 0x36, 0xdc, 0x50, 0x5c,
                0xcc, 0x43, 0xf3, 0x0e, 0x7a, 0x86, 0x9c, 0x9e, 0x25, 0x5e, 0x2a, 0xf9, 0xfc, 0xf3,
                0x0c, 0x12, 0x17, 0x96, 0xd1, 0x90, 0x00, 0x09, 0x60, 0xcb, 0x6f, 0xe2, 0xf1, 0xbf,
                0x24, 0x61, 0x18, 0xb4, 0x98, 0xf3, 0x24, 0x7f, 0x9d, 0x48, 0x4c, 0x73, 0xcf, 0x09,
                0x39, 0x30, 0x39, 0xe4, 0x53, 0x26, 0xb8, 0xff, 0xff, 0xb3, 0xe7, 0xe6, 0x15, 0x9c,
                0x46, 0x69, 0x9f, 0x10, 0x07, 0x92, 0xd4, 0x67, 0x29, 0x50, 0x34, 0x8a, 0x90, 0x55,
                0x2e, 0x45, 0x94, 0x3b, 0xee, 0xac, 0xf0, 0x3f, 0x32, 0x16, 0xf9, 0x4e, 0x27, 0x4d,
                0x63, 0xd6, 0x37, 0xd9, 0xf1, 0x90, 0xe8, 0xa2, 0x66, 0xcd, 0xee, 0xf1, 0x53, 0x53,
                0x0b, 0xee, 0x5c, 0xb8, 0x35, 0x52, 0x60, 0x50, 0x5c, 0x2c, 0x2e, 0x5d, 0x99, 0x0f,
                0xff, 0xdc, 0x34, 0xec, 0x0f, 0xf7, 0xf1, 0xaf, 0x81, 0xb2, 0x4c, 0xed, 0x0e, 0xfa,
                0x62, 0x13, 0xda, 0x6c, 0x7c, 0x60, 0xc4, 0x87, 0xf5, 0xf7, 0xb0, 0x3f, 0x81, 0x60,
                0xa0, 0x57, 0xf4, 0x6d, 0x05, 0xbf, 0x82, 0x18, 0xb3, 0xad, 0xd9, 0xc0, 0x68, 0x93,
                0xbd, 0x02, 0xdb, 0x9b, 0x61, 0x19, 0x1d, 0xfb, 0x13, 0x3b, 0xfa, 0xbe, 0x48, 0x58,
                0xe4, 0x7a, 0x4c, 0xc3, 0x2e, 0x41, 0x6e, 0xc0, 0x8b, 0x8a, 0xc7, 0x91, 0x5a, 0x43,
                0x73, 0x3f, 0x44, 0x06, 0xe9, 0xd9, 0x67, 0xc5, 0x60, 0xf3, 0x44, 0xd7, 0xe9, 0x04,
                0xa2, 0x80, 0x45, 0xd9, 0x9f, 0x3a, 0xf8, 0xc8, 0x2e, 0x97, 0xe1, 0xb9, 0xc1, 0xb2,
                0x05, 0xe5, 0x85, 0xfb, 0xeb, 0xb4, 0x8f, 0xaf, 0x58, 0xf1, 0xb6, 0x5d, 0xca, 0x24,
                0x97, 0xe0, 0x9a, 0x70, 0xaa, 0xd4, 0x86, 0x5f, 0x85, 0x71, 0x5a, 0x28, 0x0e, 0x18,
                0x6f, 0x3f, 0xc1, 0x74, 0x0d, 0x81, 0x84, 0xd3, 0x3e, 0x83, 0x22, 0x16, 0x95, 0x21,
                0xcd, 0xc1, 0x32, 0x21, 0x29, 0x39, 0xc8, 0x4a, 0x10, 0x89, 0x64, 0xe2, 0xde, 0x74,
                0xb6, 0xea, 0x55, 0xb4, 0xcb, 0x8f, 0x6f, 0x9b, 0xee, 0x98, 0xb1, 0x0d, 0x41, 0x51,
                0x09, 0x45, 0x5f, 0x48, 0xb7, 0x76, 0x08, 0x2d, 0xc3, 0x0b, 0x4b, 0xc7, 0x34, 0x77,
                0x07, 0x55, 0x11, 0x70, 0x03, 0x08, 0x15, 0x8c, 0xe2, 0xf2, 0xf9, 0xbf, 0x0f, 0x69,
                0x1b, 0x2c, 0xe5, 0x3e, 0x61, 0x14, 0x2c, 0xb7, 0x40, 0xc1, 0x5b, 0x7b, 0x62, 0x3c,
                0xf4, 0x8b, 0x3f, 0x7b, 0xfe, 0xfa, 0x31, 0xbc, 0xdc, 0x66, 0x5c, 0x6d, 0x71, 0x23,
                0xe9, 0x53, 0x50, 0x81, 0x13, 0x75, 0x94, 0x7b, 0x05, 0x5a, 0x43, 0xdb, 0x07, 0xe0,
                0x3f, 0x33, 0x62, 0x7d, 0xf5, 0xc6, 0x38, 0xbf,
            ],
            cv_net: [
                0x00, 0x55, 0xf3, 0x5c, 0x6c, 0x82, 0x62, 0xac, 0x74, 0xfe, 0x27, 0xd7, 0x2a, 0x33,
                0xbd, 0xb9, 0x6f, 0x1c, 0xe0, 0x57, 0xc3, 0x30, 0xd1, 0xcc, 0xba, 0x2f, 0x7d, 0xa8,
                0x71, 0x55, 0x00, 0xb5,
            ],
            rho: [
                0xea, 0x38, 0x44, 0x75, 0x9a, 0x9a, 0x1c, 0xc5, 0x28, 0xb2, 0x95, 0xce, 0x70, 0x13,
                0x7a, 0x85, 0xf9, 0xf0, 0x8e, 0x41, 0xa5, 0xc7, 0xc1, 0xca, 0xc1, 0x55, 0xa6, 0x69,
                0xa3, 0x18, 0x53, 0x3e,
            ],
            cmx: [
                0x6a, 0xba, 0x28, 0x10, 0x5b, 0xc0, 0x72, 0xc5, 0x2a, 0xb8, 0xa3, 0x14, 0x79, 0x7f,
                0xf8, 0x66, 0x66, 0xdf, 0xb7, 0xcd, 0x8a, 0x2a, 0xe1, 0x7c, 0x58, 0x5f, 0xb7, 0xb6,
                0x51, 0x5b, 0x97, 0x1c,
            ],
            esk: [
                0x03, 0xfb, 0x79, 0x43, 0x75, 0x27, 0x5d, 0x23, 0xd1, 0x58, 0xd5, 0x64, 0x6b, 0xc4,
                0x63, 0xa8, 0xb7, 0x38, 0xbc, 0x79, 0x38, 0xf6, 0x0d, 0xfb, 0x15, 0x5b, 0xef, 0x4d,
                0x46, 0x1e, 0xec, 0x29,
            ],
            ephemeral_key: [
                0x95, 0x9b, 0xea, 0x8e, 0x11, 0x96, 0x8b, 0x0f, 0x34, 0x3c, 0x04, 0xcd, 0x6d, 0x50,
                0x16, 0xfc, 0xd4, 0x33, 0x90, 0x75, 0x36, 0xa2, 0x46, 0xba, 0x1c, 0x5d, 0x3e, 0x88,
                0x97, 0xf3, 0x23, 0x1c,
            ],
            shared_secret: [
                0xe2, 0x69, 0x19, 0xb4, 0x0c, 0x70, 0xaf, 0x74, 0x1d, 0xf9, 0x04, 0x51, 0x72, 0x55,
                0x03, 0x58, 0x89, 0xee, 0x5a, 0x44, 0x42, 0x6d, 0x6a, 0xb8, 0x5c, 0x07, 0x4b, 0x86,
                0x2b, 0xa0, 0x63, 0x08,
            ],
            k_enc: [
                0x09, 0xda, 0xc6, 0x51, 0x1c, 0x38, 0x44, 0x58, 0x7f, 0x82, 0x9c, 0x2f, 0x1e, 0xa0,
                0x37, 0xa8, 0x1a, 0x8d, 0x54, 0x85, 0xed, 0x04, 0xea, 0xf2, 0x75, 0x80, 0x05, 0xb3,
                0x2a, 0x20, 0x47, 0x0b,
            ],
            p_enc: [
                0x02, 0xdd, 0xb7, 0xc5, 0xbc, 0x4d, 0xe9, 0xdf, 0x52, 0x1b, 0xb0, 0x4b, 0xad, 0x95,
                0x6d, 0xdc, 0x1e, 0xa7, 0xd7, 0x62, 0x2d, 0xd4, 0x17, 0xdf, 0x26, 0xdc, 0xd2, 0x20,
                0xf2, 0xb7, 0x31, 0x77, 0x2b, 0x43, 0x9e, 0x96, 0xd6, 0x14, 0xe1, 0xfa, 0xcb, 0x48,
                0x6c, 0x7a, 0x7d, 0x51, 0x71, 0xb1, 0xde, 0x35, 0x9f, 0x6a, 0xff, 0xd3, 0xa9, 0x6f,
                0x64, 0x9c, 0x96, 0x91, 0x02, 0xa1, 0x96, 0x4f, 0xb4, 0xb4, 0xa1, 0xa4, 0x27, 0x9c,
                0x68, 0xe6, 0xc3, 0x72, 0xe4, 0x21, 0x87, 0xd7, 0x54, 0xe8, 0x04, 0xa6, 0x16, 0x53,
                0x09, 0x20, 0x69, 0xfb, 0x9b, 0x6d, 0x25, 0x26, 0x68, 0x90, 0x80, 0x8b, 0x01, 0x5d,
                0xf2, 0x8c, 0x80, 0x10, 0x65, 0xda, 0x6f, 0xeb, 0xdc, 0x1a, 0x56, 0xbf, 0xd0, 0x02,
                0x62, 0x5a, 0xcf, 0xaa, 0x53, 0x73, 0xfd, 0xe1, 0x49, 0xc1, 0xcf, 0xc3, 0x64, 0x9b,
                0x48, 0x69, 0x69, 0x6d, 0x44, 0xec, 0xb1, 0x24, 0x79, 0xc5, 0xeb, 0xef, 0x99, 0x5f,
                0x10, 0x02, 0x9f, 0x8b, 0x53, 0x0e, 0xeb, 0x3f, 0xdc, 0x2e, 0x50, 0xe8, 0x75, 0x7f,
                0xc0, 0xbb, 0x9e, 0x26, 0x30, 0x23, 0xdb, 0x82, 0xf8, 0x78, 0xd9, 0xac, 0x7f, 0xfb,
                0x0b, 0xd4, 0x39, 0x1d, 0xf1, 0xd8, 0x79, 0x89, 0x9a, 0x3e, 0xf5, 0x7b, 0xfd, 0x0d,
                0x1f, 0x77, 0x55, 0x64, 0x8e, 0xdd, 0x85, 0xbb, 0x05, 0x2a, 0x6e, 0xdf, 0x71, 0xcd,
                0x26, 0x28, 0xc9, 0x87, 0x42, 0x9f, 0x36, 0xdc, 0x50, 0x5c, 0xcc, 0x43, 0xf3, 0x0e,
                0x7a, 0x86, 0x9c, 0x9e, 0x25, 0x5e, 0x2a, 0xf9, 0xfc, 0xf3, 0x0c, 0x12, 0x17, 0x96,
                0xd1, 0x90, 0x00, 0x09, 0x60, 0xcb, 0x6f, 0xe2, 0xf1, 0xbf, 0x24, 0x61, 0x18, 0xb4,
                0x98, 0xf3, 0x24, 0x7f, 0x9d, 0x48, 0x4c, 0x73, 0xcf, 0x09, 0x39, 0x30, 0x39, 0xe4,
                0x53, 0x26, 0xb8, 0xff, 0xff, 0xb3, 0xe7, 0xe6, 0x15, 0x9c, 0x46, 0x69, 0x9f, 0x10,
                0x07, 0x92, 0xd4, 0x67, 0x29, 0x50, 0x34, 0x8a, 0x90, 0x55, 0x2e, 0x45, 0x94, 0x3b,
                0xee, 0xac, 0xf0, 0x3f, 0x32, 0x16, 0xf9, 0x4e, 0x27, 0x4d, 0x63, 0xd6, 0x37, 0xd9,
                0xf1, 0x90, 0xe8, 0xa2, 0x66, 0xcd, 0xee, 0xf1, 0x53, 0x53, 0x0b, 0xee, 0x5c, 0xb8,
                0x35, 0x52, 0x60, 0x50, 0x5c, 0x2c, 0x2e, 0x5d, 0x99, 0x0f, 0xff, 0xdc, 0x34, 0xec,
                0x0f, 0xf7, 0xf1, 0xaf, 0x81, 0xb2, 0x4c, 0xed, 0x0e, 0xfa, 0x62, 0x13, 0xda, 0x6c,
                0x7c, 0x60, 0xc4, 0x87, 0xf5, 0xf7, 0xb0, 0x3f, 0x81, 0x60, 0xa0, 0x57, 0xf4, 0x6d,
                0x05, 0xbf, 0x82, 0x18, 0xb3, 0xad, 0xd9, 0xc0, 0x68, 0x93, 0xbd, 0x02, 0xdb, 0x9b,
                0x61, 0x19, 0x1d, 0xfb, 0x13, 0x3b, 0xfa, 0xbe, 0x48, 0x58, 0xe4, 0x7a, 0x4c, 0xc3,
                0x2e, 0x41, 0x6e, 0xc0, 0x8b, 0x8a, 0xc7, 0x91, 0x5a, 0x43, 0x73, 0x3f, 0x44, 0x06,
                0xe9, 0xd9, 0x67, 0xc5, 0x60, 0xf3, 0x44, 0xd7, 0xe9, 0x04, 0xa2, 0x80, 0x45, 0xd9,
                0x9f, 0x3a, 0xf8, 0xc8, 0x2e, 0x97, 0xe1, 0xb9, 0xc1, 0xb2, 0x05, 0xe5, 0x85, 0xfb,
                0xeb, 0xb4, 0x8f, 0xaf, 0x58, 0xf1, 0xb6, 0x5d, 0xca, 0x24, 0x97, 0xe0, 0x9a, 0x70,
                0xaa, 0xd4, 0x86, 0x5f, 0x85, 0x71, 0x5a, 0x28, 0x0e, 0x18, 0x6f, 0x3f, 0xc1, 0x74,
                0x0d, 0x81, 0x84, 0xd3, 0x3e, 0x83, 0x22, 0x16, 0x95, 0x21, 0xcd, 0xc1, 0x32, 0x21,
                0x29, 0x39, 0xc8, 0x4a, 0x10, 0x89, 0x64, 0xe2, 0xde, 0x74, 0xb6, 0xea, 0x55, 0xb4,
                0xcb, 0x8f, 0x6f, 0x9b, 0xee, 0x98, 0xb1, 0x0d, 0x41, 0x51, 0x09, 0x45, 0x5f, 0x48,
                0xb7, 0x76, 0x08, 0x2d, 0xc3, 0x0b, 0x4b, 0xc7, 0x34, 0x77, 0x07, 0x55, 0x11, 0x70,
                0x03, 0x08, 0x15, 0x8c, 0xe2, 0xf2, 0xf9, 0xbf, 0x0f, 0x69, 0x1b, 0x2c, 0xe5, 0x3e,
                0x61, 0x14, 0x2c, 0xb7, 0x40, 0xc1, 0x5b, 0x7b, 0x62, 0x3c, 0xf4, 0x8b, 0x3f, 0x7b,
                0xfe, 0xfa, 0x31, 0xbc, 0xdc, 0x66, 0x5c, 0x6d, 0x71, 0x23, 0xe9, 0x53, 0x50, 0x81,
                0x13, 0x75, 0x94, 0x7b, 0x05, 0x5a, 0x43, 0xdb, 0x07, 0xe0, 0x3f, 0x33, 0x62, 0x7d,
                0xf5, 0xc6, 0x38, 0xbf,
            ],
            c_enc: [
                0x7b, 0x59, 0x87, 0x78, 0xa7, 0x28, 0x4d, 0x52, 0xa7, 0x47, 0x77, 0x4c, 0x54, 0xbd,
                0x92, 0x57, 0xb3, 0xf1, 0x7a, 0xf1, 0x3e, 0xcc, 0x72, 0xc0, 0xe3, 0xcd, 0x95, 0xeb,
                0xfa, 0xfa, 0xa3, 0x7d, 0x16, 0x65, 0x15, 0x53, 0xdd, 0x27, 0xf0, 0x1c, 0x9c, 0xf2,
                0x4b, 0x62, 0xd7, 0xdc, 0xfd, 0x52, 0xfa, 0x4b, 0x2b, 0x3b, 0x4a, 0x8c, 0xa9, 0xeb,
                0xfc, 0xe7, 0xf4, 0xfc, 0xec, 0x27, 0xe6, 0x05, 0x8e, 0x44, 0x68, 0xc1, 0x50, 0x10,
                0xd0, 0x17, 0xcb, 0x90, 0x1a, 0xbf, 0xb2, 0x2e, 0xad, 0x86, 0x99, 0x83, 0xf6, 0x9a,
                0xed, 0xf2, 0xda, 0x7d, 0x6a, 0xaf, 0xd1, 0x30, 0x6e, 0xe7, 0x36, 0xf2, 0xdb, 0x33,
                0xbc, 0xe4, 0xb0, 0x9f, 0xca, 0x74, 0x69, 0x2a, 0x52, 0x09, 0xa7, 0x39, 0x2b, 0x7e,
                0xa9, 0x68, 0x5b, 0xe9, 0xec, 0x43, 0x1f, 0xfe, 0x50, 0xf7, 0x0f, 0x90, 0x22, 0x74,
                0x05, 0x03, 0x45, 0x2a, 0xb5, 0x14, 0x92, 0xb1, 0xf7, 0x47, 0x7e, 0xda, 0x42, 0x7b,
                0x42, 0x3a, 0x93, 0x1b, 0x26, 0x38, 0x6c, 0x56, 0xe4, 0x27, 0x86, 0x3d, 0x46, 0xb1,
                0x99, 0xff, 0xa0, 0x8c, 0x52, 0x9f, 0xa5, 0x72, 0x1f, 0x68, 0xe9, 0x14, 0xf6, 0xea,
                0x6a, 0x8a, 0xe6, 0xae, 0xcb, 0xf7, 0x37, 0x47, 0x1e, 0xbd, 0x83, 0xdb, 0xa9, 0xa7,
                0xcd, 0x89, 0x75, 0x66, 0x20, 0x4e, 0x2b, 0xae, 0x63, 0xe3, 0x4e, 0x70, 0x32, 0x51,
                0x02, 0x96, 0x92, 0x0d, 0x7e, 0x7a, 0x7c, 0xcf, 0x0f, 0xeb, 0xe7, 0xa8, 0x33, 0x69,
                0x6a, 0x4b, 0x67, 0x41, 0x88, 0x5e, 0x9b, 0x94, 0x0c, 0x61, 0xdd, 0x8d, 0x44, 0x38,
                0x54, 0x74, 0x15, 0x31, 0x0b, 0x15, 0xcf, 0x18, 0xdc, 0x19, 0x90, 0x07, 0x8c, 0x70,
                0x8b, 0xea, 0xc3, 0x32, 0xa8, 0xe0, 0x81, 0x46, 0xa6, 0x95, 0x8e, 0xa6, 0xf4, 0x3f,
                0xd0, 0xc2, 0xc8, 0xe9, 0x99, 0xaa, 0x4f, 0xdf, 0x1e, 0x77, 0xef, 0xde, 0x54, 0xfd,
                0x65, 0xc6, 0x7a, 0x3f, 0x07, 0xda, 0xf5, 0xf6, 0x04, 0x49, 0x60, 0xa0, 0xb6, 0xdd,
                0x84, 0x1f, 0xf8, 0xb8, 0xa5, 0x92, 0xc7, 0xb1, 0x09, 0x34, 0x2c, 0x73, 0x5c, 0x2a,
                0x0e, 0x37, 0xb3, 0x0b, 0x8b, 0xaa, 0x5c, 0x77, 0x01, 0xeb, 0xc7, 0xa8, 0xf8, 0x20,
                0xc0, 0x22, 0x7c, 0xa5, 0x00, 0x3f, 0x36, 0xee, 0x68, 0xf7, 0xb2, 0x89, 0x81, 0xc2,
                0x73, 0x32, 0x03, 0x9d, 0xd6, 0xa4, 0x94, 0xf0, 0xcd, 0x02, 0xbd, 0xd2, 0x8f, 0x68,
                0x3e, 0xca, 0x1b, 0x03, 0x2a, 0xfc, 0x09, 0xdd, 0x0c, 0xd8, 0x56, 0xcb, 0xc1, 0xa3,
                0x5e, 0x74, 0xd4, 0x0c, 0x24, 0x53, 0xdf, 0xe2, 0x42, 0xc8, 0x6a, 0x7a, 0x60, 0xbc,
                0xbd, 0xdb, 0x17, 0x96, 0x6c, 0x7d, 0xba, 0x76, 0x9e, 0xab, 0xd1, 0xc1, 0x67, 0xb7,
                0xe8, 0x19, 0x78, 0xf9, 0x12, 0x8b, 0xac, 0x26, 0xa2, 0x8d, 0x77, 0x21, 0x30, 0x79,
                0xcb, 0x56, 0xc0, 0x95, 0xa7, 0xc0, 0x60, 0xde, 0x0e, 0x77, 0x5c, 0xa8, 0xac, 0x8e,
                0x6c, 0xa9, 0x4d, 0x19, 0xc6, 0x16, 0x2e, 0x44, 0xf7, 0xa8, 0xf0, 0x14, 0x9d, 0x31,
                0xd3, 0x46, 0x3d, 0x01, 0xb6, 0x1a, 0x14, 0x63, 0xa9, 0xde, 0x3d, 0x8a, 0xb7, 0x40,
                0x04, 0x0a, 0x76, 0xe0, 0x5b, 0x37, 0x64, 0x28, 0x86, 0x29, 0x87, 0x59, 0x5b, 0x87,
                0xce, 0xa6, 0x94, 0xfe, 0x92, 0x0a, 0x06, 0x7e, 0x81, 0x6b, 0x4f, 0x29, 0xa3, 0xa2,
                0x24, 0x50, 0x14, 0x0f, 0x13, 0x5d, 0x71, 0x9a, 0x97, 0x1b, 0x81, 0xfc, 0x19, 0x16,
                0x98, 0x0a, 0x55, 0xdd, 0xf8, 0xd9, 0x87, 0x30, 0x57, 0x36, 0x35, 0xa0, 0x70, 0x85,
                0xc4, 0xe7, 0x7c, 0x7e, 0x1c, 0xdb, 0xb6, 0x85, 0x42, 0x6e, 0xe4, 0x62, 0xcc, 0x30,
                0x83, 0xa3, 0xf5, 0xa3, 0xb9, 0x17, 0xc0, 0x6f, 0x9a, 0x96, 0xf9, 0xf7, 0xbd, 0x81,
                0xac, 0xa4, 0x9b, 0xef, 0x95, 0xb9, 0x28, 0x06, 0xc4, 0x2d, 0x09, 0x12, 0x01, 0x31,
                0x42, 0xb2, 0x2a, 0x7b, 0xad, 0x72, 0x12, 0x11, 0x46, 0x91, 0xf1, 0xdc, 0x72, 0x64,
                0xc6, 0x7e, 0x76, 0x34, 0xf5, 0xd7, 0x95, 0xc9, 0x75, 0x30, 0x62, 0xe3, 0x06, 0xc0,
                0x6b, 0xc1, 0x03, 0xaa, 0x01, 0xc1, 0x0d, 0x1f, 0x5d, 0xd4, 0xcd, 0x59, 0xf6, 0x53,
                0x2c, 0xb7, 0x23, 0xe3, 0xa0, 0x26,
            ],
            ock: [
                0x4a, 0x25, 0x25, 0x4c, 0xcc, 0x44, 0x4e, 0xc6, 0x1c, 0x2b, 0xac, 0xeb, 0x2e, 0xe3,
                0x97, 0x7a, 0x63, 0x32, 0x44, 0x9a, 0x3a, 0x53, 0xad, 0xd2, 0x31, 0xab, 0xf3, 0xd1,
                0x8b, 0xb3, 0x29, 0x3d,
            ],
            op: [
                0x65, 0x3d, 0x07, 0xc9, 0x07, 0x94, 0x6a, 0xc3, 0x02, 0x0e, 0xbd, 0xe1, 0xb4, 0xf6,
                0x10, 0x21, 0x0c, 0x30, 0xc4, 0x50, 0xe4, 0x27, 0x12, 0x65, 0xa0, 0x5d, 0x6e, 0xce,
                0x44, 0x6d, 0xf4, 0x39, 0x03, 0xfb, 0x79, 0x43, 0x75, 0x27, 0x5d, 0x23, 0xd1, 0x58,
                0xd5, 0x64, 0x6b, 0xc4, 0x63, 0xa8, 0xb7, 0x38, 0xbc, 0x79, 0x38, 0xf6, 0x0d, 0xfb,
                0x15, 0x5b, 0xef, 0x4d, 0x46, 0x1e, 0xec, 0x29,
            ],
            c_out: [
                0x7b, 0xf4, 0x12, 0x7d, 0x22, 0xcc, 0x57, 0x35, 0x87, 0x51, 0x2f, 0xf8, 0x1e, 0x55,
                0x3e, 0x3c, 0x98, 0x23, 0x5f, 0x51, 0xc7, 0x23, 0x7e, 0x9e, 0x76, 0x1a, 0x08, 0xf2,
                0xe1, 0xe8, 0x0d, 0x04, 0x26, 0x98, 0xfc, 0x3b, 0x1d, 0x03, 0x18, 0xf1, 0xfd, 0xca,
                0x8e, 0x41, 0xa3, 0x16, 0xd6, 0xaf, 0x3a, 0xc0, 0xc4, 0x0c, 0xe1, 0x99, 0x47, 0xa2,
                0xba, 0xfe, 0x80, 0x4d, 0x46, 0x6e, 0xd0, 0x79, 0x82, 0x7f, 0xc1, 0x41, 0x91, 0xeb,
                0xb5, 0x99, 0x17, 0x87, 0x49, 0xe9, 0xc4, 0x06, 0xaf, 0x26,
            ],
        },
    ];
}
